%define version      7.34
%define release      20210914
%define rhel_version 8
%define rhcert_sitelib /usr/lib/python3.6/site-packages/rhcert
%define rhcert_python python3

# disable shebang ambiguity errors
%undefine __brp_mangle_shebangs

# The behaviour of the rpm-build package for python files varies between
# releases.  Sometime in the FC4 timeframe it gained a file
# /usr/lib/rpm/brp-python-bytecompile which generates pyo and pyc files for py
# files, in a phase after the install.
# This macro is needed to turn this off, for building on FC4/RHEL5 and later:
%define byte_compiled_python 0

Name:           redhat-certification
Summary:        Red Hat Certification
Version:        %{version}
Release:        %{release}.el%{rhel_version}
Group:          Development/Tools
License:        GPLv2+
URL:            http://redhat.com
Source0:        %{name}-%{version}-%{release}.tar.bz2
# snapshot
Buildroot:      %{_tmppath}/%{name}-%{version}-root
BuildArch:  noarch
Obsoletes:      rhcert-client, ccp-client
BuildRequires:  %{rhcert_python}-devel
Requires:       redhat-certification-backend = %{version}-%{release}
Requires:       httpd
Requires:       %{rhcert_python}-lxml

# for RHEL7 include django-based WUI
%if 0%{?rhel} == 7
Requires:       policycoreutils-python
Requires:       mod_wsgi
Requires:       %{rhcert_python}-django >= 1.8
%else
# otherwise assume RHEL8 - include RHCert Lab Agent
Requires:       policycoreutils-python-utils
Requires:       python3-mod_wsgi
Requires:       python3-flask
Requires:       virt-install
Requires:       python3-cryptography
Requires:       libvirt
Requires:       qemu-kvm
%endif

Requires(post): systemd
Requires(post): firewalld


# redhat-certification-backend subpackage
%package -n redhat-certification-backend
Summary:        Red Hat Hardware Test Suite Backend
Group:          Development/Tools
# for container certifications
Requires:       %{rhcert_python}-magic
# for client listener: ps
Requires:       procps
# rhcert.Test.collabRequest
Requires:       %{rhcert_python}-requests
Requires:       %{rhcert_python}-lxml

%if 0%{?rhel} <= 8
Requires:       kernel-abi-whitelists
%else
Requires:       kernel-abi-stablelists
%endif

# redhat-certification-hardware subpackage
%package -n redhat-certification-hardware
Summary:        Red Hat Hardware Certification Test Suite
Group:          Development/Tools
Requires:       redhat-certification-backend >= %{version}
Requires:       httpd, nfs-utils, gcc
Requires:       kernel-devel, kernel-headers
Requires:       policycoreutils, sos
Requires:       rfkill, pciutils
Requires:       make, iperf3, perf
Requires:       ndctl, bluez, lshw

%if 0%{?rhel} <= 8
Requires:       stress
%endif

# require usbutils for lsusb except on s390x
%ifnarch s390x
Requires:       usbutils, iw, NetworkManager
%endif
# require RHEL7 via kernel
Requires:       kernel >= 3
Provides:       redhat-certification-hardware

# redhat-certification-hardware-preview subpackage
%package -n redhat-certification-hardware-preview
Summary:        Red Hat Hardware Test Suite Preview
Group:          Development/Tools
Requires:       redhat-certification-hardware >= %{version}
Requires:       qemu-kvm libvirt %{rhcert_python}-dbus
Requires:       policycoreutils, sos
Provides:       redhat-certification-preview

# redhat-certification-cloud subpackage
%package -n redhat-certification-cloud
Summary:        Red Hat Cloud Certification Test Suite
Group:          Development/Tools
Requires:       redhat-certification-backend >= %{version}
Requires:       nmap authconfig rsyslog
Requires:       policycoreutils, sos
Provides:       stsclient-cloud-plugin, ccp-client
Obsoletes:      stsclient-cloud-plugin, ccp-client

# redhat-certification-cloud-sap subpackage
%package -n redhat-certification-cloud-sap
Summary:        Red Hat Cloud Image Certification Test Suite for SAP with HA and Update Services
Group:          Development/Tools
Requires:       redhat-certification-backend >= %{version}
Requires:       nmap authconfig rsyslog
Requires:       policycoreutils, sos
Provides:       stsclient-cloud-plugin, ccp-client
Obsoletes:      stsclient-cloud-plugin, ccp-client


# redhat-certification-software subpackage
%package -n redhat-certification-software
Summary:        Red Hat Software Certification Test Suite
Group:          Development/Tools
Requires:       redhat-certification-backend >= %{version}
Requires:       policycoreutils, sos

# redhat-certification-openstack subpackage
%package -n redhat-certification-openstack
Summary:        Red Hat OpenStack Platform Certification Test Suite
Group:          Development/Tools
Requires:       redhat-certification-backend >= %{version}
Requires:       %{rhcert_python}-jsonschema
Requires:       %{rhcert_python}-subunit
Requires:       rhosp-release
Requires:       policycoreutils, sos

# redhat-certification-baremetal subpackage
%package -n redhat-certification-baremetal
Summary:        Red Hat Baremetal certification Test Suite
Group:          Development/Tools
Requires:       redhat-certification-backend >= %{version}
Requires:       policycoreutils, sos

# redhat-certification-container subpackage
%package -n redhat-certification-container
Summary:        Red Hat Container Certification Test Suite
Group:          Development/Tools
Requires:       redhat-certification-backend >= %{version}
Requires:       podman


%description
Red Hat Certification runs certification tests for Red Hat products
%description -n redhat-certification-backend
Red Hat Certification Backend runs certification tests for Red Hat products
%description -n redhat-certification-hardware
Red Hat Hardware Certification Test Suite
%description -n redhat-certification-hardware-preview
Red Hat Hardware Certification Test Suite Preview
%description -n redhat-certification-cloud
Red Hat CCSP Certification Test Suite
%description -n redhat-certification-cloud-sap
Red Hat CCSP Certification Test Suite for SAP with HA and Update Services
%description -n redhat-certification-openstack
Red Hat OpenStack Platform Certification Test Suite
%description -n redhat-certification-baremetal
Red Hat Baremetal certification Test Suite
%description -n redhat-certification-software
Red Hat Software Certification Test Suite
%description -n redhat-certification-container
Red Hat Container Certification Test Suite

%prep
%setup -q -c

%build
[ "$RPM_BUILD_ROOT" != "/" ] && [ -d $RPM_BUILD_ROOT ] && rm -rf $RPM_BUILD_ROOT;
DESTDIR=$RPM_BUILD_ROOT RHCERT_RHEL_VERSION=%{rhel_version} RHCERT_RELEASE=20210914 RHCERT_PYTHON=/usr/bin/%{rhcert_python} RHCERT_SITE_LIB=%{rhcert_sitelib} make

%install
DESTDIR=$RPM_BUILD_ROOT RHCERT_RHEL_VERSION=%{rhel_version} RHCERT_RELEASE=20210914 RHCERT_PYTHON=/usr/bin/%{rhcert_python} RHCERT_SITE_LIB=%{rhcert_sitelib} make install

%clean
[ "$RPM_BUILD_ROOT" != "/" ] && [ -d $RPM_BUILD_ROOT ] && rm -rf $RPM_BUILD_ROOT;

%pre

%post
chcon -R system_u:object_r:httpd_sys_content_t:s0 /var/www/rhcert
chcon -R system_u:object_r:httpd_sys_rw_content_t:s0 /var/www/rhcert/store
chcon -R system_u:object_r:httpd_sys_script_exec_t:s0 /var/www/rhcert/wsgi
setsebool -P httpd_can_network_connect 1

%preun -n redhat-certification-backend
if pgrep "rhcertd" > /dev/null; then systemctl stop rhcertd.service; systemctl disable rhcertd.service; fi
systemctl daemon-reload
systemctl reset-failed

%files
%defattr(-,root,root)
/var/www/rhcert/wsgi
%if 0%{?rhel} == 7
/var/www/rhcert/application
/var/www/rhcert/css
/var/www/rhcert/fonts
/var/www/rhcert/images
/var/www/rhcert/img
/var/www/rhcert/js
/var/www/rhcert/project
/var/www/rhcert/static
/var/www/rhcert/templates
/var/www/rhcert/xsl
%endif
# set to user apache for server/cgi serving
%attr(-, apache, apache) /var/www/rhcert/store
/etc/httpd/conf.d/rhcert.conf
/etc/httpd/conf.d/rhcert.pem


%files -n redhat-certification-backend
/usr/bin/rhcert-util
/usr/bin/rhcertd
/usr/bin/rhcert-ci
/usr/bin/rhcert-cli
%{?rhcert_sitelib}
%exclude %{?rhcert_sitelib}/suites/hwcert
%exclude %{?rhcert_sitelib}/suites/hwcertpreview
%exclude %{?rhcert_sitelib}/suites/cloud
%exclude %{?rhcert_sitelib}/suites/cloud_sap
%exclude %{?rhcert_sitelib}/suites/software
%exclude %{?rhcert_sitelib}/suites/baremetal_cert
%exclude %{?rhcert_sitelib}/suites/openstack_cert
%exclude %{?rhcert_sitelib}/suites/container
/etc/rhcert-default.xml
/etc/systemd/system/rhcertd.service

%files -n redhat-certification-hardware
%defattr(-,root,root,-)
%{rhcert_sitelib}/suites/hwcert

%files -n redhat-certification-hardware-preview
%defattr(-,root,root,-)
%{rhcert_sitelib}/suites/hwcertpreview

%files -n redhat-certification-cloud
%defattr(-,root,root,-)
%{rhcert_sitelib}/suites/cloud

%files -n redhat-certification-cloud-sap
%defattr(-,root,root,-)
%{rhcert_sitelib}/suites/cloud_sap

%files -n redhat-certification-software
%defattr(-,root,root,-)
%{rhcert_sitelib}/suites/software

%files -n redhat-certification-openstack
%defattr(-,root,root,-)
%{rhcert_sitelib}/suites/openstack_cert
%{_sysconfdir}/redhat-certification-openstack/tempest.conf.sample
%{_sysconfdir}/redhat-certification-openstack/test_config.json.sample

%files -n redhat-certification-baremetal
%{_sysconfdir}/redhat-certification-openstack/baremetal.json.sample

%defattr(-,root,root,-)
%{rhcert_sitelib}/suites/baremetal_cert

%files -n redhat-certification-container
%defattr(-,root,root,-)
%{rhcert_sitelib}/suites/container

%changelog
* Thu Sep 09 2021 Greg Nichols <gnichols@redhat.com>
- CERTPX-8401 Partner should be able to see the supplemental cert of layered RHOCP cert

* Wed Sep 08 2021 Petersingh Anburaj <panburaj@redhat.com>
- CERTPX-8321 Update the FV tests to use RHEL8 image   - Fixed some permission issue for rc.local file

* Tue Sep 07 2021 Shikhar Sharma <shikshar@redhat.com>
- CERTPX-7253 Laptop keys to full support     - Updated codebase version from Python 2.7 to 3 for evdev.py to avoid reported traceback.     - Removed event object logging. Change-Id: I530058ab6cad729afd625ec424f5c7e3d2692208

* Tue Sep 07 2021 Aniket Khisti <akhisti@redhat.com>
- CERTPX-8217  - some realtime packages have been renamed  Specified platform specific rpms in realtime & fv_realtime

* Tue Sep 07 2021 Greg Nichols <gnichols@redhat.com>
- CERTPX-8395 Traceback if given incorrect IP while registering SUT through RHCERT UI

* Mon Sep 06 2021 Javed Alam <jalam@redhat.com>
- CERTPX-8303 Update the IPI test to use direct API call instead of baremetal CLI     - Added check for invalid ironic credential     - Removing API call messages from ironic client class

* Mon Sep 06 2021 Petersingh Anburaj <panburaj@redhat.com>
- CERTPX-8388 Remove some keyword from change log   - Added sensitive keywords to the list

* Fri Sep 03 2021 Javed Alam <jalam@redhat.com>
- CERTPX-8303 Update the IPI test to use direct API call instead of baremetal CLI CERTPX-8379 Install baremetal dependant packages during test run     - Updated the IPI test and now using direct API call instead of baremetal CLI     - Removed ironic_client dependencies for the Dockerfile     - Installing baremetal packages dependencies during plan time instead of rpm installation time     - Updated script file name and result file container folder

* Fri Sep 03 2021 Vipin Kumar <vipikuma@redhat.com>
- CERTPX-8262: Getting traceback error in cloud/configuration test for Subtest: Network Configuration   - updated new RHEL version in service_info   - Added commands to check service status for new RHEL version

* Thu Sep 02 2021 Shikhar Sharma <shikshar@redhat.com>
- CERTPX-8334  -HWCert LVFS sub tests failed     - Added ignoreWarnings parameter to command parsing methods - getString, getStringList, getStringDict.     - Fixed failure of lvfs subtests.

* Thu Sep 02 2021 Petersingh Anburaj <panburaj@redhat.com>
- CERTPX-8303 Update the IPI test to use direct API call instead of baremetal CLI   - Updated code to use the API version   - Fixed code for Provision State call   - Updated code to handle parameters for get call

* Tue Aug 31 2021 Petersingh Anburaj <panburaj@redhat.com>
- CERTPX-8344 Storage test is failing due to some warning   - Handled the warnings during mkfs command execution

* Tue Aug 31 2021 Greg Nichols <gnichols@redhat.com>
- CERTPX-7144 Responses to prompts requested by tests in rhcert-cli aren't present in the XML results file

* Thu Aug 26 2021 Petersingh Anburaj <panburaj@redhat.com>
- CERTPX-8303 Update the IPI test to use direct API call instead of baremetal CLI   - Added IronicClient class to make ironic API calls

* Wed Aug 25 2021 Javed Alam <jalam@redhat.com>
- New release branch 7.34

* Tue Aug 24 2021 vsodhi <vsodhi@redhat.com>
- CERTPX-8253 Release Notes 7.33   - release notes updated

* Thu Aug 19 2021 Petersingh Anburaj <panburaj@redhat.com>
- CERTPX-7967 resolve dependency issue with kernel-abi-whitelists   - Fixed the kernel-abi dependency issue for other subpackages   - Moved kernel-abi to backend package dependency

* Thu Aug 19 2021 Vipin Kumar <vipikuma@redhat.com>
- CERTPX-8302: [RHOSP]Not able to see tempest and director test in RHOSP test plans   - Removed paramiko as it's been imported in try block

* Wed Aug 18 2021 Petersingh Anburaj <panburaj@redhat.com>
- CERTPX-7967 resolve dependency issue with kernel-abi-whitelists CERTPX-8272 remove stress dependency   - Updated the dependency for kernel-abi and stress package

* Thu Aug 12 2021 Shikhar Sharma <shikshar@redhat.com>
- CERTPX-8238 LVFS test should not fail if there no firmware updates available at present     - Fixed test scenrio to pass in case of no updates.

* Thu Aug 12 2021 Greg Nichols <gnichols@redhat.com>
- CERTPX-8259 Replace remote_command with Command subclass RemoteCommand     - improve for handling passphrase only when required

* Wed Aug 11 2021 Petersingh Anburaj <panburaj@redhat.com>
- CERTPX-7102 NVME over RDMA Hardware Certification tests CERTPX-7648 Create NVME over RDMA test for Infiniband CERTPX-7649 Create NVME over RDMA test for Omnipath CERTPX-7650 Create NVME over RDMA test for RoCE CERTPX-7651 Create NVME over RDMA test for iWarp   - Added NVMe over Fabric test for each of the RDMA types   - Added network / RDMA test for the fabric test   - Fixed a Bug in Makefile

* Tue Aug 10 2021 Greg Nichols <gnichols@redhat.com>
- CERTPX-8259 Replace remote_command with Command subclass RemoteCommand     - define rhcert.remote module defining ssh/rhcert.Command classes     - RemoteConnection implements ssh connection via paramiko ssh client     - RemoteCommand is a subclass of rhcert.Command to run remote commands     - SFTP is a class allowing SFTP operations via RemoteConnection SSH.     - RemoteCommand invocations will be login in results.xml during test runs

* Thu Aug 05 2021 Petersingh Anburaj <panburaj@redhat.com>
- CERTPX-7648 Create NVME over RDMA test for Infiniband   - Refactored the current NVMe Over TCP code   - Added support for Infiniband and TCP   - Added code to disconnect the device before connecting it
- CERTPX-8230 Move nvme log info into the nvme subtest   - Moved the nvme log info into the NVMe subtest   - Renamed some storage subtests   - Make 'node device' terminology consistent in the user dialogs for NVMe test

* Wed Aug 04 2021 Javed Alam <jalam@redhat.com>
- New release branch 7.33

* Tue Aug 03 2021 vsodhi <vsodhi@redhat.com>
- CERTPX-8171 Release Notes 7.32   - release notes updated

* Mon Aug 02 2021 Petersingh Anburaj <panburaj@redhat.com>
- CERTPX-8082 fv_live_migration failing on aarch64 system saying dmidecode IDs did not match but they do match   - Fixed the bug by handling the exception

* Fri Jul 30 2021 Shikhar Sharma <shikshar@redhat.com>
- CERTPX-8233 The RHCERT test suite should install the fwupd on SUT if the test Plan includes lvfs test     - Added fwupd to required rpms of the lvfs test.

* Wed Jul 28 2021 Petersingh Anburaj <panburaj@redhat.com>
- CERTPX-8208 Keep using dt for storage test on RHEL 7.4 and earlier   - Updated the storage test to use dt for RHEL 7.4 and earlier   - It will use fio for RHEL 7.5 and later   - Both dt and fio will be runtime dependency

* Tue Jul 27 2021 Petersingh Anburaj <panburaj@redhat.com>
- CERTPX-8212 Getting error in making RPM Packages   - Fixed a bug in Makefile

* Mon Jul 26 2021 Aniket Khisti <akhisti@redhat.com>
- CERTPX-8113 Replace stress with stress-ng for OS version greater than RHEL8  - Parse the stress-ng output which are logged in stderr instead of stdout
- CERTPX-8113 Replace stress with stress-ng for OS version greater than RHEL8  - This reverts earlier commit 9f9e5e376bd73e2fc6a876fa20c8e0f0bd0fce1a  - Adds correction of utilizing ignoreWarnings instead of ignoreErrors.

* Fri Jul 23 2021 Petersingh Anburaj <panburaj@redhat.com>
- CERTPX-8079 Create redhat-certificaton packages   - Fixed a bug in spec file

* Fri Jul 23 2021 Aniket Khisti <akhisti@redhat.com>
- CERTPX-8113 Replace stress with stress-ng for OS version greater than RHEL8  - Replace stress with stress-ng in tests which are not using RHEL7 based fv-qcow2-image  - Make stress-ng package as test runtime dependency instead of package-wide dependency

* Thu Jul 22 2021 Petersingh Anburaj <panburaj@redhat.com>
- CERTPX-8079 Create redhat-certificaton packages   - Skip kernel-abi-whitelists package   - Removed server-js-bundle for RHEL8 and above

* Wed Jul 21 2021 Shikhar Sharma <shikshar@redhat.com>
- CERTPX-8179 traceback during planning on older RHEL 7.4 system     - Added exception handling in get_product_name method.     - Added 'lshw' package dependency to RPM Dependency. Change-Id: Ifd7f5607c8de658a4f57bd596fae518047330353

* Wed Jul 21 2021 Petersingh Anburaj <panburaj@redhat.com>
- CERTPX-5556 Replacement of DT in RHCert CERTPX-8078 Resolve any and all side effects from moving off DT   - Fixed a bug caused due to warning message, wrong variable name   - Improved some error, warning messages

* Fri Jul 16 2021 Petersingh Anburaj <panburaj@redhat.com>
- CERTPX-5556 Replacement of DT in RHCert CERTPX-8018 Replace DT in hwcert test suite (on feature branch)   - Replaced the DT with FIO commands   - Refactored the storage test code and improved logging
- CERTPX-5556 Replacement of DT in RHCert CERTPX-8018 Replace DT in hwcert test suite (on feature branch)   - Handled the scenario when command was returning warning message

* Wed Jul 14 2021 Javed Alam <jalam@redhat.com>
- New release branch 7.31
- CERTPX-7965 Implementation of IPI test     - Added timer in manage subtest     - Updated the power subtest

* Wed Jul 14 2021 vsodhi <vsodhi@redhat.com>
- CERTPX-8021 Release Notes 7.31   - release notes updated

* Tue Jul 13 2021 Zahid Ajaz <zajaz@redhat.com>
- CERTPX-7217 Software/RPM test blows up (fails) if 'ldd' command returns unexpected error  - Fixed added to handle 'NoneType' objects while determining shared binaries for rpm exec files
- Revert CERTPX-7217 Software/RPM test blows up (fails) if 'ldd' command returns unexpected error""

* Thu Jul 08 2021 Vipin Kumar <vipikuma@redhat.com>
- CERTPX-8097: Remove conscious language form the RHOCP test suite   - Removed extra wait time   - Added check for RHOSP Version

* Wed Jul 07 2021 Shikhar Sharma <shikshar@redhat.com>
- CERTPX-7109 LVFS test     - Implementation of LVFS Test in preview package.

* Wed Jul 07 2021 Javed Alam <jalam@redhat.com>
- CERTPX-8050 Traceback in Subtest: create_baremetal_node_subtest when node_env.json is not a json CERTPX-7965 Implementation of IPI test CERTPX-8052 Cosmetic changes in log printing of IPI tests     - Added a timer to check if the node restarted after each 15 sec upto 15 minutes     - Handled the exceptions smoothly if the content in the JSON file is not valid     - Added some cosmetic changes in log printing of IPI tests

* Tue Jul 06 2021 Javed Alam <jalam@redhat.com>
- CERTPX-7978 Change cinder cert glance configuration to use glance-cinder - Implement Test Changes     - Adding a timer to get all tempest to run

* Mon Jul 05 2021 Javed Alam <jalam@redhat.com>
- CERTPX-7978 Change cinder cert glance configuration to use glance-cinder - Implement Test Changes CERTPX-8097 Remove conscious language form the RHOCP test suite     - Added a new subtest called Cinder Galnce" under cinder volume to add glance functionality in cinder     - Added regex checks for cinder tempest     - Removed and Updated conscious language from osp-test suite     - Removed a tempest run warning"

* Wed Jun 30 2021 Petersingh Anburaj <panburaj@redhat.com>
- CERTPX-7254 Move Backlight control of attached displays to full support   - Backlight test will only be planned for RHEL8 and above   - Moved the backlight test to regular package

* Tue Jun 22 2021 Javed Alam <jalam@redhat.com>
- CERTPX-8033 Traceback in test run for baremetal     - Fixing planning and versioning issue in baremetal test suite

* Tue Jun 22 2021 vsodhi <vsodhi@redhat.com>
- CERTPX-7920 Release Notes-7.30   - release notes updated

* Mon Jun 21 2021 Javed Alam <jalam@redhat.com>
- CERTPX-8023 rhcert-cli plan is not listing test plans     - Fixing baremetal test plan issue

* Fri Jun 18 2021 Javed Alam <jalam@redhat.com>
- CERTPX-8023 Rhcert-cli plan is not listing test plans correctly     - Fixed plan issue for baremetal tests and ipi     - Updated condition checking for baremetal test plans

* Fri Jun 18 2021 Aniket Khisti <akhisti@redhat.com>
- CERTPX-7879 Create subtest for NVME over TCP test to run storage tests  - Register first (if multiple) client device node for test plan & run  - Add a subtest to trigger NVME storage tests from main hwcert package

* Thu Jun 17 2021 Javed Alam <jalam@redhat.com>
- CERTPX-7771 Implementation of IPI test CERTPX-7965 Implementation of IPI test CERTPX-7889 Need a better plan to run sosreport and supportable in container CERTPX-7763 Containerize IPI test CERTPX-7887 Remove cloud.ymal reference from the IPI test CERTPX-7943 Create a script to move result files on host dir     - Added a new test ipi" for RHOCP IPI     - Added the test in baremetal test suite     - Added supported files     - Baremetal

* Thu Jun 17 2021 Petersingh Anburaj <panburaj@redhat.com>
- CERTPX-8009 Traceback is observed when USB passthrough test is planned for PCIe device   - Fixed the code to show error when wrong device is planned manually

* Wed Jun 16 2021 Petersingh Anburaj <panburaj@redhat.com>
- CERTPX-7984 fv_usb_storage_passthrough test fails with Error: no tests match the supplied options   - Updated the code to use device name instead of host name as package in VM image is updated

* Tue Jun 15 2021 Greg Nichols <gnichols@redhat.com>
- CERTPX-7976 Unable to create hardware sandbox     - filter layers and unsupported cert types from selection     - fix ranking

* Tue Jun 15 2021 Petersingh Anburaj <panburaj@redhat.com>
- CERTPX-2641 Improve backlight test to not save UDI of device   - This prevents the test plan from changing between runs when the DRM device enumeration changes. This can happen on machines with multiple graphics cards.

* Mon Jun 14 2021 Petersingh Anburaj <panburaj@redhat.com>
- CERTPX-7918 netDevice could never be detected in RDMA related tests   - Fixed a issue because of which netDevice was not populated when address file is not present and MAC address is not present in interface file

* Fri Jun 11 2021 Shikhar Sharma <shikshar@redhat.com>
- CERTPX-7765 rfkill error messages visible in WebUI during test plan verification     - Added bluez as package dependency as it is needed during plan time.     - Added device name to the planned test.

* Thu Jun 10 2021 Vibhuti Sodhi <vsodhi@redhat.com>
- CERTPX-7849 Release Notes 7.29   - release notes  updated

* Wed Jun 02 2021 Javed Alam <jalam@redhat.com>
- New release branch 7.30

* Mon May 31 2021 Aniket Khisti <akhisti@redhat.com>
- CERTPX-7647 Create NVME over TCP test in hwcertpreview  - Fix syntax error & conflicting variable names

* Thu May 27 2021 Vipin Kumar <vipikuma@redhat.com>
- CERTPX-7708: Getting traceback error in RPM Freshness test of cloud test suite

* Thu May 27 2021 Aniket Khisti <akhisti@redhat.com>
- CERTPX-7647 Create NVME over TCP test in hwcertpreview  - Add a draft of test with plan method & a config subtest

* Thu May 27 2021 Petersingh Anburaj <panburaj@redhat.com>
- CERTPX-7841 uncore fails on x86 Intel system when no uncore events are found   - uncore test will exit in REVIEW when no events are found

* Thu May 27 2021 Shikhar Sharma <shikshar@redhat.com>
- CERTPX-7762 Multiple Bluetooth Controller Test Planning     - Added multiple host controller's version based test planning.     - Bluetoothctl now selects the specific controller before running the further subtests.

* Wed May 19 2021 Petersingh Anburaj <panburaj@redhat.com>
- CERTPX-7466 Test suite can not detect USB3.2 Gen2 x2 Speed   - Updated the USB test to use tx_lanes value while calculating the device speed   - Updated the speed check logic to use sys files

* Wed May 19 2021 Aniket Khisti <akhisti@redhat.com>
- CERTPX-6525 sosreport test taints kernel on RHEL 7.6 and later  Exit REVIEW instead of FAIL under particular conditions if kernel is tainted

* Tue May 18 2021 Greg Nichols <gnichols@redhat.com>
- CERTPX-7145 rhcert.connect.redhat.com has hard-coded date range of 45 days, preventing access to older certifications     - added session-based range settings to the configuration page

* Mon May 17 2021 Petersingh Anburaj <panburaj@redhat.com>
- CERTPX-7773 Skip the uncore subtest for non x86_64 arch CERTPX-7772 Skip the turbostat subtest for AMD systems   - Added a new class to store the system information   - uncore subtest will only execute for x86_64 arch, Intel or AMD system   - turbostat subtest will only execute for x86_64 arch, Intel system

* Wed May 12 2021 Javed Alam <jalam@redhat.com>
- New release branch 7.29

* Tue May 11 2021 Petersingh Anburaj <panburaj@redhat.com>
- CERTPX-7775 [Multihost] Not able to select two nodes for test execution ( Dropdown to select controllers and computes is not showing )   - Fixed the issue
- CERTPX-7211 OSCommand-mem should ignore if the model does not support S3   - Removed the `resume=` check for suspend-to-disk
- CERTPX-7211 OSCommand-mem should ignore if the model does not support S3   - Fixed a traceback that occurs when /sys/power/mem_sleep file is not present

* Mon May 10 2021 Vibhuti Sodhi <vsodhi@redhat.com>
- CERTPX-7710 Release Notes 7.28   - release notes updated as per the new template

* Fri May 07 2021 Javed Alam <jalam@redhat.com>
- CERTPX-7605 Add a virtwhat check in the info test     - Added a Virtwhat check to identify the underlying hypervisor

* Thu May 06 2021 Petersingh Anburaj <panburaj@redhat.com>
- CERTPX-7769 When used updated FV images for FV_tests, the result from the guest is not there in the .xml.gz   - Fixed the result file merge issue for the FV test result

* Thu May 06 2021 Shikhar Sharma <shikshar@redhat.com>
- CERTPX-7717 Bluetooth device version alignment     - Modified version match subtest to consider minor version.

* Wed May 05 2021 Petersingh Anburaj <panburaj@redhat.com>
- CERTPX-7211 OSCommand-mem should ignore if the model does not support S3   - suspend-to-mem will now be planned only if deep is present in mem_sleep file

* Wed May 05 2021 Vipin Kumar <vipikuma@redhat.com>
- CERTPX-7510: Deprecate lbaasv2 from RHOSP cert

* Mon May 03 2021 Shikhar Sharma <shikshar@redhat.com>
- CERTPX-7717 Bluetooth device version alignment     - Added Bluetooth Start/Stop at plan/run time based on initial state.     - Added version match check between Host(SUT) device and Client(Connected) Device.     - Changed Bluetooth version identification from HCI Version to LMP Version.

* Wed Apr 28 2021 Petersingh Anburaj <panburaj@redhat.com>
- CERTPX-5558 Replacement of LMBench in RHCert   - Removed the dependency of lmbench for hardware package   - Removed some lmbench code which were placed for FV image compatibility

* Thu Apr 22 2021 Javed Alam <jalam@redhat.com>
- New release branch 7.28

* Tue Apr 20 2021 Greg Nichols <gnichols@redhat.com>
- CERTPX-7593 Related Products tab showing Passthrough product as a Base Product    - fix traceback on Releated Products of a base product
- CERTPX-7711 Passthough Cloud Certs show Error: (VendorID 0, ProductID 0) After creation     - simplify CWE sync per-cert to provide missing local product info

* Tue Apr 20 2021 Vibhuti Sodhi <vsodhi@redhat.com>
- CERTPX-7642 Release Notes 7.27   - release notes file updated

* Mon Apr 19 2021 Zahid Ajaz <zajaz@redhat.com>
- CERTPX-7708 Getting traceback error in RPM Freshness test of cloud test suite  - Fix to handle PLAYBACK Cache rebuilding  - Use deferred call to update result

* Mon Apr 19 2021 Greg Nichols <gnichols@redhat.com>
- CERTPX-7600 RHCert transition to certification support cases REST API    - fix traceback on successful association.
- CERTPX-7600 RHCert transition to certification support cases REST API    - fix kbase_solution" -> "Solution"    - improve error reporting"

* Wed Apr 14 2021 Petersingh Anburaj <panburaj@redhat.com>
- CERTPX-7696 Use a different FV image XML for RHEL7 host to fix USB controller issue   - Updated the code to use a different XML file for x86_64 RHEL7 host

* Wed Apr 14 2021 Shikhar Sharma <shikshar@redhat.com>
- CERTPX-7619 modify bluetooth test to identify bluetooth level (3, 4, 5)     - Added separate version-based Bluetooth Tests.

* Wed Apr 14 2021 Jon Blackburn <jblackbu@redhat.com>
- CERTPX-7593 - Added base product id from cwe back into passthrough product. Removed base product certification list as it was showing all certifications from vendor.  Needs to be fixed in CWE call

* Wed Apr 14 2021 Greg Nichols <gnichols@redhat.com>
- CERTPX-7480 [Rhcert] Remove feature from rhcertUI  Creation of supplemental cert for the pass-through cert""

* Mon Apr 12 2021 Petersingh Anburaj <panburaj@redhat.com>
- CERTPX-7497 RhCert tool failed to detect Thunderbolt 4" device   - Updated the generation for TB4 from 'Thunderbolt 4' to 'USB4'"

* Fri Apr 09 2021 Petersingh Anburaj <panburaj@redhat.com>
- CERTPX-7675 Uncore test for AWS x86_64 instance types has command line syntax error in output   - Fixed a bug in uncore test which fails when no event is found

* Thu Apr 08 2021 Shikhar Sharma <shikshar@redhat.com>
- CERTPX-325 Implement or port Bluetooth LE test (or include in regular bluetooth test)     - Added feature to Re-scan bluetooth devices.

* Tue Apr 06 2021 Vipin Kumar <vipikuma@redhat.com>
- CERTPX-7471: Getting error executable not found in  for command python -m   - Updated the command from python to python3

* Mon Apr 05 2021 Greg Nichols <gnichols@redhat.com>
- CERTPX-7600 RHCert transition to certification support cases REST API

* Thu Apr 01 2021 Greg Nichols <gnichols@redhat.com>
- CERTPX-7599 RHCert transition to: [certification - kbases] /certification/<cert id>/kbases CERTPX-7600 RHCert transition to certification support cases REST API

* Wed Mar 31 2021 Javed Alam <jalam@redhat.com>
- New release branch 7.27

* Tue Mar 30 2021 Zahid Ajaz <zajaz@redhat.com>
- CERTPX-7608 Getting traceback error in fingerprint test for ISV certification  - Fixed the bug  - Added exception handling for regex search for empty strings

* Tue Mar 30 2021 Vibhuti Sodhi <vsodhi@redhat.com>
- CERTPX-7540 Release Notes 7.26"   - release notes updated"

* Tue Mar 30 2021 Vipin Kumar <vipikuma@redhat.com>
- CERTPX-7626: Django condiction is visible in RHCERT WUI

* Mon Mar 29 2021 Shikhar Sharma <shikshar@redhat.com>
- CERTPX-325 Implement or port Bluetooth LE test (or include in regular bluetooth test)     - Fixed error message to print only when debug is high.

* Mon Mar 29 2021 Aniket Khisti <akhisti@redhat.com>
- CERTPX-7098 create stop state test on ppc64le system with RHEL 8.4  Add one more planning condition - cpu model should be power9 only

* Mon Mar 29 2021 Greg Nichols <gnichols@redhat.com>
- CERTPX-7616 certs are not getting loaded on QA    - fixed cwe sync to continue to updating certs even if product sync has errors.

* Fri Mar 26 2021 Aniket Khisti <akhisti@redhat.com>
- CERTPX-7098 create stop state test on ppc64le system with RHEL 8.4  Fix a TypeError from the negative testing
- CERTPX-7098 create stop state test on ppc64le system with RHEL 8.4  Add power_stop test for PowerPC Stop State  Make it non-interative & plan only on el8,ppc64le

* Fri Mar 26 2021 Shikhar Sharma <shikshar@redhat.com>
- CERTPX-325 Implement or port Bluetooth LE test (or include in regular bluetooth test)     - Test will be planned only if the SUT has a bluetooth device.
- CERTPX-325 Implement or port Bluetooth LE test (or include in regular bluetooth test)     - Fixed pexpect sequential import issue.

* Fri Mar 26 2021 Greg Nichols <gnichols@redhat.com>
- CERTPX-6950 [CCSP Gold Image] checkboxes selected while creating cloud pass through product are not getting set
- CERTPX-7610 RHCert often displays make twice for hardware products    - fix product sync for hardware products to map model"->"name""
- CERTPX-7585 RHCert could not create cloud passthrough: Error: could not find product information (Vendor ID 0
- CERTPX-7480 [Rhcert]Cannot create supplemental cert for the pass-through cert     - enabled supplemental cert creation on a pass-though base cert.     - changed links for related certs to go to the Related Certifications" tab of the related cert."
- CERTPX-7607 Creating Layered certifications from wizard does not filter base certs by partner product     - fixed VendorID and ProductID passing on layering redirection     - improved selector formatting

* Thu Mar 25 2021 Greg Nichols <gnichols@redhat.com>
- CERTPX-7584 Traceback when adding comments to Product Sample page     - move calls from old xmlrpc addComment to new REST api addDialogComment     - I don't think SpecificationDialog is used any more.
- CERTPX-7587 Error: Vendor hardware product model category is invalid (-32000) when creating Passthrough cert     - pass name string instead of category ID

* Thu Mar 25 2021 Petersingh Anburaj <panburaj@redhat.com>
- CERTPX-7107 repair the fingerprint hardware test CERTPX-6844 fingerprint test planning twice on RHEL 7.6 and RHEL8   - Fixed the delete fingerprint error for RHEL7   - Moved fingerprint reader test to regular hardware package

* Wed Mar 24 2021 Shikhar Sharma <shikshar@redhat.com>
- CERTPX-325 Implement or port Bluetooth LE test (or include in regular bluetooth test)     - Fixed syntax error for python2.
- CERTPX-325 Implement or port Bluetooth LE test (or include in regular bluetooth test)     - Added Bluetooth test to Scan, Connect and Get Device Info     - The test also after getting device info, disconnects, unpairs and untrust the       connected device.

* Wed Mar 24 2021 Greg Nichols <gnichols@redhat.com>
- CERTPX-7574 Traceback when updating Product Details

* Tue Mar 23 2021 Petersingh Anburaj <panburaj@redhat.com>
- CERTPX-7107 repair the fingerprint hardware test   - Fixed the traceback in dbus that was caused due to wrong initialization of dbus in webcam test

* Fri Mar 19 2021 Petersingh Anburaj <panburaj@redhat.com>
- CERTPX-7545 Wrong status is display when same LTS is used as SUT   - Handled the failure, which occurs, when collab call returns empty list

* Fri Mar 19 2021 Greg Nichols <gnichols@redhat.com>
- CERTPX-7465 Feasibility of container/operator preview testing in RHcert

* Thu Mar 18 2021 Petersingh Anburaj <panburaj@redhat.com>
- CERTPX-7545 Wrong status is display when same LTS is used as SUT   - Moved the collab output to a new parameter in message task

* Thu Mar 18 2021 Greg Nichols <gnichols@redhat.com>
- CERTPX-7465 Feasibility of container/operator preview testing in RHcert    - Add WIP Dockerfile.in
- CERTPX-7543 RHCert 7 remove calls to Cert.getCurrentUserVendors
- CERTPX-7514 RHCert 7 transition to dialog comments GET/POST in hydra-cwe
- CERTPX-7465 Feasibility of container/operator preview testing in RHcert    - remove container suite requirement for the software suite

* Thu Mar 18 2021 Jon Blackburn <jblackbu@redhat.com>
- CERTPX-7465 Reverted back to using the list of images rather than the running containers.

* Wed Mar 17 2021 Greg Nichols <gnichols@redhat.com>
- CERTPX-7483 RHCert: storage appliance certification should show related certifications for pass-through creation      - fixed certifications to show related certifications for all programs      - passthoughs created are always hardware, except when the original cert is cloud      - moved categories to use PNS data
- CERTPX-7465 Feasibility of container/operator preview testing in RHcert    - fix logic in software/rpm test - missed checkin

* Tue Mar 16 2021 Greg Nichols <gnichols@redhat.com>
- CERTPX-7465 Feasibility of container/operator preview testing in RHcert    - fix logic in software/rpm test
- CERTPX-7537 traceback in software/fingerprint test

* Tue Mar 16 2021 Petersingh Anburaj <panburaj@redhat.com>
- CERTPX-7209 Replace tcp bw lmbench commands with iperf3   - Fixed a code bug where LTS IP was hardcoded

* Mon Mar 15 2021 Petersingh Anburaj <panburaj@redhat.com>
- CERTPX-7029 The current Perf Uncore" sub-test is not appropriate for testing on AMD systems   - Added support for AMD systems in current uncore subtest"

* Mon Mar 15 2021 Greg Nichols <gnichols@redhat.com>
- CERTPX-7533 ContainerLayerCheck traceback when registering system    - fixed packaging    - fixed traceback when no containers are running

* Thu Mar 11 2021 Greg Nichols <gnichols@redhat.com>
- CERTPX-7465 Feasibility of container/operator preview testing in RHcert    - Improvements and mode auto provisions for software and container tests

* Wed Mar 10 2021 Shikhar Sharma <shikshar@redhat.com>
- CERTPX-7095 fv_live_migration failing on some aarch64 pairs     - Fixed dmidecode ID read issue from Lab Agent to SUT.

* Wed Mar 10 2021 Greg Nichols <gnichols@redhat.com>
- CERTPX-7459 Vendor ID is missing on create Product page for hardware certs.    - removed ID reference from the dialog.

* Tue Mar 09 2021 Petersingh Anburaj <panburaj@redhat.com>
- CERTPX-7209 Replace tcp bw lmbench commands with iperf3   - Updated the TCP bandwidth test to use iperf3 instead of LMBench

* Tue Mar 09 2021 Greg Nichols <gnichols@redhat.com>
- CERTPX-7465 Feasibility of container/operator preview testing in RHcert    - adds container test suite and redhat-certification-container subpackage

* Mon Mar 08 2021 Javed Alam <jalam@redhat.com>
- New release branch 7.26

* Mon Mar 08 2021 Vibhuti Sodhi <vsodhi@redhat.com>
- CERTPX-7355 Release Notes-7.25   - release notes updated

* Mon Mar 08 2021 Vipin Kumar <vipikuma@redhat.com>
- CERTPX-7506: Getting traceback JSONDecodeError while running python file new_unmapped_plugin_tests_in_latest_rhosp.py   - Fixed the json file syntax

* Fri Mar 05 2021 Petersingh Anburaj <panburaj@redhat.com>
- CERTPX-7484 Test suite failed to get the correct IP from LTS in 25GigRoCE test   - Fixed a bug that caused link match to fail if link mac starts with 0

* Wed Mar 03 2021 Greg Nichols <gnichols@redhat.com>
- CERTPX-7493 Getting error message displayed after updating product details tab for ISV on Hosted RHCert   - revised handling of vendorproducts data in wsgi/connection   - fixed software product details updating   - removed extrainious output from cli

* Tue Mar 02 2021 Shikhar Sharma <shikshar@redhat.com>
- CERTPX-7288 Save USB socket count into XML tag     - Added usb socket count to test parameters.

* Tue Mar 02 2021 jialli <jialli@redhat.com>
- CERTPX-6837: add rh_product_version_id to the xmlrpc api Cert.createSupplementalCert

* Tue Mar 02 2021 Petersingh Anburaj <panburaj@redhat.com>
- CERTPX-7356 Warning message displayed while clicking on Hosted Rhcert Configuration Tab   - Firewall warnings will no longer be displayed in management mode

* Tue Mar 02 2021 Greg Nichols <gnichols@redhat.com>
- CERTPX-7490 RHCert needs a simple example for implementing a test suite

* Thu Feb 25 2021 Petersingh Anburaj <panburaj@redhat.com>
- CERTPX-7107 repair the fingerprint hardware test   - Updated the fingerprint test to make it work   - Updated the test to have two different subtests

* Tue Feb 23 2021 Shikhar Sharma <shikshar@redhat.com>
- CERTPX-7103 add nvme-cli into NVME test     - Added feature to log NVMe device info with various nvme cli commands output.

* Tue Feb 23 2021 Greg Nichols <gnichols@redhat.com>
- CERTPX-7455 RHCert results.xml CSS and output clean up      - command regex search lead to mysterious output of the word dead"      - configuration test also randomly prints "dead""
- CERTPX-7455 RHCert results.xml CSS shows test results doubled     - hide attachment payload     - show attachment mime-type
- CERTPX-7455 RHCert results.xml CSS shows test results doubled     - change font size in block for <summary> to 0px to hide it.     - summary:after shows it in color @ 10px

* Wed Feb 17 2021 Javed Alam <jalam@redhat.com>
- CERTPX-7360 Add support for RHOSP-16.2 in RHCert osp test suite     - Added Tempest test for RHOSP-16.2     - Added support of RHOSP-16.2 in openstack test suite

* Tue Feb 16 2021 Petersingh Anburaj <panburaj@redhat.com>
- CERTPX-7347 100G Ethernet test failing with iperf3 CERTPX-7209 Replace tcp bw lmbench commands with iperf3   - Reverted the patch for bw test to use iperf3

* Tue Feb 16 2021 Vibhuti Sodhi <vsodhi@redhat.com>
- CERTPX-7304 Release Notes 7.24   - release notes updated

* Mon Feb 15 2021 Javed Alam <jalam@redhat.com>
- New release branch 7.25

* Mon Feb 15 2021 Petersingh Anburaj <panburaj@redhat.com>
- CERTPX-7347 100G Ethernet test failing with iperf3   - Limited the max thread to 128 and iperf3 only supports 128 threads

* Mon Feb 15 2021 Shikhar Sharma <shikshar@redhat.com>
- CERTPX-7095 fv_live_migration failing on some aarch64 pairs     - Added dmidecode ID's match for SUT and Lab Agent only for aarch64 systems.

* Thu Feb 11 2021 Petersingh Anburaj <panburaj@redhat.com>
- CERTPX-7336 Not able to go on configuration tab   - Fix a bug that caused failure when firewalld service causes exception

* Thu Feb 11 2021 Shikhar Sharma <shikshar@redhat.com>
- CERTPX-7164 SSD subtest of PCIE_NVMe test not showing size of device     - Added size to the lsblk command.

* Wed Feb 10 2021 Zahid Ajaz <zajaz@redhat.com>
- CERTPX-6590 Software RPM test XML log file merge fails with 'Unbound Prefix' errors    - Fixed string names to prevent errenous xml CERTPX-6976 rhcert-cli register appears to be running test code, prompting user, etc    - corrected test planning    - restructed the checks for test execution

* Wed Feb 10 2021 Shikhar Sharma <shikshar@redhat.com>
- CERTPX-6772 Manually planning a NVME hw test on a non-nvme should identify and test should fail     - Modified condition to run NVMe Check Subtest on all NVMe tests.     - Overriden runStorage method to execute Subtest - 'Check NVMe device type' before.
- CERTPX-7164 SSD subtest of PCIE_NVMe test not showing size of device     - Updated command to print the block size from lsblk output.

* Wed Feb 10 2021 Greg Nichols <gnichols@redhat.com>
- CERTPX-7298 Product details are not getting updated for cloud cert    - update for API change to accept array of integer ids

* Mon Feb 08 2021 Petersingh Anburaj <panburaj@redhat.com>
- CERTPX-7208 LTS UI should support opening firewall ports   - LTS settings page will now show the status of firewall and allow user to open the required ports   - Added a default value for the iperf port

* Mon Feb 08 2021 Greg Nichols <gnichols@redhat.com>
- CERTPX-7276 traceback when creating new product from rhcert UI
- CERTPX-7298 Product details are not getting updated for cloud cert    - missed checkin

* Fri Feb 05 2021 Greg Nichols <gnichols@redhat.com>
- CERTPX-7298 Product details are not getting updated for cloud cert    - ported code to use new hydra-cwe api

* Wed Feb 03 2021 Petersingh Anburaj <panburaj@redhat.com>
- CERTPX-7209 Replace tcp bw lmbench commands with iperf3   - Updated the TCP bandwidth test to use iperf3 instead of bw_tcp
- CERTPX-7285 Replace tcp latency lmbench commands with iperf3   - Updated the TCP latency test to use iperf3 instead of lat_tcp

* Wed Feb 03 2021 Shikhar Sharma <shikshar@redhat.com>
- CERTPX-7284 fv_live_migration failing with Ncat: No such file or directory.: Input/output error     - Added automatic restart of libvirt daemon on Lab Agent.

* Tue Feb 02 2021 Greg Nichols <gnichols@redhat.com>
- CERTPX-7243 Creation of Software Ecosystem product in Container Category fails: product sub-category ids are required.    - changed PNS wrapper to filter out inactive categories"

* Mon Feb 01 2021 Shikhar Sharma <shikshar@redhat.com>
- CERTPX-6772 Manually planning a NVME hw test on a non-nvme should identify and test should fail     - Implemented nvme-cli for NVMe device identification.

* Fri Jan 29 2021 Greg Nichols <gnichols@redhat.com>
- Deprecate VendorProduct XMLRPC calls for accessing, creating and updating Partner Products

* Fri Jan 29 2021 Vibhuti Sodhi <vsodhi@redhat.com>
- CERTPX-7203 Release notes 7.23 doc updated   - release notes updated

* Wed Jan 27 2021 Greg Nichols <gnichols@redhat.com>
- CERTPX-7238 cannot create passthrough cert    - restored parameters for hw pass-through (cherry picked from commit ad0848d9aa87e53cbcd84391f34ffd905f1e0467)

* Mon Jan 25 2021 Greg Nichols <gnichols@redhat.com>
- CERTPX-7188 Hardware Partner Product creation does not set attributes CERTPX-7212 Product Specification Details records not getting updated CERTPX-7240 Spec Status set to Pre Production in Cert Ops when Production was selected in the WebUI       - moved Partner Product creation, access and updates to rhcert-cwe REST calls       - revised details pages for attributes changes (cherry picked from commit f243ba02b43d7560c2ef19eede3d07e8964f6494)

* Mon Jan 25 2021 Javed Alam <jalam@redhat.com>
- CERTPX-7040 Test run get stuck at cinder_lib test when run for first time on a freshly deployed System.     - Passing default 'Yes' parameter while removing unittest2 package to avoid user interaction
- New release branch 7.24

* Thu Jan 21 2021 Javed Alam <jalam@redhat.com>
- CERTPX-6877 Increase file attachment uploadation size limit upto 500 MB in RHCert dialog tab     - Added an alert if the file size exceeds 500MB

* Mon Jan 18 2021 Petersingh Anburaj <panburaj@redhat.com>
- CERTPX-6928 Investigate implement if iperf3 can replace lmbench CERTPX-5558 Replacement of LMBench in RHCert   - Changed the default port to 5201   - Fixed the code bug to handle the situation when no port is added in XML file

* Mon Jan 18 2021 Greg Nichols <gnichols@redhat.com>
- CERTPX-7187 Software Partner Product Creation Traceback when only one subcategory is chosen: No JSON object    - fixed traceback when no json is in response    - fixed createProduct call to put subcategories in a list

* Fri Jan 15 2021 Greg Nichols <gnichols@redhat.com>
- CERTPX-5563 [Software Certification] Product Specification Details tab doesn't work, no page available      - fixed for generic programs added PATCH to hydra-cwe service Wrapper with filtering based on attribute naming      - restored access to VendorProducts XMLRPC worflow for hardware, cloud, and openstack product updates

* Thu Jan 14 2021 Greg Nichols <gnichols@redhat.com>
- CERTPX-5563 [Software Certification] Product Specification Details tab doesn't work, no page available      - implemented generic product details page for generic programs
- CERTPX-7176 Create new XMLRPC API to accept/return new partner product id    - fix response handling for  Cert.getCert_7_22

* Wed Jan 13 2021 Greg Nichols <gnichols@redhat.com>
- CERTPX-7176 Create new XMLRPC API to accept/return new partner product id

* Tue Jan 12 2021 Petersingh Anburaj <panburaj@redhat.com>
- CERTPX-6928 Investigate implement if iperf3 can replace lmbench CERTPX-5558 Replacement of LMBench in RHCert   - Replaced the lmbench with iperf3 for UDP latency test   - Updated and refactored the register code to open 5203 port on SUT

* Tue Jan 12 2021 Javed Alam <jalam@redhat.com>
- CERTPX-7150 Product Logo spinning on Product Details page - tb when update urls CERTPX-7171 Product logo is not getting updated     - Initiated VendorProduct() class in Connection for wider coverage     - Fixed Product Logo spinning on Product Details page     - Product logo is getting updated now

* Fri Jan 08 2021 Petersingh Anburaj <panburaj@redhat.com>
- CERTPX-7077 Hardware Certification - s390x output looks incorrect for storage device name   - Fixed a bug in the code due to which wrong device name was captured in storage test

* Thu Jan 07 2021 Petersingh Anburaj <panburaj@redhat.com>
- CERTPX-4831 Webui error reported for HW Cert - /bin/sh ndctl command is not found   - Added ndctl package to hardware test suite dependency as ndctl command is used in planning
- CERTPX-6977 Test Suite Planning should conform to requirements   - Updated the info message

* Thu Jan 07 2021 Aniket Khisti <akhisti@redhat.com>
- CERTPX-7046 HW Certification - kdump should plan and install matching kernel version  Handle the kernel-debuginfo & kernel-debuginfo-common* package installation separately

* Wed Jan 06 2021 Greg Nichols <gnichols@redhat.com>
- CERTPX-7137 Not able to load Certs and Vendor Products on Stage and Prod env.    - fix new product sync logic (cherry picked from commit c2fa7e04e22e8c5759076e308da38785837cbbc3)

* Wed Jan 06 2021 Javed Alam <jalam@redhat.com>
- CERTPX-7113 Unsupported RHOSP Versions are visible in Dorpdown     - Added a check for supported versions

* Wed Jan 06 2021 Zahid Ajaz <zajaz@redhat.com>
- CERTPX-7027 Cloud Image Certification:Include GPG key in the installedRPMS model  - GPG key added as part of parameter 'signature' in installed rpms model  - 'signature' for each rpm is saved as feature data to results.xml  - Needs to be pushed to catalog as a part of cloud image granularity data

* Wed Jan 06 2021 Vibhuti Sodhi <vsodhi@redhat.com>
- CERTPX-7118 Release Notes 7.22   - Release notes doc updated.

* Tue Jan 05 2021 Petersingh Anburaj <panburaj@redhat.com>
- CERTPX-6839 Perf Uncore" test failed with count mismatch error   - Updated the test to return only Warning in case of any failure"

* Tue Jan 05 2021 Greg Nichols <gnichols@redhat.com>
- CERTPX-7117 Error when creating new hardware product on QA from WebUI    - fixed error reporting from vendorproducts update calls (cherry picked from commit 8e0c072e3a56000d8efa0a227cf1fe7818f4f07e)

* Mon Jan 04 2021 Javed Alam <jalam@redhat.com>
- CERTPX-5563 Product Specification Details tab doesn't work, no page available     - Added a new Product details page for S/W     - Rendered Product data on the newly added page
- New release branch 7.23

* Tue Dec 22 2020 Shikhar Sharma <shikshar@redhat.com>
- CERTPX-7097 fv_live_migration test leaves guest running instead of shutdown   - Added feature to shutdown the guest after the test execution is completed.

* Mon Dec 21 2020 Shikhar Sharma <shikshar@redhat.com>
- CERTPX-7096 fv_live_migration rollback reporting PASS when it has failed   - Stop test execution if migration fails.

* Fri Dec 18 2020 Greg Nichols <gnichols@redhat.com>
- CERTPX-7061 RHCert 7 Deprecate VendorProduct.* XMLRPC Calls    - remove most calls to VendorProduct.* XMLRPC    - replace with new support in HydraCWEService    - add id patching for moved cloud/sw partner products

* Thu Dec 17 2020 Shikhar Sharma <shikshar@redhat.com>
- CERTPX-7063 Add Roll back VM feature to FV Live Migration Test   - Fixed Passwordless ssh setup issue.

* Wed Dec 16 2020 Shikhar Sharma <shikshar@redhat.com>
- CERTPX-7046 HW Certification - kdump should plan and install matching kernel version   - Fixed syntax error in getRequiredRPMs

* Wed Dec 16 2020 Vipin Kumar <vipikuma@redhat.com>
- CERTPX-6741: [Bare Metal] Test failing deploy as rhcert is trying to boot it in BIOS mode   - parameterize create_rhcert_flavor and add_flavor_and_drivers methods so they can accept both boot_option   - added a block to clean server and flavor if fail to boot in local mode   - added steps to boot in uefi if it fails to create the server in local or bios mode

* Tue Dec 15 2020 Shikhar Sharma <shikshar@redhat.com>
- CERTPX-7063 Add Roll back VM feature to FV Live Migration Test   - Fixed the password prompt issue on Lab Agent.

* Tue Dec 15 2020 Aniket Khisti <akhisti@redhat.com>
- CERTPX-7046 hwcert/kdump test should plan and install kernel-debuginfo-* packages matching kernel version

* Mon Dec 14 2020 Shikhar Sharma <shikshar@redhat.com>
- CERTPX-7063 Add Roll back VM feature to FV Live Migration Test   - Added vm roll back feature to revert the migrated vm back to the source system.   - Enabled autoplan of the test again.

* Mon Dec 14 2020 Petersingh Anburaj <panburaj@redhat.com>
- CERTPX-6839 Perf Uncore" test failed with count mismatch error   - Added "not counted" events to "not supported" list"

* Thu Dec 10 2020 Shikhar Sharma <shikshar@redhat.com>
- CERTPX-6878 Implementation of RHEL Live Migration   - Added required RPMs to el8 package

* Thu Dec 10 2020 Vibhuti Sodhi <vsodhi@redhat.com>
- CERTPX-7032 Release Notes 7.21   - release notes document updated

* Mon Dec 07 2020 Zahid Ajaz <zajaz@redhat.com>
- release-7.22

* Fri Dec 04 2020 Shikhar Sharma <shikshar@redhat.com>
- CERTPX-6878 WIP: Implementation of RHEL Live Migration   - Disabled automatic planning of the test temporarily

* Thu Dec 03 2020 Petersingh Anburaj <panburaj@redhat.com>
- CERTPX-3853 rhcert-cli Infiniband_QDR test does not install required package opensm CERTPX-4612 fv dependencies not installed when run from rhcert-cli CERTPX-4613 fv dependencies not installed on non x86 systems - Fixed an issue in installing dependency during cli execution

* Thu Dec 03 2020 akshay gupta <akshgupt@redhat.com>
- CERTPX-7038: Added tpsd link for authentication error

* Wed Dec 02 2020 Shikhar Sharma <shikshar@redhat.com>
- CERTPX-6878 Implementation of RHEL Live Migration   - Added python-cryptography as dependency   - Fixed known hosts prompt issue   - Fixed not-well formed issue Change-Id: I55899dea9bb8b58ccb632bae04b5a723a19df110

* Tue Dec 01 2020 Shikhar Sharma <shikshar@redhat.com>
- CERTPX-6878 Implementation of RHEL Live Migration     - Added Live migration test as per the implementation plan

* Thu Nov 26 2020 Petersingh Anburaj <panburaj@redhat.com>
- CERTPX-7014 update the command used in the check_smt function   - Fixed a bug that caused check_smt to fail when lscpu output has multiple occurences of Thread
- CERTPX-6789 Create new FV Passthrough tests for Storage   - Fixed a bug that caused wrong host selection for running fv_storage test

* Wed Nov 25 2020 Shikhar Sharma <shikshar@redhat.com>
- CERTPX-6526 rhcert: kdump test should validate existence of correct kernel-debuginfo-* packages after the test run     - add a check if kernel-debuginfo utility version matches with kernel version and result in review if negative

* Mon Nov 23 2020 Aniket Khisti <akhisti@redhat.com>
- CERTPX-7001 Hide hwcert/fvtest/fv_{storage,network,{pcie,usb,storage,network}_passthrough} from users  - make the fv_network and fv_storage visible on RHEL 7 only  - fix traceback due to missing functional parameter planner

* Fri Nov 20 2020 Aniket Khisti <akhisti@redhat.com>
- CERTPX-7001 Hide hwcert/fvtest/fv_{storage,network,{pcie,usb,storage,network}_passthrough} from users  - Return empty test-plan to avoid auto-planning of above mentioned tests on all supported RHEL versions

* Thu Nov 19 2020 akshay gupta <akshgupt@redhat.com>
- CERTPX-6995: Some HTML code is visible as Announcement on RHCERT Home page.     Added html parsing capability in cwe banner message

* Thu Nov 19 2020 Zahid Ajaz <zajaz@redhat.com>
- release-7.21

* Wed Nov 18 2020 Jon Blackburn <jblackbu@redhat.com>
- Removed the 14MB limit on uploads and the messages that go along with it. Increased the limit to 500MB for uploads.

* Tue Nov 17 2020 Vibhuti Sodhi <vsodhi@redhat.com>
- CERTPX-6883 Release Notes 7.20   - release notes file updated.

* Tue Nov 17 2020 Aniket Khisti <akhisti@redhat.com>
- CERTPX-6882 Implement load-stress subtest for fv_cpu_pinning  - along with %guest, consider the %sys (kernel) spike from mpstat  - install rpm dependencies inside guest vm, before the test run    by modifying the fvtest.submitTasks() for the code reusability
- CERTPX-6882 Implement load-stress subtest for fv_cpu_pinning  - Fix a traceback due to local variable referenced before assignment

* Fri Nov 13 2020 Greg Nichols <gnichols@redhat.com>
- CERTPX-6972 Disable Product Creation for the Cloud Ecosystem

* Thu Nov 12 2020 Zahid Ajaz <zajaz@redhat.com>
- CERTPX-6943 Unable to Create passthrough certification from CCSP Gold Image  - Fixed the missing template issue  - Disabled multi-level pass-through creation for cloud certifications CERTPX-6969 For a Completed/Certified cloud Certifications we shouldn't be able to change the subscription model  - Disallow updating subscription model for completed certifications

* Wed Nov 11 2020 Aniket Khisti <akhisti@redhat.com>
- CERTPX-6882 Implement load-stress subtest for fv_cpu_pinning  - make the subtest more verbose by printing the mpstat output

* Tue Nov 10 2020 Aniket Khisti <akhisti@redhat.com>
- CERTPX-6882 Implement load-stress subtest for fv_cpu_pinning

* Tue Nov 10 2020 Greg Nichols <gnichols@redhat.com>
- CERTPX-6759 Product Name Service v4/certificationTypes/<id>/versions should show product and platform information     - check in baseline certification types json

* Mon Nov 09 2020 Zahid Ajaz <zajaz@redhat.com>
- CERTPX-6830 Cloud Certification - Update subscription model from certification details tab   - Added subscription_model" parameter to updateCloud_4_7 API"
- CERTPX-6873 Add Related vendor products functionality for Cloud Certs - Enables creation of cloud pass-through product spec - Enables creation of cloud pass-through certificatio using the new product spec
- CERTPX-6289 Add Related Certifications functionality for Cloud Certs - Enable related certifications tab for cloud certifications - Display Pass-Through certifications only - Enable creation of Pass-Through certification over cloud certs

* Mon Nov 09 2020 Javed Alam <jalam@redhat.com>
- CERTPX-6830 Cloud Certification - Update subscription model from certification details tab     - Enabled subscription model for cloud certifications     - Changed subscription model field from text box to dropdown select     - Red Hat Gold Image" will be disabled in dropdown if partners don't have permission to update it     - Updating HTML field name for Hydra API support"
- CERTPX-6830 Cloud Certification - Update subscription model from certification details tab     - Enabled subscription model for cloud certifications
- CERTPX-6868 Cloud Certification - Permission based subscription model from certification details tab     - Disable Red Hat Gold Image if the vendor doesn't have permission/subscription for the gold image     - Removed Upload image option from RHCert WUI Change-Id: Ia1fc131444aaa5a3996a5a1e5ea749f26fa1daf9

* Fri Nov 06 2020 Petersingh Anburaj <panburaj@redhat.com>
- CERTPX-6790 Create new FV Passthrough tests for Network   - Added 2 new tests for network passthrough: fv_pcie_network_passthrough, fv_usb_network_passthrough   - Improved some logging in fv tests to capture rc.local logs

* Wed Nov 04 2020 Javed Alam <jalam@redhat.com>
- CERTPX-6936 Unable to create cloud cert getting Typeerror  'NoneType' object is not iterable""

* Wed Nov 04 2020 Petersingh Anburaj <panburaj@redhat.com>
- CERTPX-6789 Create new FV Passthrough tests for Storage   - Fixed the package dependency for cryptograph   - Fixed fvTest to use the device name for parsing the result file

* Tue Nov 03 2020 Greg Nichols <gnichols@redhat.com>
- CERTPX-6934 The RHCert 7 support for Phase-0 programs - Hide Progress and Testing tabs
- CERTPX-6930 PNS output for versions or certification types, portfolio etc. should be versions" (lower case)."

* Tue Nov 03 2020 Javed Alam <jalam@redhat.com>
- CERTPX-5807 Cinderlib test     - Introduced a new test called cinder_lib" for cinder plugins.     - Added a check to plan this test for RHOSP-16 and onwards.     - Downloading and installing required cinderlib package for the test     - Running cinderlib test on cinder-volume container     - Smooth handling of errors if no container present with name cinder-volume     - A Cleanup method added to remove the installed RPMs for cinderlib"

* Fri Oct 30 2020 Greg Nichols <gnichols@redhat.com>
- CERTPX-6918 RHCert Layered Certification Creation from Certification Types     - filter base versions by selected platform and RH product version.
- CERTPX-6926 unable to create new hardware product on QA - isLayeredCertification error

* Thu Oct 29 2020 Greg Nichols <gnichols@redhat.com>
- CERTPX-6918 RHCert Layered Certification Creation from Certification Types     - fix baremetal cert creation (cherry picked from commit 6c0790d19725e8542e448ce6645ee187d69c70fd)
- CERTPX-6918 RHCert Layered Certification Creation from Certification Types

* Thu Oct 29 2020 Javed Alam <jalam@redhat.com>
- CERTPX-6906 Traceback `ValueError: invalid literal for int() with base 10     - Separate conditional check has been added for RHOP-16 and above and for olders versions.

* Wed Oct 28 2020 Greg Nichols <gnichols@redhat.com>
- CERTPX-6916 cannot create new hardware product on QA (cherry picked from commit 19081374dff1bc2c27dac098e75cea8cfc250482)

* Wed Oct 28 2020 Petersingh Anburaj <panburaj@redhat.com>
- CERTPX-6789 Create new FV Passthrough tests for Storage   - Added 2 new tests for Storage FV Passsthrough: fv_pcie_storage_passthrough, fv_usb_storage_passthrough

* Wed Oct 28 2020 jialli <jialli@redhat.com>
- CERTPX-6831: update xmlrpc api doc to include the updating of subscription model
- CERTPX-6669: add xmlrpc apis to support RHOCP cert

* Wed Oct 28 2020 Shikhar Sharma <shikshar@redhat.com>
- CERTPX-4920 rhcert incorrectly identifies an SAS HDD as an SAS_SSD device - Changed logic to identify correct SSD device partition belonging to the host.

* Tue Oct 27 2020 Greg Nichols <gnichols@redhat.com>
- CERTPX-6788 The RHCert New Certification Wizard should use PNS Certification Types     - enable partner product creation for cloud and software ecosystems (cherry picked from commit d93e85f61f9081766a830593d096176506c3f5c0)

* Tue Oct 27 2020 Javed Alam <jalam@redhat.com>
- New release branch 7.20

* Mon Oct 26 2020 Greg Nichols <gnichols@redhat.com>
- CERTPX-6788 The RHCert New Certification Wizard should use PNS Certification Types     - remove references to program/ecosystem and partner IDs from the Partner products Selection UI.

* Thu Oct 22 2020 Greg Nichols <gnichols@redhat.com>
- CERTPX-6867 Cert Creation is failing for RHOSP missing page where we used to select plug-in types    - fix cert type selector to provide program name based on selected cert type

* Thu Oct 22 2020 Jon Blackburn <jblackbu@redhat.com>
- Fixed recursion error where choose-sandbox-name.html was extending itself.  Resolves Jira CERTPX-6939

* Wed Oct 14 2020 Greg Nichols <gnichols@redhat.com>
- CERTPX-6788 The RHCert New Certification Wizard should use PNS Certification Types    - change terminology to Partner and Partner Products    - Use ecosystem" for partner products

* Tue Oct 13 2020 Greg Nichols <gnichols@redhat.com>
- CERTPX-6842 Create cert failing with Could not find vendor product id error
- CERTPX-6774 RHCert Support for Generic/Phase-0 Program Support     - fixed calls to CWE to get certifications
- CERTPX-6774 RHCert Support for Generic/Phase-0 Program Support     - fixed sort order of certifiation types (oldest products, with newest versions first)     - change new cert wizard cert type picker to pick cert type, then platform, then version     - changed new sandbox wizard to use cert types

* Tue Oct 13 2020 Aniket Khisti <akhisti@redhat.com>
- CERTPX-6778 Improve the turbostat extra columns check error message to be more transparent  - Fix a case when it should be warn instead of pass

* Mon Oct 12 2020 Greg Nichols <gnichols@redhat.com>
- CERTPX-6835 RHCert New Certification Error: no such method getProgram for CertificationTypesService
- CERTPX-6774 RHCert Support for Generic/Phase-0 Program Support     - remove special cases and general code-cleanup for programs     - added use of v4 programs and cert types from PNS     - changed new certification wizard:           step 1) pick or cerate partner Product           step 2) choose certification type (not rh product)

* Mon Oct 12 2020 Aniket Khisti <akhisti@redhat.com>
- CERTPX-6778 Improve the turbostat extra-columns-check error-message to be more transparent  - make regex pattern match strict

* Fri Oct 09 2020 Greg Nichols <gnichols@redhat.com>
- CERTPX-6766 Microservice wrapper for Product Name Service Certification Types     - fixed cache file creation for packaging
- CERTPX-6795 RHCert needs a service wrapper for Hydra-CWE Rest    - move hydra-cwe rest url to environment class.

* Tue Oct 06 2020 Greg Nichols <gnichols@redhat.com>
- CERTPX-6766 Microservice wrapper for Product Name Service Certification Types     - bug fixes re: IDs are expected to be integers
- CERTPX-6798 redhat-certification build issues on el6 (cherry picked from commit 9d70aee9933866bb7111d7e983981633e097bddc)

* Tue Oct 06 2020 Vibhuti Sodhi <vsodhi@redhat.com>
- CERTPX-6767 Release Notes 7.18   - release notes updated for 7.18

* Mon Oct 05 2020 Greg Nichols <gnichols@redhat.com>
- CERTPX-6795 RHCert needs a service wrapper for Hydra-CWE Rest    - implements getAchievableCertificationTypes(partnerProductID)    - calls /products/<partnerProductID>/certificationsSPOG

* Mon Oct 05 2020 Petersingh Anburaj <panburaj@redhat.com>
- New release branch 7.19

* Thu Oct 01 2020 Javed Alam <jalam@redhat.com>
- CERTPX-6566 Partner request to add redfish as a baremetal driver     - Added a new Redfish driver support in baremetel test     - Added a check if nodes are not available during Provisioning State check
- Revert CERTPX-6566 Partner request to add redfish as a baremetal driver     - Added a new Redfish driver support in baremetel test     - Added a check if nodes are not available during Provisioning State check""

* Thu Oct 01 2020 Aniket Khisti <akhisti@redhat.com>
- CERTPX-6778 Improve the turbostat extra-columns-check error-message to be more transparent  - add regex for required columns check, if failed, search pattern is in stderr, exception

* Mon Sep 28 2020 Aniket Khisti <akhisti@redhat.com>
- CERTPX-6576 Implement certification test - intel_sst for Speed Select Technology  - Leverage the pre-existing test suite from - https://gitlab.com/prarit/sst-test  - Add support specific to only RHEL8 and above platform versions & intel chipset  - Plan & run either one of the two subtests based on the system config & support

* Mon Sep 28 2020 Vipin Kumar <vipikuma@redhat.com>
- CERTPX-6741 [Bare Metal] Test failing deploy as rhcert is trying to boot it in BIOS mode   - removed boot_option from the code to use the default value from the config file

* Mon Sep 28 2020 Greg Nichols <gnichols@redhat.com>
- CERTPX-6766 Microservice wrapper for Product Name Service Certification Types

* Wed Sep 23 2020 Petersingh Anburaj <panburaj@redhat.com>
- CERTPX-6664 Implement Uncore subtest in Profiler test   - Perf Uncore subtest will execute only for RHEL8 and above
- CERTPX-6729 Implement Thunderbolt4 test for RHEL8.3   - Fixed the typo that caused the traceback   - Fixed traceback caused due to encoding error

* Wed Sep 23 2020 Greg Nichols <gnichols@redhat.com>
- for discussion

* Tue Sep 22 2020 Petersingh Anburaj <panburaj@redhat.com>
- CERTPX-6663 Implement USB4 test   - Fixed a Bug in USB test that caused test to wait for user input without actually printing the prompt message
- CERTPX-6729 Implement Thunderbolt4 test for RHEL8.3   - Made current thunderbolt class as parent class   - Added new test class for TB3 and TB4   - Updated plan and run to check for generation value in boltctl output

* Tue Sep 22 2020 Jon Blackburn <jblackbu@redhat.com>
- CERTPX-6603 Update for error returned with unauthorized login. login.py now corrects the response message. Change-Id: I94e168bbc7c73a760aeaca62e52c8bdf2f616852

* Mon Sep 21 2020 Jon Blackburn <jblackbu@redhat.com>
- CERTPX-6491: The Sync Range options is now a input field that allows positive numbers representing days to be submitted for the range.

* Mon Sep 21 2020 Javed Alam <jalam@redhat.com>
- CERTPX-6664 Implement Uncore subtest in Profiler test   - Renamed current Perf subtest to Core subtest   - Added new Uncore subtest in profiler test   - Updated boolean return status with TestResult class return types

* Wed Sep 16 2020 Greg Nichols <gnichols@redhat.com>
- CERTPX-6635 RHCert 8 lab agent MVP for network testing     - added /api/status to show localhost rhcertd status also
- CERTPX-6635 RHCert 8 lab agent MVP for network testing     - fix /save api response to match LTS
- CERTPX-6635 RHCert 8 lab agent MVP for network testing     - fix /save api to use /www/rhcert/store/transfer

* Wed Sep 16 2020 Vibhuti Sodhi <vsodhi@redhat.com>
- CERTPX-6637 Release Notes 7.17   - Release Notes updated for Rel-7.17

* Wed Sep 16 2020 Aniket Khisti <akhisti@redhat.com>
- CERTPX-6575 implement turbostat test for RHEL 8.3  - Do not plan it on RHEL7, replace FAIL cases by WARN

* Tue Sep 15 2020 Shikhar Sharma <shikshar@redhat.com>
- CERTPX-6663 Implement USB4 test   - Added USB4 Test and 2 sub tests - USB4_20GbpsTest, USB4_40GbpsTest with USB4 test as lead.
- CERTPX-6538 USB3 labeling changes   - Removed generation checks in USB Tests.   - Added 3 sub tests for USB3 Test - USB3_5GbpsTest, USB3_10GbpsTest, USB3_20Gbps with USB3 as lead.

* Tue Sep 15 2020 Greg Nichols <gnichols@redhat.com>
- CERTPX-6635 RHCert 8 lab agent MVP for network testing     - fix httpd conf
- CERTPX-6635 RHCert 8 lab agent MVP for network testing     - change lab agent location to /var/www/rhcert     - hosted at /rhcert, status at /rhcert/api/status     - changed rpm spec to package lab-agent on RHEL8 instead of django/LTS WUI

* Tue Sep 15 2020 Aniket Khisti <akhisti@redhat.com>
- CERTPX-6575 implement turbostat test for RHEL 8.3  - Add Turbostat subtest under cpuscaling test in hwcert suite

* Mon Sep 14 2020 Greg Nichols <gnichols@redhat.com>
- CERTPX-6635 RHCert 8 lab agent MVP for network testing     - fix status to match LTS response     - change collab api to return string responses
- CERTPX-6635 RHCert 8 lab agent MVP for network testing     - add LAN beacon support

* Mon Sep 14 2020 Zahid Ajaz <zajaz@redhat.com>
- release-7.18

* Fri Sep 11 2020 Greg Nichols <gnichols@redhat.com>
- CERTPX-6686 Microservice wrapper for Product Name Service Programs and Ecosystems

* Thu Sep 10 2020 Greg Nichols <gnichols@redhat.com>
- CERTPX-6635 RHCert 8 lab agent MVP for network testing    - initial framework using Flask    - /status    - /save for uploading test files for network bandwith tests    - /collab for other services actions SUT->LTS    - /rhcert-transfer/<filename> for download of test files

* Tue Sep 08 2020 Greg Nichols <gnichols@redhat.com>
- CERTPX-6376 500 Server Error creating a cert for non-hardware-cert user    - fixed issue when user has partner entries but no products yet.

* Tue Sep 08 2020 Vipin Kumar <vipikuma@redhat.com>
- CERTPX-6655: Count the matched numbers of deployment files present and pass the director identification test accordingly.   - Changed method of director installation identification

* Fri Sep 04 2020 akshay gupta <akshgupt@redhat.com>
- CERTPX-6643: added get partners api to check if user has any partner account

* Thu Sep 03 2020 Petersingh Anburaj <panburaj@redhat.com>
- CERTPX-6596 Updated the logic of HT test to check SMT   - Added SMT check in Hardware Health subtest

* Thu Sep 03 2020 Greg Nichols <gnichols@redhat.com>
- CERTPX-6643 RHCert should inform user with no Partner accounts on login    - adds /api/partners to return a list of partner accounts
- CERTPX-6376 500 Server Error creating a cert for non-hardware-cert user    - fixed similar traceback for /api/products

* Thu Sep 03 2020 Shikhar Sharma <shikshar@redhat.com>
- CERTPX-5582 WirelessAX tests should be renamed or otherwise include the name WiFi6   - Removed 3 name change tests for WirelessG, WirelessN and WirelessAC.   - Modified AX Test to be planned only manually, Wifi6 Test will be planned automatically.

* Wed Sep 02 2020 Greg Nichols <gnichols@redhat.com>
- CERTPX-6376 500 Server Error creating a cert for non-hardware-cert user    - fixed traceback in template processing when user has no vendors

* Wed Sep 02 2020 Javed Alam <jalam@redhat.com>
- CERTPX-6593 Updating director identification command for rhosp 16.1 images     - Generalizing director identification command to detect RHOSP 16.0 and above versions

* Mon Aug 31 2020 Javed Alam <jalam@redhat.com>
- CERTPX-6629 Rename RHELSA to RHEL4ARM in RHCert     - Renamed all RHELSA instances with RHEL4ARM

* Wed Aug 26 2020 Shikhar Sharma <shikshar@redhat.com>
- CERTPX-5582 Wireless-AC and Wireless-AX tests should be renamed or otherwise include the names Wi-Fi 5 and Wi-Fi 6   - Added 4 new tests - WiFi3, WiFi4, WiFi5 and WiFi6, those follows     WirelessG, WirelessN, WirelessAC and WirelessAX resp. as their lead.

* Wed Aug 26 2020 Vibhuti Sodhi <vsodhi@redhat.com>
- CERTPX-6562 Release Notes 7.16   - Release notes updated

* Tue Aug 25 2020 Jon Blackburn <jblackbu@redhat.com>
- CERTPX-6588 - Reverted code for results importer back to original version.  This only impacts the test results page in default mode since the upload button on the nav bar has been removed. (cherry picked from commit 17d1ad71dfef5f9fee8b6da12d2e46a88a0a069d)

* Mon Aug 24 2020 Javed Alam <jalam@redhat.com>
- New release branch 7.17

* Mon Aug 24 2020 Petersingh Anburaj <panburaj@redhat.com>
- CERTPX-6441 Don't plan thunderbolt test if system doesn't have thunderbolt port   - Updated code to first check lspci output for thunderbolt planning

* Mon Aug 24 2020 vmulaje <vmulaje@redhat.com>
- CERTPX-6593 Updating director identification command for rhosp 16.1 images 	- Fixed command to indentify 16.1 images

* Mon Aug 24 2020 jialli <jialli@redhat.com>
- CERTPX-6568: update the xmlrpc api docs

* Mon Aug 24 2020 Aniket Khisti <akhisti@redhat.com>
- CERTPX-6592 fv_realtime test failing on RHEL7 and RHEL8  - Fix a false-negative regression causing the test to always fail

* Thu Aug 20 2020 Petersingh Anburaj <panburaj@redhat.com>
- CERTPX-6556 Ethernet tests failing with socket connection: Connection refused   - Fixed traceback caused by bytes

* Wed Aug 19 2020 Javed Alam <jalam@redhat.com>
- CERTPX-6558 change user visible references from FFU/Fast Forward Update to In-place upgrades from 13 (Queens)"      - Updated references of FFU to "In-place upgrades from 13 (Queens)"      - Updated the Feature name FFU to In-place upgrades from 13 (Queens)""
- CERTPX-4992 change user visible references from FFU/Fast Forward Update to In-place upgrades from 13 (Queens)"     - Updated references of FFU to "In-place upgrades from 13 (Queens)"     - Updated the Feature name FFU to In-place upgrades from 13 (Queens)"
- Revert CERTPX-4992 change user visible references from FFU/Fast Forward Update to "In-place upgrades from 13 (Queens)"     - Updated references of FFU to "In-place upgrades from 13 (Queens)"     - Updated the Feature name FFU to In-place upgrades from 13 (Queens)""

* Wed Aug 19 2020 Petersingh Anburaj <panburaj@redhat.com>
- CERTPX-6571 fv_cpu_pinning not installing dependencies during manual plan   - Fixed the issue by adding the requiredRPMs from parent class

* Tue Aug 18 2020 Petersingh Anburaj <panburaj@redhat.com>
- CERTPX-6556 Ethernet tests failing with socket connection: Connection refused   - Updated some error handling in collab calls   - Fixed false positive issue in UDP latency test

* Tue Aug 18 2020 Vipin Kumar <vipikuma@redhat.com>
- CERTPX-6553: Trusted container test is Failing in getting value of Authoritative Source Url in subtest Detection of Non-RH Containers for RHOSP 16.1 CERTPX-6564: [RHCERT] Test are not visible in test plan for Cloud and Software cert 	- updated code to skip Authoritative Source Url detection if images do not have parameter url 	- fixed import issue

* Mon Aug 17 2020 Aniket Khisti <akhisti@redhat.com>
- CERTPX-6341 realtime and fv_realtime tests not planning automatically on RHEL 8.3  - Improve product identification logic - fix parsing by omitting first whitespace
- CERTPX-6470 Unable to manually plan new fv tests on 8.3  - Add python{2,3}-cryptography as a runtime dependency in fvPassthrough  - Add whitespaces in rpm spec file for code consistency and aesthetics

* Mon Aug 17 2020 Petersingh Anburaj <panburaj@redhat.com>
- CERTPX-6414 add check for Spectre/Meltdown mitigations   - Fixed traceback caused in RHEL6   - Positional argument specifiers is required in format for python 2.6

* Thu Aug 13 2020 Petersingh Anburaj <panburaj@redhat.com>
- CERTPX-6441 Don't plan thunderbolt test if system doesn't have thunderbolt port   - Updated code to plan thunderbolt only when system has thunderbolt port

* Thu Aug 13 2020 Kumar Vipin Yadav <kumarvipinyadav369@gmail.com>
- CERTPX-6553: Trusted container test is Failing in getting value of Authoritative Source Url in subtest Detection of Non-RH Containers for RHOSP 16.1

* Wed Aug 12 2020 Shikhar Sharma <shikshar@redhat.com>
- CERTPX-5818 cpuscaling fails on ppc64le when CPUs are offline     - Modified cpuscaling test to run only on online cpus.     - Raised warning message if mismatch in planned required-cpus and online cpus.

* Tue Aug 11 2020 Jon Blackburn <jblackbu@redhat.com>
- CERTPX-6579 Fix Unicode error when uploading some result files.
- CERTPX-6513 - Per Rob and Greg removed the upload from the PageContainer header for rhcert 7.

* Tue Aug 11 2020 Javed Alam <jalam@redhat.com>
- CERTPX-5833 Ignore always-failing false positive results in Installed RPM test     - Removed blank failures from rpm_verification_report.log as they were not helpful     - All modification time changes changed to warning     - '/var/lib/selinux/*' added to ignore list     - Group ownership in LSM i.e '/run/lsm' is added to allowedList

* Tue Aug 11 2020 Petersingh Anburaj <panburaj@redhat.com>
- CERTPX-6414 add check for Spectre/Meltdown mitigations   - Renamed Unsupported Hardware subtest to Hardware Health subtest   - Added Known System Vulnerability check in Hardware Health subtest   - Added Hyper-Threading check in Hardware Health subtest   - Added Offline CPU check in Hardware Health subtest

* Mon Aug 10 2020 Jon Blackburn <jblackbu@redhat.com>
- CERTPX-6513: Added Error output when user tries to submit results file without Certification ID or Program Type

* Wed Aug 05 2020 Vibhuti Sodhi <vsodhi@redhat.com>
- CERTPX-6490 Release Notes 7.15   - Release Notes updated.

* Wed Aug 05 2020 Jon Blackburn <jblackbu@redhat.com>
- CERTPX-6125 & CERTPX-6487 Updates to results file upload for both regular .xml files and .gz files (cherry picked from commit 6e47776fdcbe9940a9b316931a7d9793ae3d3488)

* Mon Aug 03 2020 Javed Alam <jalam@redhat.com>
- New release branch 7.16

* Tue Jul 28 2020 Petersingh Anburaj <panburaj@redhat.com>
- CERTPX-6479 Make command is failing with error 'changelog not in descending chronological order'   - Fixed the no changelog issue

* Mon Jul 27 2020 Petersingh Anburaj <panburaj@redhat.com>
- CERTPX-6479 Make command is failing with error 'changelog not in descending chronological order'   - Updated the git log command to return sorted changelog
- CERTPX-5084 Move fv_network from -preview to -hardware package CERTPX-5085 Move fv_storage from -preview to -hardware package

* Mon Jul 27 2020 Shikhar Sharma <shikshar@redhat.com>
- CERTPX-6120 Unable to proceed for the test after the interactive box for selecting the RPM appear in WUI     - Added warning to re-select correct options if 'None of these' and other options are also selected.

* Thu Jul 23 2020 Greg Nichols <gnichols@redhat.com>
- CERTPX-5284 Unable to login to the WUI, user is asked to login repeatedly    - fix undefined response" variable on HTTP error"

* Wed Jul 22 2020 Aniket Khisti <root@localhost.localdomain>
- CERTPX-6214 Move fv_cpu_pinning test from preview to regular package

* Wed Jul 22 2020 Greg Nichols <gnichols@redhat.com>
- CERTPX-5284 Unable to login to the WUI, user is asked to login repeatedly    - improve error reporting via api/login and alerts

* Wed Jul 22 2020 Shikhar Sharma <shikshar@redhat.com>
- CERTPX-6088 traceback with fv_realtime test when tuned cannot be started     - Handled fv_realtime test which was getting hanged due to tuned service.

* Tue Jul 21 2020 Jon Blackburn <jblackbu@redhat.com>
- CERTPX-6125 - Patch addressing typo for submit as well as StringIO compatibility and patch for default configuration upload.
- Finished changes for results file upload from cert details

* Mon Jul 20 2020 Petersingh Anburaj <panburaj@redhat.com>
- CERTPX-6440 Move fv_pcie_passthrough test from preview to regular package CERTPX-6439 Move fv_usb_passthrough test from preview to regular package   - Moved fv_pcie_passthrough and fv_usb_passthrough tests to regular package

* Sun Jul 19 2020 Jon Blackburn <jblackbu@redhat.com>
- Figured out reason for file upload not submitting all the way.
- Code added from main nav bar results file upload without performing a file save or read.

* Tue Jul 14 2020 Javed Alam <jalam@redhat.com>
- CERTPX-6425 openstack/fast_forward_upgrade test needs to be added as a feature in RHOSP 16.1 plugin Certifications      - Added FFU test in feature list for all components
- CERTPX-6289 rhcert-cli submit --results <results-file>" command should ask for "certification" not "portal" ID     - Updated to new xmlrpc for uploading result package to use cert id instead of cert portal id"

* Mon Jul 13 2020 Petersingh Anburaj <panburaj@redhat.com>
- CERTPX-6284 The --device" doesn't take effect in the command "rhcert-cli plan --add --test <test name> --device <device name>"   - Updated code to set device name in add command"
- CERTPX-6381 suspend test uses deprecated python platform" module
- CERTPX-6113 new vendor could not see the vendor name when they try to create the first cert   - When user has no vendor-products the vendor details are not updated in products.xml   - returning True to fix the above issue

* Mon Jul 13 2020 Zahid Ajaz <zajaz@redhat.com>
- release-7.15
- CERTPX-6220 rpm/rpm-provenance test needs a whitelist for certain directories  - whitelisted /var/run failures for rpms in rpm_provenance
- CERTPX-6338 Traceback in Software Fingerprint Test  - Fixed the traceback error  - Modified alternative executable determination method

* Mon Jul 13 2020 jgarg <jgarg@redhat.com>
- CERTPX-6435: Traceback in Cloud/supportable test on el6

* Mon Jul 13 2020 akshay gupta <akshgupt@redhat.com>
- CERTPX-6382:  Added a link to Davenport for linking partners to partner support
- CERTPX-6382: replaced Davenport url with support hub
- CERTPX-6373: removed react based configuration page

* Mon Jul 13 2020 Vibhuti Sodhi <vsodhi@redhat.com>
- CERTPX-6345 Release Notes 7.13  - Updated Release Notes
- CERTPX-6345 Release Notes 7.13   - Updated Release Notes
- CERTPX-6424 Release Notes 7.14   - Release Notes updated for 7.14

* Mon Jul 13 2020 Shikhar Sharma <shikshar@redhat.com>
- CERTPX-6088 traceback with fv_realtime test when tuned cannot be started  - Added KVM enabled check when fv_realtime test is planned.
- CERTPX-6088 traceback with fv_realtime test when tuned cannot be started  - Handled traceback when kvm check command is failed.
- CERTPX-6120 Unable to proceed for the test after the interactive box for selecting the RPM appear in WUI  - Modified the interactive checkbox to select None of these" to make it applicable to all."

* Mon Jul 13 2020 Javed Alam <jalam@redhat.com>
- CERTPX-5455 Add FFU (partner installed) test support for rhosp-13 -> rhosp-16.1 CERTPX-5379 Automate rhcert-driven installation of plugins through director     Note: A part of director plugin installation is still missing will add it after getting further inputs     - Introduced a new test called fast_forward_upgrade" for all the plugins.     - Added a check to plan this test only for RHOSP-16.1     - Checking leapp directory for precise detection of FFU     - The test will prompt the user to verify that the environment is installed via FFU     - Added a subtest to validate the plugin installation was done using director.     - The subtest will prompt the user to verify that plugin was installed via director"
- CERTPX-6372 Pre-provisioned tempest is not cleaning resources if it fail in creating accounts.yaml     - Saving tempest state before setting Pre-provisioned tempest
- New release branch <version>

* Mon Jul 13 2020 Greg Nichols <gnichols@redhat.com>
- CERTPX-611 Provide access to CSS stylesheet so results.xml is browser viewable

* Mon Jul 13 2020 Aniket Khisti <akhisti@redhat.com>
- CERTPX-5961 Implement fv_cpu_pinning test for RHV 4.4  - Fix an IndentationError
- CERTPX-5699 The NVDIMM storage test for file system DAX devices" should not be arranged by hardware test suite  - Disable planning of NVDIMM storage mode - fsdax which is in the Technology Preview for RHEL 7 & 8 as of now"
- CERTPX-5961 Implement fv_cpu_pinning test for RHV 4.4  - Fix a SyntaxError
- CERTPX-5961 Implement fv_cpu_pinning test for RHV 4.4  - Workaround until below mentioned bugzilla fix is released   - Bug 1849215 - Parse the number of cpus correctly on s390
- CERTPX-630 traceback in fv_cpu_pinning test due to virsh vcpupin output differences from RHEL 8.3 onwards  - use regex for precise pattern capture and to avoid trivial mismatches due to any possible ambiguity

* Thu Jul 09 2020 jialli <jialli@redhat.com>
- CERTPX-6426: add one new xmlrpc api to use cert is as request parameter when uploading result package

* Fri Jun 19 2020 Javed Alam <jalam@redhat.com>
- CERTPX-6198 Setup pre-provisioned tempest credentials and networks if driver runs in DHSS=True mode     - Tempest will only be cleaned-up if its initial state is saved
- CERTPX-6198 Setup pre-provisioned tempest credentials and networks if driver runs in DHSS=True mode     - Setting a pointer to clean the allocated tempest resources after creating account.yaml file
- CERTPX-6198 Setup pre-provisioned tempest credentials and networks if driver runs in DHSS=True mode     - Added a pre-check to detect DHSS enablement for manila test     - Setup pre-provisioned tempest credentials if DHSS is enabled     - Configure tempest.conf to not run with dynamic test credentials, but use the test accounts file we generated     - cleaned up test credentials after the manila test run

* Thu Jun 18 2020 akshay gupta <akshgupt@redhat.com>
- CERTPX-6348: fixing router issues

* Wed Jun 17 2020 akshay gupta <akshgupt@redhat.com>
- CERTPX-5512: reverted changes for hosted solution

* Tue Jun 16 2020 Zahid Ajaz <zajaz@redhat.com>
- CERTPX-6333  rpm/RPM version handling test: changelog regex misparses e-mail addresses with hyphens   - Fixed the regex to parse email addresses correctly

* Mon Jun 15 2020 Zahid Ajaz <zajaz@redhat.com>
- CERTPX-5986 Software Fingerprint Test  - new subtest to capture ISV application software fingerprint Capture software rpm meta-data to augment the ISV application software fingerprint

* Thu Jun 11 2020 Shikhar Sharma <shikshar@redhat.com>
- CERTPX-6331 WirelessAX test being planned on a system with WirelessN  - Added additional speed test after device is identified as AX from device name based test.

* Wed Jun 10 2020 Aniket Khisti <akhisti@redhat.com>
- CERTPX-6321 traceback on suspend test on RHEL 7  - Check if file exists before access & replace    multiple hardcoded path by instance variable

* Wed Jun 03 2020 Vibhuti Sodhi <vsodhi@redhat.com>
- CERTPX-6212 Release Notes 7.12   - small update in release notes
- CERTPX-6212 Release Notes 7.12   - RN 7.12 updated (cherry picked from commit f74d394ee353113c4a371c96a9ac5cb618e14731)

* Wed Jun 03 2020 Shikhar Sharma <shikshar@redhat.com>
- CERTPX-6088 traceback with fv_realtime test when tuned cannot be started  - Handled exception HwCertCommandErrorOutput while executing tuned-adm profile command to avoid traceback.  - Fixed all the unresolved references in fv_realtime.

* Mon Jun 01 2020 Zahid Ajaz <zajaz@redhat.com>
- release-7.13

* Mon Jun 01 2020 Javed Alam <jalam@redhat.com>
- CERTPX-5971 Baremetal code refactoring     - Avoiding execution of the next test if any dependent test failed

* Fri May 29 2020 Petersingh Anburaj <panburaj@redhat.com>
- CERTPX-5375 el8 packages in brew have no changelog   - Fixed the no changelog issue for el8 builds   - git log was returned as bytes and was compared as string so it got skipped all the time

* Tue May 26 2020 Aniket Khisti <akhisti@redhat.com>
- CERTPX-6079 Error: The suspend method was freeze and should have been mem  - Fix a syntax error

* Fri May 22 2020 Aniket Khisti <akhisti@redhat.com>
- CERTPX-5961 Implement fv_cpu_pinning test for RHV 4.4  - Modify configure_guest subtest to make sure guestfiles exist in SUT  - Remove 'iommu passthrough' requirement from mandatory prerequisites Change-Id: Ibecb3b1513826839f27e39ce0c15a260834cee3a

* Wed May 20 2020 Aniket Khisti <akhisti@redhat.com>
- CERTPX-5961 Implement fv_cpu_pinning test for RHV 4.4  - Fix a blunder of inverse RHEL version check logic in planning

* Tue May 19 2020 Shikhar Sharma <shikshar@redhat.com>
- CERTPX-6088 traceback with fv_realtime test when tuned cannot be started  - Syntax error fixed for format method in python3.

* Tue May 19 2020 Petersingh Anburaj <panburaj@redhat.com>
- CERTPX-6144 Test the latest ppc64le FV images CERTPX-6173 Test the latest aarch64 FV images   - In fv_memory test changed the code to check for guest files before updaing the RAM

* Mon May 18 2020 Petersingh Anburaj <panburaj@redhat.com>
- CERTPX-6202 rhcert: hardware cert planning should not include iPXE test by default   - Removed the auto planning of iPXE test   - Boot order which was previously stored during plan is moved to run   - Added checks for local test server and UEFI boot to the run

* Mon May 18 2020 Shikhar Sharma <shikshar@redhat.com>
- CERTPX-6152 rhcertd start failed with Traceback Error  - Default Variables are now provided in rhcert-default.xml, which are copied to results.xml when rhcert is run.  - Removed undeclared default variables in environment.py

* Fri May 15 2020 Aniket Khisti <akhisti@redhat.com>
- CERTPX-6079 Error: The suspend method was freeze and should have been mem  - change suspend to mem temporarily if system supports it but default set to freeze

* Thu May 14 2020 Shikhar Sharma <shikshar@redhat.com>
- CERTPX-5933 [Management] Unable to update details in product tab in rhcert WUI  - Modification in UpdateProduct to get vendor directly from Hydra instead of local store in managment mode.

* Wed May 13 2020 Zahid Ajaz <zajaz@redhat.com>
- CERTPX-6192 [SAP] Traceback in hwcert,openstack, baremetal cert programs - missing policy  - Fixed the issue for baremetal cert test suite
- CERTPX-6225 [SAP] RHCERT Web traceback on /certification/<program>/<id>/results  - Updated the /test/<type>/<id> url regexes to handle type 'cloud-sap'
- CERTPX-6045 Pilot Test suite for RHEL for SAP with HA (SAPwHAUS)certifications  - Separate test suite for cloud-sap New or Updated tests: CERTPX-6017 Policy Guide Update: Software Repos (SAPwHAUS) CERTPX-6018 Policy Guide Update: Package Groups (SAPwHAUS) CERTPX-6019 Policy Guide Update: Software Containers (SAPwHAUS) CERTPX-6020 Policy Guide Update: Insights (SAPwHAUS) CERTPX-6021 Policy Guide Update: Ansible (SAPwHAUS)  - Added as part of CERTPX-6025 CERTPX-6022 Policy Guide Update: Network Config (SAPwHAUS) CERTPX-6023 Policy Guide Update: Resource Limiting (SAPwHAUS) CERTPX-6024 Policy Guide Update: Default OS Runlevel (SAPwHAUS) CERTPX-6025 Policy Guide Update: System Roles (SAPwHAUS)  - Not exposed as it is in Tech Preview CERTPX-6026 Policy Guide Update: SELinux (SAPwHAUS) Bug Fixes: CERTPX-6172 [SAP] Red Hat cdn repos listed as non Red Hat repos  - Corrected error messages for unsupported Red Hat repo channels CERTPX-6160 [SAP] Traceback in System Services Subtest  - Fixed the bug caused by relative imports CERTPX-6192 [SAP] Traceback in hwcert,openstack, baremetal cert programs  - Fixed by adding the missing 'policy' paramter in the test base classes Change-Id: I6e61634816579f2b009614731bb516c5b719e898

* Wed May 13 2020 Petersingh Anburaj <panburaj@redhat.com>
- CERTPX-6144 Test the latest ppc64le FV images CERTPX-6173 Test the latest aarch64 FV images   - Updated the fv_memory test to allocate the required RAM to the VM before running the test   - Revert the config changes after running the test   - Updated some print commands in fvPassthrough.py file

* Tue May 12 2020 Javed Alam <jalam@redhat.com>
- CERTPX-6213 Traceback in baremetal     - Converted byte to string for regex match

* Tue May 12 2020 Aniket Khisti <akhisti@redhat.com>
- CERTPX-5961 Implement fv_cpu_pinning test for RHV 4.4 - Develop a non-interactive test for el>=8, in preview - Set & verify CPU affinity by virsh {vcpupin,vcpuinfo}

* Tue May 12 2020 Petersingh Anburaj <panburaj@redhat.com>
- CERTPX-6169 Release Notes for 7.11   - Updated release notes for 7.11

* Mon May 11 2020 Zahid Ajaz <zajaz@redhat.com>
- release-7.12

* Fri May 08 2020 Zahid Ajaz <zajaz@redhat.com>
- CERTPX-6134 Software test RPM/RPM Dependency Tracking misparses 'rpm -q --requires' output on subsequent commands   - Fix for handling invalid command outputs for rpm -ql   - Filter invalid file names/paths
- Software RPM test bug fixes CERTPX-6106 RPM test plans and starts running even if no non-redhat rpms are detected   - Skip rpm subtests and output failure when no non-redhat rpms are found and yet partner     asserts using rpm for software packaging CERTPX-6166 Software cert test script rpm_version_handling.py fails   - Fixed by updating 'meta' varaible definition CERTPX-6134 Software test RPM/RPM Dependency Tracking misparses 'rpm -q --requires' output   - Added special handling for rpmlib packages

* Thu May 07 2020 Javed Alam <jalam@redhat.com>
- CERTPX-6190 Traceback in getRequiredRPMs() KeyError: '16.1'" on RHOSP 16.0     - Added RHOSP 16.1 RPMs     - Precise extraction of RHOSP versions"
- CERTPX-6174 Add version detection logic for RHOSP-16.1 in RHCert     - Added version detection logic for RHOSP-16.1 in RHCert for baremetal and openstack

* Thu May 07 2020 jialli <jialli@redhat.com>
- CERTPX-6139: update cloud xmlrpc apis to support Cloud SAP

* Thu May 07 2020 Pooja Tiwari <ptiwari.redhat.com>
- CERTPX-6184 Rhcert to call appropriate apis for cloud-sap.

* Thu May 07 2020 Shikhar Sharma <shikshar@redhat.com>
- CERTPX-5500 WirelessAX Test is supported by RHEL 8.0 DUP, but Not by RhCert  - Added 'lshw' rpm dependency.

* Thu May 07 2020 Aniket Khisti <akhisti@redhat.com>
- CERTPX-6167 Update the hwcert info unsupported hardware test to warn instead of fail on < memory requirement  - In case the system does not meet RHEL standard minimum memory per logical CPU core requirement   - Change policy to 'WARN' instead of 'FAIL' in INFO & SUPPORTABLE tests which are part of all test suites   - Impact on automatic planning of few hwcert tests which is determined by using same 'ram_per_core' check     - Change user-visible message prefix to 'Warning' instead of 'Error' in core, memory and realtime tests     - Change user-visible message prefix to 'Needs Review' instead of 'Error' only in case of all FV tests

* Mon May 04 2020 Petersingh Anburaj <panburaj@redhat.com>
- CERTPX-4070 Work with RCM for creating fv DATA image file in pungi   - nvram file is not required with the new aarch64 images   - removed the file from new data image and updated the code to not download it

* Thu Apr 30 2020 Pooja Tiwari <ptiwari.redhat.com>
- Support new product Red Hat Enterprise Linux High Availability - Update Services for SAP Solutions" and program "cloud-sap""

* Thu Apr 30 2020 Shikhar Sharma <shikshar@redhat.com>
- CERTPX-5500 WirelessAX Test is supported by RHEL 8.0 DUP, but Not by RhCert  - Added new test for Wireless AX Support.  - Modification in getType to match phy and return wireless type.  - Added function to check Wireless is AX Type based on Connection Speed and Name.

* Wed Apr 29 2020 Petersingh Anburaj <panburaj@redhat.com>
- CERTPX-6111 Release Notes for 7.10   - Updated the RNs as per latest review

* Mon Apr 27 2020 Javed Alam <jalam@redhat.com>
- CERTPX-5866 New tempest tests in RHOSP-16.1 for Cinder     - Adding new tempest test regex for cinder

* Thu Apr 23 2020 Javed Alam <jalam@redhat.com>
- CERTPX-6137 Add tempest test in tempest_tests.json in RHOSP-16.1     - Added tempest tests for RHOSP-16.1

* Wed Apr 22 2020 Petersingh Anburaj <panburaj@redhat.com>
- CERTPX-6111 Release Notes for 7.10   - Updated the release notes doc for 7.10

* Tue Apr 21 2020 Petersingh Anburaj <panburaj@redhat.com>
- CERTPX-5959 Implement fv_usb_passthrough test for RHV 4.4 CERTPX-5957 Implement fv_pcie_passthrough test for RHV 4.4   - Fixed bug in usb passthrough when multiple device has same vendor/product id   - Updated command to get IP address   - Updated device driver command for pci passthrough to handle multiple devices of same vendor product   - Done some logging changes for readability purpose   - Updated the rc.local file as empty file causes rc.local service to fail inside the VM

* Mon Apr 20 2020 Zahid Ajaz <zajaz@redhat.com>
- release-7.11

* Fri Apr 17 2020 Shikhar Sharma <shikshar@redhat.com>
- CERTPX-6103 State the informative message during test planning if in case it is not planned automatically due to insufficient memory-per-core ratio     - Added Success/Error message for memory, fv_test, core, realtime and fv_realtime tests on performing 'ram_per_core' check.     - Added CPU Count, Threshold and RAM in Success/Error message in 'ram_per_core' method.

* Thu Apr 16 2020 Petersingh Anburaj <panburaj@redhat.com>
- CERTPX-6112 Update FV code to use XML files from DATA Image   - Updated code to first check the  XML file in DATA image   - Download from FTP if not present in DATA Image   - Removed downloading XML in plan command

* Wed Apr 15 2020 Petersingh Anburaj <panburaj@redhat.com>
- CERTPX-5959 Implement fv_usb_passthrough test for RHV 4.4   - Added new fv_usb_passthrough test to preview package   - Updated some import statements, to have full path, for tests in preview package CERTPX-5957 Implement fv_pcie_passthrough test for RHV 4.4   - `arp` command has some package dependency and is deprecated hence replaced it with `ip` command   - Fixed the traceback seen in ARM system

* Tue Apr 14 2020 Zahid Ajaz <zajaz@redhat.com>
- CERTPX-6094 - Refactored MultiSelect Prompt functionality - Added option '0. Select None' - Fixes Issue: Software/rpm test flags PPC64LE RH package as not-RH, causing blocked cert for Storix, Inc

* Mon Apr 13 2020 Petersingh Anburaj <panburaj@redhat.com>
- CERTPX-5957 Implement fv_pcie_passthrough test for RHV 4.4   - Fixed the below issues observed while running the test with RHEL6 VM image   - selinux-relabel issue fixed by using restorecon in rc.local file   - updated the logic for getting IP address as domifaddr is not returning the IP in RHEL6   - using /var/log/message as journalctl is not present in RHEL6

* Thu Apr 09 2020 vmulaje <vmulaje@redhat.com>
- CERTPX-6097 Fixed incorrect url printing on rhcert-cli save --server

* Wed Apr 08 2020 Javed Alam <jalam@redhat.com>
- CERTPX-6080 Traceback on configuration page     -Added conditionalize system type checking

* Wed Apr 08 2020 Petersingh Anburaj <panburaj@redhat.com>
- CERTPX-5957 Implement fv_pcie_passthrough test for RHV 4.4   - Changed the plan so that it gets planned only for RHEL8 and above   - Added `req_passthrough` so that it gets planned only when passthrough is enabled

* Tue Apr 07 2020 Zahid Ajaz <zajaz@redhat.com>
- CERTPX-5514 CERTPX-6084  - White-listing 'shim' as redhat rpm  - Resolves issue caused by package name inconsistencies in brew
- Revert CERTPX-5514 CERTPX-6084  - White-listing 'shim' as redhat rpm  - Resolves issue caused by package name inconsistencies in brew""

* Mon Apr 06 2020 Pooja Tiwari <ptiwari.redhat.com>
- Removed rhcert-cwe-api.yaml

* Mon Apr 06 2020 Petersingh Anburaj <panburaj@redhat.com>
- CERTPX-5957 Implement fv_pcie_passthrough test for RHV 4.4   - Added a new `fv_pcie_passthrough` test in preview package

* Mon Apr 06 2020 Javed Alam <jalam@redhat.com>
- CERTPX-4746 WebUi Register Systems reports the size twice under Type     - Added conditionalize system type check for cloud systems

* Fri Apr 03 2020 Pooja Tiwari <ptiwari.redhat.com>
- CERTPX-5828 New RHCert-CWE REST API Spec - Integer typed IDs across APIs. - corrected description for GET attachment API. - Fixed a typo for product api.

* Thu Apr 02 2020 Javed Alam <jalam@redhat.com>
- CERTPX-4901 Error: No module named 'paramiko'" can be seen during run of rhcert-cli plan     - Added a check to show this as a warning and only in debug high mode"

* Wed Apr 01 2020 Javed Alam <jalam@redhat.com>
- CERTPX-5984 Nova instance Creation fails when multiple networks available on Undercloud.     - Added check for multiple netowrks     - Added default selection of 'ctlplane' network if multiple networks present

* Wed Apr 01 2020 Greg Nichols <gnichols@redhat.com>
- CERTPX-5940 CWE SPOG Rules for achievable certifications      - json definition of portfolio and cert types      - maps to programs and ecosystems

* Mon Mar 30 2020 Ben Rose <brose@redhat.com>
- CERTPX-5683 - fv_realtime test virsh config needs to have 1GB/cpu (RHEL7) or 1.5GB/cpu (RHEL8)

* Mon Mar 30 2020 Zahid Ajaz <zajaz@redhat.com>
- release-7.10

* Mon Mar 30 2020 Petersingh Anburaj <panburaj@panburaj.pnq.csb>
- CERTPX-6042 Release Notes for 7.9   - Updated the release notes

* Fri Mar 27 2020 Ben Rose <brose@redhat.com>
- CERTPX-5471 - fv_realtime test failing on some RHEL 8.1 and 7.7 systems - took cieling of base vm config memory calculation - added wait cycle around systemctl start tuned command - added break to existing wait cycle block for when number of attempts runs out

* Thu Mar 26 2020 Pooja Tiwari <ptiwari.redhat.com>
- Revert Updates for running hosted under management""

* Thu Mar 26 2020 Zahid Ajaz <zajaz@redhat.com>
- CERTPX-5378 - Text strings updated - Typos corrected
- CERTPX-5813 Traceback in software/Supportable Software Modules test  - Filter unnecessary lines from command output  - Fixed keyError

* Thu Mar 26 2020 Pooja Tiwari <ptiwari@redhat.com>
- Revert CERTPX-5981 - Add application directory for Hosted RHCert""
- Revert CERTPX-5981 & CERTPX-5512  - Connect fixes for routing issues with Login/Logout/cwe create cert links""

* Thu Mar 26 2020 Greg Nichols <gnichols@redhat.com>
- CERTPX-5835 RHCERT-CWE API: Partners and Products   - update api spec
- CERTPX-5836 RHCERT-CWE API: projects    - updated api spec

* Wed Mar 25 2020 Jon Blackburn <jblackbu@redhat.com>
- CERTPX-5981 & CERTPX-5512  - Connect fixes for routing issues with Login/Logout/cwe create cert links

* Wed Mar 25 2020 Petersingh Anburaj <panburaj@redhat.com>
- CERTPX-5084 Move fv_networking from -preview to -hardware package CERTPX-5085 Move fv_storage from -preview to -hardware package   - Updated fv_network/storage test to get planned only if passthrough is enabled on host   - Removed interactive planning logic from fv_storage as that is not required

* Tue Mar 24 2020 Jon Blackburn <jblackbu@redhat.com>
- CERTPX-5981 - Add application directory for Hosted RHCert

* Tue Mar 24 2020 Greg Nichols <gnichols@redhat.com>
- CERTPX-5828 New RHCert-CWE REST API    - spec revisions for UX/UI design update    - more to do: rollups

* Tue Mar 24 2020 Aniket Khisti <akhisti@redhat.com>
- CERTPX-5998 check_ram_per_core method populate for RHEL 7 & 8 - add conditional test Planning in hwcert/realtime test as well
- CERTPX-5598 200Gig Network Test feature development

* Tue Mar 24 2020 Ben Rose <brose@redhat.com>
- CERTPX-5683 - fv_realtime test virsh config needs to have 1GB/cpu (RHEL7) or 1.5GB/cpu (RHEL8) - update configuration value for memory used by virsh in fv_realtime test

* Mon Mar 23 2020 Petersingh Anburaj <panburaj@redhat.com>
- CERTPX-5084 Move fv_networking from -preview to -hardware package   - Updated code to delete the rc.local script after fv test execution   - Required as we need to access the VM/Image for fv_network related configurations   - Modified virtCommand function so that any guestfish command can be executed

* Mon Mar 23 2020 Jon Blackburn <jblackbu@redhat.com>
- Updates for running hosted under management

* Thu Mar 19 2020 Petersingh Anburaj <panburaj@redhat.com>
- CERTPX-5729 move iPXE test from preview to regular hardware package   - Updated plan so that iPXE test gets planned only for RHEL8 and above

* Thu Mar 19 2020 Aniket Khisti <akhisti@redhat.com>
- CERTPX-5998 check_ram_per_core method populate for RHEL 7 & 8  - update existing check threshold to 1.5 > RHEL8 & to 1 for lower version  - separate out ram_per_core check from the original subtest for reusability  - introduce it as test Planning condition in hwcert/{core,memory,fv_*} tests

* Wed Mar 18 2020 vmulaje <vmulaje@redhat.com>
- CERTPX-6010 Added validation for Install guide url

* Wed Mar 18 2020 Petersingh Anburaj <panburaj@redhat.com>
- CERTPX-5729 move iPXE test from preview to regular hardware package   - Moved iPXE test from preview to regular hardware package

* Fri Mar 13 2020 Greg Nichols <gnichols@redhat.com>
- CERTPX-5974 Design for RHCert8 Projects Rules for SPOG    - prototype definitions & rules in TypeScript    - should move to Java/CWE/PNS
- CERTPX-5011 React Main Pages: Configuration Page    - fix routing and release-notes

* Thu Mar 12 2020 Petersingh Anburaj <panburaj@redhat.com>
- CERTPX-5968 Release Notes for 7.8   - Some ordering and phrasing changes in release notes

* Tue Mar 10 2020 Petersingh Anburaj <panburaj@redhat.com>
- CERTPX-5968 Release Notes for 7.8   - Updated release notes for 7.8

* Mon Mar 09 2020 Petersingh Anburaj <panburaj@redhat.com>
- CERTPX-4070 Work with RCM for creating fv DATA image file in pungi CERTPX-5084 Move fv_networking from -preview to -hardware package   - Updated fv code to make it compatible with the new data image

* Mon Mar 09 2020 Zahid Ajaz <zajaz@redhat.com>
- release-7.9

* Mon Mar 09 2020 Greg Nichols <gnichols@redhat.com>
- CERTPX-5011 React Main Pages: Configuration Page    - fix /api/rh-products to only return supported products, and to sort versions
- CERTPX-5011 React Main Pages: Configuration Page    - remove registered systems from RHCert 8 SPA - not in MVP.

* Mon Mar 09 2020 Ben Rose <brose@redhat.com>
- CERTPX-5954 ifup/ifdown command is failing in RHEL8 for wireless device     - Modify the change made previously for Socket Direct from base network test class to base rdmaConnection test class

* Fri Mar 06 2020 Javed Alam <jalam@redhat.com>
- CERTPX-5931 Director Deployment test fails on Both the role based nodes.     - Updated command to check director deployment with updated puddles

* Wed Mar 04 2020 Greg Nichols <gnichols@redhat.com>
- CERTPX-5694 RHCERT 8 POC calls to RHCert-CWE REST API    - fix LTS host api calls to use https://qa.foo.redhat.com    - requires ssl config for apache

* Tue Mar 03 2020 Petersingh Anburaj <panburaj@redhat.com>
- CERTPX-5910 baremetal_stage_deploying and redeploying test should fail when the tool could not get the demidecode from baremetal node   - Updated the command to check status of the VM/node   - Changed the logic for checking the non active instance/node CERTPX-5971 Baremetal code refactoring   - Replaced the nova commands with the openstack command   - Fixed dmidecode logic to get valid IP address

* Tue Mar 03 2020 Pooja Tiwari <ptiwari.redhat.com>
- CERTPX-5835 Changed spec to reflact /partners GET api response.

* Mon Mar 02 2020 Zahid Ajaz <zajaz@redhat.com>
- CERTPX-5378 Software Certification RPM Test     Added new subtests     - rpm_provenance     - rpm_version_handling     - rpm_dependency_tracking CERTPX-5914 RPM Validation as separate module     - Restructured and refactored RPM validation class into separate module     - This enables usage across test classes Change-Id: I90b08ee457ad55cde5e49be1d108e3084ec3a600

* Mon Mar 02 2020 Greg Nichols <gnichols@redhat.com>
- CERTPX-5694 RHCERT 8 POC calls to RHCert-CWE REST API    - add Partners listing page to Manage module for POC call.
- CERTPX-5614 RHCert 8 Module Top-Level React Implementation Approach    - restore POC calls to LTS/RHCert Agent on http://localhost/api (port 80).    - set up CORS headers in django for LTS    - CORS middleware in /server/project/settings.py commented out

* Fri Feb 28 2020 akshay gupta <akshgupt@redhat.com>
- CERTPX-5694: Removed unused code, updated Readme for running accessproxy

* Thu Feb 27 2020 Zahid Ajaz <zajaz@redhat.com>
- CERTPX-5898 Hypervisor/Partitioning status to exit as REVIEW for x86, x86_64 on Baremetal

* Thu Feb 27 2020 akshay gupta <akshgupt@redhat.com>
- CERTPX-5694: added accessprxy config, updated jwt-redhat

* Thu Feb 27 2020 Pooja Tiwari <ptiwari@redhat.com>
- CERTPX-5694 RHCERT 8 POC calls to RHCert-CWE REST API - Utilized 'jwt-redhat' library for sso redirection and fetch the token - TODO: fetch the token and pass it to API

* Wed Feb 26 2020 Javed Alam <jalam@redhat.com>
- CERTPX-5882 Result submission seems confusing for the first attempt     - Restricting code to submit result for NodeID '0'

* Wed Feb 26 2020 Jon Blackburn <jblackbu@redhat.com>
- Minor tweaks for the new configuration page.

* Tue Feb 25 2020 Jon Blackburn <jblackbu@redhat.com>
- Certpx-5512 updates for connect configuration hosting.

* Mon Feb 24 2020 Javed Alam <jalam@redhat.com>
- CERTPX-5702 manila_snapshot_revert_to_snapshot tests are not running     - Added conditionalize checking of PYTHONHASHSEED variables to run manila_snapshot_revert_to_snapshot tests

* Thu Feb 20 2020 Javed Alam <jalam@redhat.com>
- CERTPX-5910 baremetal_stage_deploying and redeploying test should fail when the tool could not get the demidecode from baremetal node     - Updated return parameter checking mechanism in baremetel suits.

* Thu Feb 20 2020 Petersingh Anburaj <panburaj@redhat.com>
- CERTPX-5746 Exception raised in test hwcert/info   - Added ignoreWarnings to rpm command as some warning messages were causing traceback

* Thu Feb 20 2020 Pooja Tiwari <ptiwari.redhat.com>
- Release Notes for 7.7

* Wed Feb 19 2020 Greg Nichols <gnichols@redhat.com>
- CERTPX-5614 RHCert 8 Module Top-Level React Implementation Approach    - fix broken merge

* Tue Feb 18 2020 Jon Blackburn <jblackbu@redhat.com>
- CERTPX-5512 Host RHCert Management Container on connect.redhat.com Adding updates for hosted RHCert Configuration.  Will use dockerfile to set settings and rhcert.conf information for the http server when building and pushing to mpaas.  That way we can still run and use rhcert elsehwere per usual. (cherry picked from commit fb615545bb8ed458a5ec4b2804a42e1c5becceca)

* Tue Feb 18 2020 Greg Nichols <gnichols@redhat.com>
- CERTPX-5614 RHCert 8 Module Top-Level React Implementation Approach    - improve generic rhcert module framework: separate class definitions to files

* Mon Feb 17 2020 Greg Nichols <gnichols@redhat.com>
- CERTPX-5614 RHCert 8 Module Top-Level React Implementation Approach    - revise for simplified module navigation    - improve generic rhcert module framework    - demo object view via /manage/product/<id> view

* Mon Feb 17 2020 Javed Alam <jalam@redhat.com>
- New release branch 7.8

* Wed Feb 12 2020 Pooja Tiwari <ptiwari.redhat.com>
- CERTPX-5870 Sahara is no longer supported for certification. - Remove the option of cert creation on sahara component.

* Wed Feb 12 2020 Javed Alam <jalam@redhat.com>
- CERTPX-5760 Node Dmidecode is getting displayed in a single line on CLI and UI     - Converted dmidecode o/p byte to string for formatted print view

* Wed Feb 12 2020 Greg Nichols <gnichols@redhat.com>
- CERTPX-5812 Automation scripts break as Cert id blank on landing page for newly created certification    - make sure /api/certifications returns cert_id in all cases

* Tue Feb 11 2020 Jon Blackburn <jblackbu@redhat.com>
- CERTPX-5512 Host RHCert Management Container on connect.redhat.com Adding updates for hosted RHCert Configuration.  Will use dockerfile to set settings and rhcert.conf information for the http server when building and pushing to mpaas.  That way we can still run and use rhcert elsehwere per usual.

* Mon Feb 10 2020 Javed Alam <jalam@redhat.com>
- CERTPX-5765 Collect certified container's URL and store in result xml     1) Added certified containers URL in XML

* Fri Feb 07 2020 Petersingh Anburaj <panburaj@redhat.com>
- CERTPX-5855 rhcert-cli plan command should take parameters specific to test   - Added a new option to the parser --property/-p" which takes key=value pairs   - Created a custom action "KeyValuePair" to parse the key=value pairs   - Moved option and optionparser class to separate parser.py file   - Updated rhcert-ci to use common parser class"

* Wed Feb 05 2020 Pooja Tiwari <ptiwari.redhat.com>
- CERTPX-5825 Updated Software:Hypervisor/Partitioning test to allow baremetal on x86_64

* Wed Feb 05 2020 Jon Blackburn <jblackbu@redhat.com>
- Added most of the functionality to the configuration page.  Need to finish Registered Systems.  Debug output was not in the mockup.  Do we need to add this in as well?

* Tue Feb 04 2020 Petersingh Anburaj <panburaj@redhat.com>
- Updated RN for 7.6

* Fri Jan 31 2020 Greg Nichols <gnichols@redhat.com>
- CERTPX-5614 RHCert 8 Module Top-Level React Implementation Approach    - Move certification projects to Build module    - implement prototype partner product view    - implement /api/product/<id> (cherry picked from commit b3c8ebd59ddbff5ba6efa94576e856ae766f8ad0)
- CERTPX-5692 Tracker: Certification Platform APIs for RHCert8    - filled out APIs via review of XMLRPC calls

* Wed Jan 29 2020 Greg Nichols <gnichols@redhat.com>
- CERTPX-5692 Tracker: Certification Platform APIs for RHCert8    - started API spec files

* Mon Jan 27 2020 Javed Alam <jalam@redhat.com>
- New release branch 7.7

* Mon Jan 27 2020 Petersingh Anburaj <panburaj@redhat.com>
- CERTPX-5781 RN 7.6   - Updated release notes for 7.6

* Mon Jan 27 2020 Greg Nichols <gnichols@redhat.com>
- CERTPX-5774 RHCert 8 Review Module XSLT via browser for results.xml    - simplified POC example to use default.xsl plus results.css stylesheet

* Mon Jan 27 2020 Jon Blackburn <jblackbu@redhat.com>
- Initial setup of the review section.  We can use the xsltProcessor to apply xsl stylesheets to our result xml files.

* Tue Jan 21 2020 Greg Nichols <gnichols@redhat.com>
- CERTPX-5614 RHCert 8 Module Top-Level React Implementation Approach    - Move Certification Projects to Build module

* Mon Jan 20 2020 Jon Blackburn <jblackbu@redhat.com>
- Fix for Maximum depth exceeded error when loading RHCert 8 spa
- Updates to -Fix for Maximum depth exceeded error when loading RHCert 8 spa-
- Adding fixes to broken select boxes -- still not fixed :(

* Thu Jan 16 2020 Petersingh Anburaj <panburaj@redhat.com>
- CERTPX-5703 cpuscaling fails on some Power 9 with RHEL 8 due to cpupower not supported   - Used command module's regex matching logic instead of manually doing it for cpupower command   - Added logic to use lscpu command, to get cpu numbers, if the cpupower command fails

* Thu Jan 16 2020 Greg Nichols <gnichols@redhat.com>
- CERTPX-5614 RHCert 8 Module Top-Level React Implementation Approach    - nested nav routing

* Thu Jan 16 2020 Javed Alam <jalam@redhat.com>
- CERTPX-5646 Error creating server: rh_cert_nova in baremetal_stage_deploying/redeploying subtests     - Updating flavor setting command for rhosp-15 or higher versions

* Tue Jan 14 2020 Gaurav Kamathe <gkamathe@redhat.com>
- CERTPX-5751 ping command option incorrectly printed

* Tue Jan 14 2020 Pooja Tiwari <ptiwari@redhat.com>
- CERTPX-5684 Result XML file to accommodate feature data usable for granularity - Introduced <feature> tag in output document to capture feature data. - Currently capturing feature data for Supportable/Installed RPM and Supportable/Software Repositories tests

* Mon Jan 13 2020 Greg Nichols <gnichols@redhat.com>
- CERTPX-5614 RHCert 8 Module Top-Level React Implementation Approach    - icons for cards
- CERTPX-5614 RHCert 8 Module Top-Level React Implementation Approach    - prototype top-level module navigation    - Manage->Certification Projects card view    - Manage->Products listing view    - login works    - calls rhcert api -> cwe api

* Mon Jan 13 2020 Petersingh Anburaj <panburaj@redhat.com>
- CERTPX-5696 suspend to disk being seen as suspend to mem   - Updated the suspend message as it is changed in new release   - Made it as list to support diff messages for diff versions

* Mon Jan 13 2020 Jon Blackburn <jblackbu@redhat.com>
- Changes for the new react version of the configuration page.

* Mon Jan 13 2020 Javed Alam <jalam@redhat.com>
- CERTPX-5731 Add a new test neutron_border_gateway_protocol_vpn for RHOSP-16     - Added a new feature BGPVPN in neutron plugin     - Added a new test neutron_border_gateway_protocol_vpn in neutron to support new bgpvpn tempest tests     - Added regexs for the new tempest tests

* Wed Jan 08 2020 Javed Alam <jalam@redhat.com>
- CERTPX-5442 New tempest tests in RHOSP-16 for neutron CERTPX-5444 New tempest tests in RHOSP-16 for manila     - Adding new tempest test regex for Neutron and Manila

* Tue Jan 07 2020 Zahid Ajaz <zajaz@redhat.com>
- CERTPX-5645 Cloud Image certification for RHEL8 root filesystem should be xfs and not ext4  - Updated policy mapping for supported root filesystems  - Updated file system test in alignment with policy updates

* Tue Jan 07 2020 Ben Rose <brose@redhat.com>
- CERTPX-4778 - RDMA tests - add support for Socket Direct

* Tue Jan 07 2020 Petersingh Anburaj <panburaj@redhat.com>
- CERTPX-5654 RN 7.5   - Updated Release Note for 7.5

* Mon Jan 06 2020 Petersingh Anburaj <panburaj@redhat.com>
- CERTPX-2259 Create iPXE test on hwcert   - Updated code to use ipxe-rhcert rpm

* Mon Jan 06 2020 Zahid Ajaz <zajaz@redhat.com>
- New release branch 7.6

* Fri Jan 03 2020 Javed Alam <jalam@redhat.com>
- CERTPX-5443 New tempest tests in RHOSP-16 for Cinder    - Removing new Revert to Snapshot tempest test regex for cinder as it would be part of RHOSP-16.1

* Fri Jan 03 2020 Petersingh Anburaj <panburaj@redhat.com>
- CERTPX-5711 Return drupal errors in the key resp_errors" and response data in the key "resp_data"   - Updated the key name in xmlrpc-api.yaml file"

* Tue Dec 31 2019 Petersingh Anburaj <panburaj@redhat.com>
- CERTPX-5660 cannot download submitted test results from the Progress page   - Fixed issue caused due to same key name 'data'   - Updated 'data' to 'resp_data' and 'errors' to 'resp_errors' in callProceedure" function"

* Tue Dec 31 2019 Javed Alam <jalam@redhat.com>
- CERTPX-5644 baremetal_stage_deploying test is failing with UnboundLocalError: local variable 'deploy_kernel' referenced before assignment     - Updated deploy_kernel and deploy_ramdisk image location for RHOSP-16

* Mon Dec 30 2019 Javed Alam <jalam@redhat.com>
- CERTPX-4228 In tempest_config test after generating tempest.conf it does not fit in the test window    - Shifted the submit button below the box its left aligned

* Tue Dec 24 2019 Javed Alam <jalam@redhat.com>
- CERTPX-4228 In tempest_config test after generating tempest.conf it does not fit in the test window

* Mon Dec 23 2019 Aniket Khisti <root@localhost.localdomain>
- CERTPX-5662 Move thunderbolt3 from hwcert/preview to regular hwcert package

* Tue Dec 17 2019 Javed Alam <jalam@redhat.com>
- CERTPX-5443 New tempest tests in RHOSP-16 for Cinder     - Adding new tempest test regex for cinder

* Tue Dec 17 2019 vmulaje <vmulaje@redhat.com>
- CERTPX-5668 Update success message for director test for less than 5 deployment files

* Tue Dec 17 2019 Pooja Tiwari <ptiwari@redhat.com>
- CERTPX-5671 Supportability RPM GPG check to allow https:" as valid URL prefix"

* Mon Dec 16 2019 Javed Alam <jalam@redhat.com>
- CERTPX-5669 Update RHOSP versions in unmapped tempest script     - Fixing version comparison issue in unmapped tempest script

* Thu Dec 12 2019 Petersingh Anburaj <panburaj@redhat.com>
- CERTPX-5597 test kdump - nfs produces a python stacktrace   - Handled the exception caused while opening the file
- CERTPX-5579 Rhcert to consume new APIs: Cert.getCertifications_7_4 and VendorProduct.list_7_4   - Updated the current API's with new one   - Updated alert message to show detailed error   - Updated the `callProceedure` to check for the errors from API   - Calls has been updated to handle data even when error occurs

* Thu Dec 12 2019 Greg Nichols <gnichols@redhat.com>
- CERTPX-5635 RHCert 8 Source and Release Stream Management     - added rhcert/spa for new RHCert SPA     - populated initially with a copy of /rhcert/server/react     - started clean-up/mock-up of new UI approach

* Wed Dec 11 2019 Javed Alam <jalam@redhat.com>
- CERTPX-5617 Director test is failing on Controller and compute node due to less than 5 deployment files     - Updated director deployment check command for RHOSP-16

* Mon Dec 09 2019 Petersingh Anburaj <panburaj@redhat.com>
- New release branch 7.5

* Mon Dec 09 2019 Prerana Sharma <presharm@redhat.com>
- added content for RN 7.4

* Fri Dec 06 2019 Zahid Ajaz <zajaz@redhat.com>
- CERTPX-5209 Added 'satellite' as a valid yum repository source

* Fri Dec 06 2019 Greg Nichols <gnichols@redhat.com>
- CERTPX-5643 RHCert management-only attempts to save certification info to disk     change cweSync api to only run for default configurations

* Thu Dec 05 2019 yangli <yangli@redhat.com>
- CERTPX-5622: add Cert.getOpenTestsInfo_7_4

* Wed Dec 04 2019 vmulaje <vmulaje@redhat.com>
- CERTPX-5633 Rhcert to consume new API: Cert.getOpenTestsInfo_7_4

* Wed Dec 04 2019 Aniket Khisti <akhisti@redhat.com>
- CERTPX-5182 Add a Thunderbolt 3 test to RHEL 8 Hardware Certification  - rename test name from 'thunderbolt' to 'thunderbolt3'  - rename 'hot-plug' to 'hotplug'  - remove assertive statements mentioning socket number as the test    can't really identify which one it is, due to hardware limitations

* Mon Dec 02 2019 Javed Alam <jalam@redhat.com>
- CERTPX-5627 unformatted tempest_tests.json file in /usr/lib/python3.6/site-packages/rhcert/suites/openstack_cert/data

* Sun Dec 01 2019 Ben Rose <brose@redhat.com>
- CERTPX-4778: RDMA tests - add support for Socket Direct

* Fri Nov 29 2019 Javed Alam <jalam@redhat.com>
- CERTPX-5626  Keeping '' cinder_backup as test name as well as in xmlrpc request body instead of "cinder_backups"     - Renaming test name `cinder_backups` as `cinder_backup`"

* Wed Nov 27 2019 jialli <jialli@redhat.com>
- CERTPX-5387: update rhcert xmlrpc apis yaml doc

* Thu Nov 21 2019 Petersingh Anburaj <panburaj@redhat.com>
- CERTPX-5464 battery test fails on 2nd battery due to unknown POWER_SUPPLY_STATUS   - Updated code to check battery status using upower if it is unknown

* Thu Nov 21 2019 Javed Alam <jalam@redhat.com>
- CERTPX-5580 Add tests specific to different plugins like neutron, manilla, cinder etc in RHOSP-16     - Added tests specific to different plugins like neutron, manilla, cinder etc in RHOSP-16
- CERTPX-5486 Traceback in rhcert-util     - Conditionalizing rhcert-util and removing 'rhcert-util clean local storage' from rhel6
- CERTPX-5569 remove sahara package dependency as it is deprecated from RHOSP 16     - Removing sahara package dependency as it is deprecated from RHOSP 16

* Thu Nov 21 2019 Prerana Sharma <presharm@redhat.com>
- added content for RN 7.3

* Wed Nov 20 2019 Petersingh Anburaj <panburaj@redhat.com>
- CERTPX-2259 Create iPXE test on hwcert   - Added the bytes to str conversion in rhcert_make_str function for python3 in exception block   - Updated the logic in rhcert_make_str function for list conversion

* Mon Nov 18 2019 Javed Alam <jalam@redhat.com>
- CERTPX-5529 Adding RHOSP 16(Train) in supported version of RCO     - Added version 16 in necessary places     - Added the list of tempest test

* Mon Nov 18 2019 Zahid Ajaz <zajaz@redhat.com>
- redhat-certification==7.4

* Fri Nov 15 2019 Javed Alam <jalam@redhat.com>
- CERTPX-5565 Typo in redhatrelease.py    - Typo corrected

* Thu Nov 14 2019 Aniket Khisti <akhisti@redhat.com>
- CERTPX-5182 Add a Thunderbolt 3 test to RHEL 8 Hardware Certification  - fix a bug in listener/serverUI to log prompt messages in results-file  - fix a bug in preview/thunderbolt to use unicode/str with python2/3  - remove redudant statusMessages informing what prompt does,    now that the prompt-messages are being logged in the results files  - fix a bug due to which test is unable to identify device type &    version, if encountered already plugged-in thunderbolt device  - handle the user-fault fail-cases/exits gracefully

* Wed Nov 13 2019 Aniket Khisti <akhisti@redhat.com>
- CERTPX-5182 Add a Thunderbolt 3 test to RHEL 8 Hardware Certification  - fixed a bug in promptInteger() of rhcert/commandLineUI to flush stdout  - changed a prompt() to promptConfirm() during fv planning to maintain consistency  - added thunderbolt device hotplug test in hwcert/preview suite for RHEL8 only   - test & repeat for number of user specified thunderbolt devices & sockets   - guess the connected thunderbolt device version, type - USB, PCI, Display

* Wed Nov 13 2019 Javed Alam <jalam@redhat.com>
- CERTPX-5489 cannot install redhat-certification on rhel8 due to policycoreutils-python dependency     - Added a check in spec file for RHEL-7 and RHEL-8 package dependency

* Mon Nov 11 2019 Javed Alam <jalam@redhat.com>
- CERTPX-5489 cannot install redhat-certification on rhel8 due to policycoreutils-python dependenciy     - Added a check in spec file for the RHEL-7 and RHEL-8 package dependency
- Revert CERTPX-5489 cannot install redhat-certification on rhel8 due to policycoreutils-python dependenciy     - Added a check in spec file for the RHEL-7 and RHEL-8 package dependency""

* Wed Oct 30 2019 Zahid Ajaz <zajaz@redhat.com>
- redhat-certification==7.3

* Tue Oct 29 2019 Greg Nichols <gnichols@redhat.com>
- CERTPX-5477 RHEL7 Cloud configuration test appears to hang if services test fails    - replace Utility with Command class

* Fri Oct 25 2019 Javed Alam <jalam@redhat.com>
- CERTPX-5341 rhcert-util command to clean out all local storage   - Added a command line utility called clean local storage" to clean out local storage and to restore RHCert's server to an initial state."
- CERTPX-5341 rhcert-util command to clean out all local storage   - Added a command line utility called clean local storage" to clean out local storage and to restore RHCert's server to an initial state.\"

* Fri Oct 25 2019 Prerana Sharma <presharm@redhat.com>
- content added for RN 7.1
- added content for RN 7.2

* Fri Oct 25 2019 Greg Nichols <gnichols@redhat.com>
- CERTPX-5472 [CCSP] Ascii traceback in Configuration test

* Thu Oct 24 2019 Zahid Ajaz <zajaz@redhat.com>
- CERTPX-5465  Supportable Modules subtest failures     - Refactored the test to decrease the use of command ouputs     - get repo name/id from get_repos() function outputs directly     - removed get_repo_names() function

* Wed Oct 23 2019 Zahid Ajaz <zajaz@redhat.com>
- CERTPX-5381 Traceback in Software Modules test  - Fixed the regression caused from fix to CERTPX-5366

* Thu Oct 17 2019 akshay gupta <akshgupt@redhat.com>
- CERTPX-5242: React Main Pages: Not brought to login page after rhcertd restart 	- Also clearing session on logout Change-Id: Ia4a116480a42bc2b45d71db780f0ea73a0cd3dd4

* Thu Oct 17 2019 Greg Nichols <gnichols@redhat.com>
- CERTPX-5407 Sandboxes cannot be deleted    - moved redundant code to a function

* Wed Oct 16 2019 Petersingh Anburaj <panburaj@redhat.com>
- CERTPX-5417 battery test selects wrong battery when laptop has 2 batteries   - Fixed the code to compare the battery and select the correct one

* Wed Oct 16 2019 Greg Nichols <gnichols@redhat.com>
- CERTPX-5407 Sandboxes cannot be deleted    - added action pull-down to sandbox listing    - added delete action with confirmation dialog

* Tue Oct 15 2019 akshay gupta <akshgupt@redhat.com>
- CERTPX-5432: Multiple tables and scroll bars displayed in Products tab when changed no.of entries to 30 	- changed legacy products page visiblity

* Tue Oct 15 2019 Greg Nichols <gnichols@redhat.com>
- CERTPX-5432 Multiple tables and scroll bars displayed in Products tab when changed no.of entries to 30     - remove legacy implementation of products listing page

* Mon Oct 14 2019 Greg Nichols <gnichols@redhat.com>
- CERTPX-5407 Sandboxes cannot be deleted

* Fri Oct 11 2019 Petersingh Anburaj <panburaj@redhat.com>
- CERTPX-4778 - RDMA tests - add support for Socket Direct   - Fixed the traceback : TabError: inconsistent use of tabs and spaces in indentation

* Wed Oct 09 2019 Ben Rose <brose@redhat.com>
- CERTPX-4778 - RDMA tests - add support for Socket Direct - Initial commit of Infiniband_Socket_Direct test

* Mon Oct 07 2019 Greg Nichols <gnichols@redhat.com>
- merge

* Mon Oct 07 2019 Zahid Ajaz <zajaz@redhat.com>
- redhat-certification==7.2

* Mon Oct 07 2019 Ben Rose <brose@redhat.com>
- CERTPX-2123 - remove old infiniband test after implementing speed checking rdma tests - Removed files and references in dunder init and make file

* Fri Oct 04 2019 Greg Nichols <gnichols@redhat.com>
- CERTPX-5382 Software Supportable/RPM validation should return Review

* Fri Oct 04 2019 Pooja Tiwari <ptiwari@redhat.com>
- CERTPX-5346 [RHOSP Trusted Container] Add image's ID too in <certified_container> tag - rhcert-util update should add the certified_container tag in updated result.

* Thu Oct 03 2019 akshay gupta <akshgupt@redhat.com>
- CERTPX-5365: Incorrect links are shown when cursor hovered from Certification/Sandboxes/Test Result tabs 	- switched to Link instead of history.push

* Wed Oct 02 2019 Greg Nichols <gnichols@redhat.com>
- CERTPX-5319 React Main Pages: Results listing should have sandbox links when not logged in
- CERTPX-5370 Test Result page is empty

* Tue Oct 01 2019 Zahid Ajaz <zajaz@redhat.com>
- CERTPX-5366 RHCERT CCSP: Minor bug in supportable test  - Fix for handling empty repo list in supportable test

* Tue Oct 01 2019 Greg Nichols <gnichols@redhat.com>
- CERTPX-5242 React Main Pages: Not brought to login page after rhcertd restart    - change Please log in" link in Alert to /logout to clear old session    - change redirect when not logged in on Certifications to /logout back to server"

* Mon Sep 30 2019 akshay gupta <akshgupt@redhat.com>
- CERTPX-5330: Products Listing Page 	- Added space betwwen make and model in lisiting

* Mon Sep 30 2019 Petersingh Anburaj <panburaj@redhat.com>
- CERTPX-2259 Create iPXE test on hwcert   - Updated the test name to iPXE instead of ipxe   - Divided the test into two subtests   - Added some print statements for clear logging

* Mon Sep 30 2019 Pooja Tiwari <ptiwari@redhat.com>
- CERTPX-5346 [RHOSP Trusted Container] Added image's ID in <certified_container> tag - Updated XML tag structure to capture image SHAs.

* Mon Sep 30 2019 Greg Nichols <gnichols@redhat.com>
- CERTPX-5330 Products Listing Page     - don't show fake products that are sandbox names.
- CERTPX-5242 React Main Pages: Not brought to login page after rhcertd restart    - change Please log in" link in Alert to /logout to clear old session"

* Fri Sep 27 2019 Petersingh Anburaj <panburaj@redhat.com>
- CERTPX-5224 Wireless_n and Wireless_g failing on RHEL 8.1   - Wrap the interface connection call with a waiting loop to confirm that interface is up   - Updated the logOnly function to remove the bad charecters from the command output

* Fri Sep 27 2019 Greg Nichols <gnichols@redhat.com>
- CERTPX-5349 Define Program <-> Ecosystem mapping in RHCert

* Fri Sep 27 2019 akshay gupta <akshgupt@redhat.com>
- CERTPX-5347: sandboxes have gone missing from Sandboxes page 	- Fixed syntax error for getTableRow

* Thu Sep 26 2019 akshay gupta <akshgupt@redhat.com>
- CERTPX-5330: Products Listing Page 	- Added product listing page with it's actions and reducers 	- Added middleware for removing data key from api responses 	- Cleaned up tootbar for tables and created utils files for table utils

* Wed Sep 25 2019 Petersingh Anburaj <panburaj@redhat.com>
- CERTPX-2259 Create iPXE test on hwcert   - Implemented the iPXE test in hardware preview package   - Updated the _run function in rhcert/command.py file, made the subprocess logic similar to start function   - Added GET logic for collab call to call a func on LTS   - Updated rhcert_make_str function to handle bytes   - TODO: Add logic to download the rhcert.efi file

* Wed Sep 25 2019 Greg Nichols <gnichols@redhat.com>
- CERTPX-5318 Pilot RHCert partition local data by user     - fix rhcert-cli registration from SUT adding login if server is multistore     - fix registration on Configuration page     - fix testing via marking request documents with store path info

* Tue Sep 24 2019 Javed Alam <jalam@redhat.com>
- CERTPX-4981 After clicking on saved multihost result it is showing only single host(compute) results   - Added check for multihost file   - Added new url for multihost file save

* Mon Sep 23 2019 Greg Nichols <gnichols@redhat.com>
- CERTPX-5330 Products Listing Page     - added /api/products

* Mon Sep 23 2019 akshay gupta <akshgupt@redhat.com>
- CERTPX-5290: Uploading results file does not work if directory path is long - appears filename is not saved with *.xml.gz 	- added .gz in file extension list

* Thu Sep 19 2019 Greg Nichols <gnichols@redhat.com>
- CERTPX-5318 Pilot RHCert partition local data by user     - fixed attribute name
- CERTPX-5318 Pilot RHCert partition local data by user     - revised code to determine path to store based on multistore-enabled setting.
- CERTPX-5303 Word syncronization and syncronizing words are spelled wrong

* Wed Sep 18 2019 akshay gupta <akshgupt@redhat.com>
- CERTPX-5309: Withdrawn Certs Status should be shown in RED 	- Added withdrawn status for cert status

* Wed Sep 18 2019 Zahid Ajaz <zajaz@redhat.com>
- CERTPX-5208 Software Modules test always failed  - Bug fix for invlid repo url mapping
- CERTPX-5208 Software Modules test always failed  - Refactored the sub-test

* Wed Sep 18 2019 Greg Nichols <gnichols@redhat.com>
- CERTPX-5301 Document new rhcert API    - completed initial version

* Wed Sep 18 2019 Petersingh Anburaj <panburaj@redhat.com>
- CERTPX-5195 7.0 release notes   - Updated release notes

* Tue Sep 17 2019 Greg Nichols <gnichols@redhat.com>
- CERTPX-5301 Document new rhcert API    - first draft
- CERTPX-5218 React Main Pages: Results File Import should import to a certification    - Fixed import resulting in unnamed sandboxes breaks Sandboxes listing    - Fixed URL generated in Alert after import of sandboxes to use sandbox URL
- CERTPX-5218 React Main Pages: Results File Import should import to a certification for Testing and Progress tabs     - fix results URL in success alert

* Tue Sep 17 2019 akshay gupta <akshgupt@redhat.com>
- CERTPX-5298: Sandboxing option is available in management configuration on login page 	- added condition for management config

* Mon Sep 16 2019 Zahid Ajaz <zajaz@redhat.com>
- redhat-certification==7.1

* Fri Sep 13 2019 akshay gupta <akshgupt@redhat.com>
- CERTPX-5119: React Main Pages: Certifications listing defects & improvements 	- Added success color for certified supported 	- added check for rhcert status to stop listing components re-rendering
- CERTPX-5289: RHCert should show hydra DB ID as certification ID"

* Fri Sep 13 2019 Greg Nichols <gnichols@redhat.com>
- CERTPX-5280 React Main Pages: Duplicate alerts showing in the Certification page    - Fix initialization of API base class for per-request initialization
- CERTPX-5289 RHCert should show hydra DB ID as certification ID"

* Thu Sep 12 2019 akshay gupta <akshgupt@redhat.com>
- CERTPX-4912: React Main Pages: Alerts for api status errors 	 - Added api error message for 500 error

* Thu Sep 12 2019 Greg Nichols <gnichols@redhat.com>
-  CERTPX-5004 React Main Pages: Login page needs Opt-out for disconnected access     - changed to Continue to Sandboxes" for opt-out"
- CERTPX-5218 React Main Pages: Results File Import should import to a certification    - fix case where upload is not to be associated with a cert
- CERTPX-5280 React Main Pages: Duplicate alerts showing in the Certification page   - clear django messages prior to sending response as meta" json"

* Wed Sep 11 2019 akshay gupta <akshgupt@redhat.com>
- CERTPX-5119: React Main Pages: Certifications listing defects & improvements         - Added colored label for cert status
- CERTPX-5218: React Main Pages: Results File Import should import to a certification for Testing and Progress tabs 	 - Fixed a type descriptor issue
- CERTPX-5131: React Main Pages: Login page Logo and Background 	- Added RH logo at top right
- CERTPX-5276:  React Main Pages: RHCert api errors not reported 	- Fixed handle error function
- CERTPX-5266: Certifications listing needs Category column

* Wed Sep 11 2019 Greg Nichols <gnichols@redhat.com>
- CERTPX-4912 React Main Pages: Alerts for api status errors     - catch api tracebacks and report them

* Tue Sep 10 2019 Greg Nichols <gnichols@redhat.com>
- CERTPX-5257 React Main Pages: Sandboxes are out of order     - change to sort first by program, and second by name

* Mon Sep 09 2019 Greg Nichols <gnichols@redhat.com>
- CERTPX-4882 React Main Pages: Login Page Layout    - update logos
- CERTPX-5266 Certifications listing needs Category column
- CERTPX-5254 WebUI clicking on last page takes user to blank screen    - Changed /api/certifications to skip certs missing product info    - added warning messages via {meta: [<Alert>]} json

* Mon Sep 09 2019 akshay gupta <akshgupt@redhat.com>
- CERTPX-5254: WebUI clicking on last page takes user to blank screen 	- Added messages handler middleware for api messages 	- Fixed banner message being shown without a message issue

* Fri Sep 06 2019 Greg Nichols <gnichols@redhat.com>
- CERTPX-5258 React Main Pages: No test results visible in Test Results tab when not logged in
- CERTPX-5242 React Main Pages: Not brought to login page after rhcertd restart     - changed wsgi.api.certifications.Certifications to derive from API     - set login required
- CERTPX-4881 React Main Pages: CWE Sync    - fixed error in debug logging causing traceback on python 2.7    - turn off debug logging
- CERTPX-5218 React Main Pages: Results File Import should import to a certification    - Fixed update and submit actions for POST to /api/results
- CERTPX-5218 React Main Pages: Results File Import should import to a certification    - fixed syntax error

* Fri Sep 06 2019 akshay gupta <akshgupt@redhat.com>
- CERTPX-4909: React Main Pages: Masthead and vertical navigation 	- Added import results button
- CERTPX-5120: React Main Pages: Sandbox listing defects & improvements 	- Fixed order of sandbox listing columns
- CERTPX-5236: RHCert landing page showing cert_id instead of cert_nid 	- Switched to cert_nid in certifications listing
- CERTPX-5242: React Main Pages: Not brought to login page after rhcertd restart 	- clearing session if cwe-status call returns not logged in 	- Added 401 check in certifications api call
- CERTPX-5218: React Main Pages: Results File Import should import to a certification for Testing and Progress tabs 	- fixed a syntax error in results.py 	- Disabled checkboxes and dropzone during upload 	- Fixed crash issue for Request Errors

* Fri Sep 06 2019 Pooja Tiwari <ptiwari@redhat.com>
- CERTPX-5252 Added a tag in RHOSP result xml to capture certified container SHAs - This is required for RHOSP-15 finger priniting - CWE to consume this data and supply it in rhosp GET cert case API

* Thu Sep 05 2019 Greg Nichols <gnichols@redhat.com>
- CERTPX-5218 React Main Pages: Results File Import should import to a certification    - added checkboxes to select whether to import to cert (default) or also submit    - Changed API call to take certification program, id, and importAction
- CERTPX-4881 React Main Pages: CWE Sync    - change background sync time to 30 min    - change rhcert-version check to 60 min
- CERTPX-5231 Typo in WebUI Certifications page    - fixed Porgram""

* Thu Sep 05 2019 akshay gupta <akshgupt@redhat.com>
- CERTPX-4909: React Main Pages: Masthead and vertical navigation 	- switched back to icons on masthead 	- added create certification button in toolbar listing
- CERTPX-4911: Fixed import request issue
- CERTPX-4827: Move to React: MVP Implement Main Pages 	- fixed not able to login issue 	- removed synchronization message
- CERTPX-5227: fixed toolbar visibility issues
- CERTPX-5134: React Main Pages: showing black page with Firefox             - Added cwe-status call after login to get session id             - Modified login call for better error message handling
- CERTPX-5004: React Main Pages: Login page needs Opt-out for disconnected access 	- Added auto redirect for logged in users 	- Added conditions for hiding side nav bar tabs

* Thu Sep 05 2019 Javed Alam <jalam@redhat.com>
- CERTPX-5209 Blacklist CDN in CCSP Supportable/Software Repositories test   - Removed cdn.redhat.com" from the cloud certifications   - Redesigned the get_policy method to differentiate the policies between cloud and software certs"

* Wed Sep 04 2019 Greg Nichols <gnichols@redhat.com>
- CERTPX-5218 React Main Pages: Results File Import should import to a certification    - added code to set certification program and id as import state    - added text to toolbar icons for New Certification and Import Results
- CERTPX-4996 React Main Pages: Certifications/cwe-sync api working without authorization     - Fixed calls when sync is already running
- CERTPX-5134 React Main Pages: showing black page with Firefox     - remove extrainious code from wsgi.main.main.Main
- CERTPX-5134 React Main Pages: showing black page with Firefox     - remove login/session editing from wsg.main.login.Login

* Wed Sep 04 2019 Javed Alam <jalam@redhat.com>
- CERTPX-5210 RPM Freshness sub-test in Software/Supportable test   - Added RPM Freshness sub-test in Software/Supportable test   - Created a new module for RPM Freshness sub-test and moved it to common directory

* Tue Sep 03 2019 Pooja Tiwari <ptiwari@redhat.com>
- CERTPX-5222 [RHOSP-15] Fixed error while running baremetal test on ppc64le - Fixed keyError due to missing user param:pm_user in instackenv.json - The pm_user name is optional while using ipmitool command

* Tue Sep 03 2019 akshay gupta <akshgupt@redhat.com>
- CERTPX-5004: updated react and redirect for logged in user
- CERTPX-5004 - Added conditions to hide side navbar tabs

* Tue Sep 03 2019 Greg Nichols <gnichols@redhat.com>
- Revert CERTPX-5004 - Added conditions to hide side navbar tabs""
- Revert CERTPX-5004: updated react and redirect for logged in user""
- CERTPX-5134 React Main Pages: showing black page with Firefox     - change /api/login to return django session id

* Fri Aug 30 2019 Greg Nichols <gnichols@redhat.com>
- CERTPX-4911 React Main Pages: Test Results Upload Modal    - fix error messages to report api errors    - fixed success messages
- CERTPX-4881 React Main Pages: CWE Sync    - revised messages returned by /api/cwe-sync    - fixed message reporting of sync messages    - added an info message at sync start    - increased info alert timeout from 3 to 10 sec    - fixed rhcert config settings for date range

* Fri Aug 30 2019 akshay gupta <akshgupt@redhat.com>
- CERTPX-5127: Fixed test result upload

* Fri Aug 30 2019 Javed Alam <jalam@redhat.com>
- CERTPX-5211 SELinux enforcing sub-test in Software/Supportable test   - Added SELinux enforcing sub-test in Software/Supportable test

* Thu Aug 29 2019 akshay gupta <akshgupt@redhat.com>
- CERTPX-5129: added django message post redirect

* Thu Aug 29 2019 Greg Nichols <gnichols@redhat.com>
- CERTPX-4911 React Main Pages: Test Results Upload Modal    - improve error detection for file importing to rhcertStore    - change api response status to 400 on import failure
- release 7.0
- CERTPX-5157 React Main Pages: Unable to create new Product - Choose the Certification page has wrong headers

* Thu Aug 29 2019 Javed Alam <jalam@redhat.com>
- CERTPX-5096 RHOSP 15 certification test suite should validate the status of OVN - Introduced a new test called openstack_configuration" for Manila and Neutron plugins. - Added a subtest called "OVN_configuration" and should be responsible for checking the status of OVN - Added a check to plan this test for RHOSP-15 and onwards. - ml2_conf.ini as a test attachment"

* Wed Aug 28 2019 akshay gupta <akshgupt@redhat.com>
- CERTPX-4911: Added result listing refresh system after uploading test results
- CERTPX-5132: added all cloumn listing filter

* Wed Aug 28 2019 Zahid Ajaz <zajaz@redhat.com>
- CERTPX-5208 'Software Modules' test always fails   - Fixed the bug   - Issue: change in 'yum module info <module>' command output Change-Id: I7ea26b45c72e3c8fd08017be38e22983bbbeb5b5

* Wed Aug 28 2019 Greg Nichols <gnichols@redhat.com>
- CERTPX-5176 React Main Pages: Sandboxes and test result listing api giving 401 error

* Tue Aug 27 2019 akshay gupta <akshgupt@redhat.com>
- CERTPX-4827: moved uploading system to redux
- Switched to internal npm repo

* Mon Aug 26 2019 akshay gupta <akshgupt@redhat.com>
- CERTPX-4827:  Added check for api when user is unauthenticated

* Mon Aug 26 2019 Zahid Ajaz <zajaz@redhat.com>
- Release Version==6.16

* Mon Aug 26 2019 Javed Alam <jalam@redhat.com>
- CERTPX-5097 Require certifying with NeutronNetworkPlugin if driver runs in DHSS=True mode - Added precheck in manila_shares for DHSS, network_api_class and multitenancy - Manila.conf as a test attachment - An intercative question added (disbled for CI) - Special handling for CIFS protocol.

* Mon Aug 26 2019 Pooja Tiwari <ptiwari@redhat.com>
- CERTPX-5192 New regex added to accommodate old-missing/new tempest tests of Neutron.

* Fri Aug 23 2019 Pooja Tiwari <ptiwari@redhat.com>
- CERTPX-5185 Release notes for 6.15
- Updated RHOSP-14 tempest test list.
- CERTPX-5193 [ISV] Traceback when adding a support case or a kbase against a certification

* Wed Aug 21 2019 akshay gupta <akshgupt@redhat.com>
- CERTPX-4912: Added alerts for request errors

* Fri Aug 16 2019 Javed Alam <jalam@redhat.com>
- CERTPX-5125 Director Template disable issue in Firefox browser 	- Fixed Director Template" disablement issue in firefox browser"

* Tue Aug 13 2019 akshay gupta <akshgupt@redhat.com>
- CERTPX-5134: added authentication details injector middleware
- CERTPX-5152: Added link on logo click

* Thu Aug 08 2019 Greg Nichols <gnichols@redhat.com>
-  CERTPX-5004 React Main Pages: Login page needs Opt-out for disconnected access     - implemented return-after" query string to support post-login redirection"
- CERTPX-5121 React Main Pages: Test Results listing defects & improvements    - added Product column for vendor/partner product being certified    - fixed certification column

* Wed Aug 07 2019 Aniket Khisti <akhisti@redhat.com>
- CERTPX-5115 adding the check_unsupported_hardware" to openstack certification - enable checking unsupported hardware subtest under supportable tests of openstack_cert suite"
- CERTPX-5114 adding the check_unsupported_hardware" to hardware certification  - enable checking unsupported hardware subtest under info tests of hwcert suite"

* Wed Aug 07 2019 Greg Nichols <gnichols@redhat.com>
- CERTPX-5076 login after timeout not working - Error: Unable to authenticate user    - fixed login modal to correctly POST to /login, as it was essentially opting out of login (cherry picked from commit 3cfad2dc3d96f1ff2b54a81f1c44e6b60765fa33)

* Tue Aug 06 2019 akshay gupta <akshgupt@redhat.com>
- CERTPX-4826: added session validity on alerts
- CERTPX-4911: Fixed css issue and add check for file upload types

* Tue Aug 06 2019 Greg Nichols <gnichols@redhat.com>
- CERTPX-4911 React Main Pages: Test Results Upload Modal    - fix content type detection for django 1.8 and 1.11

* Tue Aug 06 2019 Pooja Tiwari <ptiwari@redhat.com>
- CERTPX-5032 6.14 release notes

* Mon Aug 05 2019 Pooja Tiwari <ptiwari@redhat.com>
- CERTPX-4661 Added new feature regexes for Manila.

* Mon Aug 05 2019 Greg Nichols <gnichols@redhat.com>
- CERTPX-5120 React Main Pages: Sandbox listing defects & improvements   - fixed column order   - removed -" and platform"
- CERTPX-5131 React Main Pages: Login page Logo and Background    - removed subtitle and editted title to match typical usage on *.redhat.com
- CERTPX-5130 React Main Pages: Results File Import    - added masthead toolbar icons for file import and new certification    - removed new certication button from Certifications page    - removed Upload Results File from Test Results page
- CERTPX-5121 React Main Pages: Test Results listing defects & improvements    - sort REST api responses for Certifications, Sandboxes, and TestResults listing
- CERTPX-5121 React Main Pages: Test Results listing defects & improvements    - remove Data Updated column and re-order per Jira

* Mon Aug 05 2019 Zahid Ajaz <zajaz@redhat.com>
- redhat-certification==6.15

* Mon Aug 05 2019 jialli <jialli@redhat.com>
- CERTPX-5019: update spec file to include director related fields

* Fri Aug 02 2019 akshay gupta <akshgupt@redhat.com>
- CERTPX-4826: added cookie trail to keep track of top banner actions
- CERTPX-4826: fixed alert box-shadow issue
- CERTPX-4826: moved alerts to pf4

* Fri Aug 02 2019 Greg Nichols <gnichols@redhat.com>
- CERTPX-5121 React Main Pages: Test Results listing defects & improvements    - implemented links    - remove Data Updated column and re-order per Jira    = todo: sorting table

* Fri Aug 02 2019 Javed Alam <jalam@redhat.com>
- CERTPX-4995 : Add a field for gathering text, attachment or URL for director (heat) templates for each RHOSP & VNF certification 	1) Removed global variable for in-memory content save 	2) Added check for management" and "other" plugin 	3) Extended file format that can be uploaded as "Director Integration""

* Wed Jul 31 2019 Pooja Tiwari <ptiwari@redhat.com>
- CERTPX-5109 Software product creation should be restricted via Rhcert.
- Updated spec file for new software xmlrpc APIs.

* Tue Jul 30 2019 Pooja Tiwari <ptiwari@redhat.com>
- CERTPX-4905 Made the default value for region name work for CLI too along with UI.

* Tue Jul 30 2019 Greg Nichols <gnichols@redhat.com>
- CERTPX-4911 React Main Pages: Test Results Upload Modal    - implement POST to /api/results for results file upload
- CERTPX-4911 React Main Pages: Test Results Upload Modal    - implement calls to post uploads to server    - add progress indications to modal

* Mon Jul 29 2019 akshay gupta <akshgupt@redhat.com>
- CERTPX-4911: switched to pf4 modal
- CERTPX-4827 CERTPX-4910: switched to pf4 for table listing

* Mon Jul 29 2019 Greg Nichols <gnichols@redhat.com>
- CERTPX-4827 Implement Main Pages in Patternfly-React    - fix layout for announcement and version alerts on Certifications tab.

* Mon Jul 29 2019 Javed Alam <jalam@redhat.com>
- CERTPX-4995 : Add a field for gathering text, attachment or URL for director (heat) templates for each RHOSP & VNF certification 	1) Added a field for gathering director integration details on osp cert creation page 	2) Added an attachment field for director integration details 	3) Made install guide field mandatory

* Thu Jul 25 2019 Pooja Tiwari <ptiwari@redhat.com>
- CERTPX-4905 tempest_config test failing due to missing region name parameter - Added code to get region name from user and export OS_REGION_NAME

* Tue Jul 23 2019 Pooja Tiwari <ptiwari@redhat.com>
- CERTPX-4964 [MVP] ISV Software Certification - CERTPX-4969 Rhcert should be able to distinguish OpenStack and Software Program/Certs - CERTPX-4956 Enable ISV Software Certification Sandboxes

* Fri Jul 19 2019 Greg Nichols <gnichols@redhat.com>
- CERTPX-4827 Implement Main Pages in Patternfly-React    - fix closing alerts

* Fri Jul 19 2019 akshay gupta <akshgupt@redhat.com>
- CERTPX-4827: added back pf3

* Thu Jul 18 2019 akshay gupta <akshgupt@redhat.com>
- CERTPX-4827: added pf4 based table

* Thu Jul 18 2019 Greg Nichols <gnichols@redhat.com>
- CERTPX-4827 Implement Main Pages in Patternfly-React    - update banner and cwe status/supported version to PF4 components    - move the above to only appear on the Certifications page

* Wed Jul 17 2019 akshay gupta <akshgupt@redhat.com>
- CERTPX-4827: fixed height issue with root node

* Wed Jul 17 2019 atandale <atandale@redhat.com>
- CERTPX-4991 Fixed tempest test execution on RHOSP-14 due to usage of ostestr - Used 'tempest' cmd for >=13 versions. - From RHOSP-13 onwards, tempest run is used as a replacement of ostestr.

* Tue Jul 16 2019 akshay gupta <akshgupt@redhat.com>
- CERTPX-4827 : added basic page layout with PF4
- CERTPX-4827: Added types for redux-api-middleware

* Tue Jul 16 2019 Greg Nichols <gnichols@redhat.com>
- CERTPX-4827 Implement Main Pages in Patternfly-React    - added/changed apis to support configuration page

* Mon Jul 15 2019 akshay gupta <akshgupt@redhat.com>
- CERTPX-5004: continue to sandbox without logging in

* Mon Jul 15 2019 Pooja Tiwari <ptiwari@redhat.com>
- CERTPX-5012 Changed playback-kernel service endpoint in rhcert - The api versions v1 and v2 have been unified in playback-1.4.0 - The v2 will deprecate soon (after three rhcert releases).

* Mon Jul 15 2019 Zahid Ajaz <zajaz@redhat.com>
- redhat-certification==6.14

* Fri Jul 12 2019 akshay gupta <akshgupt@redhat.com>
- CERTPX-4882: added PF4 login page

* Fri Jul 12 2019 Prerana Sharma <presharm@redhat.com>
- content added for RN 6.13

* Fri Jul 12 2019 Greg Nichols <gnichols@redhat.com>
- CERTPX-4827 Implement Main Pages in Patternfly-React    - changed django templates so main and login pages do not pull in bootstrap or patternfly via /rhcert/js
- CERTPX-4882 React Main Pages: Login Page Layout    - make new PF4 login page at /login

* Fri Jul 12 2019 Pooja Tiwari <ptiwari@redhat.com>
- Fixed the print syntax to make it work for python3

* Thu Jul 11 2019 Greg Nichols <gnichols@redhat.com>
- CERTPX-4994 Cancel at login screen gives error
- CERTPX-4911 React Main Pages: Test Results Upload Modal    - tweek css and text to make it more PF3-like
- fix merge

* Tue Jul 09 2019 akshay gupta <akshgupt@redhat.com>
- CERTPX-4827: restrutured to properly make api calls

* Tue Jul 09 2019 Greg Nichols <gnichols@redhat.com>
- CERTPX-4996 React Main Pages: Certifications/cwe-sync api working without authorization     - set up api default to loginRequired, returns 401 error

* Mon Jul 08 2019 Javed Alam <jalam@redhat.com>
- CERTPX-4693 Make baremetal cert code compatible across python-2.7 and 3 	- Fixed TypeErrors: 'dict_keys' object does not support indexing

* Mon Jul 08 2019 Petersingh Anburaj <panburaj@redhat.com>
- CERTPX-325 Implement or port Bluetooth LE test (or include in regular bluetooth test)   - Removed multithreading and made serverAgent to run in background   - Added code to start the bluetooth if that is stopped   - Did some changes to serverAgent so that it gets terminated properly

* Mon Jul 08 2019 Greg Nichols <gnichols@redhat.com>
- CERTPX-4827 Implement Main Pages in Patternfly-React    - fixed not logged in" reported when actually logged in"

* Mon Jul 08 2019 akshay gupta <akshgupt@redhat.com>
- CERTPX-4827: added login for errors and error css

* Thu Jul 04 2019 Pooja Tiwari <ptiwari@redhat.com>
- CERTPX-4661 Addressing new API test addition for RHOSP 15 - Added a new script to identify the new and unmapped tests for a new RHSOP version. - Modified feature_test_map to make it work for new script. - Fixed the json

* Thu Jul 04 2019 Petersingh Anburaj <panburaj@redhat.com>
- CERTPX-4748 Implement profiling for instance which don't support PMU   - Updated the detection logic as cpu*cycles file is present in aarch64 system in different directory   - Replaced test -e /sys/devices/cpu/events/cpu-cycles" with "find /sys/devices/* -type f -name 'cpu*cycles'""

* Tue Jul 02 2019 Petersingh Anburaj <panburaj@redhat.com>
- CERTPX-4937 2.5GRoCE/5GRoCE tests are required for RDMA devices in redhat-certification-hardware CERTPX-4938 vmw_pvrdma driver should be added to detect the vrdma device   - Added 2 new RDMA tests 5GigRoCE and 2_5GigRoCE   - Added 'vmw_pvrdma' to driverModules for RoCEConnectionTest   - Fixed the parseDevices code for handling 'vmw_pvrdma', as done by partners

* Thu Jun 27 2019 akshay gupta <akshgupt@redhat.com>
- CERTPX-4827: Added logout api
- CERTPX-4827: added redirection link in sandbox and minor css changes
- CERTPX-4827: removed filters and switch to react-table loder
- CERTPX-4827: login form links open a new tab fix

* Thu Jun 27 2019 Pooja Tiwari <ptiwari@redhat.com>
- CERTPX-4955 Fixed the traceback in software/supportable/container test - Updated the necessary conditions to accomodate Programs.software plus   any other new program in future too. (Cloud being the default policy) - Updated logic to determine the test suite name   - All the child classes for Test should override the getSuiteName method     to return the program.   - Preserved the old logic of using test path as a secondary/fallback source.

* Thu Jun 27 2019 Javed Alam <jalam@redhat.com>
- CERTPX-4841 : Traceback while saving multihost result file from UI CERTPX-4960 : Unexpected error message on save page CERTPX-4961 : Page not found (404) error after clicking on result.xml link on save page CERTPX-4962 : Back button not redirecting properly on result save page         1) Fixed the inappropriate 'regex' assignement for multihost which was causing a wrong file type check.
- CERTPX-4973 : Unwanted messgae on login page 	1) Fixed django template import statement

* Thu Jun 27 2019 Greg Nichols <gnichols@redhat.com>
- CERTPX-4827 Implement Main Pages in Patternfly-React    - fixed /api/login DELETE to remove credentials    - removed httpOnly from session cookie
- CERTPX-4827 Implement Main Pages in Patternfly-React    - fixed errors from last patch

* Wed Jun 26 2019 Greg Nichols <gnichols@redhat.com>
- CERTPX-4827 Implement Main Pages in Patternfly-React    - set no-cache headers in json response
- CERTPX-4827 Implement Main Pages in Patternfly-React    - fix button colors (to bsStyle: primary) for Certifications and Sandboxes listing.

* Wed Jun 26 2019 Aniket Khisti <akhisti@redhat.com>
- CERTPX-3541 Test suspend to idle (a.k.a. freeze") CERTPX-4729 Plan & run main suspend test if any of the subtests compatible-supported state is present - Enable s2idle (freeze) state in suspend test for RHEL8 only."

* Tue Jun 25 2019 akshay gupta <akshgupt@redhat.com>
- CERTPX-4911: added dropzone in file upload modal
- CERTPX-4919: removed vendor column, updated column is now sorted by default
- CERTPX-4909: Hiding sidenav bar on listing unmount

* Mon Jun 24 2019 Petersingh Anburaj <panburaj@redhat.com>
- CERTPX-4748 Implement profiling for instance which don't support PMU   - Updated code to add hw_profiler and sw_profiler instead of profiler test   - hw_profiler will be planned if cpu-cycles file is found in /sys/devices/cpu/events/ directory   - sw_profiler will be planned if hw_profiler was not planned   - hw_profiler will check for cycles event   - sw_profiler will check for cpu-clock event
- New release branch 6.13

* Mon Jun 24 2019 Pooja Tiwari <ptiwari@redhat.com>
- Rhcert-6.12 Release Notes

* Mon Jun 24 2019 Javed Alam <jalam@redhat.com>
- CERTPX-4899 : Bad character while genetating testplan on ppc64le 	1) Fixed the inappropriate argument passing which was causing a wrong assignment for 'debugging' param.

* Fri Jun 21 2019 akshay gupta <akshgupt@redhat.com>
- CERTPX-4912: supported call error handlin fix
- CERTPX-4912:  better alerts for api errors
- CERTPX-4925: added cwe banner message

* Fri Jun 21 2019 Greg Nichols <gnichols@redhat.com>
- CERTPX-4827 Implement Main Pages in Patternfly-React    - set django to save sessions every request so status apis are current
- CERTPX-4827 Implement Main Pages in Patternfly-React    - delete old implementations of Certifications and Test Results
- CERTPX-4880 React Main Pages: missing cookie trail for Cert pages.
- CERTPX-4827 Implement Main Pages in Patternfly-React    - set up django not to cache json responses from /api

* Thu Jun 20 2019 Greg Nichols <gnichols@redhat.com>
- CERTPX-4911 React Main Pages: Test Results Upload Modal    - implement model    - todo: actually upload the file
- CERTPX-4909 - fix support for urls ending in slash
- update favicon
- CERTPX-4914 React Main Pages Api: status api returns content type text/html     - moved cwe status and supported versions into rhcert/server/wsgi/api     - re-implemented both calls in REST framework     - adusted React WUI implementation

* Wed Jun 19 2019 Greg Nichols <gnichols@redhat.com>
- CERTPX-4925 React Main Pages: CWE Banner Message    - add support for xmlrpc calls not requiring login via auth=false    - improved error to report login required"    - note
- CERTPX-4925 React Main Pages: CWE Banner Message    - report xmlrpc errors with 401 status    - remove alerts" from successful responses    - remove base class wsgi.view.View from wsgi.api.api.API    - adjust subclasses of API"

* Wed Jun 19 2019 akshay gupta <akshgupt@redhat.com>
- CERTPX-4882 CERTPX-4909: refactored layout for vertical navigation

* Tue Jun 18 2019 Greg Nichols <gnichols@redhat.com>
- CERTPX-4925 React Main Pages: CWE Banner Message    - move xmlrpc proxy to /api/xmlrpc    - implement get and post
- CERTPX-4881 React Main Pages: CWE Sync    - moved sync info to server settings.xml    - added check that alert arg is Alert object for View.appendAlert

* Tue Jun 18 2019 Zahid Ajaz <zajaz@redhat.com>
- CERTPX-4894 key word should be more inclusive when when checking redhat repos  - Fixed the string comparison to be more inclusive

* Tue Jun 18 2019 Michael Johnson <michjohn@redhat.com>
- Remove neutron-lbaas DDT tests for 13

* Mon Jun 17 2019 akshay gupta <akshgupt@redhat.com>
- CERTPX-4912 - Added PF style for alery utils

* Mon Jun 17 2019 Javed Alam <jalam@redhat.com>
- CERTPX-4810 : Pilot ISV Software Certification Test Suite for RHEL-8 	- Added ISV Software Certification Test Suite for RHEL-8. 	- Redesigned and refactored the code of cloude supportable tests. 	- Moved common pieces into redhat-certification-backend. 	- Using common policy for Cloud and Sofware Certification.

* Mon Jun 17 2019 Greg Nichols <gnichols@redhat.com>
- CERTPX-4827 Implement Main Pages in Patternfly-React    - centralized time interval constants    - fixed traceback due to collisions between api/status and api/sync    - changed Certifications Updated to use the correct value

* Thu Jun 13 2019 Aniket Khisti <akhisti@redhat.com>
- CERTPX-4849 Move fingerprintreader test to hwcertpreview package from hwcert

* Thu Jun 13 2019 Greg Nichols <gnichols@redhat.com>
- CERTPX-4881 React Main Pages: CWE Sync    - revised Certifications component to call cwesync    - will re-call cwesync every 5 min after that    - sync range (days) configurable on configurations page

* Thu Jun 13 2019 akshay gupta <akshgupt@redhat.com>
- CERTPX-4827: fixed a few react realted bugs

* Thu Jun 13 2019 Pooja Tiwari <ptiwari@redhat.com>
- CERTPX-4904 Traceback in CCSP/Supportable RPM Verification - Fixed UnboundLocalError: local variable 'file_data' referenced before assignment

* Wed Jun 12 2019 akshay gupta <akshgupt@redhat.com>
- CERTPX-4827:  moved rhcert-status call to redux
- CERTPX-4827: added api Error middleware
- CERTPX-4827: added common api error handler

* Wed Jun 12 2019 Greg Nichols <gnichols@redhat.com>
- CERTPX-4882 React Main Pages: Login Page Layout    - add waffle (prototyped)

* Tue Jun 11 2019 Greg Nichols <gnichols@redhat.com>
- CERTPX-4881 React Main Pages: CWE Sync    - CWESync component implementation (propably appear on the Configuration page)
- CERTPX-4881 React Main Pages: CWE Sync    - implement /api/cwe-sync for backend calls

* Tue Jun 11 2019 Petersingh Anburaj <panburaj@redhat.com>
- CERTPX-4829 UnicodeDecodeError traceback in usb2 test when device has non-ascii characters in name   - Handled exception which happens only in python2
- CERTPX-4492 hypervisor errors in log window when adding SUT to cert   - Starting the libvirtd service before using the virsh command.   - If that fails, return False

* Mon Jun 10 2019 akshay gupta <akshgupt@redhat.com>
- CERTPX-4827: added basic login reducer
- CERTPX-4827: added noty and alertUtils
- CERTPX-4827: added setInerval  instead of setTimeout

* Mon Jun 10 2019 Pooja Tiwari <ptiwari@redhat.com>
- CERTPX-4892 RHCert cert creation pull downs are showing unsupported product versions - Restored the old code that looks for isSupport param for version display.
- CERTPX-4891 [RHOSP-14] Baremetal tests not getting planned - Fixed the import error
- CERTPX-4889 Rhcert create cert page shows incorrect mapping of product version/platform/base version - Fixed rhcert product picker JS

* Mon Jun 10 2019 Greg Nichols <gnichols@redhat.com>
- CERTPX-4884 React Main Pages: /results URL produces XML fragment     - revise /rhcert/server/wsgi/api to return http error codes

* Fri Jun 07 2019 Greg Nichols <gnichols@redhat.com>
- CERTPX-4884 React Main Pages: /results URL produces XML fragment     - remove templates replaced by new React implementations
- CERTPX-4884 React Main Pages: /results URL produces XML fragment     - moved main URL specs to /rhcert/server/wsgi/main     - created a Main wsgi page handler that only handles basic redirection     - move all top-level pages under main module     - moved results xml url to /results-xml

* Thu Jun 06 2019 Pooja Tiwari <ptiwari@redhat.com>
- CERTPX-4875 Fixed the kernel error caused by the additional suffix _0" in el8 kernel - Fixed the regex that sets kenel NVR. - Now it should capture '_0' suffix too from '4.18.0-80.1.2.el8_0'"
- CERTPX-4693 Make baremetal cert code compatible across python-2.7 and 3 - Fixed import statements.
- CERTPX-4871 [RHOSP 15] Sosreport test fails for RCO and RCB - Redesigned and refactored the code of sosreport tests. - Moved common pieces into redhat-certification-backend. - Used more generic methods to make them re-usable across test suites. - Replaced the usage of 'utils' with 'Command' module. - Changed the sos container plugin validation to consider podman/docker   based on the RHOSP version.

* Thu Jun 06 2019 Greg Nichols <gnichols@redhat.com>
- CERTPX-4827 Implement Main Pages in Patternfly-React    - connected results page to /api/results call    - todo: header and status states are not current initially.    - todo: cwe certifications sync (manual and status indication)    - todo: login page layout ala single-page class    - todo: redux integration for header/status state?    - todo: generic XML->json for serialization?

* Wed Jun 05 2019 Greg Nichols <gnichols@redhat.com>
- CERTPX-4827 Implement Main Pages in Patternfly-React    - connected sandboxes page to /api/sandboxes call    - todo: connect APIs for results page    - todo: header and status states are not current initially.    - todo: cwe certifications sync (manual and status indication)    - todo: login page layout ala single-page class    - todo: redux integration for header/status state?    - todo: generic XML->json for serialization?
- CERTPX-4827 Implement Main Pages in Patternfly-React    - fixed Certifications page to use full product names/versions    - implemented API calls for certifications, sandboxes, results    - implemented django context serialization for rhcert model objects    - todo: connect APIs for sandboxes and results pages    - todo: header and status states are not current initially.    - todo: cwe certifications sync (manual and status indication)    - todo: login page layout ala single-page class    - todo: redux integration for header/status state?    - todo: generic XML->json for serialization?

* Tue Jun 04 2019 Pooja Tiwari <ptiwari@redhat.com>
- CERTPX-4693 Make baremetal cert code compatible across python-2.7 and 3

* Tue Jun 04 2019 Greg Nichols <gnichols@redhat.com>
- CERTPX-4827 Implement Main Pages in Patternfly-React    - set up /" to show "Certifications" tab    - added api for rhcert-status

* Mon Jun 03 2019 akshay gupta <akshgupt@redhat.com>
- CERTPX-4827: moved header out of router
- CERTPX-4827: added basic login form

* Mon Jun 03 2019 Pooja Tiwari <ptiwari@redhat.com>
- CERTPX-4661 Tempest test list added for OSP-15

* Mon Jun 03 2019 Petersingh Anburaj <panburaj@redhat.com>
- New release branch for 6.12

* Mon Jun 03 2019 Ajinkya Marudwar <amarudwa@redhat.com>
- Release Note 6.11

* Fri May 31 2019 Greg Nichols <gnichols@workstation-7.6>
- CERTPX-4870 apply leverage results not automatically refreshing progress page    - fixed udefined variable    - fixed notification popup alert styles

* Fri May 31 2019 Greg Nichols <gnichols@redhat.com>
- CERTPX-4827 Implement Main Pages in Patternfly-React    - set up /" to show "Certifications" tab    - re-wrote cwe status and supported version in React"

* Thu May 30 2019 akshay gupta <akshgupt@redhat.com>
- CERTPX-4827:  added rhcertConfig reducer and main page tab hiding based on config
- CERTPX-4827: added proper type checking
- CERTPX-4827: commented navbar, breadcrumbs  and main page tabs

* Thu May 30 2019 Greg Nichols <gnichols@redhat.com>
- CERTPX-4827 Implement Main Pages in Patternfly-React    - added api at /api/rhcert-status for basic info needed in masthead    - fixed Test Results url to be /results
- CERTPX-4827 Implement Main Pages in Patternfly-React    - move new api url(s) to /rhcert/server/wsgi/api

* Thu May 30 2019 Zahid Ajaz <zajaz@redhat.com>
- CERTPX-3651 [RHEL8 CCSP] configuration/Default System Logging test fails   - added ryslog as a required package for cloud certification

* Wed May 29 2019 akshay gupta <akshgupt@redhat.com>
- CERTPX-4827: added action for getting certifications data from django
- CERTPX-4827: added get certifications url for getting json data
- CERTPX-4827: added redux and certifications reducer

* Wed May 29 2019 Javed Alam <jalam@redhat.com>
- CERTPX-1906 : Using rhcert-cli save command with --server-ip equal to LTS address, should specify where the result has been saved at the server 	- Displaying LTS path of the result file during saving through rhcert-cli 	- Displaying path of result file for files who are not associated with any certs

* Wed May 29 2019 Pooja Tiwari <ptiwari@redhat.com>
- CERTPX-3275 Made RCO code compatible across python-2.7 and 3 CERTPX-4860 Modified director validation command to make this test work on all OSP versions

* Fri May 24 2019 akshay gupta <akshgupt@redhat.com>
- CERTPX-4826: added Listings pages
- CERTPX-4826: added upload test results code
- CERTPX-4826: added header, dummy  data generation, loader component
- CERTPX-4826: added react based routing

* Fri May 24 2019 Greg Nichols <gnichols@redhat.com>
- CERTPX-4820 copy leverage information not working on rhcert WebUI    - hide leverage notication alert until needed

* Thu May 23 2019 Greg Nichols <gnichols@redhat.com>
- CERTPX-4820 copy leverage information not working on rhcert WebUI    - fix js errors    - update alert html
- CERTPX-4818 no notification of being logged out of Rhcert WebUI    - move cwe alerts to show in top-level pages via app-base.html

* Thu May 23 2019 Pooja Tiwari <ptiwari@redhat.com>
- CERTPX-4821 Fixes in New Layered Cert page - Removed the unnecessary additional fields 'Platform' and 'RHEL Version'. - Restored 'Format' field.

* Tue May 21 2019 Javed Alam <jalam@redhat.com>
- CERTPX-1906 : Using rhcert-cli save command with --server-ip equal to LTS address, should specify where the result has been saved at the server 	- Specified where the result has been saved at the server(LTS) through webui and rhcert-cli command

* Tue May 21 2019 Aniket Khisti <akhisti@redhat.com>
- CERTPX-4754 cannot access cpuscaling.py error messages in the Rhcert WebUI Log window during testing - remove redudant step of making python scripts executable in Makefile

* Tue May 21 2019 Ben Rose <brose@redhat.com>
- CERTPX-4295 - rotational errors in WebUI log box during test plan verification - check for presence of rotational file prior to running cat on it

* Mon May 20 2019 Petersingh Anburaj <panburaj@redhat.com>
- CERTPX-325 Implement or port Bluetooth LE test (or include in regular bluetooth test)   - Updated the code to make bluetooth test working

* Mon May 20 2019 Greg Nichols <gnichols@redhat.com>
- CERTPX-4817 Not able to save, submit, download or delete the result file from rhcert web-ui

* Fri May 17 2019 Pooja Tiwari <ptiwari@redhat.com>
- CERTPX-4807 [RHOSP 15] Support podman in trusted container test for RHOSP 15

* Fri May 17 2019 Greg Nichols <gnichols@redhat.com>
- CERTPX-4785 Webpack version 4, and remove copies of JQuery, Bootstrap, and Patternfly    - fixed warnings on rhcert-product-picker.js    - change clean target to remove node_modules and build directories CERTPX-4808 RHOSP Cert. creation protocol selection broken due to javascript issues.    - change bootstrap version to 3.3.7

* Thu May 16 2019 Pooja Tiwari <ptiwari@redhat.com>
- CERTPX-3275 [RHOSP-15] Make OSP code compatible across python 2 and 3 - Removed the unused rpm repos - Added rpm dependencies for OSP-15
- CERTPX-4630 CERTPX-4796 Made the test plan (rhcert-cli plan) working on RHOSP-15 CERTPX-4798 CERTPX-4788 Made the feature_test_map script working on RHOSP-15 CERTPX-3275 [WIP] Make osp cert code compatible across python-2.7 and 3 CERTPX-4693 [WIP] Make baremetal cert code compatible across python-2.7 and 3 - Used absolute import statement - Fixed module renaming - Removed rpmUtils module usage due to its or its replacement unavailability in python3 - Fixed TypeErrors: a bytes-like object is required

* Thu May 16 2019 Akshay Gupta <akshgupt@localhost.localdomain>
- CERTPX-4598: webpack version upgrade to v4

* Thu May 16 2019 Greg Nichols <gnichols@redhat.com>
- CERTPX-4785 Webpack version 4, and remove copies of JQuery, Bootstrap, and Patternfly    - fixed multi-host role selection js bug.
- CERTPX-4785 Webpack version 4, and remove copies of JQuery, Bootstrap, and Patternfly    - moved legacy code in rhcert/server/js to the webpack bundle in rhcert/server/react/src/js    - adjusted references to redhat and vendor product selectors, leverage, multi-host roles and cwe sync    - fixed static and run-time errors in legacy js

* Thu May 16 2019 yangli <yangli@redhat.com>
- CERTPX-4797: update spec for Cert.getOpenTestsInfo_4_12 to return kbase info

* Wed May 15 2019 Pooja Tiwari <ptiwari@redhat.com>
- CERTPX-4771 Logout operation shouldn't call a deprecated api: User.logout

* Wed May 15 2019 Petersingh Anburaj <panburaj@redhat.com>
- CERTPX-4695 rhcert 6.10 release note   - Added release notes

* Tue May 14 2019 Petersingh Anburaj <panburaj@redhat.com>
- CERTPX-325 Implement or port Bluetooth LE test (or include in regular bluetooth test)   - This is just an initial commit to fix some formattings in bluetooth code.   - Fixed 2 import errors

* Mon May 13 2019 Pooja Tiwari <ptiwari@redhat.com>
- CERTPX-4768 [RHOSP-15] Fixed TypeError in feature_test_map.py - Made it python 2 and 3 compatible
- CERTPX-4783 Fundamental changes to support RHOSP-15 in RCO and RCB. - Added version 15 in necessary places - Added the list of tempest test (inherited from OSP-14) in config file Change-Id: Icd95bf70383ab4e631362e909b315b9dd01177f2
- Fixed following bugs w.r.t plan component to test assignment CERTPX-4747 fv_core/core and fv_memory/memory results not mapping properly CERTPX-3231 fv_realtime component matching realtime in results page CERTPX-3683 fv components not matching components properly

* Fri May 10 2019 Greg Nichols <gnichols@redhat.com>
- CERTPX-4598 Move to webpack for js and css packaging     - fixed modals that were disappearing immediately     - fixed SUT status reporting

* Wed May 08 2019 Petersingh Anburaj <panburaj@redhat.com>
- CERTPX-4727 Iptables services is getting stopped when firewalld starts from Rhcert,which makes connectivity issue and hence can't register the system   - Removed direct restart of firewalld   - Added appropriate message to open required ports if firewall-cmd command fails

* Wed May 08 2019 Greg Nichols <gnichols@redhat.com>
- CERTPX-4598 Move to webpack for js and css packaging     - patternfly depricated alert-error, changed django messages.ERROR to map to 'danger'

* Thu May 02 2019 Aniket Khisti <akhisti@redhat.com>
- CERTPX-4682 CPUSCALING test failed In RHEL 6.9 HW Certificate  - correct CPU frequency tolerance value & error messages
- CERTPX-4732 perf not getting installed - profiler not getting planned  - make 'perf' rpm package a hardware package-wide mandatory dependency

* Thu May 02 2019 Javed Alam <jalam@redhat.com>
- CERTPX-3532 : Reorganize source code of baremetal test suite CERTPX-4683 : baremetal_stage_inspecting subtest is failing CERTPX-4684 : [Baremetal]dmicode is missing from the output xml CERTPX-4685 : Unwanted logs while deleting the nodes in baremetal_stage_enrolling test CERTPX-4686 : [Baremetal] Wrong error message after command execution     1) Class level code orginized     2) Removed run_bash_command method and used Command module to print error logs in XML file     3) This patch will cover all the above mentioned JIRA id's"

* Wed Apr 24 2019 Petersingh Anburaj <panburaj@redhat.com>
- CERTPX-4714 video test failed with traceback due to UnicodeDecodeError   - Used io.open instead of open to handle UnicodeDecodeError" exception"
- CERTPX-4637 [Cloud Instance Type] - No Storage test is planned for AWS t2.micro instance   - Added the required host string pattern to match aws ebs storage (vbd-)

* Tue Apr 23 2019 Greg Nichols <gnichols@redhat.com>
- CERTPX-4598 Move to webpack for js and css packaging     - move login to use generated index.html as root template
- CERTPX-4598 Move to webpack for js and css packaging     - fix alert classes
- CERTPX-4598 Move to webpack for js and css packaging     - set up bundle install from Make rpm target
- CERTPX-4598 Move to webpack for js and css packaging     - include rhcert-basic.css for todo icons
- CERTPX-4598 Move to webpack for js and css packaging     - setup Make targets for building and installing bundle     - fix styling of alerts include

* Tue Apr 23 2019 Ajinkya Marudwar <amarudwa@redhat.com>
- Release Note 6.9

* Mon Apr 22 2019 Zahid Ajaz <zajaz@redhat.com>
- release-6.10

* Mon Apr 22 2019 Javed Alam <jalam@redhat.com>
- Revert CERTPX-3532 : Reorganize source code of baremetal test suite    1) Class level code orginized    2) Removed run_bash_command method and used Command module to print error logs in XML file""

* Thu Apr 18 2019 Aniket Khisti <akhisti@redhat.com>
- CERTPX-4636 [Cloud Instance Type] profiler test - Error: Required hardware event not available  - Plan Profiler test only if supported

* Wed Apr 17 2019 Pooja Tiwari <ptiwari@redhat.com>
- CERTPX-4651 Added hyperlink for Hardware Requirements on Product Sample page

* Mon Apr 15 2019 Aniket Khisti <akhisti@redhat.com>
- CERTPX-4653 : [Cloud Instance Type] - core test fails because /bin/sh: ./clocktest: No such file or directory - add make as hardware package wide dependency.

* Thu Apr 11 2019 Greg Nichols <gnichols@redhat.com>
- CERTPX-4598 Move to webpack for js and css packaging     - move all remaining templates to legacy-page include
- CERTPX-4598 Move to webpack for js and css packaging     - Use Make/sed to insert django content after bundle     - moved create templats to legact-page include

* Thu Apr 11 2019 Javed Alam <jalam@redhat.com>
- CERTPX-3532 : Reorganize source code of baremetal test suite    1) Class level code orginized    2) Removed run_bash_command method and used Command module to print error logs in XML file

* Tue Apr 09 2019 Greg Nichols <gnichols@redhat.com>
- CERTPX-4598 Move to webpack for js and css packaging     - mv rhcert.js into webpack bundle
- CERTPX-4598 Move to webpack for js and css packaging     - insert npm/webpack generate index.html as top-level django template     - create legacy-page.html as template to inserver service-side renders

* Tue Apr 09 2019 Zahid Ajaz <zajaz@redhat.com>
- CERTPX-4617 Cloud Instance Type - Error: Para-Virtualized guest are not valid for certification     - Disabled the paravirtualization check and warning Change-Id: Id6037ae131d2cc816863f95d45d7cf5dfff130cc
- CERTPX-4633 Traceback in Software Containers when podman is not installed   - Bug Fix

* Mon Apr 08 2019 Greg Nichols <gnichols@redhat.com>
- CERTPX-4482 Django 2.0/Python3: middleware traceback    - Renamed UrlRouterMiddleware.__init__ to work with MiddlewareMixin    - Changed HttpRedirectMiddleware to use MiddlewareMixin
- CERTPX-4482 Django 2.0/Python3: middleware traceback    - numerous encode/decode tracebacks in logs, 500 error reported    - Fixed site-specific session key generation and reading

* Fri Apr 05 2019 Petersingh Anburaj <panburaj@redhat.com>
- CERTPX-4587 About the smpquery command used in rdmaConnection.py   - Updated smpquery command to take deviceName as an option (-C)

* Fri Apr 05 2019 Greg Nichols <gnichols@redhat.com>
- CERTPX-4615 Multi-host test runs missing     - Fix overwrite errors related to CERTPX-4600 (cherry picked from commit 1a0b7e2d04ececc6749529c716bab5e5ece4710e)

* Fri Apr 05 2019 Ajinkya Marudwar <amarudwa@redhat.com>
- Release Note 6.8

* Thu Apr 04 2019 Greg Nichols <gnichols@redhat.com>
- CERTPX-4600 hwcert uploads are missing sosreports embedded in their xml    - fix for loss when saving multi-host test assignments    - add check to raise exception if attempts are made to save filtered results
- CERTPX-4600 hwcert uploads are missing sosreports embedded in their xml    - fix for loss when saving test assignments

* Thu Apr 04 2019 Zahid Ajaz <zajaz@redhat.com>
- CERTPX-4327 CCSP RHEL 8 - Check if registry.redhat.io is configured and working for containers   - Added container registry check

* Wed Apr 03 2019 Greg Nichols <gnichols@redhat.com>
- CERTPX-4551 RHCert Javascript platform: React/webpack initial toolchain setup     - Add Main wrapper
- CERTPX-4600 hwcert uploads are missing sosreports embedded in their xml     - add results file attachment validation (size > 0).

* Wed Apr 03 2019 Zahid Ajaz <zajaz@redhat.com>
- CERTPX-4568 Add registry.redhat.io to checklist in OSP trusted container test

* Tue Apr 02 2019 Greg Nichols <gnichols@redhat.com>
- CERTPX-4551 RHCert Javascript platform: React/webpack initial toolchain setup     - rename App to RHCert as single-page starter app

* Tue Apr 02 2019 Aniket Khisti <akhisti@redhat.com>
- CERTPX-4328 suites/hwcert/tests/core/clocktest.c Test Failure  - Make CPU mask to be the number of actual online CPUs     instead of the configured number of CPUs.  - Refactor code to compare previous & current CPU runs.

* Tue Apr 02 2019 Petersingh Anburaj <panburaj@redhat.com>
- CERTPX-4586 Added 4m" as message size for "40GigEthernet" test"

* Mon Apr 01 2019 Zahid Ajaz <zajaz@redhat.com>
- release-6.9
- release-6.8
- CERTPX-4470 CCSP RHEL 8 - Require that the Insights client is installed   - implementation of 'Insights' subtest

* Mon Apr 01 2019 Greg Nichols <gnichols@redhat.com>
- npm run eject
- CERTPX-4551 RHCert Javascript platform: React/webpack initial toolchain setup     - clean up dev app/css
- fix rules for building
- rename webpack to react
- CERTPX-4551 RHCert Javascript platform: React/webpack initial toolchain setup    - fix dependancies
- CERTPX-4551 RHCert Javascript platform: React/webpack initial toolchain setup    - add xmlrpc proxy at /cwe/xmlrpc
- CERTPX-4551 RHCert Javascript platform: React/webpack initial toolchain setup    - initial commit with basic structure and configuration
- CERTPX-4551 RHCert Javascript platform: React/webpack initial toolchain setup    - fix ts complilation errors
- CERTPX-4551 RHCert Javascript platform: React/webpack initial toolchain setup    - Make and npm build rules.
- CERTPX-4551 RHCert Javascript platform: React/webpack initial toolchain setup     - fix name/icon in react test app

* Mon Apr 01 2019 Aniket Khisti <akhisti@redhat.com>
- CERTPX-4579 Traceback on RHCERT UI ImportError at / No module named certificationtest - Remove incorrect & unused import statements
- CERTPX-4523 [Bug 1676937] 25GigRoCE test fails because commands not found on RHEL8 SUT - Add perftest package as RHEL8 specific dependency in RDMA tests
- CERTPX-4523 [Bug 1676937] 25GigRoCE test fails because commands not found  - Add perftest package as dependency in RDMA tests

* Mon Apr 01 2019 jkinsman <jkinsman@redhat.com>
- Test parsing factory 2.0 syntax messages.

* Mon Apr 01 2019 Pooja Tiwari <ptiwari@redhat.com>
- CERTPX-4525 Fixed a traceback in Baremetal test that used to occur if only one node exists in instackenv

* Mon Apr 01 2019 Javed Alam <jalam@redhat.com>
- CERTPX-4502 : [Baremetal]RHOSP version details removed from Supportable Subtest Register Openstack version from the SUT" 	- Added RHOSP version details for Baremetal result files."

* Mon Apr 01 2019 Ben Rose <brose@redhat.com>
- CERTPX-4052 - video test failing updated hardcoded display value to the display value created at beginning of test for xdpyinfo call

* Fri Mar 08 2019 Ajinkya Marudwar <amarudwa@redhat.com>
- Release Note 6.7

* Fri Mar 08 2019 Ben Rose <brose@redhat.com>
- Revert CERTPX-4328 Make Clocktest subtest fail immediately on encountering mismatch between number of CPUs configured vs active.""

* Thu Mar 07 2019 Greg Nichols <gnichols@redhat.com>
- CERTPX-4500 Feature WUI presentation refinements   - show feature status as list of component status icons   - add Confirmed/Not Confirmed to component status   - removed legend

* Wed Mar 06 2019 Zahid Ajaz <zajaz@redhat.com>
-  CERTPX-3829 [CCSP] Additional check in Supportable/Software Container test      - Fix for NoneType vendor object
-  CERTPX-3829 [CCSP] Additional check in Supportable/Software Container test      - Fixed the 'NoneType' object issues

* Wed Mar 06 2019 Petersingh Anburaj <panburaj@redhat.com>
- CERTPX-4474 netDevice not getting populated in RDMA test   - Coverted MAC address to lower case so that it matched with the gid

* Wed Mar 06 2019 Greg Nichols <gnichols@redhat.com>
- CERTPX-4304 Add a view to show the feature data for a certification    - revise names and descriptions, add legend

* Tue Mar 05 2019 Greg Nichols <gnichols@redhat.com>
- CERTPX-4304 Add a view to show the feature data for a certification    - change feature rollup to tristate
- CERTPX-4304 Add a view to show the feature data for a certification    - fixed traceback on hardware publish page    - fixed missing feature name on hardware publish page

* Mon Mar 04 2019 Zahid Ajaz <zajaz@redhat.com>
- CERTPX-4290 [Management]SUT register should not be possible for management LTS   - Changed the workflow to prohibit cli register on management LTS   - Removed login_protect on status url to allow access in all modes

* Fri Mar 01 2019 Zahid Ajaz <zajaz@redhat.com>
-  CERTPX-3829 [CCSP] Additional check in Supportable/Software Container test      - Fixed the container config output parsing issues      - Refactored code

* Thu Feb 28 2019 Aniket Khisti <akhisti@redhat.com>
- CERTPX-4328 Make Clocktest subtest fail immediately on encountering mismatch between number of CPUs configured vs active.

* Wed Feb 27 2019 Javed Alam <jalam@redhat.com>
- CERTPX-4472 : Traceback in baremetal_stage_enrolling test for rhosp version 	- Used updated OSP_version

* Tue Feb 26 2019 Greg Nichols <gnichols@redhat.com>
- CERTPX-4304 Add a view to show the feature data for a certification    - added features to rhcert/model    - implemented tree view of features and components on the publish tab for hardware cert.    - compatable with existing featureless plan information

* Tue Feb 26 2019 Aniket Khisti <akhisti@redhat.com>
- CERTPX-4345 add 'mesa-dri-drivers' as a dependency for the video test

* Mon Feb 25 2019 Petersingh Anburaj <panburaj@redhat.com>
- CERTPX-3366 hardware tests are being run that were not selected   - The list variabe 'tests' was having the old tests along with the new one.   - This happened due to the Mutable Default Arguments" for the function (https://docs.python-guide.org/writing/gotchas/#mutable-default-arguments).   - Fix the issue by intializing the argument to None."

* Fri Feb 22 2019 Javed Alam <jalam@redhat.com>
- CERTPX-3848 : Spurious reporting of RHOSP version in baremetal suit 	- version detection should not be a part of rhcertd process 	- OSP Version detection steps should be performed at once during baremetal test plan 	- Used a class varaible to hold OSP version

* Fri Feb 22 2019 Aniket Khisti <akhisti@redhat.com>
- CERTPX-4319 [RHEL8] need wget dependency for fv_realtime test - add wget as required rpm to resolve dependency issue

* Thu Feb 21 2019 yangli <yangli@redhat.com>
- CERTPX-4303 Cert.getOpenTestsInfo_4_12 return features of test

* Thu Feb 21 2019 Petersingh Anburaj <panburaj@redhat.com>
- CERTPX-4310 FV image download via proxy   - Updated wget command to use proxy for fv tests   - Updated default rhcert.xml file to add ftp proxy

* Thu Feb 21 2019 Zahid Ajaz <zajaz@redhat.com>
- CERTPX-3829 [CCSP] Additional check in Supportable/Software Container test  - Added check to fail the test if container tool 'podman' is not installed  - remove 'podman' from required rpms Change-Id: Iffe316046917b63146d41791cd3979b4f171c947

* Thu Feb 21 2019 Ajinkya Marudwar <amarudwa@redhat.com>
- Release Note 6.6

* Tue Feb 19 2019 Javed Alam <jalam@redhat.com>
- CERTPX-4167 : Warning in baremetal_stage_deploying and redeploying test in manageable mode 	- Added mode check for manageable before entring in manageable mode.

* Tue Feb 19 2019 Ben Rose <brose@redhat.com>
- CERTPX-4335 - multiple tracebacks with 25GigRoce test - Adding robustness in the form of attempting REST calls to the LTS from the SUT as part of the test more than once prior to moving on - Catch exception ConnectionError

* Mon Feb 18 2019 Zahid Ajaz <zajaz@redhat.com>
- release-6.7

* Fri Feb 15 2019 Zahid Ajaz <zajaz@redhat.com>
- CERTPX-4338 [BUG] Invalid character encoding throwing tracebacks when build with 'make install'   - Substituted invalid characters

* Fri Feb 15 2019 Javed Alam <jalam@redhat.com>
- CERTPX-4280 : new make text box of passthrough cert out of line 	- Aligned the textbox by changing their blocks

* Thu Feb 14 2019 Ben Rose <brose@redhat.com>
- CERTPX-4212 - wireless tests are failing - fix cast to int
- CERTPX-4212 - Wireless tests are failing - fix regex to match on % packet loss with decimals

* Wed Feb 13 2019 Javed Alam <jalam@redhat.com>
- CERTPX-4275 : [Management] can't submit result file as Upload Result button" is not visible in management mode 	- Removed condition checking for management mode to show Upload Result button 	- Added conditions to check proper numbers of column for management and default mode"

* Wed Feb 13 2019 Zahid Ajaz <zajaz@redhat.com>
- CERTPX-3600 [CCSP] [New Test] Software Modules   - Fix to return FAIL if command fails to list modules

* Wed Feb 13 2019 Petersingh Anburaj <panburaj@redhat.com>
- CERTPX-4143 Traceback when feature_test_map.py executed with -ov option   - Added multi-attach releted tests to cinder feature list

* Wed Feb 13 2019 Greg Nichols <gnichols@redhat.com>
- CERTPX-4322 Default category for creating new Product is now Desktop/Workstation instead of Server    - hard-code category order to be the same as it used to be.

* Tue Feb 12 2019 Greg Nichols <gnichols@redhat.com>
- CERTPX-4312 rhcert-cli plan traceback on Fedora 29     - Fedora has no minor version (AKA update).     - unit tests were broken     - parsing uname fixed

* Tue Feb 12 2019 Ben Rose <brose@redhat.com>
- CERTPX-4212 - wireless tests are failing - use nmcli dev connect
Tue, 12 Feb 2019 18:11:03 +0000,Ben Rose,brose@redhat.com,5fd794af,CERTPX-4265 - rhcertd does not start when -preview package is installed

* Tue Feb 12 2019 Zahid Ajaz <zajaz@redhat.com>
- CERTPX-3600 [CCSP] [New Test] Software Modules   - Refactored the subtest to be more comprehensive   - Updated error logging and corrective actions

* Mon Feb 11 2019 Petersingh Anburaj <panburaj@redhat.com>
- CERTPX-3653 test_extend_attached_volume test can be ignored for NFS protocol in RHOSP13   - Updated code to handle blacklist for particular OSP version   - Updated policy to blacklist 'test_extend_attached_volume' for RHOSP 12 and 13
- CERTPX-4132 oprofile pkg being replaced by perf   - Tests are failing due to unwanted warning messages   - Updated the code to handle warning messages
- CERTPX-4143 Traceback when feature_test_map.py executed with -ov option   - Updated OpenStackTest.OSP_VERSION variable in feature_test_map.py   - Changed the import statement to preserve the value of OpenStackTest.OSP_VERSION     Value of OpenStackTest.OSP_VERSION was getting lost due to difference in import statements

* Mon Feb 11 2019 Ben Rose <brose@redhat.com>
- CERTPX-3787 - add librdmacm-utils" to the self.requiredRPMs of RdmaConnectionTest - added "librdmacm-utils" to the self.requiredRPMs of RdmaConnectionTest"

* Fri Feb 08 2019 Zahid Ajaz <zajaz@redhat.com>
- CERTPX-4286 [CCSP] Traceback in Software Repositories Subtest   - Fixed the logical bug in check_required_repos_enabled()   - Cleaned up redundant ':' symbols in messages

* Fri Feb 08 2019 Aniket Khisti <akhisti@redhat.com>
- CERTPX-4212 [RHEL8] wireless tests are failing - change the source of wireless-interfaces stats logs
- CERTPX-4260 Network tcp_lat passes despite no route to host"  - Correct test failure case"

* Fri Feb 08 2019 Greg Nichols <gnichols@redhat.com>
- CERTPX-3374 [CCSP] Logs duplicated for Configuration test - deprected echo - use run! - change rpm test to use explicit exception handler to ignore stderr output
- CERTPX-4261 Add Cloud Instance Type" as a Category in hwcert    - added Cloud Instance Type to system categories    - fixed create templates to use rhcert.tags.SystemCategories"

* Thu Feb 07 2019 Zahid Ajaz <zajaz@redhat.com>
- CERTPX-3594 [CCSP] Add support for zVM architecture on RHEL8  - Added support for kvm, zvm over s390x

* Wed Feb 06 2019 Zahid Ajaz <zajaz@redhat.com>
- CERTPX-3616 rhcert-cli register is showing unwanted response when I try to register SUT for Management LTS  - Removed login required on 'save' url to fix the response  - 'save' can't be directly referenced and hence this change doesn't change     anything from security perspective
- CERTPX-3600 Software modules test   - New Subtest under Cloud/supportable   - Have resorted to using yum sub-command 'module' outputs for validation   - Removed faulty condition on enabled repos check Change-Id: Iacd5849ac4045c379df5d1af208880fa573bc126

* Wed Feb 06 2019 Petersingh Anburaj <panburaj@redhat.com>
- CERTPX-4193 iwarp interface config failing   - Added 2 sec of waiting time before we restart the interface   - Corrected the use of function parameter in restartInterface function

* Wed Feb 06 2019 Aniket Khisti <akhisti@redhat.com>
- CERTPX-2684 Related Products tab of a Passthrough product incorrectly shows that it is a base product - Fixed traceback due to missing base vendor id

* Wed Feb 06 2019 Ben Rose <brose@redhat.com>
- CERTPX-4266 Infiniband tests planning twice - one regular and one in preview - removed rdmaConnection tests from preview package

* Tue Feb 05 2019 Javed Alam <jalam@redhat.com>
- CERTPX-4024 : Selected protocol in manila is showing blank element in the list      - Checking the protocol value before adding to the planned_protocols list so that empty values should not be added to the list.
- CERTPX-2562 : Not able to update yes, no answer type question in cert-fication->details tab 	- Typecasting the values from unicode to int datatype for efficient comparison

* Tue Feb 05 2019 Pooja Tiwari <ptiwari@redhat.com>
- CERTPX-4257 Fixed a traceback on login page. - Fixed AttributeError:     VendorProductsDocument instance has no attribute 'getDebug'     VendorProductsDocument instance has no attribute 'getDialogOrder' - Used server document for parameters: debug and dialog order

* Tue Feb 05 2019 Greg Nichols <gnichols@redhat.com>
- CERTPX-3374 [CCSP] Logs duplicated for Configuration test - added HwCertCommandStringNotFound for Command.getString - re-wrote ServiceControlTest to use Command exceptions

* Thu Jan 31 2019 Petersingh Anburaj <panburaj@redhat.com>
- CERTPX-3802 Couldn't open display " for command "xvinfo"
- CERTPX-4195 wget doesn't get installed while running fv_memory test   - Igorning the exception caused due to warning messages in whatprovides command

* Wed Jan 30 2019 Greg Nichols <gnichols@redhat.com>
- CERTPX-4233 contention over vendor products cache causes tracebacks in httpd log    - move debug, dialog order to a separate settings.xml    - keep sync time and status in products.xml

* Wed Jan 30 2019 Petersingh Anburaj <panburaj@redhat.com>
- CERTPX-4227 audio HDMI test fails with traceback   - Converted str to int
- CERTPX-4132 oprofile pkg being replaced by perf   - Updated the profiler test to use perf package
- CERTPX-4049 failed to gather ip choices from LTS for RoCE test of QL41262HLCU   - Changed the match condition so that correct device gets populated in plan"

* Wed Jan 30 2019 Pooja Tiwari <ptiwari@redhat.com>
- CERTPX-4222 Results parsing fails for el8 (major release 8.0) due to invalid OS release version - Fixed a conditional statement which was returning False if version is 0

* Wed Jan 30 2019 Ajinkya Marudwar <amarudwa@redhat.com>
- Release Note 6.5

* Mon Jan 28 2019 Petersingh Anburaj <panburaj@redhat.com>
- CERTPX-4144 rhcert-hw-preview tests are not planning on RHEL8   - Updated the import statement as in Python 3,     implicit relative imports within packages are no longer available     only absolute imports and explicit relative imports are supported
- CERTPX-4153  traceback in fv_realtime test   - Added new echo function to ignore the warnings   - Used echoIgnoreWarnings for yumdownloader command to ignore warnings

* Mon Jan 28 2019 Pooja Tiwari <ptiwari@redhat.com>
- Set owner as certpx@redhat.com" across project."
- CERTPX-4220 hwcert/info fails with a stack trace on RHEL 6.10 on s390x (IBMz) - Restored the code which uses product short name in upper case while accessing service cache.

* Mon Jan 28 2019 Zahid Ajaz <zajaz@redhat.com>
- release-6.6

* Mon Jan 28 2019 Aniket Khisti <akhisti@redhat.com>
- CERTPX-3989 cpuscaling test not running subtests on RHEL 7.6 on X86 - Added warning message in case of cstate subtest failure - Corrected the if-condition whether to continue testing ptest or not

* Fri Jan 25 2019 Petersingh Anburaj <panburaj@redhat.com>
- CERTPX-4201 Click on 'Test' after selecting hardware SUT gives traceback - Fixed attribute error: 'Test' object has no attribute 'hosts'

* Thu Jan 24 2019 Pooja Tiwari <ptiwari@redhat.com>
- CERTPX-4201 Click on 'Test' after selecting SUT gives traceback - Fixed attribute error: 'Test' object has no attribute 'hosts'

* Wed Jan 23 2019 Ben Rose <brose@redhat.com>
- CERTPX-4192 - traceback in fv_memory and fv_core for ARM and s390x - use the latest of possible, known rhcert versions and corresponding dependency directory

* Wed Jan 23 2019 Greg Nichols <gnichols@redhat.com>
- CERTPX-4199 [RHOSP-14] After Selecting SUT roles and click on Test Button do not show test plan selection     - changed to wait for all selected hosts to be ready before redirection back to Testing tab.

* Tue Jan 22 2019 Greg Nichols <gnichols@redhat.com>
- CERTPX-4188 Add support for custom/development catalog" URLs"

* Mon Jan 21 2019 Aniket Khisti <akhisti@redhat.com>
- CERTPX-3868 Refactor/rework functionality in fv_* test to not require mounting (in VM) hwcertData.img - Fix a bug to avoid removing results immediately after test run, so it can be copied-out - Unmount hwcertData image once its content is copied into host - Remove whitespaces

* Mon Jan 21 2019 Javed Alam <jalam@redhat.com>
- CERTPX-4047 : Capture the rpm verification failures in a separate file

* Mon Jan 21 2019 Petersingh Anburaj <panburaj@redhat.com>
- CERTPX-4153 traceback in fv_realtime test for RHEL8   - Added yum-utils" in dependency as "yumdownloader" is not there in RHEL8   - Converted decimal to int for hugepage size configuration   - Improvised some error messages for easy debugging"

* Fri Jan 18 2019 Aniket Khisti <akhisti@redhat.com>
-  CERTPX-3989 cpuscaling test not running subtests on RHEL 7.6 on X86 - Make the Cstate sub-test's overall result-status as WARN instead of FAIL if not PASS

* Thu Jan 17 2019 Pooja Tiwari <ptiwari@redhat.com>
- CERTPX-4141 RCO should accept custom path of tempest.log, provided in tempest.conf Minor fixed in rhcert/configfile to set appropriate key and value.

* Thu Jan 17 2019 Petersingh Anburaj <panburaj@redhat.com>
- CERTPX-4139 Dependency issues in fv_realtime test for RHEL8   - Removed python-xmltodict" as this is not used in code and not found the repository   - Removed "python" as this will be already installed.     Causing issue in RHEL8 as there is no python package there is python2 and python36   - Removed "qemu-kvm-tools-rhev" as it is not present in RHEL8.     It is required in RHEL7 as it is dependency for "tuned-profiles-nfv".     Installing "tuned-profiles-nfv" should automatically install "qemu-kvm-tools-rhev" in RHEL7   - Fixed python3 compatibility issue. As "dict.keys()" doesn't returns list in python3"
- CERTPX-4130 Fixed the traceback in fv_memory test related to UnicodeDecodeError in debug mode

* Thu Jan 17 2019 Javed Alam <jalam@redhat.com>
- CERTPX-4092 : During cert creation for RHOSP, 'Upstream availability date:' shows blank on olders versions of browsers

* Thu Jan 17 2019 Ben Rose <brose@redhat.com>
- CERTPX-4049 - failed to gather ip choices from LTS for RoCE test of QL41262HLCU - centralize gid/net device matching logic for rdma tests and fix for missing net device for some RoCE setups"
- CERTPX-4049 - failed to gather ip choices from LTS for RoCE test of QL41262HLCU - corrected comparison of gid and inet link (mac address) to enable RoCE matches"

* Wed Jan 16 2019 Aniket Khisti <akhisti@redhat.com>
- CERTPX-3868 Refactor/rework functionality in fv_* test to not require mounting (in VM) hwcertData.img - Initial Commit - - Removed mounting(in VM) code - Added methods to transfer files between host & guest without mounting - Removed redundant code & comments Change-Id: I0a5a114a6f9196dc7e4d377d96a5caf6c6d8da41

* Fri Jan 11 2019 Pooja Tiwari <ptiwari@redhat.com>
- CERTPX-4080 [RHOSP] Fixed an issue where test doesn't work if 'log_file' parameter in tempest.conf points to cwd. - Removed the code which makes CWD to /tmp/<xyz>_tempest - Resolves: https://access.redhat.com/certops/internal/#/certification/02279591

* Fri Jan 11 2019 Petersingh Anburaj <panburaj@redhat.com>
- CERTPX-4044 no qemu-kvm-tools package available   - Removed dependency for qemu-kvm-tools package as it is not used in test   - Added dependency for tar package as it is not present in RHEL8

* Thu Jan 10 2019 Aniket Khisti <akhisti@redhat.com>
- CERTPX-4057 make NFS systemd service file usage consistent across RHEL versions

* Wed Jan 09 2019 Petersingh Anburaj <panburaj@redhat.com>
- CERTPX-3875 kernel modules test failing   - Added new function to return the kernel-modules package name   - Added file list of kernel-modules package as some module are linked with it

* Wed Jan 09 2019 Greg Nichols <gnichols@redhat.com>
- CERTPX-4121 Configuration Page has inconsistent start/remove confirmation dialogs

* Wed Jan 09 2019 Ben Rose <brose@redhat.com>
- CERTPX-4081 - [RHEL8] Traceback with cpuscaling test on Power 9 and ARM systems - wrapped <dict>.items() with list() where objects deleted from result in for loop to accomodate change in python3

* Tue Jan 08 2019 Ajinkya Marudwar <amarudwa@redhat.com>
- Release Note 6.4

* Mon Jan 07 2019 Greg Nichols <gnichols@redhat.com>
- release 6.5

* Fri Jan 04 2019 Zahid Ajaz <zajaz@redhat.com>
- CERTPX-4107 Handle special labels in product name during SUT product discovery  - Remove identified extra labels from product name
- CERTPX-4105 Usability of valid kernel cache when service is inaccessible  - Handling product version

* Fri Jan 04 2019 Pooja Tiwari <ptiwari@redhat.com>
- Updated local service cache

* Thu Jan 03 2019 Zahid Ajaz <zajaz@redhat.com>
- CERTPX-4096 File System Layout shows incorrect values for partition size  - Reworked checks for validating partition size
- CERTPX-3731 Could not determine vendor product in kernel test, in a IBMz/s390x system CERTPX-3938 rpm freshness does not pass for RHEL 8.0 Beta CCSP  - Modified regexes to handle Beta labels in product name and release  - Added release-label to handle 'Beta' in versioning  - Pep-8 formatting for long lines and stacked function definitions

* Thu Dec 27 2018 Pooja Tiwari <ptiwari@redhat.com>
- CERTPX-4091 Fixed traceback when I click on Test button after selecting SUT roles

* Mon Dec 24 2018 Javed Alam <jalam@redhat.com>
- CERTPX-1310 : Fixed invalid date range on Create new OSP certification page

* Mon Dec 24 2018 Pooja Tiwari <ptiwari@redhat.com>
- CERTPX-4083 Fixed a traceback while submitting results from Progress tab Upload File""

* Fri Dec 21 2018 Pooja Tiwari <ptiwari@redhat.com>
- CERTPX-3945 [RHOSP-12] Fixed an issue that was dis-allowing copying tempest.log in desired location - Fixed the code that checks OSP version.

* Fri Dec 21 2018 Aniket Khisti <akhisti@redhat.com>
- CERTPX-4049 Failed to gather ip choices from LTS" for RoCE test of QL41262HLCU - handle RocE GID finding strategy peculiarly."

* Fri Dec 21 2018 Javed Alam <jalam@redhat.com>
- CERTPX-1631 : Fixed Long file name overlaps with the Upload button in Firefox browser

* Tue Dec 18 2018 Aniket Khisti <akhisti@redhat.com>
- CERTPX-3989 cpuscaling test not running subtests on RHEL 7.6 on X86 - wrap the cstate logic in a subtest
- CERTPX-4067 ValueError while executing /usr/bin/rhcertd in RHEL6  - handled the case that python 2.6 doesn't allow empty braces as placeholders in format() method

* Mon Dec 17 2018 Pooja Tiwari <ptiwari@redhat.com>
- CERTPX-4066 Fixed an issue while updating the deferred test results: - Rpm Freshness service is returning 500 due to null" in request body"

* Mon Dec 17 2018 Javed Alam <jalam@redhat.com>
- CERTPX-3187 Neutron tab, first time, 'clear all' checkbox can be seen as selected but no other checkboxes for any features are selected
- CERTPX-3891 Fixed Login failure does not report errors on login page

* Fri Dec 14 2018 Aniket Khisti <akhisti@redhat.com>
- CERTPX-2476 select protocols for manila are displying with unicoded string during test run - Handle list input to rhcert.compatability.rhcert_make_str and use that while displaying manila protocols - Make files PEP8 complaint
- CERTPX-3972 [RHEL8] suspend test needs pm-utils package for el8 - Replace pm-utils package commands by more common systemctl commands - Make suspend.py PEP8 complaint

* Fri Dec 14 2018 Petersingh Anburaj <panburaj@redhat.com>
- CERTPX-4019 Container test fails when no images present on the SUT 	- Updated the command to not return heading if container is not present.

* Thu Dec 13 2018 Pooja Tiwari <ptiwari@redhat.com>
- CERTPX-3904 rhcert 6.3 release note

* Thu Dec 13 2018 Petersingh Anburaj <panburaj@redhat.com>
- CERTPX-4045 Fixed traceback on Realtime SUT 	- removed RHELMRG and added RHELRT for 7 and 8

* Wed Dec 12 2018 Aniket Khisti <akhisti@redhat.com>
- CPERTPX-3882 Running unmentioned commands in --help of rhcertd  - Remove the registration code from rhcertd.py  - Make PEP8 complaint
- CERTPX-3882 Running unmentioned commands in --help of rhcertd  - Remove the registration code from rhcertd.py

* Wed Dec 12 2018 Petersingh Anburaj <panburaj@redhat.com>
- CERTPX-3875 kernel modules test failing 	- Updated code to use 'Command' module instead of 'popen' 	- Updated code to use 'kernel-core' rpm if 'kernel' rpm fails to return module list

* Wed Dec 12 2018 Zahid Ajaz <zajaz@redhat.com>
- CERTPX-3734 Missing login causes 'certification not found' and redirects to the results tab

* Wed Dec 12 2018 Ben Rose <brose@redhat.com>
- CERTPX-4025 - Test suite detected device as RoCE when it set as iwarp   Check transport line of output from ibv_devinfo for device   Add qedr driver modules to list for iWarp planning

* Tue Dec 11 2018 Petersingh Anburaj <panburaj@redhat.com>
- CERTPX-4050 Fixed traceback on realtime SUT in 'rhcert-cli plan' command 	- converted 'str' to 'int'
- CERTPX-4045 Fixed traceback on Realtime SUT with rhcertd start 	- Updated 'self.getVersion' to 'self.getVersion()'
- CERTPX-4043 Fixed traceback with rhcertd start when just redhat-certification-backend is installed 	- Added dependency for python3-lxml" in 'redhat-certification-backend' package."

* Tue Dec 11 2018 Ben Rose <brose@redhat.com>
- CERTPX-3973 - DVD test not showing media to be tested correctly   in python 3, a map() result is not subscriptable, so force into list

* Mon Dec 10 2018 Greg Nichols <gnichols@redhat.com>
- CERTPX-4042 Result parsing is failing when I submit result from CLI    - set <certification><os> if missing before CLI submission

* Mon Dec 10 2018 Petersingh Anburaj <panburaj@redhat.com>
- Created new release branch release-6.4

* Fri Dec 07 2018 Greg Nichols <gnichols@redhat.com>
- CERTPX-4041 [Multihost] Upload followed by Submit changes results file name to single-host format

* Thu Dec 06 2018 Greg Nichols <gnichols@redhat.com>
- CERTPX-4012 [RHOSP 14][Multi-host] While result submission result file is not compressed to xml.gz
- CERTPX-3975 Progress Page Improvements     - moved buttons for actions not specific to a test to the table header-left.     - fixed the submit buttons that are row/test specific for multi-host     - added Cancel buttons to submit dialogs

* Thu Dec 06 2018 Pooja Tiwari <ptiwari@redhat.com>
- CERTPX-4030 Traceback while downloading submitted result file from progress tab

* Wed Dec 05 2018 Pooja Tiwari <ptiwari@redhat.com>
- CERTPX-4029 Fixed an issue during result upload from Progress page. - Added multiHostFileRegex as an acceptable result file format.
- CERTPX-4026 [RHOSP 14][Multi-host] Test" button is not enabled after selecting host roles. - Fixed javascript to not to consider 'reset' option while comparing the selected vs expected roles."

* Wed Dec 05 2018 Javed Alam <jalam@redhat.com>
- CERTPX-247 Fixed Interactive Testing: Replace 'restart' with 'cancel' button

* Wed Dec 05 2018 Greg Nichols <gnichols@redhat.com>
- CERTPX-4030 Traceback while downloading submitted result file from progress tab     - removed CertificationDocument.getHostname     - added ResultsDocument.getHostname based on getHostOS
- CERTPX-3985 Multi-Host Test Run Attachments not found    - missed checkin: download needs roleID xslt parameter
- CERTPX-3931 Multi-host Workflow for Assigning Host Roles   - and button for re-selecting hosts

* Wed Dec 05 2018 jkinsman <jkinsman@redhat.com>
- CERTPX-3612: Updates redhat-certification-hardware-preview package to use new el7/el8 package naming conventions for python-dbus dependency.

* Tue Dec 04 2018 Aniket Khisti <akhisti@redhat.com>
- CERTPX-3894 CWE CCSP transition UnitTesting part -2  - Write/Modify unittest for CCSP APIs  - Make rhcert/workflow/tests/test_* PEP8 compliant

* Tue Dec 04 2018 Greg Nichols <gnichols@redhat.com>
- CERTPX-3985 Multi-Host Test Run Attachments not found    - add roleID to specify attachments in multi-host results    - enhance rhcert-util translate" to handle xslt parameters"
- CERTPX-3985 Multi-Host Test Run Attachments not found    - preserve attachment payload on combining host results
- CERTPX-3931 Multi-host Workflow for Assigning Host Roles   - implement constaints in host selection

* Tue Dec 04 2018 Zahid Ajaz <zajaz@redhat.com>
- CERTPX-3853 rhcert-cli Infiniband_QDR test does not install required package opensm CERTPX-3873 many hardware dependent packages not getting installed   - Reworked the flow for handling installation or required RPMs   - Removed version dependency for specific required RPMs

* Tue Dec 04 2018 Pooja Tiwari <ptiwari@redhat.com>
- CERTPX-3984 Fixed the panel IDs in testing tab to display the multi host result correctly. - Used host ID to to form test and attachment IDs.

* Mon Dec 03 2018 Javed Alam <jalam@redhat.com>
- CERTPX-3302 Fixed issue: rhcert-cli run --test director_undercloud with debug=high says The following tests will be skipped: director_undercloud

* Mon Dec 03 2018 Pooja Tiwari <ptiwari@redhat.com>
- CERTPX-3999 Fixed: Missing <role> in certification, hardware and test tags in multi-host result file CERTPX-3983 Fixed: SUT Status as 'certification for Red Hat Enterprise Linux" does not match host OS " "' Additionally: - Renamed some of the variables for better code readability. - Removed the un-used url 'testrole' and its view method."

* Fri Nov 30 2018 Petersingh Anburaj <panburaj@redhat.com>
- CERTPX-3987 Fixed the issue of different SUT getting added automatically
- CERTPX-3958 'l.decode(..)' was not changing the 'l' to unicode, updated it to 'l = l.decode(..)'

* Fri Nov 30 2018 Anshul Behl <abehl@redhat.com>
- CERTPX-3991 Plan only tests that are related to certification created in RHOSP

* Fri Nov 30 2018 Pooja Tiwari <ptiwari@redhat.com>
- CERTPX-3966 CERTPX-3984 CERTPX-3985 Fixed the panel IDs to display the multi host result correctly. - Used host ID rather than device to form the subtest and attachment IDs.

* Fri Nov 30 2018 Greg Nichols <gnichols@redhat.com>
- CERTPX-3513 RHCert results XML schema change for host roles and multi-host test plans     - schema corrected for rhcert-results and rhcert-muli filetypes

* Thu Nov 29 2018 Pooja Tiwari <ptiwari@redhat.com>
- CERTPX-3852 Fixed a trackeback with baremetal_stage_deploying test - Removed an unecessary extra argument from caller method.
- CERTPX-3990 Fixed traceback while accessing Testing tab - There was a typo in a variable name
- CERTPX-3957 Fixed issue while accessing system's host name and ip.

* Thu Nov 29 2018 Zahid Ajaz <zajaz@redhat.com>
- CERTPX-3940 password (authselect) test should give corrective action when appropriate  - Added corrective action
- CERTPX-3939 nftables not running warning should have corrective action specified  - Added corrective action to advise users to run/enable a service if dead/disabled

* Thu Nov 29 2018 Greg Nichols <gnichols@redhat.com>
- CERTPX-3970 Multihost results file deletion error

* Wed Nov 28 2018 Javed Alam <jalam@redhat.com>
- CERTPX-2387 updated appendError, appendErrors and appendAlert to display alert error like view.py
- CERTPX-3897 Added a flag called isSandbox to check on which page we have to redirect to

* Wed Nov 28 2018 Greg Nichols <gnichols@redhat.com>
- CERTPX-3932 Multi-host Workflow for selecting tests and tested protocol     - implemented state management: host selection, test selection, and testing

* Tue Nov 27 2018 Pooja Tiwari <ptiwari@redhat.com>
- CERTPX-3969 Fixed traceback while restarting the SUT from configuration page.

* Tue Nov 27 2018 Greg Nichols <gnichols@redhat.com>
- CERTPX-3514 RHCert WUI support for display and execution of multi-host testing    - fixed ordering of multihost results (newest at top)
- CERTPX-3968 Exception on clicking submit for multihost results
- CERTPX-3514 RHCert WUI support for display and execution of multi-host testing    - non-required tests are not selected by default    - implemented test selection    - todo: fix interactive prompt responses (nested forms)    - todo: state management (client-side)

* Tue Nov 27 2018 Petersingh Anburaj <panburaj@redhat.com>
- CERTPX-3958 Using decode as we are converting logs to unicode, 	Changed the except condition so that UnicodeDecode exception is caught below

* Tue Nov 27 2018 Anshul Behl <abehl@redhat.com>
- CERTPX-3967 Make the openstack director test mandatory

* Tue Nov 27 2018 jkinsman <jkinsman@redhat.com>
- CERTPX-2657: Port logic to start/stop lmbench services on a per-test basis from hwcert to rhcert, modify for python3 support.

* Fri Nov 23 2018 Petersingh Anburaj <panburaj@redhat.com>
- CERTPX-3806 Removed 'rhcert_make_unicode()' from 'getSystemLog()' function, as 	    getSystemLogSinceBoot() return a list which is getting converted to unicode.
- CERTPX-3883 Using if/else instead of try/except due to the known bug in subprocess python 2.6.6

* Fri Nov 23 2018 Pooja Tiwari <ptiwari@redhat.com>
- CERTPX-3953 Fixed traceback in openstack/supportable test in 'Log Versions' subtest.
- CERTPX-3852 Added a missing quote.
- CERTPX-3699 [RHOSP-14] Fixed name for octavia test.

* Thu Nov 22 2018 Pooja Tiwari <ptiwari@redhat.com>
- CERTPX-3852 [RHOSP] Fixed issues while connecting to remote host (key based authentication): - Change in baremetal_stage_deploying test:   Using stack user's public key while creating the keypair.   Using stack user's private key while connecting to provisioned server, - Change in openstack director test:   Using stack user's private key while connecting to controller node.

* Thu Nov 22 2018 Anshul Behl <abehl@redhat.com>
- CERTPX-3946 [RHOSP 12] tempest Tests are not running in manila tests

* Thu Nov 22 2018 Petersingh Anburaj <panburaj@redhat.com>
- CERTPX-3874 Updated code to have min thread count as 1 for threaded_memtest

* Wed Nov 21 2018 Pooja Tiwari <ptiwari@redhat.com>
- CERTPX-3847 [RHOSP14] Fixed issue: Baremetal/Sos report test is failing: - There is an issue with logs plugin in sos-3.6 (default sos version on 7.6). - Running sosreport with logs plugin ends up with failure: Process killed" - Disabled the logs plugin in the sos command as it is not mandatory."
- CERTPX-3846 [RHOSP-14] Change in Baremetal/director_unercloud test: - Removed the check for existence of stack to validate director deployment.

* Wed Nov 21 2018 Petersingh Anburaj <panburaj@redhat.com>
- CERTPX-3947 Removed string as string don't have split attribute in python3

* Wed Nov 21 2018 Greg Nichols <gnichols@redhat.com>
- CERTPX-3928 Traceback on Configuration page on web UI on 6.3 upgrade    -- fixup pre 6.3 results XML for use re: host/os information

* Tue Nov 20 2018 Greg Nichols <gnichols@redhat.com>
- CERTPX-3931 Multi-host Workflow for Assigning Host Roles   - clean up testing page   - provide role pull-down menus to allow selection of all hosts

* Tue Nov 20 2018 Petersingh Anburaj <panburaj@redhat.com>
- CERTPX-3941 Updated get_json_output function to return empty dictionary when command has no output.
- CERTPX-2412 Implemented new workflow for leveraging result.

* Tue Nov 20 2018 Ajinkya Marudwar <amarudwa@redhat.com>
- Release Notes 6.2

* Mon Nov 19 2018 Petersingh Anburaj <panburaj@redhat.com>
- CERTPX-3871 Added unicode as utf8 to convert bytes to string in python3 CERTPX-3883 Changed iteritems to items for python3 support
- Updated the release version to 6.3 in Makefile

* Mon Nov 19 2018 Greg Nichols <gnichols@redhat.com>
- CERTPX-3929 traceback on testing page: not match for testrole" url"

* Fri Nov 16 2018 Aniket Khisti <akhisti@redhat.com>
- CERTPX-3895: CWE CCSP Transition Unit Testing part - 1

* Fri Nov 16 2018 Greg Nichols <gnichols@redhat.com>
- CERTPX-3659 Multi-Node MVP in RHOSP Certification
- CERTPX-3514 RHCert WUI support for display and execution of multi-host testing   - fix multi-host run time methods
- CERTPX-3514 RHCert WUI support for display and execution of multi-host testing   - add display for merged multihost files

* Thu Nov 15 2018 Aniket Khisti <akhisti@redhat.com>
- CERTPX-3899 [VNF]Traceback while creating vnf certification

* Thu Nov 15 2018 Anshul Behl <abehl@redhat.com>
- CERTPX-3898 During test run of baremetal, test is trying to run a command 'baremetal configure boot' which is not an openstack command

* Sat Nov 10 2018 Ben Rose <brose@redhat.com>
- CERRTPX-3881 - fix typo in Command class fix a typo

* Tue Nov 06 2018 Greg Nichols <gnichols@redhat.com>
- CERTPX-3515 RHCert LTS merging of multiple host results for multi-host test runs     - add detection of results from multi-host testing to initiate merge     - defined new file type for merged multihost runs with prefix rhcert-multi-     - added merging code in rhcertStore and ResultsDocument

* Mon Nov 05 2018 Zahid Ajaz <zajaz@redhat.com>
- CERTPX-3770 [Hwcert] rhcertd fails to restart in python3 env  - Fixed the python3 compatibility issue

* Mon Nov 05 2018 Greg Nichols <gnichols@redhat.com>
- CERTPX-3514 RHCert WUI support for display and execution of multi-host testing   - merge multi-host to single results file on submit""

* Fri Nov 02 2018 Aniket Khisti <akhisti@redhat.com>
- CERTPX-3844 rhcertd can't start on RHEL 6.5 - added python-six as required dependacy for backend package

* Fri Nov 02 2018 Greg Nichols <gnichols@redhat.com>
- CERTPX-3513 RHCert results XML schema change for host roles and multi-host test plans     -  allow multiple <hardware><os> elements     - move <test><run><os> to <test><os>

* Fri Nov 02 2018 Pooja Tiwari <ptiwari@redhat.com>
- CERTPX-3775 Changes in Manila testing: - manila_share_types is no longer a separate test. It is included in manila_share test. - test_share_types_extra_specs" regex is now part of manila_share."
- CERTPX-3842 Avoid product redundancy in RH product list. - An RH product can be part of more than one ecosystem (in PNS)   but it should show up only once in product list (New Cert Page)

* Thu Nov 01 2018 Gonéri Le Bouder <goneri@redhat.com>
- VolumesExtendAttachedTest is OSP14 only

* Thu Nov 01 2018 Pooja Tiwari <ptiwari@redhat.com>
- CERTPX-3836 Minor fixes in container test. - Fixed a typo. - Re-phrased a log message.
- CERTPX-3791 Fixed director test for RHOSP 14. - Changed regex in the director validation command.

* Thu Nov 01 2018 Greg Nichols <gnichols@redhat.com>
- CERTPX-3513 RHCert results XML schema change for host roles and multi-host test plans     - update XMLRPC API spec

* Thu Nov 01 2018 Ajinkya Marudwar <amarudwa@redhat.com>
- updated certification release 6.1 content

* Thu Nov 01 2018 Anshul Behl <abehl@redhat.com>
- CERTPX-3461 Baremetal certification compatibility for OSP 14

* Wed Oct 31 2018 Pooja Tiwari <ptiwari@redhat.com>
- CERTPX-3461 Added openstack version 14 in baremetal osp version detection code.
- CERTPX-3836 Changed container test: - To use image id rather name for inspect. - Handle the case when orphan containers exist on the SUT. - It impacts OSP trusted_container and ccsp supportable/software_container tests.

* Wed Oct 31 2018 Greg Nichols <gnichols@redhat.com>
- CERTPX-3514 RHCert WUI support for display and execution of multi-host testing   - fixed interactive test run/prompting

* Tue Oct 30 2018 Greg Nichols <gnichols@redhat.com>
- CERTPX-3514 RHCert WUI support for display and execution of multi-host testing   - minor fixes

* Mon Oct 29 2018 Zahid Ajaz <zajaz@redhat.com>
- New branch release-6.2 created

* Fri Oct 26 2018 Pooja Tiwari <ptiwari@redhat.com>
- CERTPX-3601 Minor fix in ccsp software container test: - Test should pass if no container exists.
- CERTPX-3826 Removed unnecessary rpm dependencies from trusted container test.
- Fixed an issue with python2 and 3 compatibilty - string.atoi is not available in python3 - Replaced string.atoi() with int() across the code. - Resolves: CERTPX-3596

* Fri Oct 26 2018 Ben Rose <brose@redhat.com>
- CERTPX-3822 - traceback with 10GigRoCE test on el6     - handle errors more elegantly

* Fri Oct 26 2018 Greg Nichols <gnichols@redhat.com>
- CERTPX-3819 Disable server on el8 builds   - comment out the httpd config via undefined env variable

* Thu Oct 25 2018 Greg Nichols <gnichols@redhat.com>
- CERTPX-3514 RHCert WUI support for display and execution of multi-host testing   - initial prototype test selection widget

* Thu Oct 25 2018 Ben Rose <brose@redhat.com>
- CERTPX-3822 - traceback with 10GigRoCE test on el6 - added check for blank or no return for ping so next time it will fail gracefully
- CERTPX-3803 - Include ipv6 value in search for matching ethernet device for rdma device - Improve readability and consolidate some of the functionality pairing rdma gid w/ ethernet device - Add ipv6 to values compared with gid for that purpose

* Thu Oct 25 2018 Pooja Tiwari <ptiwari@redhat.com>
- CERTPX-3809 Fix an issue for RHEL-8, while writing to output.log - TypeError: ord() expected string of length 1, but int found

* Thu Oct 25 2018 Zahid Ajaz <zajaz@redhat.com>
- CERTPX-3599 Enable relevant Software Repositories to support CCSP on RHEL8   - Enhanced the test result log messages

* Wed Oct 24 2018 Petersingh Anburaj <panburaj@redhat.com>
- CERTPX-3755 Reduced the sleep time and it is waiting for long time and causing some failures

* Wed Oct 24 2018 Zahid Ajaz <zajaz@redhat.com>
- CERTPX-3790 Error displayed in Disk Size Supportable subtest in CLI  - Fixed bug in re.split to split on one or more whitespaces
- CERTPX-3596 Update 'Unsupported Hardware' test criteria for RHEL8   - Added new check to verify RAM per core is above threshold

* Wed Oct 24 2018 Ben Rose <brose@redhat.com>
- CERTPX-3809 - all HW tests are failing on el6 with empty traceback - workaround for issue w/ 2.6.6 refusing to write unicode to binary

* Tue Oct 23 2018 Aniket Khisti <akhisti@redhat.com>
- CERTPX-3745 Move new RDMA tests out of preview package and into regular hardware package
- Resolved importError for python3 compatibilty encountered during make rpm for el8 - Removed from __builtin__ import False from 2 files

* Tue Oct 23 2018 Ben Rose <brose@redhat.com>
- CERTPX-3817 - traceback with kdump test - fixed config file operation to account for empty lines

* Tue Oct 23 2018 Zahid Ajaz <zajaz@redhat.com>
- CERTPX-3599 Enable relevant Software Repositories to support CCSP on RHEL8  - checks to verify if the required repos are enabled
- CERTPX-3595 Root File System test criteria changes for RHEL8  - Make 'disk size checks' rhel version specific

* Mon Oct 22 2018 Petersingh Anburaj <panburaj@redhat.com>
- CERTPX-3796  ifdown and ifup interface to resolve network issue
- CERTPX-3796 Changed the command to check if rcopy is running CERTPX-3755 Changed the command to check if rping is running

* Mon Oct 22 2018 Zahid Ajaz <zajaz@redhat.com>
- CERTPX-3597 [CCSP] Network Configuration test changes for RHEL8   - check if firewalld is enabled   - validate the firewall backend   - Enhanced ConfigFile to handle user defined separator Change-Id: I4f0e8a380c4b23964be9ac6dbae43ec707343280
- CERTPX-3595 Root File System test criteria changes for RHEL8  - New subtest for rhel8 to validate file system layout

* Fri Oct 19 2018 Greg Nichols <gnichols@redhat.com>
- CERTPX-3252 - Refactor existing RDMA tests into network speed specific tests    - remove tab character

* Thu Oct 18 2018 Pooja Tiwari <ptiwari@redhat.com>
- CERTPX-3601 Test status for CCSP Supportable/Software Container: - if no container exists:     PASS for CCSP     FAIL for OSP - fixed a minor typo
- CERTPX-3788 Fixed xml.parsers.expat.ExpatError - For OSP (python2.6):     error due to bad char in output.log     Made use of existing method for removing such char. - For CCS on RHEL-8 (python3):      error due to bad char in certification.xml.      Solved a python 2 and 3 compatibilty issue w.r.t maps.

* Thu Oct 18 2018 Petersingh Anburaj <panburaj@redhat.com>
- CERTPX-3796 Fixed interface name issue in network test for RDMA interfaces, 	Fixed false PASS for rping and ping test, 	Applied pep8 standards for rdmaConnection.py file.

* Wed Oct 17 2018 Pooja Tiwari <ptiwari@redhat.com>
- CERTPX-3601 Bug fixes in RHEL-8 CCSP Supportable/Software Container test
- CERTPX-3699 Octavia implementation testing capabilities for RHOSP 14 - Changed test name - Updated api regex
- CERTPX-3386 API regex addition for cinder multi-attach.

* Wed Oct 17 2018 Greg Nichols <gnichols@redhat.com>
- CERTPX-3514 RHCert WUI support for display and execution of multi-host testing   - initial prototype with host selection/display on the Testing page

* Wed Oct 17 2018 Zahid Ajaz <zajaz@redhat.com>
- CERTPX-3603 [CCSP] SELinux Enforcing  - Enforced policy rules based on program

* Tue Oct 16 2018 Ben Rose <brose@redhat.com>
- CERTPX-3252 - Refactor existing RDMA tests into network speed specific tests - update mechanism for initiating on-demand commands on LTS initiated by tests run on SUT - modify comments to include more information

* Tue Oct 16 2018 Zahid Ajaz <zajaz@redhat.com>
- CERTPX-3603 [CCSP] SELinux Enforcing  - Refactored SELinux policy check subtest  - Common test class for all programs  - Updated test description  - add compatibility for str.format in rhel6 Change-Id: Ia4fefccc2596e50245a260187236be1adf376649

* Tue Oct 16 2018 Greg Nichols <gnichols@redhat.com>
- CERTPX-3513 RHCert results XML schema change for host roles and multi-host test plans     - fix calls to os/host access     - initial prototype multi-host results page
- CERTPX-3513 RHCert results XML schema change for host roles and multi-host test plans     - add rhcert.model access methods

* Mon Oct 15 2018 Pooja Tiwari <ptiwari@redhat.com>
- CERTPX-3776 Fixed traceback in osp/sosreport test: - AttributeError: 'GenerateSystemReportOpenstack' object has no attribute 'set_detected_version'
- CERTPX-3355 Red Hat Certification 6.0 Release Notes

* Mon Oct 15 2018 Greg Nichols <gnichols@redhat.com>
- CERTPX-3513 RHCert results XML schema change for host roles and multi-host test plans
- CERTPX-3744 Can not view or extract sosreport file after downloading attachment from the rhcert WUI

* Mon Oct 15 2018 Zahid Ajaz <zajaz@redhat.com>
- CERTPX 3597 [CCSP] Network Configuration test changes for RHEL8   - Added 'nftables' as network access service for rhel8

* Fri Oct 12 2018 Pooja Tiwari <ptiwari@redhat.com>
- CERTPX-3601 Bug fix in RHEL-8 CCSP Supportable/Software Container test
- CERTPX-3699 Octavia implementation testing capabilities for RHOSP 14 - Added neutron_octavia_load_balancer test.
- CERTPX-3601 [CCSP] [New Subtest] Supportable/Software Containers - This subtest will execute based on the underlined rhel version. - Moved common container validation code into backend and re-used it in   ccsp and osp tests.

* Fri Oct 12 2018 Petersingh Anburaj <panburaj@redhat.com>
- CERTPX-3504 Removed unicode for python3 support, code refactoring.

* Fri Oct 12 2018 Ben Rose <brose@redhat.com>
- CERTPX-3755 - Make rping RDMA subtest more resilient - added sleep/loop around call to kick off rping on LTS, checking ps to make certain it is running

* Thu Oct 11 2018 Greg Nichols <gnichols@redhat.com>
- CERTPX-3742 Improve RPM change log generation

* Thu Oct 11 2018 Ben Rose <brose@redhat.com>
- CERTPX-3252 - Refactor existing RDMA tests into network speed specific tests CERTPX-2253 Update RDMA *connection tests to use ib_read_bw, ib_send_bw, etc - initial commit - moved to preview package for this release

* Wed Oct 10 2018 Pooja Tiwari <ptiwari@redhat.com>
- CERTPX-3386 Multi attach volume addition in RHSOP-14 cinder testing - Black-listed test_volume_swap_with_multiattach for now.

* Wed Oct 10 2018 Petersingh Anburaj <panburaj@redhat.com>
- CERTPX-3504 Updated the parameter name, found that it was wrong.
- CERTPX-3504 Removed 'DHSS False' from the UI list and added logic to add 'dhss_false' if 'dhss_true' is not selected.

* Wed Oct 10 2018 Greg Nichols <gnichols@redhat.com>
- CERTPX-3513 RHCert results XML schema change for host roles and multi-host test plans     - add a <host> element to each test plan component to capture host and role information

* Tue Oct 09 2018 Greg Nichols <gnichols@redhat.com>
- CERTPX-3690 [RHEL8] Enable rhcert to use 'authselect' for CCSP Hashing algorithm Security subtest
- CERTPX-3725 [RHEL8 CCSP] Traceback in result submission through CLI
- CERTPX-3707 [CCSP] Traceback in Configuration service status test in WUI
- CERTPX-3593 [CCSP] Supported architectures on RHEL8

* Tue Oct 09 2018 Zahid Ajaz <zajaz@redhat.com>
- Added NVDIMM to hwcertpreview package

* Tue Oct 09 2018 Aniket Khisti <akhisti@redhat.com>
- CERTPX-3686 100GigRoCE test not getting planned  - Stripped rate unit - 'Gb'  - Corrected condition to check rate  - Added 'bnxt_re' into necessary driver module for RoCE test  - Formatted Error:" statement for consistency Change-Id: Ib3f5447636bf614916b7dfc96fc66626e736a7aa (cherry picked from commit 4c35ab5d26a2ecc9fbac65fe901bf95f49ad9342)"

* Mon Oct 08 2018 Aniket Khisti <akhisti@redhat.com>
- CERTPX-3686 100GigRoCE test not getting planned  - Stripped rate unit - 'Gb'  - Corrected condition to check rate  - Added 'bnxt_re' into necessary driver module for RoCE test  - Formatted Error:" statement for consistency Change-Id: Ib3f5447636bf614916b7dfc96fc66626e736a7aa"

* Mon Oct 08 2018 Pooja Tiwari <ptiwari@redhat.com>
- rhcert-6.1
- OSP Test suite code refactored: - OSP Version detection steps should be performed at once in the start rather than for each test. - Used a class varaible to hold OSP version which gets used in almost all tests. - Fixed pep8 errors - CERTPX-3666 OSP version detection is now a part of test plan. - CERTPX-2366 RHOSP version detection should not be a part of rhcertd process.

* Mon Oct 08 2018 Zahid Ajaz <zajaz@redhat.com>
- CERTPX-2383 Develop test for NVDIMM  - Planning mechanism for NVDIMM  - Subtest for NVDIMM

* Thu Oct 04 2018 Greg Nichols <gnichols@redhat.com>
- CERTPX-3703 rhcert-cli register asks to confirm deletion of current results even if there are none

* Thu Oct 04 2018 Ben Rose <brose@redhat.com>
- Revert CERTPX-2383 Develop test for NVDIMM  - Planning mechanism for NVDIMM  - Subtest for NVDIMM""

* Wed Oct 03 2018 Petersingh Anburaj <panburaj@redhat.com>
- CERTPX-3578 Create M2_NVMe test CERTPX-3579 Create U2_NVMe test

* Wed Oct 03 2018 Anshul Behl <abehl@redhat.com>
- CERTPX-3584 The test result should fail if 'sudo sh -c 'dmidecode'' on baremetal return no valid value

* Wed Oct 03 2018 Zahid Ajaz <zajaz@redhat.com>
-  CERTPX-2377 Split out PCIE_NVMe storage test (as-is) from existing storage test  - Default planning method hostPatternString

* Wed Oct 03 2018 Greg Nichols <gnichols@redhat.com>
- CERTPX-3696 RHEL8: sosreport doesn't run
- CERTPX-3692 [RHEL8 CCSP] 'ModuleNotFoundError' in rhcert-ci and rhcert-util

* Wed Oct 03 2018 jkinsman <jkinsman@redhat.com>
- Explictly provide RHCERT_PYTHON=/usr/bin/python when invoking Make from redhat-certification-backend RPM spec file to ensure shebangs are set properly.
- Explicitly cast LooseVersion values parsed from Brewroot to strings for comparison purposes. This addresses a Python 3 behavioral change, where these values can be cast to integers for comparison purposes under specific circumstances.

* Tue Oct 02 2018 Greg Nichols <gnichols@redhat.com>
- CERTPX-3624 [RHEL8] rhcertd unable to locate/use python3 via '#!/usr/bin/env python'    - fix %build directive
- CERTPX-3624 [RHEL8] rhcertd unable to locate/use python3 via '#!/usr/bin/env python'    - change default RHCERT_PYTHON to /usr/bin/python    - change spec file generation to use os.path.basename(RHCERT_PYTHON)
- CERTPX-3684 RHEL8: traceback on rhcertd start creating /etc/rhcert/xml     - remove low-level handler for OSError so upper-level code and hande it.
- CERTPX-3624 [RHEL8] rhcertd unable to locate/use python3 via '#!/usr/bin/env python'    - change Makefile to set shebang to RHCERT_PYTHON value.

* Tue Oct 02 2018 jkinsman <jkinsman@redhat.com>
- Pass RHCERT_LIB_DIR and RHCERT_PYTHON to rhcertSpec.py when building Dockerfile and redhat-certification-devel spec file.

* Mon Oct 01 2018 Petersingh Anburaj <panburaj@redhat.com>
- CERTPX-3664 Fixed exception for hwcert/rdma/Infiniband_QDR test

* Fri Sep 28 2018 Greg Nichols <gnichols@redhat.com>
- CERTPX-3660 limit results file name length to 80 characters

* Thu Sep 27 2018 Greg Nichols <gnichols@redhat.com>
- CERTPX-3650 [RHEL8 CCSP] configuration test stray 'b" characters and escaping of <command> taging"
- CERTPX-3663 [RHEL8 CCSP] rhcert-cli register detection of LTS on LAN doesn't work.

* Thu Sep 27 2018 Petersingh Anburaj <panburaj@redhat.com>
- CERTPX-3576 Added M2 SATA test CERTPX-3577 Added U2 SATA test

* Thu Sep 27 2018 Pooja Tiwari <ptiwari@redhat.com>
- CERTPX-3654 'rhcert/peer' test should not plan/run for any program: - Disabled planning for 'rhcert/peer' test. - Fixed a traceback 'AttributeError: 'str' object has no attribute 'combine' in 'rhcert/peer' test.
- CERTPX-3652 Unable to login at rhcert WUI - Fixed: File does not exist: /var/www/rhcert/img/bg-login.jpg

* Thu Sep 27 2018 Ben Rose <brose@redhat.com>
- CERTPX-3657 - Registering system in rhcert web ui results in error - changed client proxy run call to runXML to match change in -backend code

* Wed Sep 26 2018 Greg Nichols <gnichols@redhat.com>
- CERTPX-3649 [RHEL8 CCSP] configuration test traceback on systemctl start chrond

* Tue Sep 25 2018 Greg Nichols <gnichols@redhat.com>
- CERTPX-3610 Research: SUT Peer Requests for Multi-host Testing     - allow rhcert-cli clean via peer call.
- CERTPX-3610 Research: SUT Peer Requests for Multi-host Testing     - moved PeerDemo to PeerTest as a base class for peer tests     - fixed merging of attached results files
- release-6.0

* Tue Sep 25 2018 Pooja Tiwari <ptiwari@redhat.com>
- Updated local cache files for pns and valid-kernels services.

* Tue Sep 25 2018 Petersingh Anburaj <panburaj@redhat.com>
- CERTPX-3604 Change in design for planning storage test and converting SATA and SAS to base class CERTPX-3220 Resolves the issue with SAS SSD planning CERTPX-3221 Resolves the issue with SATA SSD planning

* Mon Sep 24 2018 Greg Nichols <gnichols@redhat.com>
- CERTPX-3610 Research: SUT Peer Requests for Multi-host Testing     - adds an rhcertd daemon server method to run a rhcert-cli command     - adds an rhcertd listener server method to get current results.xml     - adds a PeerDemo test that calls rhcert/self_check on a peer SUT

* Fri Sep 21 2018 Pooja Tiwari <ptiwari@redhat.com>
- CERTPX-3521 Distinguish connect and catalog containers based on vendors in docker inspect

* Fri Sep 21 2018 Zahid Ajaz <zajaz@redhat.com>
- CERTPX-3537  [CCSP] Password Configuration subtest fails everytime on RHEL-7.6  - Moved required rpms list to spec file  - Removed function calls to get/install required rpms

* Fri Sep 21 2018 Ben Rose <brose@redhat.com>
- CERTPX-3542 - UnicodeDecodeError traceback running hardware tests on RHEL6.10 - encode/cast log to utf-8

* Fri Sep 21 2018 Greg Nichols <gnichols@redhat.com>
- CERTPX-3581 pulldowns on result page missing     - remove HTML/XML escaping from rhcert.log.Log.logOnly     - fixes to cloud/supportable rewrite to use rhcert.command.Command
- CERTPX-3580 Error: Register Request Failed - 'Systems' object has no attribute 'server'     - changes system page to use RHCertClient class     - various unicode and typing fixes

* Thu Sep 20 2018 Greg Nichols <gnichols@redhat.com>
- CERTPX-3582 log window in testing page stuck on checking...     - revised call to SUT to use rhcert.client.client.RHCertClient
- CERTPX-3550 Various unicode and string handling errors on RHEL8 CCSP     - fixed traceback when rhcertd writes a PID
- CERTPX-3550 Various unicode and string handling errors on RHEL8 CCSP     - fixed WUI host status via new RHCertClient class     - replaced calls to sys.stdout.log.write with sys.stdout.logOnly     - rhcert.localTestServer: replaced urrlib code with requests CERTPX-3575 [CCSP] Multiple tracebacks in el7 tests     - fixed attachment encoding and md5sum on python2 and python3

* Wed Sep 19 2018 jkinsman <jkinsman@redhat.com>
- CERTPX-3244: Testing el8 Brew builds.

* Wed Sep 19 2018 Ben Rose <brose@redhat.com>
- CERTPX-2253 Update RDMA *connection tests to use ib_read_bw, ib_send_bw, etc - fix except syntax for python3
- CERTPX-3548 - fv_memory and fv_core failing due to missing python-libvirt dependency - python3-libvirt for python versions > 2, libvirt-python for pythong versions <= 2

* Tue Sep 18 2018 Greg Nichols <gnichols@redhat.com>
- CERTPX-3550 Various unicode and string handling errors on RHEL8 CCSP     - revised rhcert.log.Log to handle unicode uniformly for test logs     - added tools/porting23.py to demo approach     - rhcert.localTestServer: replaced urrlib code with requests

* Tue Sep 18 2018 Zahid Ajaz <zajaz@redhat.com>
- CERTPX-3537 [CCSP] Password Configuration subtest fails everytime on RHEL-7.6  - Fixed by adding authconfig as required rpm for security subtest
-     CERTPX-3489 All Storage Tests Are Failing       - Added missing return statement

* Tue Sep 18 2018 Petersingh Anburaj <panburaj@redhat.com>
- CERTPX-1425 - Updated the print statement to have local variable.

* Mon Sep 17 2018 Pooja Tiwari <ptiwari@redhat.com>
- CERTPX-3384 Added a title for the baremetal node dmicode info in the baremetal test log

* Mon Sep 17 2018 Zahid Ajaz <zajaz@redhat.com>
- CERTPX-2163 Add SSD component into storage test as a subtest   - Refactored and renamed ssd device detection function CERTPX-3489 All Storage Tests Are Failing   - Fixed error handing

* Mon Sep 17 2018 Greg Nichols <gnichols@redhat.com>
- CERTPX-3203 investigate/resolve modules for python3 for rhel8     - add processing for test plan-time requires python-<rpm name> to python3-<rpm name>
- CERTPX-3203 investigate/resolve modules for python3 for rhel8     - add handling for python vs python3 in package names
- CERTPX-3203 investigate/resolve modules for python3 for rhel8     - remove dbus-python from redhat-certification-backend     - remove dbus-python from redhat-certification-hardware     - add %Rquires dbus-python to redhat-certification-hardware-preview (for now).
- CERTPX-3203 investigate/resolve modules for python3 for rhel8     - remove m2crypto

* Mon Sep 17 2018 Ben Rose <brose@redhat.com>
- CERTPX-2253 Update RDMA *connection tests to use ib_read_bw, ib_send_bw, etc - update thresholds for ethernet and ib_* subtests - update to support python3 syntax

* Sat Sep 15 2018 Ben Rose <brose@redhat.com>
- CERTPX-2253 Update RDMA *connection tests to use ib_read_bw, ib_send_bw, etc - initial commit

* Fri Sep 14 2018 Petersingh Anburaj <panburaj@redhat.com>
- CERTPX-3241 Fixed traceback with rhcert-ci plan --program hardware - AttributeError: 'str' object has no attribute 'getHostname'

* Fri Sep 14 2018 Greg Nichols <gnichols@redhat.com>
- CERTPX-3524 File upload code needs re-rewrite for RHEL8    - rename module from rhcert.http to rhcert.httpUpload to remove std lib conflict    - rename class HwCertHttp to HttpUpload    - re-implement to use the requests module for RHEL6-8 compatability

* Wed Sep 12 2018 Petersingh Anburaj <panburaj@redhat.com>
- CERTPX-1105 Improvised the error message when no test suite installed.

* Wed Sep 12 2018 Pooja Tiwari <ptiwari@redhat.com>
- Revert CERTPX-3373 Fixed the multiSelect UI prompt: - to handle single as well as multi choice. - to behave similar as command line multiSelect prompt.""

* Mon Sep 10 2018 jkinsman <jkinsman@redhat.com>
- CERTPX-3244: Replace python_sitelib references in RPM specfile with rhcert_sitelib to enable building EL8 packages on EL7, and vice-versa.
- CERTPX-3244: test

* Mon Sep 10 2018 Anshul Behl <abehl@redhat.com>
- CERTPX-3472 Collecting RHOSP 13 docker logs from sosreport using docker plugin - Checking if docker plugin is active or not. - sosreport test status sets to Needs Review in case docker plugin is disabled.

* Fri Sep 07 2018 jkinsman <jkinsman@redhat.com>
- CERTPX-3244: Adds just enough to enable local EL8 builds on Jenkins build systems.

* Fri Sep 07 2018 Pooja Tiwari <ptiwari@redhat.com>
- CERTPX-3373 Fixed the multiSelect UI prompt: - to handle single as well as multi choice. - to behave similar as command line multiSelect prompt.

* Thu Sep 06 2018 Ben Rose <brose@redhat.com>
- CERTPX-3252 - Refactor existing RDMA tests into network speed specific tests - ethernet subtest fail should fail overall for rdma tests that call them
- CERTPX-3252 - Refactor existing RDMA tests into network speed specific tests - Created infiniband QDR, FDR, EDR tests, RoCE and iWarp 100Gig, 50Gig, etc. tests - Encorporated ethernet tests into those as well as renamed omnipath test

* Thu Sep 06 2018 Greg Nichols <gnichols@redhat.com>
- CERTPX-3476 rhcertd status shows rhcertd deamon is not running" after restart"

* Wed Sep 05 2018 Ben Rose <brose@redhat.com>
- CERTPX-3217 - Update hwcert realtime test to support different requirements per cpu socket count - change dmidecode command to lscpu command for determining number of sockets

* Wed Sep 05 2018 Zahid Ajaz <zajaz@redhat.com>
- CERTPX-3220 Create SAS SSD storage test  - Fixed the Traceback in SSD Storage test  - Changed print statements to print function  - removed str.format() to retain compatibilty in el6 version Change-Id: I0863fb5f1ebab5372c11d9aab1d795d0148c8cce

* Wed Sep 05 2018 Pooja Tiwari <ptiwari@redhat.com>
- CERTPX-3455 Fixed traceback in rhcert-util update operation: - AttributeError: class StringIO has no attribute 'StringIO'

* Tue Sep 04 2018 Pooja Tiwari <ptiwari@redhat.com>
- CERTPX-3455 Fixed traceback in rhcert-util update operation: - NameError: global name 'StringIO' is not defined

* Tue Sep 04 2018 Zahid Ajaz <zajaz@redhat.com>
- CERTPX-3458 KeyError during execution of Supportable/Installed RPMs test
- CERTPX-2163 - Add SSD component into storage test as a subtest CERTPX-3220 - Create SAS SSD storage test CERTPX-3221 - Create SATA SSD storage test
- CERTPX-3321 Disable login required on Urls for certification host results activities in default configuration 	- Removed unnecessary statements 	- Refactored conditional statements 	- Used configuration based redirection Change-Id: I9e8d5abdb48b4b638f796d142b54f2ba0303246e

* Fri Aug 31 2018 Aniket Khisti <akhisti@redhat.com>
- CERTPX-3313 CERTPX-3314 CERTPX-3315 - Fixed - refactored - enabled  unit tests for APIs -  - Cert.getAvaliableLayeredProductVersion  - Cert.addSupportCase_4_7 &  Cert.getSupportCases_4_7  - Cert.createSupplementalCert  - VendorProduct.get_5_4  - Cert.getBannerMessage_5_3

* Fri Aug 31 2018 Greg Nichols <gnichols@redhat.com>
- CERTPX-3431 Enable RHEL8/python3 Builds     - fix RHEL version detection for installing rhcert.pem
- CERTPX-3431 Enable RHEL8/python3 Builds     - manage python version in spec file generation
- CERTPX-3431 Enable RHEL8/python3 Builds     - python3 compatability changes to builds scripting

* Thu Aug 30 2018 Greg Nichols <gnichols@redhat.com>
- CERTPX-3202 update urllib2 imports to new python3 modules for rhel8

* Tue Aug 28 2018 Greg Nichols <gnichols@redhat.com>
- CERTPX-3390 Installing CCSP suite brings Hardware code on the SUT     - update excludes for -backend package

* Mon Aug 27 2018 Greg Nichols <gnichols@redhat.com>
- CERTPX-3389 hwcert subpackage installation conflicts with earlier hwcert releases

* Mon Aug 27 2018 Pooja Tiwari <ptiwari@redhat.com>
- CERTPX-3289 rhcert 5.17 release notes

* Mon Aug 27 2018 Ben Rose <brose@redhat.com>
- CERTPX-3364 - Move hwcert test suite for RHEL7+ into the main rhcert repo as a subpackage - add __init__.py to suites/hwcert/hwcert

* Thu Aug 23 2018 zajaz <zajaz@redhat.com>
- CERTPX-3375 Remove Host Results not working - Fixed the bug
- CERTPX-3370  Internal Server Error with supported python-django version 1.8.11
- CERTPX-3369  Allow modifications in configuration files for 'L readLink(2) path mismatch' in rpm verification  - Updated filter to include 'L' flag for config file whitelisting

* Wed Aug 22 2018 Greg Nichols <gnichols@redhat.com>
- CERTPX-3364 Move hwcert test suite for RHEL7+ into the main rhcert repo as a subpackage 	- move preview package
- CERTPX-3364 Move hwcert test suite for RHEL7+ into the main rhcert repo as a subpackage

* Tue Aug 21 2018 Greg Nichols <gnichols@redhat.com>
- CERTPX-3360 [CCSP] [el7] Encoding traceback in Configuration test CERTPX-3359 [CCSP] [el6] NFS related traceback in Configuration testA     - fixes for unicode handling related to python3 compatability

* Tue Aug 21 2018 zajaz <zajaz@redhat.com>
- CERTPX-3321 Disable login required on Urls for certification host results activities in default configuration
- CERTPX-3358 Internal Server Error due to improperly configured settings and custom django-middleware  - MIDDLEWARE setting is effective for django versions >=2.0 only
- CERTPX-3271 Make ccsp code compatible across python-2.6, 2.7 and 3  - Hotfix, syntax error

* Tue Aug 21 2018 Pooja Tiwari <ptiwari@redhat.com>
- CERTPX-3354 Fixed a traceback for trusted container test: - 'KeyError: 'authoritative-source-url' - For one of the image, the docker inspect output has   'Authoritative_Registry' instead of 'authoritative-source-url'

* Mon Aug 20 2018 Greg Nichols <gnichols@redhat.com>
- CERTPX-3341 traceback running storage/SATA test     - rewrite rhcert_get_status_output to use rhcert.Command on python3     - uses commands.getstatusoutput for python2
- CERTPX-3271 Make ccsp code compatible across python-2.6, 2.7 and 3    - initial changes to run tests on RHEL8/python3    - unicode compatability via rhcert.compatability    - filter() changes

* Fri Aug 17 2018 Aniket Khisti <akhisti@redhat.com>
- CERTPX-3338 Traceback when rhcert-cli plan executed AttributeError: 'module' object has no attribute 'exist'""
- CERTPX-3199 use subprocess module instead of commands module to support rhel8 - Fixed logic of checking for XEN para-virtualization

* Fri Aug 17 2018 Pooja Tiwari <ptiwari@redhat.com>
- CERTPX-3223 Made trusted_container test madatory for rhosp-13 and upper versions.

* Thu Aug 16 2018 Dimitri Savineau <dsavinea@redhat.com>
- CERTPX-3333 Add support for RHOSP 14 (Rocky)

* Thu Aug 16 2018 Pooja Tiwari <ptiwari@redhat.com>
- Updated service cache

* Wed Aug 15 2018 Greg Nichols <gnichols@redhat.com>
- CERTPX-3198 Make rhcert code compatible across python-2.6, 2.7 and 3    - added more compatability, minor fixes

* Tue Aug 14 2018 Pooja Tiwari <ptiwari@redhat.com>
- - CERTPX-3300 Capture $docker-inspect cmd output for all containers   under Logging subtest. - CERTPX-3301 Made use of 'authoritative-source-url' for RH/non-RH   container detection. - Adds a tabular representation for containerd data under   'Detection of RH/non-RH containers' subtest.

* Thu Aug 09 2018 Ben Rose <brose@redhat.com>
- CERTPX-3222 - rhcert 5.16 release notes, release candidate and errata advisory. - update release notes for hardware certification specific modifications (cherry picked from commit 3bd1a5afdb2e2d6c0bfff40dd58076d8864671da)
- CERTPX-3318 - The test harness at times references an undeclared variable resulting in stack trace - declare variable with default value so this does not happen (cherry picked from commit eedaf6684df2af252ec009a8558a8572a4375cab)

* Thu Aug 09 2018 Pooja Tiwari <ptiwari@redhat.com>
- CERTPX-3222 Red Hat Certification 5.16 Release Notes

* Tue Aug 07 2018 zajaz <zajaz@redhat.com>
- CERTPX-3305 Traceback with submit results - type object 'View' has no attribute 'serve'        - Fixed the bug        - Added url '/run' to management black list        - Corrected parameter mapping type >> program Change-Id: I213fb0149d144366030beae33cda6a1dd1c74872 (cherry picked from commit a5a3edfafa4a7241ad045616da38b5ffe7137f0a)

* Mon Aug 06 2018 Pooja Tiwari <ptiwari@redhat.com>
- Bumping to version 5.17

* Fri Aug 03 2018 Pooja Tiwari <ptiwari@redhat.com>
- CERTPX-3235 Fixed a traceback which occurs in case of plugin test execution before tempest_test (i.e. no tempest.conf)
- CERTPX-3294 Fixed exception in baremetal/sosreport test: - NameError: global name 'utils' is not defined""
- CERTPX-3294 Fixed exception in baremetal test suite: - NameError: global name 'utils' is not defined""

* Wed Aug 01 2018 zajaz <zajaz@redhat.com>
- CERTPX-3280 Traceback: TypeError at /create/sandbox/ view() got an unexpected keyword argument 'loginRequired'
- CERTPX-3268  [el6] [CCSP] Traceback in Configuration test through CLI    - Fixed the unicode issue persistent in python2.6 Change-Id: Ie2a440fbbccfc703fab637c795d46e1f04877fe5

* Wed Aug 01 2018 Pooja Tiwari <ptiwari@redhat.com>
- CERTPX-3279 Fixed 'TypeError: unicode object is not callable' - Changed the name of local varaible which was initially overriding   the python in-built method type()

* Tue Jul 31 2018 zajaz <zajaz@redhat.com>
- CERTPX-3082  - Fixed restricted opeartions error message  - Reverted CERTPX-3156 as not fixed

* Mon Jul 30 2018 Pooja Tiwari <ptiwari@redhat.com>
- CERTPX-3273 Fixed JSONDecodeError exception

* Fri Jul 27 2018 zajaz <zajaz@redhat.com>
- CERTPX-3082 [RhCert on OpenShift] Security Updates   - CERTPX-3151 interactive.py calls requestRun with one parameter, but run.py:requestRun does not have any   - CERTPX-3164 CVE-2018-10864  /run?rpath=<existing-but-invalid-xml-file> does not close the opened file   - CERTPX-3148 regular users (and unauthenticated users) should not be able to make changes to the whole application   - CERTPX-3159 CVE-2018-10868  an unauthenticated user can do a Denial of Service through a Billion Laugh attack   - CERTPX-3146 CVE-2018-10868  some functions should be completely inaccessible in management-only mode.   - CERTPX-3156 rhcertStore.py uses a lot of pattern matching to categorize files (e.g. results, certifications, etc.)   - CERTPX-3145 settings.py should be checked for production-ready deployment.   - CERTPX-3162 CVE-2018-10866  /configuration allows to remove a host/system file (with/without login) not belonging to him   - CERTPX-3149 DEBUG should be set to False in settings.py   - CERTPX-3143 most of the pages are accessible even if the user has not logged in.   - CERTPX-3163 CVE-2018-10865  /configuration allows to restart a host of a customer (with/without login)   - CERTPX-3154 /blank seem like test pages. Remove them if they are so.   - CERTPX-3153 mailto.py is probably not used (it doesn't work since it uses Page without importing it). Remove it.   - CERTPX-3182 Invalidate URLs that are not relevant to management interface

* Fri Jul 27 2018 Anshul Behl <abehl@redhat.com>
- CERTPX-3269 CVE:10869 corner case for rpath download allowing relative paths

* Thu Jul 26 2018 Pooja Tiwari <ptiwari@redhat.com>
- CERTPX-1372 Added missing cinder protocols: SAS, SATA, RoCE

* Tue Jul 24 2018 zajaz <zajaz@redhat.com>
- CERTPX-3258 [el6] Exception observed in 'rhcertd restart'

* Tue Jul 24 2018 Pooja Tiwari <ptiwari@redhat.com>
- CERTPX-3259 Fixed issue with cssp test plan. - Fixed importError for configparser.

* Mon Jul 23 2018 zajaz <zajaz@redhat.com>
- CERTPX-3258  [el6] Exception observed in 'rhcertd restart'

* Mon Jul 23 2018 Ben Rose <brose@redhat.com>
- CERTPX-3198 - Make rhcert code compatible across python-2.6, 2.7 and 3 - string.atoi() should be replaced with int(), not str()

* Mon Jul 23 2018 Pooja Tiwari <ptiwari@redhat.com>
- CERTPX-3256 Fixed 'UrllibProxyHandler' importError.

* Fri Jul 20 2018 Greg Nichols <gnichols@redhat.com>
- CERTPX-3198 Make rhcert code compatible across python-2.6, 2.7 and 3    - fix more unicode issues in log analysis code, etree wrappers
- CERTPX-3198 Make rhcert code compatible across python-2.6, 2.7 and 3    - fix more unicode issues
- CERTPX-3198 Make rhcert code compatible across python-2.6, 2.7 and 3    - provide rich" comparison operators to support test sorting in python3    - fix more unicode issues"

* Fri Jul 20 2018 Aniket Khisti <akhisti@redhat.com>
- CERTPX-3253 Write unit-tests for Hardware Hydra APIs for Phase-2 - Fixed traceback due to print syntax error - Fixed cert.getSupportCases_4_7 API unittest - Changed unit test-suite default program to hardware

* Thu Jul 19 2018 Aniket Khisti <akhisti@redhat.com>
- CERTPX-3199 use subprocess module instead of commands module to support rhel8

* Thu Jul 19 2018 Greg Nichols <gnichols@redhat.com>
- CERTPX-3198 Make rhcert code compatible across python-2.6, 2.7 and 3    - change to absolute module references in imports    - raw_input is input in python3
- CERTPX-3248 sosreport test gives error -'TypeError: unsupported operand type(s) for /: 'str' and 'int''
- CERTPX-3198 Make rhcert code compatible across python-2.6, 2.7 and 3    - replace dict iteritems, itervalues, iterkeys with items and values    - python3 str is unicode, no 'unicode' type    - fix up module references
- CERTPX-3198 Make rhcert code compatible across python-2.6, 2.7 and 3    - replace dict iteritems and itervalues with items and values

* Thu Jul 19 2018 Pooja Tiwari <ptiwari@redhat.com>
- CERTPX-3168 Red Hat Certification 5.15 Release Notes - Little language changes (suggested by Rob)

* Wed Jul 18 2018 Pooja Tiwari <ptiwari@redhat.com>
- Replaced tab with spaces to avoid issue during build.
- CERTPX-3200 CERTPX-3198 Support syntax of except for python-2 and 3.
- CERTPX-3168 Red Hat Certification 5.15 Release Notes

* Wed Jul 18 2018 Greg Nichols <gnichols@redhat.com>
- CERTPX-3198 Make rhcert code compatible across python-2.6, 2.7 and 3    - fix exception syntax (replace , with as)    - various module changes via rhcert.compatability    - django 1 and 2 compatability

* Tue Jul 17 2018 Pooja Tiwari <ptiwari@redhat.com>
- CERTPX-3198 Make rhcert code compatible across python-2.6, 2.7 and 3: - Converted the print statement to the print() function.

* Tue Jul 17 2018 Greg Nichols <gnichols@redhat.com>
- CERTPX-3198 Make rhcert code compatible across python-2.6, 2.7 and 3    - fix exception syntax (replace , with as)    - various module changes
- CERTPX-3198 Make rhcert code compatible across python-2.6, 2.7 and 3    - Changed except syntax to use as"    - rhcert.compatability module and other module adjustments    - no unicode() function (use str() for python3)    - no 'unicode' type either    - no __metaclass__ (use the "six" compatibility module)    - no dict().iteritems (use items unless dict is large)    - file.write must be opened binary in some cases"
- CERTPX-3198 Make rhcert code compatible across python-2.6, 2.7 and 3

* Mon Jul 16 2018 Greg Nichols <gnichols@redhat.com>
- CERTPX-3191 update references to /usr/bin/python for rhel8    - fix passing of RHCERT_PYTHON to bin/Makefile
- CERTPX-3191 update references to /usr/bin/python for rhel8    - remove reference to deleted /rhcert/server/wsgi/product directory

* Fri Jul 13 2018 Greg Nichols <gnichols@redhat.com>
- CERTPX-3191 update references to /usr/bin/python for rhel8
- 5.16

* Tue Jul 10 2018 zajaz <zajaz@redhat.com>
- CERTPX-3216 typo on layered cert page

* Tue Jul 10 2018 Pooja Tiwari <ptiwari@redhat.com>
- Updated local static file for service cache.
- Chnage in info/release-notes.txt: Made the version bump text bold so that it can be highlighted and differentiated with other text.

* Thu Jul 05 2018 Anshul Behl <abehl@redhat.com>
- CERTPX-3158 /download=rpath should not allow download outside the store directory

* Wed Jul 04 2018 Aniket Khisti <akhisti@redhat.com>
- CERTPX-2747 Write unit-tests for Hardware Hydra APIs for Phase-2 (CREATE APIs) Part 2 of 2 - Added unittest for VendorProduct.create_5_4, Cert.createPassThroughSpec,   Cert.addSupportCases_4_7 & Cert.getSupportCases_4_7 Hydra APIs for HardWare Certs - Moved multiple-times hardcoded SSO credentials from test files TO data.json config file

* Wed Jul 04 2018 Pooja Tiwari <ptiwari@redhat.com>
- Added RHOSP version 14 in feature_test_map

* Fri Jun 29 2018 Pooja Tiwari <ptiwari@redhat.com>
- CERTPX-3134 Enabled cert creation for new product 'Red Hat OpenStack Platform for Real-Time Applications'.
- CERTPX-2663 Replaced ironic cli with openstack baremetal cli.

* Thu Jun 28 2018 zajaz <zajaz@redhat.com>
- CERTPX-3121 [Management] Hostname, configuration details are showing as None is certification/details tab   - Fixed the template tag
- CERTPX-3114 rhcert-cli plan forces user to register SUT for the first time.

* Tue Jun 26 2018 Pooja Tiwari <ptiwari@redhat.com>
- CERTPX-3142 Fixed traceback in baremetal/instackenv.json_stackrc_validation test - Further subtests need instackenv and stackrc files, therefore exiting test execution   if files do not found(i.e. instackenv.json_stackrc_validation subtest fails). - Providing corrective action.

* Mon Jun 25 2018 Pooja Tiwari <ptiwari@redhat.com>
- CERTPX-3169 [Proxy]Not able to login to RHCERT
- CERTPX-3142 Fixed traceback in baremetal/instackenv.json_stackrc_validation test.
- Revert CERTPX-3135 [RhCert on OpenShift] 18) rhcertStore.py:__saveResultsFile does not check whether the path is in the serverDirectory     - change rpm spec to limit apache user ownership to /var/www/rhcert/store""
- CERTPX-3066 Red Hat Certification 5.14 Release Notes

* Thu Jun 21 2018 Greg Nichols <gnichols@redhat.com>
- CERTPX-3135 [RhCert on OpenShift] 18) rhcertStore.py:__saveResultsFile does not check whether the path is in the serverDirectory     - change rpm spec to limit apache user ownership to /var/www/rhcert/store
- CERTPX-3135 [RhCert on OpenShift] 18) rhcertStore.py:__saveResultsFile does not check whether the path is in the serverDirectory     - add validation of assembled destination path to be certain it's in the /var/www/rhcert/store directory.     - add _str_ method on Alerts for plain-text responses     - fix wsgi/save.py to correctly return plain text errors
- release-5.15

* Thu Jun 21 2018 Aniket Khisti <akhisti@redhat.com>
- CERTPX-2611 XMLRPC API specification file correction for Hydra hardware transition phase2 - changed support_case_id type from integer to string

* Wed Jun 20 2018 Ben Rose <brose@redhat.com>
- CERTPX-2155 kvm-rt: work/port script provided into hwcert test    - updated for readability

* Wed Jun 20 2018 Rajasi Kulkarni <rajkulka@redhat.com>
- CERTPX-2674: Partner should be able to add configuration details for a passthrough device in WUI and CLI during planning the fv_storage test - Truncate new line characters from end of output string

* Tue Jun 19 2018 Ben Rose <brose@redhat.com>
- CERTPX-2155 kvm-rt: work/port script provided into hwcert test - add other extensions to be included in copying from source to run directory

* Mon Jun 18 2018 Aniket Khisti <akhisti@redhat.com>
- CERTPX-3125 No validation for blank comment in certification->dialog tab

* Mon Jun 11 2018 zajaz <zajaz@redhat.com>
- CERTPX-3113 Getting traceback on configuration tab while restarting the SUT  - Corrected host, connection parameters in html  - Fixed the file IO bug in documentbase class  - Bug fix for missing certification object

* Mon Jun 11 2018 Rajasi Kulkarni <rajkulka@redhat.com>
- CERTPX-2443: suspend test fails with function keys - Correct the condition to check for marker strings in   /var/log/messages

* Fri Jun 08 2018 Greg Nichols <gnichols@redhat.com>
- CERTPX-2734 Attempting to add and SUT to a cert results in Error: unsupported command "    - change client listener to handle unicode in XML

* Thu Jun 07 2018 Pooja Tiwari <ptiwari@redhat.com>
- CERTPX-1634 Fixed minor grammatical error in Publish tab.

* Wed Jun 06 2018 Greg Nichols <gnichols@redhat.com>
- release 5.13

* Tue Jun 05 2018 Greg Nichols <gnichols@redhat.com>
- CERTPX-3110 [Management]Getting trace back on login page    - fix to check debug only for default and testing configurations    - debug setting works after login.

* Tue Jun 05 2018 Pooja Tiwari <ptiwari@redhat.com>
- CERTPX-2737 Red Hat Certification 5.13 Release Notes - Also updated service cache

* Mon Jun 04 2018 zajaz <zajaz@redhat.com>
- CERTPX-3103 Not able to login into RHCERT_UI   - Fixed the 'undefined' variable bug

* Mon Jun 04 2018 Dimitri Savineau <dsavinea@redhat.com>
- CERTPX-3100 Use instackenv_path from configuration

* Fri Jun 01 2018 Greg Nichols <gnichols@redhat.com>
- CERTPX-3074 Expand the xml request response when debug is high     - add support for passing in file-like object to Config, such as sys.stdout

* Thu May 31 2018 Anshul Behl <abehl@redhat.com>
- CERTPX-2662 Provisioned machine ssh timeout additions for Dell
- CERTPX-3096 Traceback in director_undercloud test
- Enable RHOSP 13 in production

* Wed May 30 2018 Aniket Khisti <akhisti@redhat.com>
- CERTPX-2678 Write unit-tests for Hardware Hydra APIs for Phase-2 (CREATE APIs) Part 1 of 2

* Tue May 29 2018 zajaz <zajaz@redhat.com>
- CERTPX-2477 rhcret-ci plan not showing list of tests like rhcert-cli plan

* Mon May 28 2018 Anshul Behl <abehl@redhat.com>
- CERTPX-3083 Fixing the Mixed Content error when running edge route on Openshift

* Fri May 25 2018 zajaz <zajaz@redhat.com>
- CERTPX-1327 rhcert-cli --help showing error   - Fixed the issue   - Improvised help workflow

* Thu May 24 2018 Greg Nichols <gnichols@redhat.com>
- CERTPX-3074 Expand the xml request response when debug is high     - changed to use /var/www/rhcert/store/log for log files on WUI

* Wed May 23 2018 Aniket Khisti <akhisti@redhat.com>
- CERTPX-2588 - In changelog, instead of commiter/uploader name, display author/owner name associated with the commit. - also improved filter to skip merge commits from changelogs

* Tue May 22 2018 Greg Nichols <gnichols@redhat.com>
- CERTPX-3072 [Management] Traceback in Product Details Tab when uploading Product Logo     - Changed to use Connection to access VendorProducts

* Tue May 22 2018 Pooja Tiwari <ptiwari@redhat.com>
- CERTPX-2675 Fix in trusted container result update functionality.
- CERTPX-1142 Improvised log messages in OSP Supportable/Compare Openstack Versions test. - Replaced Finding out" with "Checking"."

* Mon May 21 2018 Pooja Tiwari <ptiwari@redhat.com>
- CERTPX-2605 Blacklisted neutron_ipv4 scenario test. - comma was missed.
- CERTPX-3064 Fixed a typo in variable name to resolve NameError exception.

* Fri May 18 2018 Anshul Behl <abehl@redhat.com>
- CERTPX-3059 Tempest list maintenance workflow and automation

* Fri May 18 2018 Pooja Tiwari <ptiwari@redhat.com>
- CERTPX-2675 Trusted Container result file update when container service is inaccessible: - This feature is implemented as part of `$rhcert-util update` command. - Based on service response, it updates the logs and status for Container Validation subtest.
- CERTPX-2497 Prevent traceback if tempest.log file is not generated.
- CERTPX-1142 Improvised log messages in OSP Supportable/Compare Openstack Versions test.
- CERTPX-2605 Blacklisted neutron_ipv4 scenario test.

* Tue May 15 2018 zajaz <zajaz@redhat.com>
- CERTPX-1654 grubenv is marked config file and being marked as a fail when it should not  - Fixed the path trailing slash issue which was causing the patch to fail

* Tue May 15 2018 Greg Nichols <gnichols@redhat.com>
- CERTPX-2753 [Field Issue] Error while downloading the result file from progress" tab     - remove extrainious reset of program in download method"

* Tue May 15 2018 Aniket Khisti <akhisti@redhat.com>
- CERTPX-2678 Write unit-tests for Hardware Hydra APIs for Phase-2 (CREATE APIs) Part 1 of 2 - Write unit test to create Hardware Cert - Update necessary API unit test as per the latest changes with API responses.

* Fri May 11 2018 Pooja Tiwari <ptiwari@redhat.com>
- release-5.13
- Minor language change in release notes and trusted container test message.

* Fri May 11 2018 Greg Nichols <gnichols@redhat.com>
- CERTPX-2753 [Field Issue] Error while downloading the result file from progress" tab     - fixed download to patch certID and program before saving file locally."

* Fri May 11 2018 Aniket Khisti <akhisti@redhat.com>
- Revert CERTPX-2714 if rhcertd.service started once

* Thu May 10 2018 zajaz <zajaz@redhat.com>
- CERTPX-1352  Supportable/Installed RPMs: Bifurcate the package identification part into two sub tests.   - Hide metadata info message when no non-redhat pkgs are found   - corrected value for extra pkgs list found in redhat product service check

* Thu May 10 2018 Pooja Tiwari <ptiwari@redhat.com>
- CERTPX-2744 Fixed an issue with rhosp-10 manila test report generation

* Wed May 09 2018 Aniket Khisti <akhisti@redhat.com>
- CERTPX-2714 if rhcertd.service started once, it will be active automatically from next reboot.
- CERTPX-2691  RPM Specification file updated to do pre-uninstalltion cleanup.

* Tue May 08 2018 Pooja Tiwari <ptiwari@redhat.com>
- CERTPX-2661 Red Hat Certification 5.12 Release Notes
- CERTPX-2736 Update service cache in rhcert git repo
- CERTPX-2563 RHSOP-13 Trusted Container test - Better success messages. - Priniting pretty json wherever required.

* Mon May 07 2018 zajaz <zajaz@redhat.com>
- CERTPX-2732 Non-RH rpm check in supportable test is reporting 'gpg-pubkey' as an non-RH package

* Mon May 07 2018 Pooja Tiwari <ptiwari@redhat.com>
- CERTPX-2563 RHOSP-13 Trusted Container Test - Accommodated service response change.

* Fri May 04 2018 Pooja Tiwari <ptiwari@redhat.com>
- CERTPX-2563 Trusted Container test for RHOSP-13 - CERTPX-2564 Filter out RH provided containers and expect explanation for non-RH containers. - CERTPX-2565 Multi select prompt to know which container(s) a Partner wants to test. - CERTPX-2568 Captures layers for image on which detected rhc containers are built. - CERTPX-2566 Makes a service call to detect if supplied container image is   certified by Red Hat. - CERTPX-2676 CI execution - CERTPX-2567 Adds a new tag 'container_projects' at test level in result xml.

* Wed May 02 2018 zajaz <zajaz@redhat.com>
- CERTPX-1654 grubenv is marked config file and being marked as a fail when it should not    - White listing /boot/grub2/grubenv for packaging errors
- CERTPX-1059 Whitelist CA cert RPM for RHUI and Satillite in CCSP supportable RPM checks  - Added white-listing criteria for specific packages CERTPX-1352 Supportable/Installed RPMs: Bifurcate the package identification part into two sub tests.  - Added provisional_pkg_whitelisting method to bypass specific rpms from rpm_verification  - Bifurcated package identification into separate sub tests

* Wed May 02 2018 Aniket Khisti <akhisti@redhat.com>
- CERTPX-2691 rhcertd.service file is still present in system after the uninstallation of rhcert package - initd/rhcertd & sytemd/rhcertd.service along with their symlinks will be removed after uninstallation.

* Tue May 01 2018 Greg Nichols <gnichols@redhat.com>
- CERTPX-2595 Research: Reduction of Portal Dependencies on Certification Workflow     - document CERTPX architecture

* Mon Apr 30 2018 zajaz <zajaz@redhat.com>
- CERTPX-2644 The Sanbox testing tab should have a remove button for each host listed

* Fri Apr 27 2018 Aniket Khisti <akhisti@redhat.com>
- CERTPX-2693 [initd/rhcertd] Remove redundant message displayed by command # rhcertd status

* Fri Apr 27 2018 Pooja Tiwari <ptiwari@redhat.com>
- CERTPX-2692 Improvements in rhcert multi selection prompt: - Made it more readable. - Changed it to accept choice value as well as choice number. - Changed it to allow/accept space separated choices.

* Fri Apr 27 2018 Rajasi Kulkarni <rajkulka@redhat.com>
- CERTPX-2684: Related Products tab of a Passthrough product incorrectly              shows that it is a base product - Remove unneccesary code to download a passthrough product, as those would   now be returned during sync by VendorProduct.list

* Mon Apr 23 2018 Anshul Behl <abehl@redhat.com>
- UNIFIED-2997 adding spec for vnf changes in createOpenstack api

* Mon Apr 23 2018 Pooja Tiwari <ptiwari@redhat.com>
- CERTPX-2598 Red Hat Certification 5.11 Release Notes

* Sat Apr 21 2018 Pooja Tiwari <ptiwari@redhat.com>
- release-5.12

* Wed Apr 18 2018 Ben Rose <brose@redhat.com>
- CERTPX-2680 - add back chkconfig commands for el6
- CERTPX-2680 - change chkconfig commands to systemctl equivalents in code responsible for rebooting SUT

* Wed Apr 18 2018 zajaz <zajaz@redhat.com>
- CERTPX-2222 Capture rpm data on foreign RPMS to allow for faster exception processing

* Wed Apr 18 2018 Rajasi Kulkarni <rajkulka@redhat.com>
- CERTPX-2671: Traceback seen after uploading test result in the Test Results tab - Use string comparison for result document's certification ID as IDs are now   strings and not integers

* Tue Apr 17 2018 Anshul Behl <abehl@redhat.com>
- CERTPX-2589 Adding lbaas tests and install lbaas test rpm
- CERTPX-2603 Fix the policy regexes with respect to RHOSP13 for Manila
- Fix traceback with api error on certification creation

* Tue Apr 17 2018 Aniket Khisti <akhisti@redhat.com>
- CERTPX-2615 Write unit-tests for Hardware Hydra APIs for Phase-1 (GET APIs) CERTPX-2519 XMLRPC API specification file correction for Hydra hardware transition phase1

* Tue Apr 17 2018 jkinsman <jkinsman@redhat.com>
- Testing: Remove /etc/init.d/rhcertd from RPM spec file for el7, since the init sub directory is no longer included in the RPM build root.

* Mon Apr 16 2018 Aniket Khisti <akhisti@redhat.com>
- CERTPX-2483: RPMDIFF: rhcertd is not systemd - updated root level Makefile to include systemd instead of initd

* Fri Apr 13 2018 zajaz <zajaz@redhat.com>
- CERTPX-2557 rhcert picks up only 1 hypervisor out of 2 in supportable test
- CERTPX-2086 Add the verification(G,M of /var/log/gdm) to the white list CERTPX-1660 The verification error of /usr/share/openstack-dashboard/static/dashboard/manifest.json should be ignored in RPM verification

* Fri Apr 13 2018 Anshul Behl <abehl@redhat.com>
- CERTPX-2604 Blacklisting VXLAN tests
- CERTPX-2651 Support Ironic testing with RHOSP13

* Fri Apr 13 2018 Greg Nichols <gnichols@redhat.com>
- CERTPX-2647 click on related tab of ironic cert gives exception

* Fri Apr 13 2018 Rajasi Kulkarni <rajkulka@redhat.com>
- CERTPX-2194: Support RHV by fixing fv_storage test - Remove old code supporting xen for full virtualization   Xen is dropped in RHEL since RHEL 6.0

* Wed Apr 11 2018 jkinsman <jkinsman@redhat.com>
- Refactor Yum repsitory update logic to identify any signed packages available from Brew, regardless of the signing key's fingerprint. TEST: Attempt to determine the existence of a package signature dynamically, since there are now RPM packages on Brewroot that have been signed by different keys.

* Wed Apr 11 2018 Pooja Tiwari <ptiwari@redhat.com>
- Updated service cache.
- CERTPX-2646 Fixed traceback in baremetal/baremetal_stage_Redeploying test.
- Enabled rpm verification for baremetal.

* Tue Apr 10 2018 Greg Nichols <gnichols@redhat.com>
- CERTPX-2640 TemplateSyntaxError traceback while creating new hardware product

* Mon Apr 09 2018 Aniket Khisti <akhisti@redhat.com>
- CERTPX-2483 RPMDIFF: rhcertd is not systemd - Added systemd script for RHEL7

* Mon Apr 09 2018 Pooja Tiwari <ptiwari@redhat.com>
- CERTPX-2621 Ironic enrolling subtest should ask about which node to be provisioned if there are more than one nodes in instackenv.

* Fri Apr 06 2018 Greg Nichols <gnichols@redhat.com>
-  CERTPX-2637 rhcert sources reorganization - wsgi modules    - moved /cwe/* urls and code
- CERTPX-2547 RHCert should allow strings for IDs returned and passed to XMLRPC APIs.     - removed int() casts     - added Munger test class for inserting strings in id values (disabled).
- CERTPX-2463 Related Certifications tab needs a new API to avoid iterated calls to CWE    - merge branch code: calls new API getReleatedCerts    - TODO: Restricted visibility, node IDs?

* Fri Apr 06 2018 Rajasi Kulkarni <rajkulka@redhat.com>
- CERTPX-2625: Unable to create Realtime layered cert from New Certification page - Add a query parameter to a URL only if the parameter has some value   Other views get None parameters as string 'None' in the views
- CERTPX-2600: Not able to create Ironic cert on top of certified rhel product - Changes to accomodate two different RHSOP products in PNS

* Fri Apr 06 2018 Pooja Tiwari <ptiwari@redhat.com>
- CERTPX-2528 Gather and log hardware info as part of Ironic testing once nodes are up - Call to method 'log_dmidecode()' was missed in last patch.

* Thu Apr 05 2018 Anshul Behl <abehl@redhat.com>
- CERTPX-2604 Fix the policy regexes with respect to RHOSP13 for Neutron
- CERTPX-2589 Tempest changes for RHOSP13. New tests additions in tempest_tests.json
- CERTPX-2604 Octavia changes not needed because of bugfix of -https://bugzilla.redhat.com/show_bug.cgi?id=1563563
- CERTPX-2589 Tempest changes for RHOSP13

* Thu Apr 05 2018 Pooja Tiwari <ptiwari@redhat.com>
- Added VNF certification in OSP workflow: CERTPX-2530 - New certification-vnf-component option in osp cert creation form. - New page for vnf guest os question. CERTPX-2531 - Option to upload vnf config report during cert creation.

* Wed Apr 04 2018 Pooja Tiwari <ptiwari@redhat.com>
- CERTPX-2528 Gather and log hardware info as part of Ironic testing once nodes are up - The dmidecode logs will be part of baremetal/baremetal_stage_deploying test. - Defined a new class RemoteCommand which deals with command execution on remote host. - Changed openstack and baremetal caller functions accrordingly. - ToDo: Use the Command wrapper so that the XML is marked up
- Added unit test for openstack vnf cert creation.

* Tue Apr 03 2018 Greg Nichols <gnichols@redhat.com>
- CERTPX-659 rhcert sources reorganization - rhcert.model for xml docs

* Tue Apr 03 2018 Pooja Tiwari <ptiwari@redhat.com>
- Change in baremetal test name.

* Mon Apr 02 2018 jkinsman <jkinsman@redhat.com>
- CERTPX-2273: Add certifi Python module to redhat-certification-unittest Python package requirements file.

* Mon Apr 02 2018 Pooja Tiwari <ptiwari@redhat.com>
- CERTPX-2620 Added Baremetal program in kernel validation. - Kernel test criteria for Baremetal(ironic) is similar to openstack.
- CERTPX-2607 Ironic to Baremetal transition: - The ironic-preview package is renamed as redhat-certification-baremetal. - The ironic test tag is now replaced with baremetal. - The config file ironic.json is now known as baremetal.json - All the tests and subtests have been renamed to use 'baremetal' term in place of ironic.

* Fri Mar 30 2018 Pooja Tiwari <ptiwari@redhat.com>
- Disabled service-cache parameter of make.
- CERTPX-2617 Updated PNS, Playback caches for 5.10 - Updated caches with QA data since production is not yet updated. - Minor fix in kernel test so that it can make use of cache for new variants   in case of service unavailability. - Disabled the cache rebuilding part for final 5.10 RC build so that up-to-date   git files (pns and playback static files) can be stored in it.
- CERTPX-2524 rhcert 5.10 release notes
- rhcert-5.11

* Thu Mar 29 2018 Rajasi Kulkarni <rajkulka@redhat.com>
- CERTPX-2597: Use new APIs Cert.getCurrentUserVendors and Cert.getPublicVendors_5_10 - Store in products.xml the vendors obtained from API Cert.getCurrentUserVendors - Do not use Strate APIs to get list of vendors for a user
- CERTPX-2600: Not able to create Ironic cert on top of certified - Remove commented code

* Wed Mar 28 2018 Anshul Behl <abehl@redhat.com>
- CERTPX-2582 Adding fix to pick first machine and not last

* Wed Mar 28 2018 Greg Nichols <gnichols@redhat.com>
- CERTPX-2578 Certifications referencing missing vendor products cause tracebacks

* Tue Mar 27 2018 Shreyas Patil <shrpatil@redhat.com>
- CERTPX-2498 Improved auto-detection for assigning plan component to test name for test result submission.

* Tue Mar 27 2018 Rajasi Kulkarni <rajkulka@redhat.com>
- CERTPX-2600: Not able to create Ironic cert on top of certified - If base certifications of a product cannot be fetched, render   page to choose different product while creating a layared cert

* Mon Mar 26 2018 Rajasi Kulkarni <rajkulka@redhat.com>
- CERTPX-2597: Use new APIs Cert.getCurrentUserVendors and Cert.getPublicVendors_5_10

* Mon Mar 26 2018 zajaz <zajaz@redhat.com>
- CERTPX-2545 [Sandbox]In the result saving, if there is any error, we are getting errors correctly, but the action fails again with valid hostname

* Mon Mar 26 2018 Greg Nichols <gnichols@redhat.com>
- RHCWE-2572 New Cert.getRelatedCerts call should return CWE ID, not portal ID

* Mon Mar 26 2018 Pooja Tiwari <ptiwari@redhat.com>
- CERTPX-2591 Added following new products in allowed programs to avoid traceback during their cert creation: * Power BE, Power 9, IBM z, IBM z (structure A)

* Thu Mar 22 2018 zajaz <zajaz@redhat.com>
- CERTPX-2587 Getting traceback during rhcert-ci run

* Thu Mar 22 2018 Anshul Behl <abehl@redhat.com>
- CERTPX-2581 Add ssh keypair of undercloud in the provisioned barmetal through certification CERTPX-2513 Gather the BMC hardware details in certification after ironic introspection CERTPX-2582 Only pick up one machine to be provisioned with ironic certification

* Thu Mar 22 2018 Shreyas Patil <shrpatil@redhat.com>
- CERTPX-2468 Feature for removing SUT from certification testing tab with a button.

* Wed Mar 21 2018 zajaz <zajaz@redhat.com>
- CERTPX-2580 The rhcert daemon is NOT running
- CERTPX-2546 sandboxes are sorted randomly in sandbox tab

* Wed Mar 21 2018 Greg Nichols <gnichols@redhat.com>
- CERTPX-2583 Diagnostic vendor products listing page /products

* Wed Mar 21 2018 Aniket Khisti <akhisti@redhat.com>
- CERTPX-2386 No var/log/message in sosreport - Henceforth, SOS report will collect logs as well. - Added attribute in rhcert.xml to limit the size of each set of log collected   by any SOS report plugin, to default cap of 50MB. - Removed RHEL5 applicable code (e.g. sysreport or --no-progressbar)

* Tue Mar 20 2018 Anshul Behl <abehl@redhat.com>
- CERTPX-2434 Ironic tests should be able to identify openstack version from undercloud

* Tue Mar 20 2018 Pooja Tiwari <ptiwari@redhat.com>
- CERTPX-2500 Fixed sut product detection logic. Synced with PNS and playback. CERTPX-2526 RHELRT vs RHELMRG products. CERTPX-2573 Fixed OS mismatch issue while adding an SUT via UI. CERTPX-2492 Fixed issue: kernel validation test fails on s390x with 7.5-ALT.

* Mon Mar 19 2018 zajaz <zajaz@redhat.com>
- CERTPX-2550 rhcert-cli submit should take file path as an argument

* Thu Mar 15 2018 Aniket Khisti <akhisti@redhat.com>
- CERTPX:965 - On WebUI, added single checkbox to select/unselect all the subsequent openstack  protocols & their supported features, on the openstack cert creation page of respective plugins.

* Tue Mar 13 2018 Aniket Khisti <akhisti@redhat.com>
- CERTPX-2518: unit tests suite should support production environment - enabled unittests for testing against prod, with default user cwetestuser - updated local .../tests/data.json schema for prod phase

* Tue Mar 13 2018 zajaz <zajaz@redhat.com>
- CERTPX-2542 [Sandox]when there is no SUT registred still we are getting override mismatch

* Tue Mar 13 2018 Ben Rose <brose@redhat.com>
- CERTPX-2496 - add functionality to Command to create dictionary object from output using regex groups

* Mon Mar 12 2018 zajaz <zajaz@redhat.com>
- CERTPX-2516 Unable to close RHCert Version Notification Alert in WUI  - Made alert dismissable  - Updated workflow for skipping alert when using higher versions on dev
- CERTPX-2363 SUT registration should support the port format also  - Fixed the loophole of host/ip overridding  - Refactored code

* Mon Mar 12 2018 Aniket Khisti <akhisti@redhat.com>
- VendorProduct.list API UnitTest should fetch latest product by Portal id instead of CWE id
- CERTPX-2519 XMLRPC API specification file correction for - 1) VendorProduct.get_5_4 - 2) Changed Cert.createLayeredCert to Cert.createLayerCert - 3) Changed all the type 'array' to 'list'

* Mon Mar 12 2018 Greg Nichols <gnichols@redhat.com>
- release notes revisions (cherry picked from commit 51104f3324932bcce18188c338d71a9a4943a6ac)

* Fri Mar 09 2018 jkinsman <jkinsman@redhat.com>
- CERTPX-2523: Root cause was patch for CERTPX-2475. Solution involved removing rhcertd's reference to the virtual TTY device *without* explicitly closing it.
- CERTPX-2293: Add a best-effort attempt to ensure requisite rhcert packages are imported from the redhat-certification code line instead of the locally-installed packages.

* Fri Mar 09 2018 Rajasi <rajkulka@redhat.com>
- CERTPX-2517: New hardware vendor cannot create the first              hardware product or certification from rhcert WUI - For a hardware vendor for new product, create a entry in cache   to enable new vendor to create 1st product - In New Certification Dialog, show the vendor name in vendor   product picker, even if no product exists for the vendor Change-Id: If9a0fc25dc24a9256844ddfe1966b2fc5d8e19f8

* Fri Mar 09 2018 Pooja Tiwari <ptiwari@redhat.com>
- CERTPX-2450 rhcert 5.9 release notes

* Fri Mar 09 2018 Greg Nichols <gnichols@redhat.com>
- rhcert 5.10

* Thu Mar 08 2018 Anshul Behl <abehl@redhat.com>
- CERTPX-2494 create an async view for product logo like attachments, kbases and supportcases

* Wed Mar 07 2018 Rajasi <rajkulka@redhat.com>
- CERTPX-2519 : Mark deprecated APIs VendorProduct.create and VendorProduct.get_4_7

* Tue Mar 06 2018 Shiyi Yuan <shiyuan@redhat.com>
- RHCWE-2522: Related Certifications tab needs a new API to avoid iterated calls to CWE

* Tue Mar 06 2018 Rajasi Kulkarni <rajkulka@redhat.com>
- CERTPX-2372: click Related Certification" of some HPE certs will return TypeError - Improve error handling for getting details of related certs - Use "certification_result" instead of "certification_status" to get status of cert   from the response of API Cert.getHardware_4_10"

* Mon Mar 05 2018 Pooja Tiwari <ptiwari@gmail.com>
- CERTPX-2484 Removed python-paramiko from rhcert spec file. - paramiko does not require before plan time. It can   be installed during plan time like other osp packages.

* Mon Mar 05 2018 Pooja Tiwari <ptiwari@redhat.com>
- CERTPX-2400 Fixed typo and corrected the alert message.
- Updated static files for PNS and kernel service.

* Fri Mar 02 2018 Shreyas Patil <shrpatil@redhat.com>
- CERTPX-2173 Fixed the issue causing failure while adding test system through WUI

* Thu Mar 01 2018 Shreyas Patil <shrpatil@redhat.com>
- CERTPX-2418 Submit result file in case of Management instead of moving file to the store to avoid traceback in case of RHCERT Management configuration

* Wed Feb 28 2018 Aniket Khisti <akhisti@redhat.com>
- CERTPX-2481: RPMDIFF spec file license failure - Changed License from GPL to GPLv2+

* Wed Feb 28 2018 Greg Nichols <gnichols@redhat.com>
- CERTPX-2507 add the test plan description in Progress of the hardware cert.

* Tue Feb 27 2018 Aniket Khisti <akhisti@redhat.com>
- CERTPX-1454: rhcert-util update command should not show error:invalid command if options are invalid. - Added validation for 1) Invalid File Path, 2) Invalid Results File & 3) Invalid file size

* Tue Feb 27 2018 Greg Nichols <gnichols@redhat.com>
- Revert CERTPX-2173 Prevent IOError traceback occuring in case of uploading gzipped files downloaded from Google Chrome browser to RHCERT WUI results.""

* Tue Feb 27 2018 Shreyas Patil <shrpatil@redhat.com>
- CERTPX-2173 Prevent IOError traceback occuring in case of uploading gzipped files downloaded from Google Chrome browser to RHCERT WUI results.

* Tue Feb 27 2018 Anshul Behl <abehl@redhat.com>
- CERTPX-2504 Not able to upload attachment in product-details tab

* Mon Feb 26 2018 Greg Nichols <gnichols@redhat.com>
- CERTPX-2482 [-backend.el6] RPMDIFF build log error flagged: /builddir/build/BUILDROOT/.../etc/rhcert-default.xml: No such file or directory
- CERTPX-2349 After uploading results from the progress tab it is redirecting to Testing tab

* Mon Feb 26 2018 zajaz <zajaz@redhat.com>
- CERTPX-1612 Sandbox: Adding of SUT requires clicking 'Override mismatch'
- CERTPX-2400 rhcert WUI should provide an alert if it detects a new version

* Mon Feb 26 2018 Ben Rose <brose@redhat.com>
- CERTPX-2381 - add constant for s390x arch

* Thu Feb 22 2018 Aniket Khisti <akhisti@redhat.com>
- CERTPX-1958: spelling mistake 'Reployment' instead 'Redeployment'

* Wed Feb 21 2018 Anshul Behl <abehl@redhat.com>
- CERTPX-2493 Attachment view still serially called in Product details tab

* Tue Feb 20 2018 Aniket Khisti <akhisti@redhat.com>
-   Modified unittest for checking vendor_nid as new param from API

* Mon Feb 19 2018 jkinsman <jkinsman@redhat.com>
- CERTPX-2475: Explicitly close stdin when running daemon, and/or listener processes in the background (review-only).

* Fri Feb 16 2018 Rajasi <rajkulka@redhat.com>
- CERTPX-2403 Red Hat Certification 5.8 Release Notes - Update release notes

* Fri Feb 16 2018 Greg Nichols <gnichols@redhat.com>
- rhcert 5.9
- CERTPX-2403 Red Hat Certification 5.8 Release Notes

* Fri Feb 16 2018 Pooja Tiwari <ptiwari@redhat.com>
- CERTPX-2473 Added exception handling during PNS response decoding

* Thu Feb 15 2018 Greg Nichols <gnichols@redhat.com>
- CERTPX-2474 remove service call from rhcertd (rhcert.redhatrelease.py)

* Wed Feb 14 2018 Greg Nichols <gnichols@redhat.com>
- CERTPX-2472 Certification dialog page includes more than two serial running calls to CWE/Hydra

* Wed Feb 14 2018 Aniket Khisti <akhisti@redhat.com>
- CERTPX-2432: unittests should accept necessary ids as arguments while running individual test via CLI - Unittest will check if parameters are provided via CLI arguement(env var), OR then   it will attempt to use the latest cert details of available programs, OR eventually   it will use older hard-coded values for the test. - Reordered test cases as first all creation, then all get-fetching & then update tests are defined.

* Tue Feb 13 2018 Greg Nichols <gnichols@redhat.com>
- CERTPX-2433 Certification details page includes more than two serial running calls to CWE/Hydra

* Tue Feb 13 2018 Pooja Tiwari <ptiwari@redhat.com>
- CERTPX-2464 [CCSP] Architecture test fails with case issue in Power9.
- CERTPX-2446 Realtime host showing as MRG in OS- no match on select host page. - Set RHELMRG as product short name for all real time products (MRG/RT)   to make it work with playback kernel service.

* Tue Feb 13 2018 Rajasi Kulkarni <rajkulka@redhat.com>
- CERTPX-2462: traceback when starting rhcert

* Mon Feb 12 2018 Greg Nichols <gnichols@redhat.com>
- CERTPX-2446 Realtime host showing as MRG in OS- no match on select host page

* Mon Feb 12 2018 Pooja Tiwari <ptiwari@gmail.com>
- CERTPX-2457 [RCO] Fixed issue with installation of required rpms.

* Fri Feb 09 2018 zajaz <zajaz@redhat.com>
- CERTPX-2357 Redirect to sandboxes when CWE is unreachable and alert error message
- CERTPX-2390 - Add new system should prompt alert on submitting empty hostname field
- CERTPX-2429 details tab, supported_features_default should show list of supported tests only not the unicode strings
- CERTPX-2410: Deleted or cleaned results file objects throwing Trace Backs on page reload

* Fri Feb 09 2018 jkinsman <jkinsman@redhat.com>
- CERTPX-2293: Remove report_script.py functionality that is unnecessary for Jenkins integration; add 'unittest' import to test_workflow to prevent NameError when importing WorkflowUnit class.

* Fri Feb 09 2018 Pooja Tiwari <ptiwari@gmail.com>
- CERTPX-2224 Change in director test: - Used 'heat-admin' user to login to overcloud. - Changed the utility function to run command with sudo.

* Thu Feb 08 2018 Greg Nichols <gnichols@redhat.com>
- CERTPX-2262 re-registration of an SUT does not update the LTS in all cases     - re-organized RedHatRelease.getKernelProductName to be callable in __init_     - moved logging out of getKernalProductName into platform test
- CERTPX-2262 re-registration of an SUT does not update the LTS in all cases     - add clean all to register command
- CERTPX-2444 restart" button error: doClean() got an unexpected keyword argument 'byPassPrompt'"

* Thu Feb 08 2018 zajaz <zajaz@redhat.com>
- CERTPEX-2363 SUT registration should support the port format also

* Thu Feb 08 2018 jkinsman <jkinsman@redhat.com>
- Add unittest backport package (unittest2) as a dependency for the redhat-certification unit tests.

* Thu Feb 08 2018 Pooja Tiwari <ptiwari@gmail.com>
- CERTPX-2224 [RCO] Change in director test: - Added prompt to enter overcloud node ip when test fails to detect   it via $ nova list"."

* Wed Feb 07 2018 Greg Nichols <gnichols@redhat.com>
- CERTPX-2372 click Related Certification" of some HPE certs will return TypeError"

* Wed Feb 07 2018 Pooja Tiwari <ptiwari@gmail.com>
- CERTPX-2436 [RCO] OSP test suite should be able to identify openstack version from undercloud. - Added rhosp-release as rpm dependency.
- CERTPX-2224 [RCO] Director test should be allowed to run from undercloud node as well. - Test can still be run from overcloud. Test logic remains same on gathering files   from controller. Added a feature to run command over ssh connection. - Made the directer an interactive test which means config file needs to be changed for CI run. - Added python-paramiko as a new dependency for rco. (This package already presents on   undercloud as well overcloud node so no need to install it separately.)
- CERTPX-2435 [Ironic] Added interactive tag in director undercloud test.

* Wed Feb 07 2018 Aniket Khisti <akhisti@redhat.com>
- CERTPX-2428: rhcert-util configuration command needs cosmetic change for ambiguous acknowledgement

* Tue Feb 06 2018 Aniket Khisti <akhisti@redhat.com>
- CERTPX-2424 : Use JUnitXML TestRunner for generating workflow unittests reports for jenkins consumption - included junitxml test runner in report_script.py

* Mon Feb 05 2018 Greg Nichols <gnichols@redhat.com>
- CERTPX-2262 re-registration of an SUT does not update the LTS in all cases

* Fri Feb 02 2018 Pooja Tiwari <ptiwari@redhat.com>
- Updated local static files for PNS and Kernel data.

* Thu Feb 01 2018 Shreyas Patil <shrpatil@redhat.com>
- CERTPX-2327 Using getMakesByVendor_5_7 instead of getMakesByVendor

* Tue Jan 30 2018 Aniket Khisti <akhisti@redhat.com>
- Fixed UnitTests for 1. Potential tracebacks due to absolute-relative paths 2. Removed phase=qa condition of API parameter assertions to allow testing    hydraAPI parameters on phase=hydrastage 3. Added temporary skip for WIP/failing tests to get cleaner TestSuit report 4. Included Cert.getMakesByVendor API UnitTest which was missed by erlier patch 5. Renamed script file to avoid conflict with test discovery. Change-Id: Ib538f0e7b899f560d3cdae8415474b5feef93604

* Tue Jan 30 2018 Pooja Tiwari <ptiwari@redhat.com>
- CERTPX-2319 Updated release notes for 5.7

* Mon Jan 29 2018 Shreyas Patil <shrpatil@redhat.com>
- CERTPX-1610 Added Back Button to create forms in WUI. Back button replicates functionality of Browser back button.

* Mon Jan 29 2018 Greg Nichols <gnichols@redhat.com>
- rhcert 5.8

* Mon Jan 29 2018 Rajasi Kulkarni <rajkulka@redhat.com>
- CERTPX-2327: Related Products tab of base/original RHEL cert does not show the related pass through products - Display base and pass through products on Related Products tab

* Fri Jan 26 2018 Gonéri Le Bouder <goneri@redhat.com>
- 1538831 - rhcert-ci junit output is not consistent with what has been actually run junit: handle REVIEW summary as PASS
- junit: handle REVIEW summary as PASS

* Fri Jan 26 2018 Greg Nichols <gnichols@redhat.com>
- CERTPX-2396 Results file links on the Results tab redirect to Certifications in cert not accessable.
- CERTPX-2373: cannot create passthrough cert for most vendors - Ensure missing ids are seen on Related Certifications tab

* Thu Jan 25 2018 Aniket Khisti <akhisti@redhat.com>
- CERTPX-2228: improve unit-tests to check for all the parameters of necessary APIs CERTPX-2226: Implement a script to perform the automated regression testing on the HydraAPIs CERTPX-2225: Write configuration file for unit-tests to switch between STAGE-QA env

* Thu Jan 25 2018 Pooja Tiwari <ptiwari@redhat.com>
- CERTPX-2319 rhcert 5.7 release notes.

* Wed Jan 24 2018 Rajasi Kulkarni <rajkulka@redhat.com>
- CERTPX-2371 API Performance Benchmark Integration - Minor Makefile changes
- CERTPX-2373: cannot create passthrough cert for most vendors - Download the vendor and product for passthru before redirect to   the pass through cert

* Wed Jan 24 2018 Greg Nichols <gnichols@redhat.com>
- CERTPX-2371 API Performance Benchmark Integration

* Wed Jan 24 2018 Pooja Tiwari <ptiwari@redhat.com>
- RCO bug fixes and code cleanup: - Fixed broken sahara test (CERTPX-2321) - Removed rhosp-9 specific and unused code. - Refactored code to remove unnecessary api based methods.

* Tue Jan 23 2018 Anshul Behl <abehl@redhat.com>
- CERTPX-1596 Missed changing Gluster name to that in tempest classes

* Mon Jan 22 2018 Shreyas Patil <shrpatil@redhat.com>
- CERTPX-2316 Updated the message displayed with loader while fetching makes for given vendor

* Mon Jan 22 2018 Greg Nichols <gnichols@redhat.com>
- CERTPX-2331 Related Certifications tab should show correct cert IDs
- CERTPX-2255 login does not redirect to the previous page
- CERTPX-2369 redirect from certification url to progress url causes redundant XMLRPC call

* Mon Jan 22 2018 Pooja Tiwari <ptiwari@redhat.com>
- CERTPX-2366 RHOSP version detection should not be a part of rhcertd process.

* Fri Jan 19 2018 Anshul Behl <abehl@redhat.com>
- CERTPX-1596 Mapping GlusterFS to GLUSTERFS

* Fri Jan 19 2018 Jianjun Wang <jianjwan@redhat.com>
- RHCWE-2468 Can API Cert.getMakesByVendor accept vendor_id instead of vendor_name like API VendorProduct.get_5_4

* Fri Jan 19 2018 Greg Nichols <gnichols@redhat.com>
- CERTPX-2358 rhcert-ci halts for interactive prompt
- CERTPX-2355 After uploading result file In testing tab it is loading logs and status of the SUT     - removed errors generated when there is no way to reach the host

* Thu Jan 18 2018 Anshul Behl <abehl@redhat.com>
- CERTPX-1596 Duplicate removal and GlusterFS string fixed

* Wed Jan 17 2018 Greg Nichols <gnichols@redhat.com>
- CERTPX-2350 After uploading result file it is not reflected in progress tab test plan    - change upload/submit dialog to save the file on the LTS if submitting
- CERTPX-2338 Consistent Certification Data Access and Storage    - remove diagnostic print

* Wed Jan 17 2018 Rajasi Kulkarni <rajkulka@redhat.com>
- CERTPX-2347: in product->product details tab, click on 'save' gives traceback : 'global name 'getEngineWorkflow' is not defined
- CERTPX-2329: Dell passthrough certs showing as vendor Sandbox Vendor in main cert page CERTPX-2328: Traceback on Create Sandbox when there is a Dell PT cert - Assign vendor_id as -1 to default Sandbox Vendor to avoid collision with vendor id   of any public vendor

* Tue Jan 16 2018 Anshul Behl <abehl@redhat.com>
- CERTPX-1596 Adding print statement to check the protocol info in stdout
- CERTPX-1596 The related test items should not be displayed when the protocols are not selected in manila test

* Tue Jan 16 2018 Greg Nichols <gnichols@redhat.com>
- CERTPX-2338 Consistent Certification Data Access and Storage    - remove redundant implementations updating VendorProduct info    - trigger VendorProduct reload on missing vendor products

* Mon Jan 15 2018 Aniket Khisti <akhisti@redhat.com>
- CERTPX-2333: rhcert should support testing new Hydra XMLRPC APIs for stage env.            : added phase=hydrastage" and phase="hydraqa" env attributes"

* Mon Jan 15 2018 Greg Nichols <gnichols@redhat.com>
- CERTPX-2338 Consistent Certification Data Access and Storage    - remove unnecessary downloads prior to redirects after cert creation
- CERTPX-2337 Platform and Status fields empty Certifications tab after creation
- CERTPX-2338 Consistent Certification Data Access and Storage    - added methods to model for syncronizing data    - moved code to Connection from View classes

* Thu Jan 11 2018 Greg Nichols <gnichols@redhat.com>
- CERTPX-2336 Unexpected keyword argument 'overwrite traceback when create HW cert"

* Thu Jan 11 2018 Pooja Tiwari <ptiwari@redhat.com>
- CERTPX-2326 [rco] Added exception handing in report generation. Resolves: https://gss--c.na7.visual.force.com/apex/Case_View?srPos=0&srKp=500&id=500A000000ZPSmP&sfdc.override=1

* Wed Jan 10 2018 Aniket Khisti <akhisti@redhat.com>
- CERTPX-2333: rhcert should support testing new Hydra XMLRPC APIs for stage env.     : added phase=hydrastage""

* Wed Jan 10 2018 Greg Nichols <gnichols@redhat.com>
- CERTPX-2334 testplan not visible in xml for manila certs    - changed wsg.connection so default config will save cert updates locally

* Wed Jan 10 2018 Shreyas Patil <shrpatil@redhat.com>
- CERTPX-1517 Display warning message for the user when trying to run tests without registering the server with a LTS. In case of AUTO mode prompts will be ignored

* Tue Jan 09 2018 Greg Nichols <gnichols@redhat.com>
- CERTPX-2312 leveraged test results not listed in Related Certifications page    - moved CWE Test Plan download code to wsgi Certification base class    - changed Progress and Related pages to call it

* Tue Jan 09 2018 Rajasi Kulkarni <rajkulka@redhat.com>
- CERTPX-2320: Old Passthrough certs are not getting downloaded in rhcert default installation - On Reltaed certifications tab of base cert, download all passthrough spec and cert   - those created earlier on hardware.redhat.com   - those created on differenet rhcert installation

* Tue Jan 09 2018 Pooja Tiwari <ptiwari@redhat.com>
- CERTPX-2275 [cloud] fixed minor typo in output of cloud/configuration test.

* Mon Jan 08 2018 Greg Nichols <gnichols@redhat.com>
- CERTPX-2322 traceback on /cwe/sync for QA Environment
- CERTPX-2323 results files uploaded from Sandboxes into Certifications can not be submitted

* Mon Jan 08 2018 Shreyas Patil <shrpatil@redhat.com>
- CERTPX-2286 Temporarily turning off the move to dustbin certificates to be shown in the certifications RHCERT UI

* Fri Jan 05 2018 Greg Nichols <gnichols@redhat.com>
- rhcert-5.7
- CERTPX-2314 Release Notes should allow html links

* Fri Jan 05 2018 Pooja Tiwari <ptiwari@redhat.com>
- CERTPX-2310 Fixed typo in rhcert.xml
- CERTPX-2311 [rco] Fixed traceback while displaying skipped tests in rco test report.

* Fri Jan 05 2018 Rajasi Kulkarni <rajkulka@redhat.com>
- CERTPX-2287: can't create Passthrough cert for different vendor CERTPX-2308: Passthrough cert showing wrong vendor on Stage - Set the Pass through vendor name for the Pass through cert and spec

* Thu Jan 04 2018 zajaz <zajaz@redhat.com>
- CERTPX-2309 - Upload results from Test Results tab hangs - Fixed the JS Issue CERTPX-2290 - JS cleanup

* Thu Jan 04 2018 Pooja Tiwari <ptiwari@redhat.com>
- Use api response as data source for all rhcert config(mngmt/test/def) except sandbox. Sandbox should fetch data from local store. Fixing following issues: CERTPX-2305 Product details URLS not saved in WebUI CERTPX-2306 Product Sample data not saving in WebUI CERTPX-2304 Certification Publish date not saving in rhcert WebUI CERTPX-2285 Platform and Status fields empty on Certification page

* Wed Jan 03 2018 Shreyas Patil <shrpatil@redhat.com>
- CERTPX-2303 Return error responses returned by JWT services for processing and displaying errors on login page
- CERTPX-2286 'Move to Dustbin' status will be displayed in Certifications table for all dustbin certs

* Wed Jan 03 2018 zajaz <zajaz@redhat.com>
- CERTPX 2290 - Upload Results file from HW Testing page hangs removed inline JS added alert on no file selected

* Tue Jan 02 2018 Rajasi Kulkarni <rajkulka@redhat.com>
- CERTPX-2287: can't create Passthrough cert for different vendor - Allow partner to create passthrough spec and psaathrough certs for   different/public vendors - Update API spec - Add unit test for API to get makes of a vendor

* Tue Jan 02 2018 zajaz <zajaz@redhat.com>
- CERTPX-2290 Upload Results file from HW Testing page hangs - JS client incompatibility issue

* Wed Dec 27 2017 Jianjun Wang <jianjwan@redhat.com>
- RHCWE-2453 Cert.getCertifications should include any certs moved to dustbin

* Wed Dec 27 2017 zajaz <zajaz@redhat.com>
- CERTPX-1611- OpenStack new certification WUI has Create label instead of Next

* Tue Dec 26 2017 Rajasi <rajkulka@redhat.com>
- CERTPX-2274: Hydra APIs aren't returning 401 fault code after access token expires - Fix the unit test for the new timeout value of access token expiry

* Tue Dec 26 2017 Rajasi Kulkarni <rajkulka@redhat.com>
- CERTPX-2248: In httpd log, while creating a new hardware product calls to both VendorProduct.create              and VendorProduct.create_5_4 are seen - Remove unnecessary debugPrint statements

* Thu Dec 21 2017 Greg Nichols <gnichols@redhat.com>
- CERTPX-2292 Results File upload should allow user to also submit the file to Red Hat

* Thu Dec 21 2017 zajaz <zajaz@redhat.com>
- CERTPX-2272: traceback when accessing results from Test Results page

* Wed Dec 20 2017 Pooja Tiwari <ptiwari@redhat.com>
- CERTPX-2282 [rco] Tagged all neutron feature tests with tag 'neutron'.

* Wed Dec 20 2017 Greg Nichols <gnichols@redhat.com>
- CERTPX-2169 Proxy configuration: login and microservice calls ignore proxy settings in /etc/rhcert.xml

* Tue Dec 19 2017 Pooja Tiwari <ptiwari@redhat.com>
- CERTPX-2249 [rco] Reason of skipped test should be part of openstack test report.

* Mon Dec 18 2017 zajaz <zajaz@redhat.com>
- CERTPX-701- RHCERT-CLI does not show submit command in help - Added description for submit in rhcert-cli help

* Mon Dec 18 2017 Pooja Tiwari <ptiwari@redhat.com>
- CERTPX-2229 [rco] For manila the subtests grouping needs to happen on the path level rather than class.

* Fri Dec 15 2017 Pooja Tiwari <ptiwari@redhat.com>
- CERTPX-2206 Manila Features should have subtests.
- CERTPX-2250 Added release notes as a part of rhcert package: - The release notes should be a plan text file packaged within rhcert rpm. - The rhcert WUI should provide a link from the configuration page to show the release notes.
- CERTPX-2267 Fixed 'format' method syntax to support Python 2.6.

* Fri Dec 15 2017 Rajasi Kulkarni <rajkulka@redhat.com>
- CERTPX-2254: copy leverage information not working - For default installation we get the cert from CWE and not from store,   for leverage we try to copy component details to cert in store,   but that fails as the cert has not stored the local file path - This patch is modifying to use for rhcert default installation   the cert from the store and not from CWE for all tabs of the Certification""

* Wed Dec 13 2017 Shreyas Patil <shrpatil@redhat.com>
- CERTPX-2234 Display respective CatalogServer URL's when user clicks 'Open a new support case' button in WUI

* Wed Dec 13 2017 Pooja Tiwari <ptiwari@redhat.com>
- CERTPX-2207 [rco] Restructured the tempest_config test to enable prompt on UI.

* Tue Dec 12 2017 Shreyas Patil <shrpatil@redhat.com>
- CERTPX-1600 Handled 'ValueError' in EL-6 as Python 2.6 doesn't allow empty braces as placeholders in format() method

* Tue Dec 12 2017 Rajasi <rajkulka@redhat.com>
- CERTPX-1995: 'Enable Debug Output' doesn't work as expected - Correct the logic to store the bebug status in views
- CERTPX-1995: 'Enable Debug Output' doesn't work as expected - Remove unused template

* Mon Dec 11 2017 Greg Nichols <gnichols@redhat.com>
- CERTPX-2240 Certification Details Page should change Portal ID" to "ID"."

* Fri Dec 08 2017 Shreyas Patil <shrpatil@redhat.com>
- CERTPX-2168 Moved to JS to inline script, and changing to call only onClick in case of Restart button on Configuration Page

* Fri Dec 08 2017 Pooja Tiwari <ptiwari@redhat.com>
- CERTPX-2191 [rco] Removed interactive tag from Neutron/Manila/Cinder tests.

* Thu Dec 07 2017 Shreyas Patil <shrpatil@redhat.com>
- CERTPX-2168 Allow Partners to delete lock, clean results and logs from the RHCERT WUI

* Thu Dec 07 2017 Greg Nichols <gnichols@redhat.com>
- CERTPX-2246 rhcert-util should provide utility command to test xslt translation of results.xml

* Thu Dec 07 2017 Anshul Behl <abehl@redhat.com>
- CERTPX-2227 [RHOSP12][IRONIC] Introspection test is in waiting state

* Thu Dec 07 2017 Pooja Tiwari <ptiwari@redhat.com>
- CERTPX-2207 [rco] tempest_config test should have a subtest.

* Wed Dec 06 2017 Greg Nichols <gnichols@redhat.com>
- CERTPX-2230 created field is blank in details tab of certification     - removed from page

* Tue Dec 05 2017 Ben Rose <brose@redhat.com>
- CERTPX-2238 - add constant to be consistent for rhcert-transfer alias for pulling hwcert fv files from LTS

* Mon Dec 04 2017 Shreyas Patil <shrpatil@redhat.com>
- CERTPX-1304 URL Validation while creating Openstack Certificates or updating an existing Openstack Product details on Certification page
- CERTPX-1568 Displaying CERT_NID in alert message instead of CERT_ID for better user experience

* Fri Dec 01 2017 Greg Nichols <gnichols@redhat.com>
- release-5.6

* Fri Dec 01 2017 Shreyas Patil <shrpatil@redhat.com>
- CERTPX-1600 Wrongly checked LC_ALL instead of LANG environment variable, causing tests to fail

* Fri Dec 01 2017 Anshul Behl <abehl@redhat.com>
- CERTPX-2128 Fix the policy regexes with respect to RHOSP12

* Thu Nov 30 2017 Shreyas Patil <shrpatil@redhat.com>
- CERTPX-1600 Change locale to 'en_US.UTF-8' for non-english locale systems for duration of running the tests.

* Thu Nov 30 2017 Rajasi Kulkarni <rajkulka@redhat.com>
- Print the workflow exceptions in httpd error log

* Wed Nov 29 2017 Anshul Behl <abehl@redhat.com>
- CERTPX-2220 [Ironic] Node introspection runs for only one node in instackenv

* Tue Nov 28 2017 Shreyas Patil <shrpatil@redhat.com>
- CERTPX-1613 CERTPX-1615 De-select checkboxes for Cinder and Manila when Other Protocol/Plugin" input box is empty"
- CERTPX-2152 Display '--no-wait' in the help for 'rhcert-ci run --help'

* Tue Nov 28 2017 Rajasi Kulkarni <rajkulka@redhat.com>
- CERTPX-2158: kdump nfs test should return kdump.conf file to original state - Dump config file changes to a file before panic/reboot

* Mon Nov 27 2017 Anshul Behl <abehl@redhat.com>
- CERTPX-2210 For RHOSP11, 'test_name'-tempest.log not showing the logs of tempest run

* Mon Nov 27 2017 Rajasi Kulkarni <rajkulka@redhat.com>
- CERTPX-1816: RDMA: iWARP tests run via rhcert-cli prompt for unreasonable input strings - Instead of expecting IP address on prompt, ask partner to select the   choice number. Accept choice number as well as the choice value in the   prompt(Here IP address). - This affects all tests expecting copy/paste in prompt from question

* Thu Nov 23 2017 Rajasi Kulkarni <rajkulka@redhat.com>
- CERTPX-2196: traceback in suspend test on el6 - 'module' object has no attribute 'check_output' - for redhat-certification-hardware.el6, python 2.6 on RHEL 6 does not   support check_output method of subprocess

* Wed Nov 22 2017 Pooja Tiwari <ptiwari@redhat.com>
- CERTPX-2140 Checked and disabled checkbox for supportable sandbox test.

* Tue Nov 21 2017 Pooja Tiwari <ptiwari@redhat.com>
- CERTPX-2023 [rco] Improved test report: - Segregated test report based on the test class. - Added 'Test Summary' in tabular format to show the test classes and counts. - Affects manila, cinder and neutron.
- CERTPX-2167 [rco] Fixed traceback while running sahara.

* Mon Nov 20 2017 Aniket Khisti <akhisti@redhat.com>
- CERTPX-2067 : Test API Cert.getCertifications from rhcert  - Fixed traceback in unittest due to None responose.  - Commented with necessary QA-STAGE cert details for    HYDRA-CWE XMLRPC API Testing.

* Fri Nov 17 2017 Benjamin Berg <bberg@redhat.com>
- CERTPX-2183: Add input device class

* Fri Nov 17 2017 Pooja Tiwari <ptiwari@redhat.com>
- [rco] Fixed traceback: - CERTPX-2167 Fixed: NameError: global name 'CONFIG_FILE' is not defined" - Reorganised code: removed unused constansts

* Thu Nov 16 2017 Rajasi <rajkulka@redhat.com>
- CERTPX-1701: Partners are not notified they will be contacted for further process after uploading a spec for a Supplemental Cert - Partners should be allowed to create a Supplemental cert from rhcert, just like CWE

* Thu Nov 16 2017 Pooja Tiwari <ptiwari@redhat.com>
- CERTPX-2124 Added test blacklist for cinder boot.

* Thu Nov 16 2017 Greg Nichols <gnichols@redhat.com>
- CERTPX-1398 Document proxy configuration for rhcert WUI and CLI     - add commented-out example to defult rhcert.xml config file
- CERTPX-2145 no message to login after timeout

* Wed Nov 15 2017 Shreyas Patil <shrpatil@redhat.com>
- CERTPX-1479 Generate Django secret key while starting the rhcert application for the first time

* Wed Nov 15 2017 Greg Nichols <gnichols@redhat.com>
- CERTPX-2178 User.login and User.logout XMLRPC calls should be marked deprecated""
- CERTPX-2179 Fedora: Tests fail on fedora as syslog cannot be read

* Wed Nov 15 2017 Pooja Tiwari <ptiwari@redhat.com>
- CERTPX-2104 [rco] Fixed bug: IPV6 tempest tests showing in neutron_ipv4 feature test.
- CERTPX-2117 [rco] Capture tempest.log created as part of each openstack tempest run.

* Tue Nov 14 2017 Pooja Tiwari <ptiwari@redhat.com>
- CERTPX-2151 [rco] All neutron feature tests should have subtests.

* Mon Nov 13 2017 Pooja Tiwari <ptiwari@redhat.com>
- rhcert-5.5
- CERTPX-2151 [rco] All cinder feature tests should have subtests: - Cinder Backup subtest for cinder_backups feature. - Cinder Consistency Group subtest for cinder_consistency_groups feature.

* Mon Nov 13 2017 Anshul Behl <abehl@redhat.com>
- CERTPX-2153 Ironic test is failing in rhcert-ci test run if no config

* Mon Nov 13 2017 Pooja Tiwari <ptiwari@gmail.com>
- CERTPX-2164 [rco] Fixed the given traceback in tempest_config test: - AttributeError: 'OpenStackTempestVerifyTest' object has no attribute 'tempest_conf'

* Mon Nov 13 2017 Shreyas Patil <shrpatil@redhat.com>
- CERTPX-2159 Getting URL path instead of absolute URL along with query params to avoid problem while resolving for the correct view in the middleware

* Fri Nov 10 2017 Rajasi <rajkulka@redhat.com>
- CERTPX-2146: Not able to login - Traceback seen when trying to login without installing ca certs on qa/stage env

* Fri Nov 10 2017 Anshul Behl <abehl@redhat.com>
- CERTPX-2108 Fixed the ironic tempest dependency issues

* Fri Nov 10 2017 Pooja Tiwari <ptiwari@redhat.com>
- CERTPX-2108 [RCO] Used rco utility for command execution.

* Thu Nov 09 2017 Anshul Behl <abehl@redhat.com>
- CERTPX-2111 Ironic rhcert-ci test is interactive

* Thu Nov 09 2017 Aniket Khisti <akhisti@redhat.com>
- CERTPX-2056 : Test API FIle.upload from rhcert CERTPX-2057 : Test API File.download from rhcert  - refactored unittest into separate test file    for rhcert.rhcert.workflow.engine.py

* Thu Nov 09 2017 Pooja Tiwari <ptiwari@redhat.com>
- Reorganised ironic files to fix build issues.

* Wed Nov 08 2017 Rajasi <rajkulka@redhat.com>
- CERTPX-2112: In management only, after getting certs from CWE they get stored in /var/www/rhcert/store/results - While submitting results to a cert, results file should not be copied in rhcert store

* Wed Nov 08 2017 Pooja Tiwari <ptiwari@redhat.com>
- CERTPX-2108 [RCO] Use command response as primary source for listing tempest tests. - Used $ostesr -l for rhosp-11/12 and $testr list-tests for rhosp-10. - Fallback to local file if command fails. - Rhosp-9 still uses local file.
- CERTPX-2131 [RCO] Fixed tempest test execution issue for rhosp10: - Defined getHarmfulRPMs(), similar to getRequiredRPMs(), for tests. - Added logic to remove unwanted packages for rhosp10 as they hinder   test execution. - The package openstack-tempest-all installs some of the unwanted packages   that cause issue, therefore removed it from the list of required   rpms and added the useful ones.

* Wed Nov 08 2017 Shreyas Patil <shrpatil@redhat.com>
- CERTPX-2000 CERTPX-2003 CERTPX-2007 CERTPX-2134 - Using Django resolve() for lookup instead of regex - Code clean up for read-ability

* Tue Nov 07 2017 Greg Nichols <gnichols@redhat.com>
- CERTPX-2012 The Certification->Results page should show previously-submitted test runs     - add listing of submitted results to progress page     - provide download of submitted results
- CERTPX-2012 The Certification->Results page should show previously-submitted test runs     - remove print statements

* Tue Nov 07 2017 Shreyas Patil <shrpatil@redhat.com>
- CERTPX-2134 CERTPX-2003 CERTPX-2007 Handled traceback on debug message print and added filter for urls to disallow navigation to results

* Mon Nov 06 2017 Shreyas Patil <shrpatil@redhat.com>
- CERTPX-2003 CERTPX-2007 Disallow certain routes while Server configuration is not default. Implemented Django middleware for processing views

* Mon Nov 06 2017 Aniket Khisti <akhisti@redhat.com>
- CERTPX-2048 CERTPX-2049 CERTPX-2050 CERTPX-2054 CERTPX-2055  - refactored & added unittest for rhcert.workflow.vendorProdoct.py

* Fri Nov 03 2017 Shreyas Patil <shrpatil@redhat.com>
- CERTPX-2038 Fixed traceback while navigating to 'Related Certifications' tab on Certification caused because of vendorID added as part of getProduct API

* Thu Nov 02 2017 Greg Nichols <gnichols@redhat.com>
- CERTPX-2092 Not able to create vendor products
- CERTPX-2012 The Certification->Results page should show previously-submitted test runs     - fix unit test
- CERTPX-2027 Remove 'create new cloud product' from rhcert    - if cloud product create is attempted, a page with a message is produced instead
- CERTPX-2121 rhcert does not provide error details for Workflow Proxy Error""

* Thu Nov 02 2017 Aniket Khisti <akhisti@redhat.com>
- CERTPX-2047: Test API Cert.getSubmittedLog from rhcert  - Added unittest for Cert.getSubmittedLog API  - fixed getComments test

* Thu Nov 02 2017 Shreyas Patil <shrpatil@redhat.com>
- CERTPX-1905: Handled rhcertStore logic in connection

* Thu Nov 02 2017 Pooja Tiwari <ptiwari@redhat.com>
- CERTPX-2083 Mark supportable mandatory test in OpenStack, Cloud and Ironic test suite.
- Updated repo url in Dockerfile.in.

* Wed Nov 01 2017 Gonéri Le Bouder <goneri@redhat.com>
- JUNIT: XML protect the test logs

* Tue Oct 31 2017 Shreyas Patil <shrpatil@redhat.com>
- CERTPX-1905 Fix for traceback while uploading Sandbox results
- CERTPX-2085 rhcert-cli --help doesn't show 'version' option. Converted the help string to triple quotes

* Tue Oct 31 2017 Greg Nichols <gnichols@redhat.com>
- RHCWE-2363 XMLRPC VendorProduct.create and VendorProduct.get should accept and return vendor_id

* Tue Oct 31 2017 Pooja Tiwari <ptiwari@redhat.com>
- Updated rhcert local static files: redhat-products.json, valid-kernels.json

* Mon Oct 30 2017 Anshul Behl <abehl@redhat.com>
- CERTPX-2089 director_undercloud test is failing and giving traceback
- CERTPX-1982 [RHOSP12 Manila cert] manila_snapshot_revert_to_snapshot test is running random compute tempest tests

* Mon Oct 30 2017 Aniket Khisti <akhisti@redhat.com>
- CERTPX-2043 & CERTPX-2044 : Added unit tests for  - Cert.getCommentsOfCert & Cert.addCommentForCert API

* Mon Oct 30 2017 Greg Nichols <gnichols@redhat.com>
- CERTPX-2012 The Certification->Results page should show previously-submitted test runs     - add workflow wrapper and unit tests
- CERTPX-2091 Results submission through CLI fails with error: 'Error: missing or invalid login/password'
- CERTPX-2005 Login page causes traceback in rhcert web ui testing" mode.    - redirect login to sandboxes tab on testing installation"

* Mon Oct 30 2017 Pooja Tiwari <ptiwari@redhat.com>
- CERTPX-2026 Backup separated out as a feature in Cinder certification.

* Fri Oct 27 2017 Aniket Khisti <akhisti@redhat.com>
- CERTPX-2041: Test API Cert.updateOpenstack_4_7 from rhcert - modified unittest with expected arguments for XML RPC V2

* Fri Oct 27 2017 Greg Nichols <gnichols@redhat.com>
- CERTPX-2021 COMMAND method(s) logging    - fix rpm build to exclude rhcert/suites from base packages

* Fri Oct 27 2017 Pooja Tiwari <ptiwari@redhat.com>
- CERTPX-2028 Change in cloud configuration subscription service test: - Better mechanism to detect if SUT is using Satellite subscription.

* Thu Oct 26 2017 Greg Nichols <gnichols@redhat.com>
- CERTPX-2021 COMMAND method(s) logging    - update schema definition
- CERTPX-2021 COMMAND method(s) logging    - simplify rpm spec to include all of site-packages/rhcert
- CERTPX-2021 COMMAND method(s) logging    - added rhcert.model module for XML docs/wrappers    - added CommandXML for capturing rhcert.command.Command as XML during test runs    - updated CSS for rendering new command elements in WUI

* Thu Oct 26 2017 Shreyas Patil <shrpatil@redhat.com>
- CERTPX-2031 Yes radio button on Product Sample page not saving Setting active tab as 'sample' with program as Hardware will update certification details resolving the problem

* Thu Oct 26 2017 Anshul Behl <abehl@redhat.com>
- CERTPX-1588 [Tracker]Supporting OSP12 certification

* Thu Oct 26 2017 Shiyi Yuan <shiyuan@redhat.com>
- RHCWE-2331: A CWE API call(s) is/are needed to allow rhcert to list and download previously submitted results files.

* Thu Oct 26 2017 Aniket <akhisti@redhat.com>
- CERTPX-1969: write unit test case for updateOpenStack API  - added updateospcert test & related tests  - added docstrings & refactored unit tests

* Wed Oct 25 2017 Shreyas Patil <shrpatil@redhat.com>
- CERTPX-1172 Improvement of error message when open ports could not be checked - Showing error messages thrown by the test on STDERR

* Wed Oct 25 2017 Greg Nichols <gnichols@redhat.com>
- CERTPX-2084 Traceback on Progress page if not logged-in
- CERTPX-2082 rhcert WUI sends refresh token unncecessarily.

* Wed Oct 25 2017 Pooja Tiwari <ptiwari@redhat.com>
- Fixed CERTPX-2066 and CERTPX-2072 - Used argparse module in place of click to avoid extra dependency. - Fixed possible traceback errors.

* Tue Oct 24 2017 Rajasi <rajkulka@redhat.com>
- CERTPX-2010: For management installation - The local store should never be accessed - For the Related Certs tab, all the details should be displayed without accessing   local store
- CERTPX-2010: For management installation - The local store should never be accessed - Related Certifications should not fetch info from local store for defalut and mangement installation
- CERTPX-2036: Same banner messages can be seen multiple times on same page of RHCERT WUI - Display banner messages only on the rhcert homepage

* Tue Oct 24 2017 Aniket <akhisti@redhat.com>
- CERTPX-1968: Unit Tests for creating new RHELOSP cert for each component      -  added unittests for creating openstack certification with 	management application plugin
- CERTPX-1785: Refactor unit tests in rhcert.workflow.workflow.py to a   diferent unit tests script

* Fri Oct 20 2017 Greg Nichols <gnichols@redhat.com>
- release 5.4
- CERTPX-1743 Remove rhcert apache config files from redhat-certification-backend.el6    - remove chcon calls on web directories
- CERTPX-2018 rhcert should support testing new Hydra XMLRPC APIs
- CERTPX-2032 traceback with comments in Product Sample page
- CERTPX-1743 Remove rhcert apache config files from redhat-certification-backend.el6    - add notInstalled" server configuration for environment API    - do not try and run server mode tests if server is not installed"
- CERTPX-2008 Unable to create new hardware vendor product in Management-only configuration    - work-around for ambiguity in vendor names vs ids.

* Thu Oct 19 2017 Ben Rose <brose@redhat.com>
- CERTPX-1979 - add config value for nvram file required for ARM fv
- CERTPX-1979 - add constant for aarch64 arch

* Wed Oct 18 2017 Rajasi <rajkulka@redhat.com>
- CERTPX-2018: rhcert should support testing new Hydra XMLRPC APIs - Support new catalog URL's endpoint https://access.qa.redhat.com/hydra/rest/cwe/xmlrpc/v2   for testing hydra implemented XMLRPC when phase = hydraqa" in rhcert.xml conf file"
- CERTPX-1977: Traceback occurs when user uploads a non gz file through the 'Upload results file' button in Testing tab

* Wed Oct 18 2017 Greg Nichols <gnichols@redhat.com>
- CERTPX-2015 installing rhcert-hw does not install all dependencies needed to start rhcert
- CERTPX-2016 traceback on Product Details page    - prevent traceback if product info is missing    - add alert if product info is missing

* Tue Oct 17 2017 Greg Nichols <gnichols@redhat.com>
- CERTPX-1743 Remove rhcert apache config files from redhat-certification-backend.el6
- CERTPX-2004 Investigate: Call Strata directly for Vendor Product information

* Tue Oct 17 2017 Rajasi <rajkulka@redhat.com>
- CERTPX-1935: Show the banner message(s) in RHCERT - Display banner messages as dismissible alerts in the base template

* Tue Oct 17 2017 Aniket <akhisti@redhat.com>
- CERTPX-1968: Unit Tests for creating new RHELOSP cert for each component  - added unittests for creating openstack certification with Blockstorage,    Networking, Filestorage & Objectstorage plugins

* Tue Oct 17 2017 Rajasi Kulkarni <rajkulka@redhat.com>
- CERTPX-2011: Clicking on 'Save Assignment' button at Certification->Testing gives traceback

* Mon Oct 16 2017 Anshul Behl <abehl@redhat.com>
- CERTPX-1946 CLONE - Need a system to track tempest tests to cert feature tests

* Mon Oct 16 2017 Greg Nichols <gnichols@redhat.com>
- CERTPX-1994 RHCERT should pass the JWT format token not rh_sso format to CWE when calling cwe api    - remove failure code from JWT to legacy SSO

* Mon Oct 16 2017 Rajasi <rajkulka@redhat.com>
- CERTPX-1840: Size of attachment is not specified In Certification>Dialog tab - Cap the maximum file size limit for attachments that will be stored to bugzilla   to 14MB

* Mon Oct 16 2017 Ben Rose <brose@redhat.com>
- CERTPX-1779 - add ppc64le to constants

* Fri Oct 13 2017 Rajasi <rajkulka@redhat.com>
- CERTPX-2001: Fix unit test for VendorProducts.list
- CERTPX-1998: Logout on results page gives a traceback
- CERTPX-1935: Show the banner message(s) in RHCERT - Modified API name - Update creds to cert request fixed

* Fri Oct 13 2017 Shiyi Yuan <shiyuan@redhat.com>
- RHCWE-2313 : Provide API to return the banner message to RHCERT

* Thu Oct 12 2017 Aniket Khisti <akhisti@redhat.com>
- CERTPX-1820: WARN" Status displayed in green on rhcert-WUI instead of yellow  - Fixed

* Thu Oct 12 2017 Greg Nichols <gnichols@redhat.com>
- CERTPX-1938 Management Installation: do not expose file system in rhcert.conf apache config
- CERTPX-1758 Invalid Error displayed when user uploads a non-gz file from 'Test Results' tab on landing page
- CERTPX-1997 cwe status traceback

* Thu Oct 12 2017 Rajasi <rajkulka@redhat.com>
- CERTPX-1922: The rhcert WUI should require login - For default rhcert installation, the Cancel button on login page   should be presented with only Sandbox and Results tab
- CERTPX-1935: Show the banner message(s) in RHCERT - Added unit test for API Cert.getBannerMessage

* Wed Oct 11 2017 Rajasi <rajkulka@redhat.com>
- CERTPX-1967: Not able to run tests for openstack when I click on add a system in              Testing tab getting exception and also getting the same error              when i click on any button from testplan - synchronize certs and products for default installation - Modified the calls to CWE workflows as per the new Connection class design

* Wed Oct 11 2017 Greg Nichols <gnichols@redhat.com>
- CERTPX-1882 Add Configuration Setting for Management and Disconnected Installation     - add rhcert-util configure" to show current installation configuration"
- CERTPX-1883 WUI: Don't Show Certification Testing functions for a Management Installation    - revise configuration headings
- CERTPX-1987 Unable to submit cloud results with rhcert pointing to qa

* Tue Oct 10 2017 Greg Nichols <gnichols@redhat.com>
- CERTPX-1883 WUI: Don't Show Certification Testing functions for a Management Installation    - revise configuration page to show installed configuration and filter output appropriately.

* Tue Oct 10 2017 Rajasi <rajkulka@redhat.com>
- CERTPX-1967: Not able to run tests  for openstack when I click on add a system in Testing tab getting exception and also getting the same error when i click on any button from testplan - Add redirect in getting cert from local store fails

* Mon Oct 09 2017 Rajasi <rajkulka@redhat.com>
- CERTPX-1922: The rhcert WUI should require login - For management installation hide the Cancel button on login page

* Fri Oct 06 2017 Pooja Tiwari <ptiwari@gmail.com>
- CERTPX-1947 Test Logging Improvement in OpenStack Certification. - Change applied to all plugins: cinder, sahara, manila etc. - Mainly improves the neutron test logging for RHOSP-10.

* Thu Oct 05 2017 Rajasi <rajkulka@redhat.com>
- CERTPX-1823: For disconnected/Sandbox use, the login page should not appear. - Hide the login dropdown from the Configuration page
- CERTPX-1967: Not able to run tests  for openstack when I click on add a system in Testing tab getting exception and also getting the same error when i click on any button from testplan
- CERTPX-1978: Update action on sandboxes test results is giving a traceback
- CERTPX-1974: Traceback occurs when user clicks on Test Results tab on Landing page

* Wed Oct 04 2017 Rajasi <rajkulka@redhat.com>
- CERTPX-1823: For disconnected/Sandbox use, the login page should not appear. - Login dropdown in the upper right section of page should not appear for disconnected/testing rhcert - Hide the Refresh button for disconnected/testing rhcert - Disable calls to check CWE ping status and to auto sync certs for disconnected/testing rhcert - The default view for disconnected/testing rhcert should be sandboxes and not certifications
- CERTPX-1823: For disconnected/Sandbox use, the login page should not appear. - Login page will not be shown for discoonection/testing installation   Redirect to the certifications page

* Wed Oct 04 2017 Pooja Tiwari <ptiwari@redhat.com>
- CERTPX-1845 Support additional architectures and hypervisors in CCSP.

* Tue Oct 03 2017 Rajasi <rajkulka@redhat.com>
- CERTPX-1922: The rhcert WUI should require login - changed views to require login

* Tue Oct 03 2017 Greg Nichols <gnichols@redhat.com>
- CERTPX-1971 Certification - Testing page won't load
- CERTPX-1885 Management Installation: Provide Session/Memory-based Certification classes     - fix new cert with product creation workflow

* Mon Oct 02 2017 Greg Nichols <gnichols@redhat.com>
- CERTPX-1885 Management Installation: Provide Session/Memory-based Certification classes     - clean up unused product pages/templates
- CERTPX-1885 Management Installation: Provide Session/Memory-based Certification classes     - fix background sync for default installation
- .woff2 font files needed by patternfly are missing

* Fri Sep 29 2017 Rajasi <rajkulka@redhat.com>
- Mark deprecated APIs in the spec file

* Fri Sep 29 2017 Greg Nichols <gnichols@redhat.com>
- release-5.3

* Thu Sep 28 2017 Rajasi <rajkulka@redhat.com>
- CERTPX-1799: no link to support cases in Certification - Details page - Bug fixes to support adding kbase and support case for all programs

* Thu Sep 28 2017 Greg Nichols <gnichols@redhat.com>
- CERTPX-1932 Actions - Save in Results page brings me to Test Results tab

* Wed Sep 27 2017 Rajasi <rajkulka@redhat.com>
- CERTPX-1002: Investigation: Allow a partner to open a support case from a certification CERTPX-1799: no link to support cases in Certification - Details page On Certifications > Details tab, - Added link to view the Knowledge base articles/solution on Customer Portal - Reference to Knowledge base articles can be associated with a cert by entering its ID
- CERTPX-1799: no link to support cases in Certification - Details page CERTPX-1002: Investigation: Allow a partner to open a support case from a certification On Certifications > Details tab, - Added link to open/view the support cases on Customer Portal - Support case can be associated with a cert by entering its ID

* Wed Sep 27 2017 Anshul Behl <abehl@redhat.com>
- CERTPX-1940 Ironic driver validation test in interactive but during ironic run it's not showing that it is interactive

* Wed Sep 27 2017 Aniket <akhisti@redhat.com>
- CERTPX-1924: Display the sandbox certification ID in the Sandboxes page - Fixed.

* Wed Sep 27 2017 Pooja Tiwari <ptiwari@redhat.com>
- CERTPX-1936 Removed RHELMRG from product list. - User will no longer be able to create MRG certification.

* Tue Sep 26 2017 Rajasi <rajkulka@redhat.com>
- CERTPX-1187: Add validations in test result update via WUI. - Fixed the alert to persist over the session
- CERTPX-1930: When a product has multiple certified base RHEL certs available for              creating layered certs, all are shown in different select options              in case of creating Ready State certs
- CERTPX-1548: Active tabs not highlighted under Product tab,              for Cloud certifications

* Tue Sep 26 2017 jkinsman <jkinsman@redhat.com>
- CERTPX-1900: Remove reference to variable that no longer exists.
- CERTPX-1900: cleaned up version of original patch.

* Tue Sep 26 2017 Anshul Behl <abehl@redhat.com>
- CERTPX-1929 Changing the name of ironic subpackage to redhat-certification-ironic-preview

* Tue Sep 26 2017 Greg Nichols <gnichols@redhat.com>
- CERTPX-1885 Management Installation: Provide Session/Memory-based Certification classes     - add results submission from the progress page

* Tue Sep 26 2017 Aniket <akhisti@redhat.com>
- CERTPX-1707 : model shows twice in Product field of Certification Details page - Fixed the value of Product field for hardware, cloud & openstack.

* Tue Sep 26 2017 Pooja Tiwari <ptiwari@redhat.com>
- CERTPX-1379 rhcert/self_check using RPMVerification class functionality

* Mon Sep 25 2017 Anshul Behl <abehl@redhat.com>
- CERTPX-1927 director_undercloud tests shows 'review' when running ironic
- CERTPX-1929 Install only redhat-certification-ironic when running ironic tests
- CERTPX-1928 Change the name of ironic preview package to redhat-certification-ironic

* Mon Sep 25 2017 jkinsman <jkinsman@redhat.com>
- CERTPX-1900: Refactor repository creation logic to include the most recently-built redhat-certification packages from Brew.

* Mon Sep 25 2017 Greg Nichols <gnichols@redhat.com>
- CERTPX-1885 Management Installation: Provide Session/Memory-based Certification classes     - update cert/product creation to use wsgi.Connection over rhcert.rhcertStore
- CERTPX-1883 WUI: Don't Show Certification Testing functions for a Management Installation
- CERTPX-1885 Management Installation: Provide Session/Memory-based Certification classes

* Fri Sep 22 2017 Greg Nichols <gnichols@redhat.com>
- CERTPX-1922 The rhcert WUI should require login    - changed certifications and certification views to require login    - added Connection class to manage local vs. CWE data for different server configurations
- CERTPX-1882 Add Configuration Setting for Management and Disconnected Installation

* Fri Sep 22 2017 Aniket <akhisti@redhat.com>
- CERTPX-1877 - Replace the control label Brand logo" with "Product logo"  in the product creation and product details template - Fixed"

* Fri Sep 22 2017 Rajasi <rajkulka@redhat.com>
- CERTPX-1187: Add validations in test result update via WUI. - Fixes to the update functionality

* Fri Sep 22 2017 Rajasi Kulkarni <rajkulka@redhat.com>
- CERTPX-1903: Correct the log message Make sure that a valid service url is              configured in /etc/rhcert.xml" in rhcert-util update command"

* Thu Sep 21 2017 Pooja Tiwari <ptiwari@redhat.com>
- CERTPX-1764 Added support for 7.4-Alt Power9 kernel. - Defined a new method RedHatRelease.getKernelProductName to determine   the product info. - Used PNS for product info. Made use of Product version IDs rather   than the strings.

* Wed Sep 20 2017 Greg Nichols <gnichols@redhat.com>
- CERTPX-1912 Sync Performance Improvements    - change product processing to use index

* Wed Sep 20 2017 Anshul Behl <abehl@redhat.com>
- CERTPX-1850 Replacing Fail with Error for subtests

* Wed Sep 20 2017 Pooja Tiwari <ptiwari@redhat.com>
- Change in software rpm subtest: - CERTPX-1789 change in rpm verification:   -Perform validation on rpm fauilres, reported by $rpm -V cmd even    if there is any stderr(verification part should not be skipped).   -Capture and display the $rpm-V stderr (if any) and set status review. - Corrected the logic to determine whitelist packages (gpg-pubkey).
- Syced local cache files with services.
- CERTPX-1907 Corrected the product name: - As per product naming brand team, adding the (POWER 9) is not   acceptable according to our naming conventions. - Red Hat Enterprise Linux for Power LE" is acceptable."

* Tue Sep 19 2017 Anshul Behl <abehl@redhat.com>
- CERTPX-1850 Changing the deploy subtest to boot nova instance instead of deploying overcloud -Also changes the redeploy subtest

* Tue Sep 19 2017 Rajasi <rajkulka@redhat.com>
- CERTPX-1187: Add validations in test result update via WUI. - Update action visible only when result document contains deferred tests - Fixed the redirections after error - Removed the update confirmation page
- CERTPX-1640: Invalid results file upload leads to dead-end page with no back-links

* Mon Sep 18 2017 Greg Nichols <gnichols@redhat.com>
- CERTPX-1703 even the hardware cert is published, the status still show as in progress" in the certification list.    - debug logging improvements"

* Mon Sep 18 2017 Pooja Tiwari <ptiwari@redhat.com>
- CERTPX-1781 Change in software rpm verification test: - When the command, $rpm -V <package>, reports failures but none of   them is critical due to which verification passes for the package.   It should inform it with a info msg instead of empty list.

* Fri Sep 15 2017 Rajasi <rajkulka@redhat.com>
- CERTPX-1871: In Certification > Dialog tab, attachment description should be mandatory - Fixed javascript for Cloud and OpenStack certs

* Fri Sep 15 2017 Greg Nichols <gnichols@redhat.com>
- CERTPX-1703 even the hardware cert is published, the status still show as in progress" in the certification list.    - fix unicode handling in debug log"
- CERTPX-1703 even the hardware cert is published, the status still show as in progress" in the certification list.    - add debug mode when /cweSync is called in foreground."

* Fri Sep 15 2017 Aniket <akhisti@redhat.com>
- CERTPX-1811 : Sanbox id should be displayed in rhcert-UI. 	- sandbox id is displayed now.

* Thu Sep 14 2017 Rajasi <rajkulka@redhat.com>
- CERTPX-1510: For OpenStack Certs: Highlight Missing required information in the left navigation              (Certification and Product tabs), as well as specific sub-tabs. - Added highlighting for missing info in Nutron tab for certs with networking component

* Wed Sep 13 2017 Greg Nichols <gnichols@redhat.com>
- CERTPX-1851 Provide a means of associating a results file with a certification

* Wed Sep 13 2017 Rajasi <rajkulka@redhat.com>
- CERTPX-1510: For OpenStack Certs: Highlight Missing required information in the left navigation              (Certification and Product tabs), as well as specific sub-tabs. - Completed for specification - ToDo: Completer for the plugin types

* Tue Sep 12 2017 Anshul Behl <abehl@redhat.com>
- CERTPX-1588 Supporting OSP12 for and CI/CD for DCI team

* Tue Sep 12 2017 Aniket Khisti <akhisti@redhat.com>
- CERTPX-1759 : Refactor unit tests in rhcert.workflow.certifications to a different unit tests script      - Added Assertions to all the test methods.      - Separated test_updateHardwarePublishDate to test_HardwarePublishDateSet        and test_HardwarePublishDateUnset.

* Tue Sep 12 2017 Rajasi <rajkulka@redhat.com>
- CERTPX-1871: In Certification > Dialog tab, attachment description should be mandatory - If file is chosen for upload, then form should validate that description is provided   CWE File.upload API returns error otherwise

* Mon Sep 11 2017 Rajasi <rajkulka@redhat.com>
- CERTPX-1647: RHEL cert creation Version" dropdown items are unsorted - fixed the method to sort the versions"

* Mon Sep 11 2017 Ben Rose <brose@redhat.com>
- CERTPX-1865 - handle periods and spaces in test name for results accordion

* Fri Sep 08 2017 jkinsman <jkinsman@redhat.com>
- Integration patch: Makefile changes necessary to perform automated Brew builds on newer versions of the rhcert code line.
- Rev Makefile version to 5.2

* Thu Sep 07 2017 Rajasi <rajkulka@redhat.com>
- Build cache with latest file for rhcert-5.1 release
- CERTPX-1840: Size of attachment is not specified In Certification>Dialog tab - Add message that file size should be less than 5MB - Added js validation to check file size

* Thu Sep 07 2017 Greg Nichols <gnichols@redhat.com>
- CERTPX-1619 Certifications status is not updated on the Certifications tab
- CERTPX-1862 reset sync time even if errors occur

* Thu Sep 07 2017 Anshul Behl <abehl@redhat.com>
- CERTPX-1857 Remove openstack log version test from Ironic

* Wed Sep 06 2017 Greg Nichols <gnichols@redhat.com>
- CERTPX-1143 Switch to new-style labels in Dockerfiles    - small fix to repo building
- CERTPX-1143 Switch to new-style labels in Dockerfiles

* Wed Sep 06 2017 Jianjun Wang <jianjwan@redhat.com>
- RHCWE-2183 Cert.getOpenTestsInfo needs more information on test plan status

* Wed Sep 06 2017 Anshul Behl <abehl@redhat.com>
- CERTPX-1844 sos test should check only for Ironic is active

* Wed Sep 06 2017 Rajasi <rajkulka@redhat.com>
- CERTPX-1797: Modify the dialog of creating OpenStack certifications - Added line break in error message
- CERTPX-1578: can't choose name for Realtime and Arm Sandboxes

* Tue Sep 05 2017 Anshul Behl <abehl@redhat.com>
- CERTPX-1827 Compare sos plugins to check if openstack plugins are enables in sosreport test
- CERTPX-1710 Enrolling subtest stdout fix with commands and outputs
- CERTPX-1826 Fixing the inpect subtest

* Tue Sep 05 2017 Rajasi <rajkulka@redhat.com>
- CERTPX-1810: Vendor not set correctly in Pass-through cert when different vendor chosen
- CERTPX-1806: Cancel button for New Certification for Pass-Through and Supplemental              cert not redirecting
- CERTPX-1797: Modify the dialog of creating OpenStack certifications - Improve the wording of a Error message

* Tue Sep 05 2017 Ben Rose <brose@redhat.com>
- CERTPX-1727 - fix issue introduced switching off of importlib

* Mon Sep 04 2017 Rajasi <rajkulka@redhat.com>
- CERTPX-1807: Create layered certification for RHOSP Ironic from rhcert WUI - Store the format name (Compute or Ready State) for RHOSP layered certs
- CERTPX-1740: Certification->Dialog tab should support attachments

* Mon Sep 04 2017 Jianjun Wang <jianjwan@redhat.com>
- RHCWE-2262 API Cert.getCertifications should return rh_product_version_format_name in the response so that rhcert can differentiate between Compute and Ready State RHOSP layered certs

* Mon Sep 04 2017 Anshul Behl <abehl@redhat.com>
- CERTPX-1826 Fixing the inspect subtest
- CERTPX-1833 Create a redhat-certification-ironic-preview package for ironic certification

* Mon Sep 04 2017 Pooja Tiwari <ptiwari@redhat.com>
- CERTPX-1155 Cloud/config- system service test: - Defined generic method for el6 and el7.

* Fri Sep 01 2017 Anshul Behl <abehl@redhat.com>
- CERTPX-1825 Add new test director_undercloud that will check director from undercloud node

* Fri Sep 01 2017 Greg Nichols <gnichols@redhat.com>
- CERTPX-1831 Error during template rendering traceback when click on Product
- CERTPX-1760 Leverage Component Certifications
- CERTPX-1760 Leverage Component Certifications    - added info popovers
- CERTPX-1798 dialog tab needs to show numbered comments and history for easy reference

* Fri Sep 01 2017 Pooja Tiwari <ptiwari@redhat.com>
- CERTPX-1155 Additional check of Service Configuration vs. Actual State" in System Services subtest. - if the service is enabled and running - Pass - if the service is enabled and not running - Fail - if the service is disabled and running - Fail - if the service is disabled and not running - Pass"
- Imported missing TestResult class in openstack/sosreport
- CERTPX-1127 Added log messages in cloud/configuration system services test.

* Fri Sep 01 2017 Rajasi <rajkulka@redhat.com>
- CERTPX-1807: Create layered certification for RHOSP Ironic from rhcert WUI - RHSOP Ironic layered certs can be created from rhcert homepage
- CERTPX-1807: Create layered certification for RHOSP Ironic from rhcert WUI - Enabled creating RHOSP Ironic layered cert from Related Cert tab of base RHEL - ToDo: Create Ironic layered cert from rhcert homepage         Display Format - Compute(Nova) / Ready State(Ironic) in Related Certs tab and cert header

* Thu Aug 31 2017 Greg Nichols <gnichols@redhat.com>
- CERTPX-1722 Automate background CWE Sync    - implement automatic sync: on Certifications page load, every 30 min if idle.

* Thu Aug 31 2017 Pooja Tiwari <ptiwari@redhat.com>
- CERTPX-1351 Made sosreport mandatory test for cloud and openstack: - Run sosreport test with each test run.
- CERTPX-1227 Criteria update for cloud/configuration network test: - IPtables/firewalld and sshd services should also be enabled.

* Thu Aug 31 2017 Anshul Behl <abehl@redhat.com>
- CERTPX-1801 Only ask for path of stackrc and instackrc if they dont exist in default location - Fixed some cyclic dependencies -Wrong namespace fixed for instackenv_validator
- CERTPX-1801 Validation of instackenv and stackrc file

* Wed Aug 30 2017 Ben Rose <brose@redhat.com>
- CERTPX-1728 - fix sandbox testing page accordian for same test different device results
- CERTPX-1814 - use alternative to importlib to support el6

* Wed Aug 30 2017 Pooja Tiwari <ptiwari@redhat.com>
- CERTPX-1351 New test named as 'sosreport' added for Cloud and OpenStack: - With this change sosreport generation will no longer be a part of cloud   or openstack supportable test. - cloud/sosreport and openstack/sosreport tests are non-interactive tests. - Sos report gathering will be done in the same way as it was earlier for   cloud and OpenStack respectively. No change in execution.
- CERTPX-1367 Change in cloud/configuration network configuration test: - Used ip command in place of ifconfig. - Better prompt and logging while ask system's ip.

* Wed Aug 30 2017 Greg Nichols <gnichols@redhat.com>
- CERTPX-1739 Add Product->Dialog tab   - disable tab pending API support

* Tue Aug 29 2017 Anshul Behl <abehl@redhat.com>
- CERTPX-1709 Ask user for the driver that they support
- CERTPX-1710 Counting the number of nodes using pm_addr rather than mac

* Tue Aug 29 2017 Greg Nichols <gnichols@redhat.com>
- CERTPX-1809 Related Certifications tab should show leveraged relationships
- CERTPX-1760 Leverage Component Certifications    - bug fix for removal of leverage application
- CERTPX-1760 Leverage Component Certifications    - implement save/apply links and targets for leveraging component certs    - links appear on Related Certifications for component pass-through certs    - target appear on Progress tabs

* Tue Aug 29 2017 Pooja Tiwari <ptiwari@redhat.com>
- CERTPX-1812 Supportable/Kernel test throws traceback when service returns OK response but not the kernel info.

* Tue Aug 29 2017 Rajasi <rajkulka@redhat.com>
- CERTPX-1794: Upload vendor/product logo while creating a hardware or cloud product - Added call to API to upload a logo just after creating a hardware or cloud product

* Mon Aug 28 2017 Greg Nichols <gnichols@redhat.com>
- CERTPX-1722 Remove Manual CWE Sync (Refresh" button).    - implement automatic sync: on Certifications page load
- CERTPX-1716: With each rhcert build the latest product info from PNS, should be downloaded in redhat-products.json file - use service-call target dependancy on building the source tar
- CERTPX-1716: With each rhcert build the latest product info from PNS, should be downloaded in redhat-products.json file - move the call as the last step of the install target.

* Mon Aug 28 2017 Rajasi <rajkulka@redhat.com>
- CERTPX-1716: With each rhcert build the latest product info from PNS, should be downloaded in redhat-products.json file - call the script to build the local cache in the install target in Makefile
- CERTPX-1797: Modify the dialog of creating OpenStack certifications - Create a RHOSP Nova layered hardware program cert, if vendor selects Hardware product - Create a RHOSP software plugin OpenStack program cert, if vendor selects OpenStack product - Display error page for creating a new Hardware product while create a RHOSP cert

* Fri Aug 25 2017 Greg Nichols <gnichols@redhat.com>
- CERTPX-1720 Product->Related Products tab
- CERTPX-1739 Add Product->Dialog tab

* Thu Aug 24 2017 Anshul Behl <abehl@redhat.com>
- CERTPX-1801 [IRONIC] Subtest for validation of instackenv and stackrc file
- CERTPX-1784 Sos version check test always returns output as Review even its in accepted version list
- CERTPX-1584 .test_list_show_extensions should not be a part of neutron_ipv4 feature test

* Thu Aug 24 2017 Aniket Khisti <akhisti@redhat.com>
-  CERTPX-1389 : For rhcert-ci plan command, the help message is incorrect  - Fixed with correct options as per the latest version.

* Thu Aug 24 2017 Rajasi <rajkulka@redhat.com>
- CERTPX-1761: Version field empty in Power9 cert pull down - Update local PNS for Power9, ARM - Add allowed program for Power 9 - Update local valid-kernels.json

* Wed Aug 23 2017 Greg Nichols <gnichols@redhat.com>
- CERTPX-1388 Leverage Component Pass-through cert and Tests in RHCERT    - fix initial page load for leverage targets
- CERTPX-1388 Leverage Component Pass-through cert and Tests in RHCERT    - better feedback and bug fixes

* Wed Aug 23 2017 Ben Rose <brose@redhat.com>
- CERTPX-1729 - raise errors in client harness in a better way

* Wed Aug 23 2017 Aniket Khisti <akhisti@redhat.com>
- CERTPX-1759 : Refactor unit tests in rhcert.workflow.certifications to a different unit tests script - Duplicate argument error fixes by replacing hardcoded parameters with random-values generating methods

* Tue Aug 22 2017 Aniket Khisti <aniketkhisti@gmail.com>
- CERTPX-1759 : Refactor unit tests in rhcert.workflow.certifications to a different unit tests script - TestCases signature modification with reference to unittest standards & minor bug fixes   & removal of trailing whitespaces.

* Mon Aug 21 2017 Greg Nichols <gnichols@redhat.com>
- CERTPX-1388 Leverage Component Pass-through cert and Tests in RHCERT     - javascript streamlining of leverage actions
- rhcert 5.1

* Mon Aug 21 2017 Rajasi <rajkulka@redhat.com>
- CERTPX-1783: Layered certs shouldn't be created on Supplemental certs - Disable creating layered certs on Supplemental certs

* Mon Aug 21 2017 Pooja Tiwari <ptiwari@redhat.com>
- CERTPX-1367 Change in cloud/configuration network test: - Pass SUT's external IP address to nmap command instead of localhost.

* Fri Aug 18 2017 Ben Rose <brose@redhat.com>
- CERTPX-1728 - add option to run collab functions via queue

* Fri Aug 18 2017 Pooja Tiwari <ptiwari@redhat.com>
- Updated local cache (static files) for PNS and valid kernels. - Syced with service response. - Used 'make service-cache' command for doing it.

* Thu Aug 17 2017 Anshul Behl <abehl@redhat.com>
- CERTPX-1712 Deploying Subtest CERTPX-1713 [IRONIC] Redeploying subtest
- CERTPX-1738 Check sos version for openstack certifications due to missing plugins between sos versions

* Thu Aug 17 2017 Pooja Tiwari <ptiwari@redhat.com>
- CERTPX-1653 Fixed AttributeError in supportable/Kernel-Module test. - Set the default value for debug parameter.

* Wed Aug 16 2017 Rajasi <rajkulka@redhat.com>
- CERTPX-1721: While creating a layered cert, when there is only a single In-Progress cert to choose as a base cert, the Create button should be disabled. - Disabled Create button if all base certs in progress - Added better warning messages
- CERTPX-1723: When creating a layered cert from the Related Certifications tab of a base cert,              clicking on Cancel button should not create a new layered cert              - Fix redirection when layered cert is getting created from Related Certs tab

* Wed Aug 16 2017 Abhishek Tiwary <atiwary@redhat.com>
- configuration.py file is changed for supporting RHEL6.5 and below version

* Wed Aug 16 2017 Pooja Tiwari <ptiwari@redhat.com>
- CERTPX-1423 Allow modifications in configuration files for L readLink(2) path mismatch" in rpm verification."

* Fri Aug 11 2017 Anshul Behl <abehl@redhat.com>
- CERTPX-1711 Inspecting Subtest CERTPX-1752 CERTPX-1762- ironic_undercloud_validation subtest is showing status 'REVIEW' even there is an error: 'stack:no user exits'

* Fri Aug 11 2017 Rajasi <rajkulka@redhat.com>
- CERTPX-1723: When creating a layered cert from the Related Certifications tab of a base cert,              clicking on Cancel button should not create a new layered cert

* Thu Aug 10 2017 Rajasi <rajkulka@redhat.com>
- CERTPX-1748: getCatalogServer traceback when I submit results
- CERTPX-1583: Remove option to upload product/brand logo while creating a product

* Wed Aug 09 2017 Anshul Behl <abehl@redhat.com>
- CERTPX-1710 [IRONIC] Enrolling Subtest CERTPX-1754 ironic_undercloud_validation subtest should show message in one line CERTPX-1753 ironic_undercloud_validation subtest saying 'Success: Found undercloud.conf under /home/stackrc' it should say 'Success: Found undercloud.conf under /home/stack' CERTPX-1752 ironic_undercloud_validation subtest is showing PASS even it's failing

* Wed Aug 09 2017 jkinsman <jkinsman@redhat.com>
- Test patch: Revert new respin logic and Jenkins build numbers from automated Brew builds.

* Tue Aug 08 2017 Anshul Behl <abehl@redhat.com>
- CERTPX-1708 Undercloud validation to check if ironic tests are running on the designated node
- CERTPX-1709 [IRONIC] subtest for determining if a supported driver is configured for the designated system

* Tue Aug 08 2017 Shiyi Yuan <shiyuan@redhat.com>
- RHCWE-2208: A related products/specs API call is needed

* Tue Aug 08 2017 Greg Nichols <gnichols@redhat.com>
- CERTPX-1388 Leverage Component Pass-through cert and Tests in RHCERT     - initial implementation for component leveraging

* Tue Aug 08 2017 Rajasi <rajkulka@redhat.com>
- CERTPX-1530: For updating Openstack cert details, if the plugin type is In-Tree, vendor shouldn't be allowed to update the download URL - For plugin type In Tree" hide download URL from the product details page - For plugin type "Out of Tree" hide the upstream availability date from the product details page"

* Mon Aug 07 2017 Greg Nichols <gnichols@redhat.com>
- CERTPX-1744 JWT access token refresh does not update browser session

* Mon Aug 07 2017 Rajasi <rajkulka@redhat.com>
- CERTPX-1704: Alerts for failed login attempts persist after failed logins - Clear the alerts after succesful login

* Mon Aug 07 2017 Anshul Behl <abehl@redhat.com>
- CERTPX-979 Adding Test Skeleton for Ironic and related SubTests

* Sun Aug 06 2017 Ben Rose <brose@redhat.com>
- CERTPX-1672 - fix passing in args and kwargs in collabrequirements and added error string to 500 message body

* Fri Aug 04 2017 Greg Nichols <gnichols@redhat.com>
- CERTPX-1582 rhcert should use access.redhat.com for microservices and xmlrpc calls.

* Thu Aug 03 2017 Jianjun Wang <jianjwan@redhat.com>
- RHCWE-2144/RHCWE-2205 VendorProduct.list return the public status and product type of hardware products
- RHCWE-2165 Cert.updateHardware_4_7 should accept a parameter which can change the cert status to In Progress

* Thu Aug 03 2017 Rajasi <rajkulka@redhat.com>
- CERTPX-1726: When creating a Red Hat OpenStack Platform Plugin (OpenStack program) cert,              only OpenStack products should be shown in the filter - Modified allowed programs for OpenStack plugin certifications

* Thu Aug 03 2017 Feng Wang <fwang@redhat.com>
- RHCWE-1821: change API getInProgressCertifications to return all products if product_id and program is not specified
- RHCWE-2188: add product_nid in VendorProduct.get_4_7

* Wed Aug 02 2017 Rajasi <rajkulka@redhat.com>
- CERTPX-1648: Unsupported OSP versions shown in RHCERT Configuration page - Show only supported versions of all Certification Programs

* Wed Aug 02 2017 Greg Nichols <gnichols@redhat.com>
- CERTPX-1388 Leverage Component Pass-through cert and Tests in RHCERT     - add integration in unit test for Cert.getSubmittedLog

* Tue Aug 01 2017 Rajasi <rajkulka@redhat.com>
- CERTPX-1671: For the RHOSP Nova layered certs that are created, the name is displayed as              RHOSP Plugin on the home page in the Certifications tab and also in the Cert's details - Name for the RHOSP Nova product will be displayed as Red Hat OpenStack Product"   when PNS live is not reachable"

* Mon Jul 31 2017 Greg Nichols <gnichols@redhat.com>
- CERTPX-1705 traceback on CWE sync if user has no vendor products

* Fri Jul 28 2017 Greg Nichols <gnichols@redhat.com>
- release-5.0

* Thu Jul 27 2017 Rajasi <rajkulka@redhat.com>
- CERTPX-1671: For the RHOSP Nova layered certs that are created, the name is displayed as              RHOSP Plugin on the home page in the Certifications tab and also in the Cert's details - Added hack to distinguish between the OpenStack hardware(Nova) and software(Plugin) products   after getting product details from PNS live - Name for the RHOSP Nova product will be displayed as Red Hat OpenStack Product
- CERTPX-1668: Support creation of new RHEL Realtime 7.4 and Gluster 3.3 layered product certs CERTPX-1245: Layered Certification Creation in rhcert WUI RHCWE-2214: can't create Gluster layered cert from 6.9 base cert - Add the base versions in the local cache of redhat products JSON file   that CWE has added in PNS - Improve messages for allowed programs in layered certs creation

* Thu Jul 27 2017 Greg Nichols <gnichols@redhat.com>
- CERTPX-1685 Testplan Status needs a display UI

* Thu Jul 27 2017 Pooja Tiwari <ptiwari@redhat.com>
- Removed SSL Bypass

* Wed Jul 26 2017 Pooja Tiwari <ptiwari@redhat.com>
- CERTPX-1060 Fixes in Kernel test. - one elif statement was missing. - Taken care if 'hwcert' is passed as suitename. - ByPassesd the SSL issue.

* Wed Jul 26 2017 Greg Nichols <gnichols@redhat.com>
- CERTPX-1697 rhcert uses http when https is specified for the catalog url in /etc/rhcert.xml
- CERTPX-1582 rhcert should use single catalog-url" domain for microservices calls.     - restore services url for rhcert.services

* Wed Jul 26 2017 Ben Rose <brose@redhat.com>
- Revert CERTPX-1687 - refresh button now does full reload of products/vendors""

* Wed Jul 26 2017 Anshul Behl <abehl@redhat.com>
- CERTPX-1609 New tempest_tests for RHOS11 as well as new pattern for cinder tests

* Tue Jul 25 2017 Anshul Behl <abehl@redhat.com>
- CERTPX-1617 Misaligned cancel/dismiss button on inline popups in rhcert WUI

* Tue Jul 25 2017 Rajasi <rajkulka@redhat.com>
- CERTPX-1245: Layered Certification Creation in rhcert WUI CERTPX-1622: Improvement for the Related Certifications tab of Hardware Certifications - Fixed creating Layered certs from New Certification dialog from rhcert homepage - Fixed redirections in error cases
- CERTPX-1690: Use the version in API Cert.getOpenTestsInfo
- CERTPX-1688: Disable the New Product" button while creating a New Layered Certification from the New Certification creation dialog."

* Tue Jul 25 2017 Greg Nichols <gnichols@redhat.com>
- CERTPX-1582 rhcert should use single catalog-url" domain for microservices calls."

* Tue Jul 25 2017 Ben Rose <brose@redhat.com>
- CERTPX-1674 - Add client function to base class test.py for calling collab LTS hosted service
- CERTPX-1686 - fix attribute error when catalog not reachable
- CERTPX-1687 - refresh button now does full reload of products/vendors

* Mon Jul 24 2017 Rajasi <rajkulka@redhat.com>
- CERTPX-1641: TemplateDoesNotExist Exception: OpenStack Platform Nova sandbox CERTPX-1643: OpenStack Nova Layered Certification can be created against OpenStack product
- CERTPX-1622: Improvement for the Related Certifications tab of Hardware Certifications - Fix typos in filenames - Change redirection to Product Details tab from the Conform Supplemental page - Fix to download the newly created supplemental cert

* Mon Jul 24 2017 Anshul Behl <abehl@redhat.com>
- CERTPX-1622 Fixing some issues with the new dialog for passthrough

* Mon Jul 24 2017 Greg Nichols <gnichols@redhat.com>
- CERTPX-1622 Improvement for the Related Certifications tab of Hardware Certifications    - show layered certs on non-layered certs RelatedCerts tab    - fix cert status coloring    - changed supplemental flow to direct user to product details

* Fri Jul 21 2017 Pooja Tiwari <ptiwari@redhat.com>
- CERTPX-1060 Update kernel test results (warn/review/pass/fail) for various circumstances. - Updated kernel service url to point to v2.0/valid-kernels api. - Updated cache rebuilding code. - Updated info/valid-kernels.json with v2.0/valid-kernels response. - Made changes in Kernel test (affects all programs). - Added unit test for it.

* Fri Jul 21 2017 Ben Rose <brose@redhat.com>
- CERTPX-1672 - Add service to rhcert to allow tests running on SUT to run functions on LTS
- CERTPX-1519 let individual tests see what has already been planned

* Fri Jul 21 2017 Greg Nichols <gnichols@redhat.com>
- CERTPX-1622 Improvement for the Related Certifications tab of Hardware Certifications    - fix supplemental cert creation from the Related Certs tab    - revised related certs tab to display cert type and base cert info    - combined passthrough and passthrough-with-supplemental
- CERTPX-1670 After certificate creation, test plan shows blank

* Fri Jul 21 2017 Rajasi <rajkulka@redhat.com>
- CERTPX-1668: Support creation of new RHEL Realtime 7.4 and              Gluster 3.3 layered product certs - Added product definitions in the JSON file

* Thu Jul 20 2017 Greg Nichols <gnichols@redhat.com>
- CERTPX-1622 Improvement for the Related Certifications tab of Hardware Certifications    - fix layered cert creation from Releated Certifications tab    - fix layered cert creation from Certifications page
- CERTPX-1622 Improvement for the Related Certifications tab of Hardware Certifications    - use tables to show related certs    - move layered and supplimental cert code to create dialog
- CERTPX-1628 rhcert should pass Authorization header with access token for hydra    - Implemented token refresh and retry for proxy exception 401

* Wed Jul 19 2017 Rajasi <rajkulka@redhat.com>
- CERTPX-1637 The product id is invalid in Pass Through cert - Product Details tab
- CERTPX-1630: Related certifications tab should be visible only              for Hardware Certifications
- CERTPX-1504: Create Supplemental Cert via the Related certifications              tab of the parent certification - Added checkbox in Hardware Specification to indicate attachment of   a specification file for reviewers

* Wed Jul 19 2017 Greg Nichols <gnichols@redhat.com>
- CERTPX-1656 The Progress page should show test plan status

* Tue Jul 18 2017 Anshul Behl <abehl@redhat.com>
- CERTPX-1644 RHOSP Version 8 is present in the product name dictionary and can be selected for cert creation
- CERTPX-1645 Cannot cancel cert creation if product version field has no content
- CERTPX-1629 - Improvement for the Related Certifications tab of Hardware Certifications - Show the product information along with cert ID for the related certs

* Tue Jul 18 2017 Rajasi <rajkulka@redhat.com>
- CERTPX-1504: Create Supplemental Cert via the Related certifications tab of the parent certification - Added button to create supplemental Cert from Related certifications   tab of base Certification - ToDo: Upload specification file in Specification for reviewer to let   him know to create the supplemental components

* Mon Jul 17 2017 Anshul Behl <abehl@redhat.com>
- CERTPX-1633 Unable to open RHCERT UI on rhel 7.4 - Adding wildcard in django settigs so that all hosts are accessible
- CERTPX-1503 Fix for Left pane not visible in passthrough form

* Mon Jul 17 2017 Rajasi <rajkulka@redhat.com>
- CERTPX-1245: Layered Certification Creation in rhcert WUI     - Fix for creating RHOSP Nova Layered Certs from New Certification       creation dialog     - Disable selecting In Progress certs as a base cert

* Mon Jul 17 2017 Feng Wang <fwang@redhat.com>
- RHCWE-2184: adding ecosystem to differentiate RHOSP product

* Mon Jul 17 2017 Pooja Tiwari <ptiwari@redhat.com>
- Implemented Hwcert Publish workflow based on cert status: CERTPX-1585 INPROGRESS certs (removed 'leave as INPROGRESS' option). CERTPX-1586 CERTIFIED/Unpublished certs. CERTPX-1587 CERTIFIED/Published certs.

* Fri Jul 14 2017 Anshul Behl <abehl@redhat.com>
- CERTPX-1104 product version need to be added in openstack entry page

* Fri Jul 14 2017 jkinsman <jkinsman@redhat.com>
- CERTPX-1393: Modify build_rhcert_release.py to parse redhat-certification package NVR from CI Message metadata for Jenkins builds.

* Fri Jul 14 2017 Greg Nichols <gnichols@redhat.com>
- CERTPX-1628 rhcert should pass Authorization header with access token for hydra

* Fri Jul 14 2017 Rajasi <rajkulka@redhat.com>
- CERTPX-1607 Move addCWECertification and downlodProducts to common base classes to avoid duplication CERTPX-1245 Layered Certification Creation in rhcert WUI - Minor fixes   1. Substituting invalid call to debugPrint with print   2. Correcting the invocation of Alert class
- CERTPX-1245: Layered Certification Creation in rhcert WUI - Creating layered certs from new Certificate creation workflow - Enabled product type RHOSP Nova for OpenStack layered certs

* Thu Jul 13 2017 Anshul Behl <abehl@redhat.com>
- CERTPX-1606 Adding client side validation TODO: Fix the left pane not visible issue.

* Thu Jul 13 2017 Greg Nichols <gnichols@redhat.com>
- CERTPX-1607 Move addCWECertification and downlodProducts to common base classes to avoid duplication    - move compileVendorProducts to rhcert.server.wsgi.view.View
- CERTPX-1607 Move addCWECertification and downlodProducts to common base classes to avoid duplication     - replace addCWECertification with rhcert.wsg.view.View.syncronizeCertifications

* Thu Jul 13 2017 root <root@rhcert-save.localdomain>
- CERTPX-1503 Passthrough product creation TODO: Client side javascript validation and new field for Make Dropdown       Moving addCWECertification and downloadProducts to base classes

* Wed Jul 12 2017 Rajasi <rajkulka@redhat.com>
- CERTPX-1605: Unable to upload attachment

* Wed Jul 12 2017 Greg Nichols <gnichols@redhat.com>
- CERTPX-1608 Support RHEL7.4 base versions for OSP10, 11 in the Product Name Dictionary     - also change the product selector to filter on isSupport rather than isPublic.

* Wed Jul 12 2017 Pooja Tiwari <ptiwari@redhat.com>
- Added unit test to reopen a hwcert.

* Tue Jul 11 2017 Greg Nichols <gnichols@redhat.com>
- CERTPX-1594 Five minute login timeout raises 401 Not Authorized errors    - removed refresh token from all XMLRPC calls    - added handling for xmlrpc fault 401 to refresh token and retry call    - added token refresh call to /cwe/status (js call in menu-bar)

* Mon Jul 10 2017 Greg Nichols <gnichols@redhat.com>
- version 4.12
- CERTPX-1594 Five minute login timeout raises 401 Not Authorized errors    - added token refresh calls to all XMLRPC calls.
- CERTPX-1591 Certification' object has no attribute 'isLoggedIn' traceback with New Certification     - fix traceback on new vendor product create
- CERTPX-1595 Cert.getOpenTestsInfo: Bug ID not found - api_version missing from call

* Mon Jul 10 2017 Rajasi Kulkarni <rajkulka@redhat.com>
- CERTPX-1581: Accessing Sandbox results through Test Results tab              giving authorization error - Fix the redirection for Sandbox results and Sandbox Certification   Details from the TestResults Tab

* Mon Jul 10 2017 Shiyi Yuan <shiyuan@redhat.com>
- RHCWE-2139: A CWE API call is needed to get a list of hardware certs for layering on

* Fri Jul 07 2017 Greg Nichols <gnichols@redhat.com>
- CERTPX-1591 Certification' object has no attribute 'isLoggedIn' traceback with New Certification
- CERTPX-1499 Add token refresh call to rhcert    - fixed failover from jwt to legacy sso
- CERTPX-1499 Add token refresh call to rhcert    - fixed failover from jwt to legacy sso    - Other API's always pass token as password""

* Fri Jul 07 2017 Rajasi Kulkarni <rajkulka@redhat.com>
- CERTPX-1572: jawbreakericon.jpg" text viewed even if no brand logo uploaded while creating cloud product"

* Thu Jul 06 2017 Greg Nichols <gnichols@redhat.com>
- CERTPX-1499 Add token refresh call to rhcert
- CERTPX-1499 Add token refresh call to rhcert    - added rhcert.services.authorization for new JWT auth calls.    - defines rhcert.workflow.workflow.WorkflowCredentials to manage auth tokens    - changes the rhcert.workflow.workflow.Workflow.login call to capture      both current sso token and new tokens.    - adds a new XMLRPC wrapper call Workflow.callProceedure      - inserts credentials into every call      - supports debug logging of call, parameters and response    - Workflow.call also adds credentials, but no debug logging    - changed workflow subclasses (Certification, Engine, VendorProduct)      to use new Workflow.callProceedure method.

* Wed Jul 05 2017 Anshul Behl <abehl@redhat.com>
- CERTPX-1560 TemplateDoesNotExist Exception on creating Hyperconverged Infra sandbox with rhcert WUI

* Wed Jul 05 2017 Rajasi Kulkarni <rajkulka@redhat.com>
- CERTPX-1344: Partner should able to add product logo for hardware and cloud product from RHCERT

* Wed Jul 05 2017 Pooja Tiwari <ptiwari@redhat.com>
- CERTPX-1576 Fixed UnboundLocalError in server.wsgi.submit
- CERTPX-1576 Fixed NameError in server.wsgi.submit

* Tue Jul 04 2017 Pooja Tiwari <ptiwari@redhat.com>
- CERTPX-1546 Hwcert Publish Tab: Unset/Remove the publish date. CERTPX-1551 Fixed typo in HW cert Publish tab alert.
- CERTPX-1504 Fix to show ToDo icon in publish date attribute. Modified unit test to supply NULL" to unset publish date."
- CERTPX-1507 Certification->Publish (New Tab) to set publish date for a Hardware Certification. Added unit test to set/unset publish date. Fixed issue in server/wsgi/certification/certification.py TODO: Unset publish date.
- CERTPX-1531 Improvement in NVR check logic implementation: - Used workflow module to only return API response. - Moved the analytical part in rhcert.server.wsgi.submit. - Better warning message for unsupported versions.

* Tue Jul 04 2017 Rajasi Kulkarni <rajkulka@redhat.com>
- CERTPX-1509: For Cloud Certs: Highlight Missing required information in the left navigation (Certification and Product tabs), as well as specific sub-tabs. CERTPX-1455: The cloud image name of cloud cert should be write-once for partner Diabling the readonly inputs in templates so that they are not available as form post parameters in Django views

* Tue Jul 04 2017 Greg Nichols <gnichols@redhat.com>
- CERTPX-1544 Cert.attachments is getting called for all product related requests     - created specific wsgi subclasses for spec details pages     - moved code to get attachments up to wsgi.certification     - added calls to get attachments to spec details pages.

* Mon Jul 03 2017 Anshul Behl <abehl@redhat.com>
- CERTPX-1451 DDT tests should not be part of the LBaaS tests in Neutron

* Mon Jul 03 2017 Rajasi Kulkarni <rajkulka@redhat.com>
- CERTPX-1509: For Cloud Certs: Highlight Missing required information in the left navigation (Certification and Product tabs), as well as specific sub-tabs. - Update product URL from specification page, if it is missing

* Mon Jul 03 2017 Pooja Tiwari <ptiwari@redhat.com>
- CERTPX-1124 Fixed KeyError and other possible failures in cloud/supportable Root Filesystem test.

* Fri Jun 30 2017 Pooja Tiwari <ptiwari@redhat.com>
- Fixed issue in server/wsgi/certification/certification.py. (Already fixed in feature branch) Ref: https://code.engineering.redhat.com/gerrit/#/c/109923/1/server/wsgi/certification/certification.py

* Thu Jun 29 2017 Anshul Behl <abehl@redhat.com>
- CERTPX-1505 Adding comment api and changing some labels Also fixes CERTPX-1543
- CERTPX-1500 Close openstack cert for RHOSP8 and older in rhcert WUI creation

* Thu Jun 29 2017 Greg Nichols <gnichols@redhat.com>
- CERTPX-1513 Support RHEL7.4 versions in the Product Name Dictionary

* Thu Jun 29 2017 Rajasi Kulkarni <rajkulka@redhat.com>
- CERTPX-1245: Layered Certification Creation in rhcert WUI - Show the relationship between parent and layered certs - Allow creating layered cert from for avilable layered product versions

* Mon Jun 26 2017 Jianjun Wang <jianjwan@redhat.com>
- RHCWE-2105 Expose Priority" to partners to allow them to Escalate a certification"

* Fri Jun 23 2017 Rajasi Kulkarni <rajkulka@redhat.com>
- CERTPX-1245: Layered Certification Creation in rhcert WUI - Partial implemetation to show available layered Product certifications that can be created for a base hardware Cert

* Fri Jun 23 2017 Greg Nichols <gnichols@redhat.com>
- CERTPX-1540 Wrong/weird debug information can be seen in certification->Details tab

* Thu Jun 22 2017 Huanhuan Li <huali@redhat.com>
- RHCWE-2129: update the api doc for creating pass-through cert

* Thu Jun 22 2017 Anshul Behl <abehl@redhat.com>
- CERTPX-1505 API spec parameter changes

* Thu Jun 22 2017 Greg Nichols <gnichols@redhat.com>
- CERTPX-1503 Product -> Product Details Tab: Create Passthrough via existing product details (spec). CERTPX-1504 Product -> Product Details tab: Create Supplemental via new product details (spec)    - create Related" tabs to start intermediate UI"

* Thu Jun 22 2017 Rajasi Kulkarni <rajkulka@redhat.com>
- CERTPX-1344: Partner should able to add product logo for hardware and cloud product from RHCERT - Adding calls to CWE APIs VendorProduct.uploadProductLogo_4_10 and VendorProduct.getProductLogoUrl_4_10 in workflow and their unit tests

* Wed Jun 21 2017 Greg Nichols <gnichols@redhat.com>
- CERTPX-1532 Certification Details and Syncronization of Data    - fix status colors, create time
- CERTPX-1532 Certification Details and Syncronization of Data

* Wed Jun 21 2017 Anshul Behl <abehl@redhat.com>
- CERTPX-1505 Changing checkbox to Radio Button
- CERTPX-1503 Adding getPublicVendor API Fixing some unit test issues with Cert.createPassThroughSpec

* Wed Jun 21 2017 Pooja Tiwari <ptiwari@redhat.com>
- CERTPX-1501 Modified attribute names as per response of Cert.getHardware_4_10.

* Tue Jun 20 2017 Rajasi Kulkarni <rajkulka@redhat.com>
- CERTPX-1455: The cloud image name of cloud cert should be write-once for partner
- CERTPX 1535: On Cloud cert Product Details page, if all supported regions are unselected, then after save the supported regions update does not work

* Tue Jun 20 2017 Anshul Behl <abehl@redhat.com>
- CERTPX-1505 Product->Sample tab: Details of sample hardware sent or to send to RedHat TODO: checkbox param mapping to 1
Tue, 20 Jun 2017 06:13:25 -0400,Pooja Tiwari,ptiwari@redhat.com,c13f49ea,CERTPX-1501 For hwcert: product

* Mon Jun 19 2017 Rajasi Kulkarni <rajkulka@redhat.com>
- CERTPX-1509: For Cloud Certs: Highlight Missing required information in the left              navigation (Certification and Product tabs), as well as specific sub-tabs.

* Mon Jun 19 2017 Pooja Tiwari <ptiwari@redhat.com>
- CERTPX-1511 Fixed traceback by Cloud/Configuration Subscription Service test.

* Fri Jun 16 2017 Greg Nichols <gnichols@redhat.com>
- fix build errors re: update dir deleted
- release 4.11

* Fri Jun 16 2017 Shiyi Yuan <shiyuan@redhat.com>
- CERTPX-1344: Api for upload product logo

* Fri Jun 16 2017 jkinsman <jkinsman@redhat.com>
- CERTPX-1452: (Part One) Remove CI code from redhat-certification code line.

* Thu Jun 15 2017 Greg Nichols <gnichols@redhat.com>
- CERTPX-1496 Not able to download attachment in Firefox.
- CERTPX-1518 Templatedoesnotexist traceback when selecting Product from crumb trail
- CERTPX-1477 RHEL Hardware Certs are missing platforms (ppc64, s390x ??)

* Thu Jun 15 2017 Rajasi Kulkarni <rajkulka@redhat.com>
- CERTPX-1494: Fixed error in attachment download when no description given - Make description a mandatory field if an attachment is chosen for upload

* Thu Jun 15 2017 Jianjun Wang <jianjwan@redhat.com>
- RHCWE-2094 added update time on all cert details calls

* Wed Jun 14 2017 jkinsman <jkinsman@redhat.com>
- CERTPX-1392: Modify rhcert-build-release script to accept Brew build parameters from environment variables that will be defined by Jenkins.

* Wed Jun 14 2017 Greg Nichols <gnichols@redhat.com>
- CERTPX-1462 Create Cert has empty pull-downs with old firefox
- CERTPX-1516 Cert Creation: add All" option to Make for Vendor Product Selection"

* Tue Jun 13 2017 Greg Nichols <gnichols@redhat.com>
- CERTPX-1334 Sandbox Creation UI Improvements: Simplified naming and deletion
- CERTPX-1491 Not able to create a New Cloud Product.

* Tue Jun 13 2017 Pooja Tiwari <ptiwari@redhat.com>
- CERTPX-1474 Open port, non-RH packages and non-RH repos Needs Review prompt should not appear twice while running through CLI.

* Mon Jun 12 2017 Greg Nichols <gnichols@redhat.com>
- CERTPX-1470 Traceback with create sandbox - Sandbox' object has no attribute 'vendorProductID

* Mon Jun 12 2017 Shiyi Yuan <shiyuan@redhat.com>
- RHCWE-2060: Cert.getSupportCases_4_7 does not return a meaninful description of the case

* Mon Jun 12 2017 Rajasi Kulkarni <rajkulka@redhat.com>
- CERTPX-1412: rhcert WUI: integrate messages with Alert class to handle              non-redirected and redirected messages            - Added alert after creating a new Product for a new Certification

* Sun Jun 11 2017 Rajasi Kulkarni <rajkulka@redhat.com>
- CERTPX-1409: Support for Certification File Attachments - Upload attachments to a certification from its specification - Removed the page to confirm update for Product Details

* Fri Jun 09 2017 Anshul Behl <abehl@redhat.com>
- CERTPX-1472 Add MapRFS to the manila protocol list

* Fri Jun 09 2017 Rajasi Kulkarni <rajkulka@redhat.com>
- CERTPX-1409: Support for Certification File attachments - List and download file attachments from a Certification

* Thu Jun 08 2017 Jianjun Wang <jianjwan@redhat.com>
- RHCWE-1656 Provide API for RHCERT to be enable leverage Component Pass-through cert and Tests by partner

* Wed Jun 07 2017 Rajasi Kulkarni <rajkulka@redhat.com>
- CERTPX-1412: rhcert WUI: integrate messages with Alert class to handle non-redirected and redirected messages - Added success and error alerts on redirection for Product Details update - Added alert and redirection after creating a new Cert
- CERTPX-1409: Support for Certification File attachments -Minor typo corrections

* Wed Jun 07 2017 Shiyi Yuan <shiyuan@redhat.com>
- RHCWE-2080: Cloud: Cert.createCert should not require image_name              and Cert.updateCloud should allow full updates.

* Wed Jun 07 2017 Anshul Behl <abehl@redhat.com>
- CERTPX-1386 Neutron Cert Creation Survey clean-up - Part 2

* Wed Jun 07 2017 Huanhuan Li <huali@redhat.com>
- RHCWE-2081: add a new api Cert.getHardware_4_10 to unify product_url for hardware, cloud, openstack

* Tue Jun 06 2017 Jianjun Wang <jianjwan@redhat.com>
- RHCWE-2075 Cert.getCertifications should include most-recent update date-time
- RHCWE-2083 VendorProduct.list should return category

* Tue Jun 06 2017 Greg Nichols <gnichols@redhat.com>
- CERTPX-1333 Certifications Page: Activity Feedback    - added update_time field to certifications page and certification details

* Tue Jun 06 2017 Pooja Tiwari <ptiwari@redhat.com>
- Fixed typo

* Mon Jun 05 2017 Greg Nichols <gnichols@redhat.com>
- CERTPX-1396 New Certification Completion in Tabs    - filled in sample tab fields, toDo marking
- CERTPX-1394 New Certification Dialog Changes     - added program filtering when New Product is created
- CERTPX-1456 Attempts to create new product during certification creation results in use of existing product
- CERTPX-1394 New Certification Dialog Changes     - added  vendor product filtering based on RH cert chosen

* Mon Jun 05 2017 Rajasi Kulkarni <rajkulka@redhat.com>
- CERTPX-664: RHCERT WUI Update Openstack certification - Support for updating Certification-networking-plugin - Remove update confirmation for Cert update - Typo fix

* Mon Jun 05 2017 Pooja Tiwari <ptiwari@redhat.com>
- CERTPX-1459 Fixed rhcert-util update traceback for OSP-11 result file.

* Fri Jun 02 2017 Greg Nichols <gnichols@redhat.com>
- CERTPX-1396 New Certification Completion in Tabs    - added Product Sample tab for hardware products (specs)

* Fri Jun 02 2017 Rajasi Kulkarni <rajkulka@redhat.com>
- CERTPX-664: RHCERT WUI Update Openstack certification -Support to update OpenStack certifcation parameters
- CERTPX-664: RHCERT WUI should support Openstack certification update -Improved the template to display the Openstack certification specification

* Thu Jun 01 2017 Greg Nichols <gnichols@redhat.com>
- CERTPX-1396 New Certification Completion in Tabs    - set todo icons for hardware product details (spec)
- CERTPX-1396 New Certification Completion in Tabs    - implemented css class todo-icon to mark to-do items    - added javascript for display (show/hide) by id and class    - implemented to-do items for cloud cert details page
- CERTPX-1394 New Certification Dialog Changes     - fixed creation dialog titles/descriptions

* Thu Jun 01 2017 Poornima Kshirsagar <pkshiras@redhat.com>
- CERTPX-1107 fix rhcert-cli save --server-ip command

* Thu Jun 01 2017 Pooja Tiwari <ptiwari@redhat.com>
- Minor fix in unit testing of productnameservice.py

* Wed May 31 2017 Greg Nichols <gnichols@redhat.com>
- CERTPX-1394 New Certification Dialog Changes     - change vendor product selection to cascading selectors

* Wed May 31 2017 Pooja Tiwari <ptiwari@redhat.com>
- rhcert-util update improvements and bug fixes: CERTPX-617  Improve debug statements CERTPX-1190 Installed RPM test status should be updated correctly CERTPX-666  Update the deferred OpenStack test results xml file correctly

* Wed May 31 2017 Rajasi Kulkarni <rajkulka@redhat.com>
- CERTPX-1434: While creating cloud product the supported regions              accepted form the vendor are saved

* Tue May 30 2017 Greg Nichols <gnichols@redhat.com>
- CERTPX-1445 Traceback when proxy is configured.

* Tue May 30 2017 Rajasi Kulkarni <rajkulka@redhat.com>
- CERTPX 1412: -Modified server.wsgi.alert to act as wrapper over messages framework -Modified page.html to handle redirected and non-redirected messages -Modified the currently present alerts to conform to the new Alerts class

* Sun May 28 2017 Yanis Guenane <yguenane@redhat.com>
- Improve Junit output details in case of failure

* Fri May 26 2017 Greg Nichols <gnichols@redhat.com>
- CERTPX-1394 New Certification Dialog Changes     - initial implementation

* Fri May 26 2017 Pooja Tiwari <ptiwari@redhat.com>
- CERTPX-1433 Added fix to parse 'fdisk' cmd output.

* Fri May 26 2017 Rajasi Kulkarni <rajkulka@redhat.com>
- CERTPX-1394: replace reference of productnameservice.Program with rhcert.tags.Programs

* Thu May 25 2017 Greg Nichols <gnichols@redhat.com>
- CERTPX-1394 New Certification Dialog Changes     - add getAllProducts method returning products for all programs     - removed productnameservice.Program, replaced references with rhcert.tags.Programs
- fix version to 4.10
- fix version should be 4.9

* Thu May 25 2017 Pooja Tiwari <ptiwari@redhat.com>
- CERTPX-1433 Handled 'fdisk -l' command warnings in rhcert.command when command gets executed successfully but with warning (not error).

* Wed May 24 2017 Pooja Tiwari <ptiwari@redhat.com>
- Updated rhcert version to 4.10
- CERTPX-1433 Added support for GPT partition in 'M' failure of rpm verification for Cloud.

* Wed May 24 2017 Greg Nichols <gnichols@redhat.com>
- CERTPX-1396 New Certification Completion in Tabs    - implement rhcert.workflow wrappers and unit tests

* Wed May 24 2017 Yanis Guenane <yguenane@redhat.com>
- director: Transform test in subtest

* Wed May 24 2017 Jianjun Wang <jianjwan@redhat.com>
- RHCWE-1993 Cert.getCertifications needs date-limiting for scaling (UI/performance)
- RHCWE-1839 added some new return fileds for the API Cert.getCertifications

* Mon May 22 2017 Rajasi Kulkarni <rajkulka@redhat.com>
- CERTPX-356: - After selecting the 'Debug' checkbox on the Testing page of RHCERT UI, the tests are run in debug mode

* Mon May 22 2017 jkinsman <jkinsman@redhat.com>
- CERTPX-1185: Automates system creation and provisioning workflow for VMs that can build redhat-certification packages for Jenkins.

* Mon May 22 2017 Greg Nichols <gnichols@redhat.com>
- CERTPX-1429 rhcert-cli showing error: Invalid command
- CERTPX-1416 LogVersionOpenstack import issues with move of LogVersionTests

* Fri May 19 2017 Poornima Kshirsagar <pkshiras@redhat.com>
- CERTPX-722 Fix rhcert-cli register typeerror
- CERTPX-1079 fixed rhcertcli help message for invalid arguments

* Thu May 18 2017 Greg Nichols <gnichols@redhat.com>
- CERTPX-722 rhcert-cli register throws an error while firewall is started    - also makes firewalld changes persistent/permanent

* Wed May 17 2017 Anshul Behl <abehl@redhat.com>
- CERTPX-1421 Fixing the prefixes for openstack logging

* Wed May 17 2017 Greg Nichols <gnichols@redhat.com>
- CERTPX-1325 WUI Certification->Details: 'support cases','knowledge base articles' fields are showing blank

* Wed May 17 2017 Shiyi Yuan <shiyuan@redhat.com>
- RHCWE-2050: File.upload/File.download only support cert

* Tue May 16 2017 Greg Nichols <gnichols@redhat.com>
- CERTPX-1418 WUI: Minor Layout Issues
- CERTPX-1198 Test Vendor" is being prepended to sandbox hardware certs"
- CERTPX-1413 Geeting exception 'Test object has no attribute program' during adding SUT
- CERTPX-1414 rhcert-cli command not performing run operation.

* Tue May 16 2017 Ben Rose <brose@redhat.com>
- CERTPX-1242 alert info level instead of error
- CERTPX-1242 - avoiding the cannot marshal None error, indicating to user not logged in

* Mon May 15 2017 Anshul Behl <abehl@redhat.com>
- CERTPX-1400 Improve the logging of tempest tests CERTPX-1402 stdout from manila is not showing any failures

* Mon May 15 2017 Greg Nichols <gnichols@redhat.com>
- CERTPX-1307 rhcert-cli plan should show resulting test plan
- CERTPX-1405  Manila: DHSS as Feature Selection    - add DHSS True and DHSS False features    - remove old selections for DHSS
- CERTPX-12 Use the Product Name Microservice instead of Certification Index    - final clean up    - fix version policy - simplify and hard-code    - fix program->package mapping for config page

* Mon May 15 2017 Pooja Tiwari <ptiwari@redhat.com>
- CERTPX-632 Added LogVersions test in supportable: - Defined common tests.platform.LogVersionsTest. - It logs the installed kernel and RHEL versions.

* Fri May 12 2017 Greg Nichols <gnichols@redhat.com>
- CERTPX-1409 Support for Certification File attachments     - added rhcert.workflow.engine  support for File.upload and File.download XMLRPC     - added rhcert.workflow.certification support for Cert.attachments XMLRPC     - Unit testing for certification attachments (upload, listing, download)

* Fri May 12 2017 Feng Wang <fwang@redhat.com>
- RHCWE-1999: add new API Util.ping and update Cert.getInProgressCertifications

* Fri May 12 2017 Huanhuan Li <huali@redhat.com>
- RHCWE-1893: update api version

* Fri May 12 2017 Yanis Guenane <yguenane@redhat.com>
- print: Allow one to specify output format

* Fri May 12 2017 Rajasi Kulkarni <rajkulka@redhat.com>
- CERTPX-341: Adding separator between node name and IP for sandbox testing

* Thu May 11 2017 Greg Nichols <gnichols@redhat.com>
- CERTPX-1407 WUI Certification->Details: 'product','product version','category' fields are showing blank
- CERTPX-1320 Error Toast Alerts disappear after a few seconds

* Thu May 11 2017 Pooja Tiwari <ptiwari@redhat.com>
- CERTPX-1170 cloud/security pass config test internal logic change. - Used authconfig to identify hashing algorithm.

* Wed May 10 2017 Pooja Tiwari <ptiwari@redhat.com>
- CERTPX-1201 Cloud/Supportable/Software Repo Test: Allow a Partner/Reviewer to understand the criteria of identifying the RH Repos. - Highlighted the matching part of base URL by displaying it in uppercase.

* Tue May 09 2017 Rajasi Kulkarni <rajkulka@redhat.com>
- CERTPX-1331: fix typo where" to "were" in Progress page for Certification"
- CERTPX-341 rhcert page needs separator between node name and ip address

* Mon May 08 2017 Greg Nichols <gnichols@redhat.com>
- CERTPX-1357 WUI: Manila Certification specific questions page tooltips do not work
- rhcert 4.9
- CERTPX-1324 Progress Tab: under result processing column shows Not Run even if logs are submitted
- CERTPX-1397 rhcert-cli submit traceback: WorkflowCLI object has no attribute getCatalogServer

* Mon May 08 2017 Pooja Tiwari <ptiwari@redhat.com>
- CERTPX-932 Warning in rhcert for a result from unapproved test suite version. - Modified the logic a bit to display the Warning alert (if required) on submit page when it appears after clicking on 'Submit Results' of progress page.

* Fri May 05 2017 Anshul Behl <abehl@redhat.com>
- CERTPX-1374 Fix for PASS tests handling

* Fri May 05 2017 Greg Nichols <gnichols@redhat.com>
- CERTPX-1360 daemon dying on ppc64 and ppc64le when added as SUT
- CERTPX-1296 OpenStack: rhcert can not match system when selecting host for testing

* Fri May 05 2017 Rajasi Kulkarni <rajkulka@redhat.com>
- CERTPX-1303: WUI: Unable to update product description through rhcert WUI.              - Making product description readonly as it cant be updated.

* Thu May 04 2017 Greg Nichols <gnichols@redhat.com>
- CERTPX-1384 Neutron Cert Creation Survey clean-up - Part 1    - remove attach diagram    - remove LBaaS, VPNaaS, FWaaS, description    - moved hardware question to general openstack page
- CERTPX-1385 Manila Cert Creation Survey clean-up - Part 1    - remove old protocol selector, Min/Max API    - remove old share migration and Snapshots
- CERTPX-434 rhcert needs better diagnostics about what it can't reach the catalog     - implement Util.ping call for checking CWE reachability     - revise /cwe/status to use new call, and remove call requiring login.
- CERTPX-1345 Manila protocol/feature selection not reflected in Product Details page CERTPX-1346 Cinder protocol/feature selection not reflected in Product Details page

* Thu May 04 2017 Anshul Behl <abehl@redhat.com>
- Fix:change dir bug when temp dir is deleted

* Thu May 04 2017 root <root@dhcp200-245.gsslab.pnq.redhat.com>
- CERTPX-1374 Manila, Cinder log validation failures with new feature based design

* Wed May 03 2017 Anshul Behl <abehl@redhat.com>
- CERTPX-1365 SOS is still collecting journaldata, which is causing scalability issues for rhcert
- CERTPX-1364 Sahara test runs before tempest-config test, result in failed sahara test
- CERTPX-1363 In /etc/redhat-certification/test_config.json file cinder tests should not be seen

* Wed May 03 2017 Greg Nichols <gnichols@redhat.com>
- CERTPX-1329 create hw cert gives traceback with chinese characters in product name    Fix Unsupported Command "" " caused by XML encode/decode errors."

* Wed May 03 2017 Rajasi Kulkarni <rajkulka@redhat.com>
- CERTPX-1303: WUI: Unable to update product description through rhcert WUI.              - Disabled Save button until product description is set as                attribute for all types of VendorProducts.
- CERTPX-1272: Vendor cloud and hw product update not working from all links              Fixing a call to certificationWorkflow
- CERTPX-1253: There is no --tag option for rhcert-ci command              Adding --tag option for rhcert-ci run subcommand              This patch is only for locally running tests using --tag

* Wed May 03 2017 Pooja Tiwari <ptiwari@redhat.com>
- fixed following bugs: CERTPX-1230 Response box should not have any data for interactive tests as response. CERTPX-1229 Interactive tests should not continue through cli without any giving response. CERTPX-1330 Cloud Open Ports check does not associate user response with open port.
- Added fix to plan other protocol correctly in cinder/manila.

* Tue May 02 2017 Anshul Behl <abehl@redhat.com>
- CERTPX-1355 Making director test non-interactive

* Tue May 02 2017 Ben Rose <brose@redhat.com>
- CERTPX-1312 - report alerts in login page same as current messages are done for consistency
- CERTPX-1297 do not display cwe toast messages in sandbox

* Tue May 02 2017 Greg Nichols <gnichols@redhat.com>
- CERTPX-1248 Replace Catalog, CatalogWeb and CatalogText with rhcert.workflow module     - fix rhcert-cli submit
- CERTPX-1329 create hw cert gives traceback with chinese characters in product name
- CERTPX-1358 RHEL 6.9 and 7.3 SUT stuck at verifying test plan

* Tue May 02 2017 Pooja Tiwari <ptiwari@redhat.com>
- CERTPX-1126 Added HwCertCommandException in Supportable Installed RPM test.

* Mon May 01 2017 Greg Nichols <gnichols@redhat.com>
- CERTPX-1258 Cert.getCertifications return xmlrpclib.Binary objects    - handle xmlrpclib.Binary objects as unicode

* Fri Apr 28 2017 Anshul Behl <abehl@redhat.com>
- CERTPX-1062 Feature based manila certification tests

* Fri Apr 28 2017 Pooja Tiwari <ptiwari@redhat.com>
- CERTPX-932 Results from outdated version should be uploadable via WUI.
- fixed typo

* Fri Apr 28 2017 Rajasi Kulkarni <rajkulka@redhat.com>
- CERTPX-1272: Vendor cloud and hw product update not working              from all links              - Enabling product details update through the                certification specification's Product Details"                tab for cloud and harware product"

* Fri Apr 28 2017 Greg Nichols <gnichols@redhat.com>
- CERTPX-1328 Progress Page should display CWE Test Plan Components

* Thu Apr 27 2017 Greg Nichols <gnichols@redhat.com>
- CERTPX-1248 Replace Catalog, CatalogWeb and CatalogText with rhcert.workflow module     - restore most of wsgi.page     - correct some other problems
- CERTPX-1248 Replace Catalog, CatalogWeb and CatalogText with rhcert.workflow module     - replace CatalogWeb with Workflow and its subclasses     - remove some dead code re: containers
- CERTPX-1319 Detection of catalog reachability should use XMLRPC, not a simple http request.     - implement isReachable on the new rhcert.workflow.workflow base class
- CERTPX-1315 On RHCERT UI, in progress tab, platform field is showing blank

* Thu Apr 27 2017 Huanhuan Li <huali@redhat.com>
- RHCWE-1973: api design of new protocols for cinder plugin

* Thu Apr 27 2017 Rajasi Kulkarni <rajkulka@redhat.com>
- CERTPX-1231 Add LBaaSv2 to Neutron test             Not setting start version at the feature level,             and using the default component level start version

* Thu Apr 27 2017 Pooja Tiwari <ptiwari@redhat.com>
- CERTPX 1165 and CERTPX-1063 Implemented formation of request body params to pass to cwe api call for creating cinder and manila certs.

* Thu Apr 27 2017 Poornima Kshirsagar <pkshiras@redhat.com>
- CERTPX-1253 Adds --tag option to rhcert-ci command

* Thu Apr 27 2017 Anshul Behl <abehl@redhat.com>
- CERTPX-1166 Tests for cinder feature based certs

* Wed Apr 26 2017 Rajasi Kulkarni <rajkulka@redhat.com>
- CERTPX-1231 Add LBaaSv2 to Neutron test

* Wed Apr 26 2017 Anshul Behl <abehl@redhat.com>
- CERTPX-1299 director test is giving an error - 'Error: Minimum of 5 deployment files were not foundgit add director.py' on RHOP9

* Wed Apr 26 2017 Greg Nichols <gnichols@redhat.com>
- CERTPX-1306 rhcert-cli print gives tracback    - added default format option for rhcert-cli    - fixed rhcert-ci print --help
- CERTPX-1298 Rhcert Web UI not able to add Cert with firefox-38.4.0-1.el7     - translated product picker to remove class.     - polyfill lack of String.prototype.includes

* Wed Apr 26 2017 Pooja Tiwari <ptiwari@redhat.com>
- CERTPX-972 Updated RPM verify subtest based on type of failure.

* Tue Apr 25 2017 Anshul Behl <abehl@redhat.com>
- CERTPX-1262 Making neutron test non-interactive
- CERTPX-980 attach tempest.conf to tempest_config test
- CERTPX-1262 Create tempest_config as a mandatory test for openstack certs

* Tue Apr 25 2017 Greg Nichols <gnichols@redhat.com>
- CERTPX-1165 WUI for Cinder Feature Based Certification   - change form variables to return protocols supported as array   - change form to return feature (tests) as an array for each protocol
- CERTPX-1165 WUI for Cinder Feature Based Certification    - fix actions of other" protocol to check tests    - add rhosp version-filtering of tests"
- CERTPX-1165 WUI for Cinder Feature Based Certification    - added filestorage/manila to rhosp-features.json
- CERTPX-1165 WUI for Cinder Feature Based Certification    - created rhcert/server/template/include directory for widgets    - moved widget code    - replaced code with includes for widgets
- CERTPX-1165 WUI for Cinder Feature Based Certification    - updated create page with protocol/feature UI changes
- CERTPX-1165 WUI for Cinder Feature Based Certification    - add test->feature mapping popovers    - support for required tests
- CERTPX-1165 WUI for Cinder Feature Based Certification    - javascript control for selections

* Tue Apr 25 2017 Pooja Tiwari <ptiwari@redhat.com>
- CERTPX-1165 WUI for Cinder Feature Based Certification - Design borrowed from blank.html. - TODO: parameter passing to cwe api call.

* Mon Apr 24 2017 Greg Nichols <gnichols@redhat.com>
- CERTPX-1165 WUI for Cinder Feature Based Certification    - initial ideas for protocol/feature widget (blank page)

* Mon Apr 24 2017 Huanhuan Li <huali@redhat.com>
- RHCWE-1893: add a api getHardwareRelatedCerts_4_7" to get related certs of one hardware cert"

* Thu Apr 20 2017 Anshul Behl <abehl@redhat.com>
- CERTPX-1282 Fixing exception for RHOS9,10

* Wed Apr 19 2017 Anshul Behl <abehl@redhat.com>
- CERTPX-1288 Unable to push attachments to CWE/CAAS
- CERTPX-1282 Some feature tests are throwing exceptions.

* Wed Apr 19 2017 Jianjun Wang <jianjwan@redhat.com>
- RHCWE-1715 rename the Cert.getVendorList to Cert.getPublicVendors_4_7

* Wed Apr 19 2017 Ben Rose <brose@redhat.com>
- CERTPX-1277 - display login modal when clicking save and not logged in
- CERTPX-1277 - display login modal when clicking update and not logged in
- CERTPX-1275 - display login modal for 'New Certification' button click when not logged in
- CERTPX-1276 capitalize platform in create hardware page for consistency

* Tue Apr 18 2017 Anshul Behl <abehl@redhat.com>
- CERTPX-1281 for single Neutron feature cert creation is failing
- CERTPX-1257 from test_config.json neutron tests should be removed
- CERTPX-1244 mismatch between output of testr list-tests and tempest_test.json

* Tue Apr 18 2017 Rajasi Kulkarni <rajkulka@redhat.com>
- CERTPX-699: rhcert-cli plan --help command shows incorrect information.             Fixed the help message for rhcert-cli plan --help and             rhcert-ci plan --help commands

* Tue Apr 18 2017 Pooja Tiwari <ptiwari@redhat.com>
- CERTPX-1144 Cloud/Supportable S/W Repo test should report status(enabled/disabled) for each repo.

* Tue Apr 18 2017 Poornima Kshirsagar <pkshiras@redhat.com>
- CERTPX-1199 Fixed rhcert-ci print --help command

* Mon Apr 17 2017 Rajasi Kulkarni <rajkulka@redhat.com>
- CERTPX-1267 WUI: Error shown on clicking product update button             Hide Update button for OpenStack product details page
- CERTPX-1266 Clicking the Update button for hardware cert shows error TemplateDoesNotExist at /update/certification/" Fixing template to show Update only for cloud certification"

* Thu Apr 13 2017 Greg Nichols <gnichols@redhat.com>
- rhcert 4.8
- CERTPX-1250 WUI: Empty tooltip text in neutron certification component specific questions page
- CERTPX-1258 Cert.getCertifications return xmlrpclib.Binary objects    - add better unicode handling to DocumentBase objects    - setAttribute(None) should product u"
- CERTPX-1260 Sandbox missing navigation and Local Products are Wrong
- CERTPX-1258 Cert.getCertifications return xmlrpclib.Binary objects    - add better unicode handling to DocumentBase objects

* Thu Apr 13 2017 Anshul Behl <abehl@redhat.com>
- CERTPX-1261 Remove four feature for which upstream tempest tests are not available

* Thu Apr 13 2017 Rajasi Kulkarni <rajkulka@redhat.com>
- CERTPX-1219 Show Subscription Model to partners on RHCERT UI

* Wed Apr 12 2017 Rajasi Kulkarni <rajkulka@redhat.com>
- CERTPX-1136 Rhcert web UI needs to support cloud certification updates             - Fixed the update button visibility

* Wed Apr 12 2017 Greg Nichols <gnichols@redhat.com>
- CERTPX-1224 Creating Local Certification Sandbox Causes Traceback     - revised top-level sandboxes page     - implemented sandbox-specific views

* Tue Apr 11 2017 Shiyi Yuan <shiyuan@redhat.com>
- RHCWE-1991: XMLRPC support for get attachments for a vendor product or a cert

* Tue Apr 11 2017 Ben Rose <brose@redhat.com>
- CERTPX-940 - apply change to other templates with the accordian dropdown of test subtest results

* Mon Apr 10 2017 Anshul Behl <abehl@redhat.com>
- CERTPX-1071 Fixing regex for neutron_attribute_extensions
- CERTPX-1071 Removed lbaas as a test from UI as well as a test.

* Mon Apr 10 2017 Greg Nichols <gnichols@redhat.com>
- CERTPX-1238 Placeholder in right column of Test Results page visible
- CERTPX-1214 WUI /certifications page scaleability and performance (refresh button).     - added date-range selector     - Added query parameter to /cwe/sync?range=[<int>
Mon, 10 Apr 2017 09:37:23 -0400,Greg Nichols,gnichols@redhat.com,4b0c079f,    CERTPX-1232"

* Mon Apr 10 2017 Rajasi Kulkarni <rajkulka@redhat.com>
- CERTPX-1136 Rhcert web UI needs to support cloud certification updates             - Added call cert.updateCloud to update Cloud cert             - Created views and updated templates accordingly

* Mon Apr 10 2017 root <root@dhcp200-229.gsslab.pnq.redhat.com>
- CERTPX-1071 Making neutron feature tests minimal w.r.t to user inputs.

* Mon Apr 10 2017 Ben Rose <brose@redhat.com>
- CERTPX-940 fixed accordion drop down id collision amongst same tests with diff devices

* Sun Apr 09 2017 Ben Rose <brose@redhat.com>
- CERTPX-1113 do not display login requirement toast for sandbox creation
- CERTPX-1135 - add detail values to hardware certification details page and remove submit button

* Fri Apr 07 2017 jkinsman <jkinsman@redhat.com>
- CERTPX-1211: Use jQuery context to properly resolve sidebar() function call to patterfly.js

* Fri Apr 07 2017 Huanhuan Li <huali@redhat.com>
- RHCWE-1966: add a new value for cloud cert detail

* Fri Apr 07 2017 Greg Nichols <gnichols@redhat.com>
- CERTPX-1214 WUI /certifications page scaleability and performance (refresh button).     - indexing in VendorProducts to support ID lookups     - fix CertificationDocument.setVendor() to shallow-copy

* Fri Apr 07 2017 Pooja Tiwari <ptiwari@redhat.com>
- CERTPX-1222 Fixed rhcert-cli tagging mechanism and added neutron tag.

* Fri Apr 07 2017 Ben Rose <brose@redhat.com>
- CERTPX-1128 - display hardware product details
- CERTPX-1128 - added update template for hardware product

* Fri Apr 07 2017 Jianjun Wang <jianjwan@redhat.com>
- RHCWE-1827 added the API Cert.updateCloud_4_7

* Thu Apr 06 2017 Anshul Behl <abehl@redhat.com>
- CERTPX-1071 Feature as tests in RHCERT UI and CLI

* Thu Apr 06 2017 Greg Nichols <gnichols@redhat.com>
- CERTPX-1204 Cannot Create New Hardware Product
- CERTPX-1191 Decompose rhcert library code for calling XMLRPCs     - re-organized unit tests into a Unit class     - added some TODO comments
- CERTPX-1216 cwe/status gives a traceback
- CERTPX-1212 Unable to create neutron cert from RHCERT UI
- CERTPX-1214 WUI /certifications page scaleability and performance (refresh button).     - implement background cert/product refresh     - /cwe/sync pulls all products and certs for the current user     - sync status is logged in rhcertStore/vendorProducts     - configuration page shows sync status and allows reset
- CERTPX-1214 WUI /certifications page scaleability and performance (refresh button).     - add Alert feature for appending multiple message lines to an single Alert     - clean up error reporting from workflow.certification

* Thu Apr 06 2017 Huanhuan Li <huali@redhat.com>
- RHCWE-1893: for pass-through or pass-through with supplemental certs, maybe it also has layered certs

* Thu Apr 06 2017 Rajasi Kulkarni <rajkulka@redhat.com>
- CERTPX-999 rhcert web UI support for vendor cloud product updates   - Add call to VendorProduct.get on the page to view the product details   - After successful update redirect to view the updated product details

* Wed Apr 05 2017 Greg Nichols <gnichols@redhat.com>
- CERTPX-1202 Clicking Refresh on Certifications page errors
- CERTPX-1207 AttributeError at /results/ when we click Test Results tab.
- CERTPX-1200 RHEL version is showing different than the entered from RCERT during creating cert     - changed product picker form names to match XMLRPC convention     - revised backwards translation for cloud and hardware cert creation

* Wed Apr 05 2017 Pooja Tiwari <ptiwari@redhat.com>
- CERTPX-1018 CCSP Configure network port subtest criteria update

* Tue Apr 04 2017 Greg Nichols <gnichols@redhat.com>
- CERTPX-1168 Revise WUI Navigation to be Certification-centric     - split openstack product details (specs) between two tabs     - fix display of openstack settings from CWE     - fix traceback on openstack cert creation

* Tue Apr 04 2017 jkinsman <jkinsman@redhat.com>
- CERTPX-1197: Adds requirements.txt file that details all third-party Python dependencies (compatible with Pip)

* Tue Apr 04 2017 Anshul Behl <abehl@redhat.com>
- CERTPX-1070 Fixing the api params to send dictionary for neutron feature changes

* Mon Apr 03 2017 Greg Nichols <gnichols@redhat.com>
- CERTPX-1191 Decompose rhcert library code for calling XMLRPCs     - added vendorProduct.get_4_7 - not in CWE yet     - added engine.fileUpload and fileDownload     - added Cert.supportCases and Cert.Kbase
- CERTPX-1168 Revise WUI Navigation to be Certification-centric     - implement support cases and kbases on cert details page
- CERTPX-1168 Revise WUI Navigation to be Certification-centric     - remove redundant info on certification details tabs.
- fix typo re: workfow
- CERTPX-1168 Revise WUI Navigation to be Certification-centric     - update main results page per spec

* Mon Apr 03 2017 Rajasi Kulkarni <rajkulka@redhat.com>
- CERTPX-999 rhcert web UI support for vendor cloud product updates   - Adding call to update cloud vendor product in rhcert catalog   - Updating template and view to handle update functionality   - Restructing the view of the update test results functionality

* Fri Mar 31 2017 Jianjun Wang <jianjwan@redhat.com>
- RHCWE-1958 XMLRPC calls needed to support hardware and cloud product view

* Fri Mar 31 2017 jkinsman <jkinsman@redhat.com>
- CERTPX-1193: Refactors to more effectively impose package naming convention when the branch name is provided via ${GIT_BRANCH}

* Thu Mar 30 2017 Huanhuan Li <huali@redhat.com>
- RHCWE-1959: reutrn api implemented or supported features based on rhosp version

* Thu Mar 30 2017 Anshul Behl <abehl@redhat.com>
- CERTPX-1071 Neutron features test adding lbaasv2 as UI and policy

* Thu Mar 30 2017 Greg Nichols <gnichols@redhat.com>
- CERTPX-1168 Revise WUI Navigation to be Certification-centric     - integrated workflow details API calls (Cert.get*)

* Thu Mar 30 2017 Pooja Tiwari <ptiwari@redhat.com>
- CERTPX-997 Fix in Supportable Installed RPM test.

* Wed Mar 29 2017 Anshul Behl <abehl@redhat.com>
- Adding feature names for neutron w.r.t api names for cinder sahara
- CERTPX-1071 Adding more policy changes to Neutron feature based on TAM suggestions.

* Wed Mar 29 2017 Greg Nichols <gnichols@redhat.com>
- CERTPX-1168 Revise WUI Navigation to be Certification-centric     - updated main results table per UX design
- CERTPX-1168 Revise WUI Navigation to be Certification-centric     - fix testing and assignment sub-pages
- CERTPX-1191 Decompose rhcert library code for calling XMLRPCs     - added RPCs to workflow/certification.py     - added unit tests     - created workflow/engine.py for non-model calls
- CERTPX-1168 Revise WUI Navigation to be Certification-centric

* Wed Mar 29 2017 jkinsman <jkinsman@redhat.com>
- Typo
- CERTPX-1193: If the branch name is provided by Jenkins via ${GIT_BRANCH}, make sure the string has non-zero length
- Addresses merge conflicts.

* Wed Mar 29 2017 Pooja Tiwari <ptiwari@redhat.com>
- CERTPX-991 Display gpg details for configured Red Hat repo's in Cloud/Supportable Software Repo test.

* Tue Mar 28 2017 Greg Nichols <gnichols@redhat.com>
- CERTPX-1184 Enable Feature Builds in rhcert    fix respin detection for features.
- CERTPX-1168 Revise WUI Navigation to be Certification-centric    - implement top-level pages: certifications/test results/sandboxes/products
- CERTPX-1191 Decompose rhcert library code for calling XMLRPCs     - fix spec files - added rhcert/workflow
- CERTPX-1191 Decompose rhcert library code for calling XMLRPCs     - moved current cert calls to workflow/certifications.py

* Mon Mar 27 2017 Huanhuan Li <huali@redhat.com>
- RHCWE-1959: update supported features to keep it insistent with create function
- RHCWE-1932: Add a new api createOpenstack_4_7 to support neutron, cinder, manila feature based test, for other component, it's the same behavior as before.

* Mon Mar 27 2017 Greg Nichols <gnichols@redhat.com>
- CERTPX-1191 Decompose rhcert library code for calling XMLRPCs     - initial example for VendorProduct calls.

* Mon Mar 27 2017 Jianjun Wang <jianjwan@redhat.com>
- RHCWE-1827 Provide APIs by Program for RHCERT to update certs

* Mon Mar 27 2017 Pooja Tiwari <ptiwari@redhat.com>
- CERTPX-958 Made server as mandatory param in rhcert-ci save command.
- CERTPX-957 Added missing print usage in rhcert-ci help command.

* Fri Mar 24 2017 Greg Nichols <gnichols@redhat.com>
- CERTPX-1184 Enable Feature Builds in rhcert

* Thu Mar 23 2017 Greg Nichols <gnichols@redhat.com>
- RHCWE-1659 Create an API to create the layered cert for a given cert
- CERTPX-1174 Unable to create Manila certification for OSP-11    - allow Manila for RHOSP-10 and higher    - fix sort-order for RHOSP

* Thu Mar 23 2017 Ben Rose <brose@redhat.com>
- CERTPX-1175 - add el6.9 GA to valid-kernels.json cache

* Wed Mar 22 2017 Huanhuan Li <huali@redhat.com>
-  RHCWE-1959: update some params to keep insistent with create function

* Wed Mar 22 2017 Anshul Behl <abehl@redhat.com>
- Fixing log message prefixes
- CERTPX-1071 Made changes to test_config.json.sample relevant to new features

* Wed Mar 22 2017 Greg Nichols <gnichols@redhat.com>
- rhcert 4.7 belated marking: should be 3-15-2017 on

* Tue Mar 21 2017 Huanhuan Li <huali@redhat.com>
- RHCWE-1959: provide apis for rhcert to get certification details

* Tue Mar 21 2017 Greg Nichols <gnichols@redhat.com>
- CERTPX-1136 rhcert web UI needs to support cloud certification updates     - re-organized image name and build attributes     - removed base OS from product certifications list for cloud
- CERTPX-1159 creating local product/sandbox results in error template not found

* Tue Mar 21 2017 Anshul Behl <abehl@redhat.com>
- CERTPX-1163 Fix wrong condition rhosp-release

* Tue Mar 21 2017 jkinsman <jkinsman@redhat.com>
- CERTPX-1160: Removes Python 2.7+ syntax from __major function

* Tue Mar 21 2017 Shiyi Yuan <shiyuan@redhat.com>
- RHCWE-1904: The xml api doc for get or add kbase and support case

* Mon Mar 20 2017 Anshul Behl <abehl@redhat.com>
- CERTPX-1156 Subtests of supportable tests are not showing on rhcert ui

* Mon Mar 20 2017 root <root@dhcp207-192.lab.eng.pnq.redhat.com>
- CERTPX-1071 Feature-Based Neutron Certification Tests TODO : selection is still interactive, will fix after rhcert changes

* Mon Mar 20 2017 Greg Nichols <gnichols@redhat.com>
- CERTPX-1158 Disable Product and Certification Details pages

* Mon Mar 20 2017 Pooja Tiwari <ptiwari@redhat.com>
- CERTPX-650 Cloud/Configuration Subscription Service test updated. - Permitting only RHUI/Satellite subscription, not RedHat CDN.

* Fri Mar 17 2017 root <root@dhcp207-192.lab.eng.pnq.redhat.com>
- CERTPX-1119 There is no content of tempest.conf in configuration section of log when partner via command line
- CERTPX-1101 rhcert-ci support for RHOS11 CERTPX-441 There is no 0 file in tempest/.testrepository

* Thu Mar 16 2017 Anshul Behl <abehl@redhat.com>
- CERTPX-1153 - Log RHEL version as a supportable openstack test

* Thu Mar 16 2017 Greg Nichols <gnichols@redhat.com>
- CERTPX-1070 WUI for Feature-Based Neutron Certification    - add feature widget to cert details for networking
- CERTPX-1070 WUI for Feature-Based Neutron Certification    - re-organize cert creation templates.
- CERTPX-1070 WUI for Feature-Based Neutron Certification     - more-compact feature selector with pop-over details     - changed order of questions

* Thu Mar 16 2017 jkinsman <jkinsman@redhat.com>
- Accidentally committed irrelevant files.
- Fixes typo.
- CERTPX-1103: rhcert/version.py Make target is no longer circularly-dependent.

* Wed Mar 15 2017 Greg Nichols <gnichols@redhat.com>
- CERTPX-1128 rhcert web UI support for vendor hardware product updates CERTPX-1135 rhcert web UI needs to support hardware certification updates CERTPX-1136 rhcert web UI needs to support cloud certification updates CERTPX-664 rhcert web UI needs to support openstack certification updates
- CERTPX-1147 redirect after results upload is invalid (traceback).   - fixed the case where the results have no cert info, and must send the user to view the XML/CSS for the file.
- RHCWE-1959 XMLRPC call Cert.get_4_6 Needed for cert details

* Wed Mar 15 2017 Anshul Behl <abehl@redhat.com>
- CERTPX-1070 WUI for Feature-Based Neutron Certification Adds: based on version shows selector widget -design borrowed from blank template for selector widget

* Tue Mar 14 2017 root <root@dhcp200-235.gsslab.pnq.redhat.com>
- CERTPX-1084 RHOSP11 tempest changes Also Fixes: CERTPX-1096 Bundle the RHOS11 tests in tempest_tests.json file CERTPX-1097 for RHOS11 use discover-tempest-config binary instead of config_tempest.sh script CERTPX-1098 Add the new version detection mechanism available for RHOS10 and 11 CERTPX-1099 Detect any extra regexes required for cinder,neutron.manila and sahara cert suites CERTPX-1095 Move away from run_tempest.sh to tempest run command in RHOS11

* Tue Mar 14 2017 Anshul Behl <abehl@redhat.com>
- CERTPX-484 Director test runs on undercloud while api tests run on overcloud

* Mon Mar 13 2017 Ben Rose <brose@redhat.com>
- CERTPX-152 update login page message and forgot user/pass link

* Fri Mar 10 2017 Anshul Behl <abehl@redhat.com>
- CERTPX-1098 Add the new version detection mechanism available for RHOS10 and 11 - Adds supportable test to check     *rhosp-release file     *openstack-nova rpm

* Fri Mar 10 2017 Greg Nichols <gnichols@redhat.com>
- CERTPX-1133 RHOSP 11 must be added to the Product Name Service
- CERTPX-1129 On RHCERT UI, under certification column, no certificates can be seen     - fixed exception raised when base version ID is missing from CWE data.

* Thu Mar 09 2017 jkinsman <jkinsman@redhat.com>
- CERTPX-1123: rhcert/version.py release variable no longer contains .el[6
Wed, 8 Mar 2017 16:17:00 -0500,Greg Nichols,gnichols@redhat.com,932b4dd8,CERTPX-657 design: rhcert web UI needs to support certification updates     - added a separate product details page     - added left-navigation to product certifications and details     - product plain URL redirects to product certifications     - reorganized template and wsgi files"

* Wed Mar 08 2017 jkinsman <jkinsman@redhat.com>
- Fixes circular import during build process.

* Wed Mar 08 2017 Greg Nichols <gnichols@redhat.com>
- CERTPX-657 design: rhcert web UI needs to support certification updates     - added separate cert details page     - moved generic cert details from progress page to new details page.     - reorganized certification wsgi and template directories
- CERTPX-1114 Convert systems mismatch warning to toast alert
- CERTPX-1073 Feature Selector Widget    - clarified json feature definition with labels

* Wed Mar 08 2017 Ben Rose <brose@redhat.com>
- Get around cookie testcleanup for modal

* Wed Mar 08 2017 Rajasi Kulkarni <rajkulka@redhat.com>
- CERTPX-672 Added confirm option for updating test results and improved the validation messages.

* Tue Mar 07 2017 Greg Nichols <gnichols@redhat.com>
- CERTPX-1073 Feature Selector Widget    - defined component feature selection data service    - temporary demo code on /blank showing use.    - accordion widget for display

* Tue Mar 07 2017 Ben Rose <brose@redhat.com>
- CERTPX-981 return for unfound substring is -1, not falsy

* Tue Mar 07 2017 Pooja Tiwari <ptiwari@redhat.com>
- Fixed CERTPX-557 - Cloud/Configuration Subscription Service test should look for rhui repos if subscribed with RHUI.
- CERTPX-531 Updated gpg check criteria in cloud/supportable s/w repo test. - Fail if gpg check is disabled (Warn in case of non-rh repos) - Fail if gpg key is missing (Warn for in case of non-rh repos) - Fail if invalid gpg key (Warn in case of non-rh repos)

* Tue Mar 07 2017 jkinsman <jkinsman@redhat.com>
- Add build changes to -devel RPM spec as well.
- Fix Brew build issue by adding RHCERT_RELEASE environment variable value to Make via command line invocation from RPM specs (instead of exporting value in current shell via the Makefile)

* Mon Mar 06 2017 jkinsman <jkinsman@redhat.com>
- Adds additional clarification to Makefile
- Reverts rhcert/version.py to .PHONY target.
- Jenkins Build numbers are now properly displayed in RPM package names.
- Temporary hack to allow the build user to install dependencies without being prompted for a root password. This will later be managed by Puppet.
- Temporary fix for circular dependency.
- Temporary fix to remove circular build dependency.
- Checkpoint:  Builds RHEL 7 redhat-certification packages for rhcert-ui, cloud, and openstack.
- Adds back build-rhcert-release.py (accidental removal)
- Adds ug+x permission to build-rhcert.sh script.
- test commit
- Adds job description and dummy shell script to run in response to code changes.

* Fri Mar 03 2017 Greg Nichols <gnichols@redhat.com>
- rhcert 4.6
-  CERTPX-1091 The rhcert rpm should use the source copy of Product Name json data
- CERTPX-1089 rhcert passes list parameters as strings in certification creation calls.     - change form processing to correctly code list/array values

* Fri Mar 03 2017 Rajasi Kulkarni <rajkulka@redhat.com>
- CERTPX-672 Added update utility option in rhcert UI on the Testing" page. Implementing review comments."

* Thu Mar 02 2017 Greg Nichols <gnichols@redhat.com>
- fixed for 4.5

* Thu Mar 02 2017 Pooja Tiwari <ptiwari@redhat.com>
- CERTPX-1023 Made adjustments in PNS response locally for displaying correct data in rhcert configuration page.

* Wed Mar 01 2017 Greg Nichols <gnichols@redhat.com>
- CERTPX-961 on manila create page. The value for CephFS show as NFS"     - also removing "tested" radio buttons per PM."
- CERTPX-1074 Traceback when I create cert in local sandbox (no baseVersions).
- CERTPX-1068 RHOSP Cert base RHEL not correctly downloaded from CWE

* Wed Mar 01 2017 Ben Rose <brose@redhat.com>
- CERTPX-981 change to redirect button on page load if not logged in

* Tue Feb 28 2017 Anshul Behl <abehl@redhat.com>
- CERTPX-977 Using load method instead of loadFiltered as xsl files are not bundled with rhcert-backend

* Tue Feb 28 2017 Greg Nichols <gnichols@redhat.com>
- CERTPX-1025 Can't Create Sandbox

* Mon Feb 27 2017 Greg Nichols <gnichols@redhat.com>
- CERTPX-1029 Unable to create RHOSP cert via the Web UI: 'The product id '2960863' is invalid or does not exist'    - changed the RHOSP dialog to use the Product Name Service    - added base RHEL selector    - added protocol selection for cinder

* Mon Feb 27 2017 Ben Rose <brose@redhat.com>
- CERTPX-1053 - hide cwe status toast by default

* Sat Feb 25 2017 Ben Rose <brose@redhat.com>
- CERTPX-1046 Update login modal to closer match style in pdf
- CERTPX-1047 - update unreachable cwe modal to be prettier
- CERTPX-1045 - update toast in login too
- CERTPX-1045 - change cwe status toast messages to match style of other error toasts

* Fri Feb 24 2017 Greg Nichols <gnichols@redhat.com>
- CERTPX-1048 certification creation from product alert results in traceback

* Thu Feb 23 2017 Greg Nichols <gnichols@redhat.com>
- CERTPX-1026 select host showing mismatch between OS and cert versions     - fixed Base OS" in cert view page     - fixed cookie trail"
- CERTPX-665 rhcert web UI support for vendor product creation     - alert/errors references
- CERTPX-665 rhcert web UI support for vendor product creation    - added Alert class for WebUI alerts    - improved alert on product view to provide link to create a cert
- CERTPX-665 rhcert web UI support for vendor product creation    - clean up error messages as toast notifications
- CERTPX-665 rhcert web UI support for vendor product creation     - fixed cert and product creation to return correctly when product or cert is created.

* Thu Feb 23 2017 Ben Rose <brose@redhat.com>
- CERTPX-1032 change frequency of cwe status check

* Thu Feb 23 2017 Pooja Tiwari <ptiwari@redhat.com>
- CERTPX-473 Fixes in Dockerfile: - Used 'rhel7:7.3-released' base image. - Enabled yum operations.

* Wed Feb 22 2017 Greg Nichols <gnichols@redhat.com>
- CERTPX-1024 Can't create Product - no vendor     - added vendor selection to the Choose Program step     - vendor IDs are shown if multiple vendors have the same name
- CERTPX-665 rhcert web UI support for vendor product creation     - fixed RH product selector showing blank version     - added New Product button to products page     - moved buttons to table headings     - changed program titles to use full names in create dialogs
- CERTPX-930 call service to create product name service cache in every build     - move cache update from install to rpm-prep.

* Wed Feb 22 2017 Feng Wang <fwang@redhat.com>
- RHCWE-1827: update xmlrpc API doc adding new api Cert.updateCert

* Tue Feb 21 2017 Greg Nichols <gnichols@redhat.com>
- CERTPX-665 rhcert web UI support for vendor product creation/updates    - fix products.py inadvertant import
- CERTPX-665 rhcert web UI support for vendor product creation/updates    - split CertificationDocument into its owm rhcert.certificationdocument    - adjusted code for XMLRPC revisions    - replaced most RH product metadata access to use ProductNameService    - reverted default url to products page

* Tue Feb 21 2017 Ben Rose <brose@redhat.com>
- CERTPX-930 call service to create product name service cache in every build

* Mon Feb 20 2017 Jianjun Wang <jianjwan@redhat.com>
- RHCWE-1839 CWE provide an API to return all certifications

* Mon Feb 20 2017 Greg Nichols <gnichols@redhat.com>
- CERTPX-665 rhcert web UI support for vendor product creation/updates     - removed old cert creation UI     - changed cert creation button on vendor product page to new UI

* Mon Feb 20 2017 Pooja Tiwari <ptiwari@redhat.com>
- Fixed error message.
- Removed ValidateRPMs class from services/rpmfreshness.

* Fri Feb 17 2017 Greg Nichols <gnichols@redhat.com>
- CERTPX-665 rhcert web UI support for vendor product creation/updates     - adjusted for changed CWE API calls     - added confirmation page after certification created
- CERTPX-665 rhcert web UI support for vendor product creation/updates     - updated CWE calls to new API

* Thu Feb 16 2017 Ben Rose <brose@redhat.com>
- CERTPX-1000 Do not hide navigation bar

* Thu Feb 16 2017 Greg Nichols <gnichols@redhat.com>
- CERTPX-12 Use the Product Name Microservice instead of Certification Index     - fix make

* Wed Feb 15 2017 Greg Nichols <gnichols@redhat.com>
- CERTPX-12 Use the Product Name Microservice instead of Certification Index     - added getProduct method to provide data for a single product     - separated microservices classes into a new rhcert.services module
- CERTPX-12 Use the Product Name Microservice instead of Certification Index     - changed the ProductNameService to supply data in json form filtered by program.

* Tue Feb 14 2017 Kun Yan <kyan@redhat.com>
- RHCWE-1869 Add VendorProduct.list/create/update api spec

* Tue Feb 14 2017 Ben Rose <brose@redhat.com>
- CERTPX-995 - update cwe/status to include errors when unreachable, updated modal message in web ui
- CERTPX-981 - Change buttons/links reliant on cwe login to pull up login modal when logged out.

* Mon Feb 13 2017 Huanhuan Li <huali@redhat.com>
- Add Cert.checkNVRSupported API specification in swagger yaml file

* Mon Feb 13 2017 Greg Nichols <gnichols@redhat.com>
- CERTPX-656 design: rhcert web UI support for vendor product creation/updates    - temporarily make cert/product downloads manual via Refresh" button."
- CERTPX-656 design: rhcert web UI support for vendor product creation/updates    - move New Product button to header when creating product    - fix new hardware product creation form
- CERTPX-975 create rhcert endpoint cwe/status that uses simple CWE xmlrpc call

* Mon Feb 13 2017 Ben Rose <brose@redhat.com>
- CERTPX-982 - unburden cpu and fix memory leak
- CERTPX-714 - create login modal, set link in relavent toast

* Mon Feb 13 2017 Pooja Tiwari <ptiwari@redhat.com>
- CERTPX-12 Use the Product Name Microservice instead of Certification Index. CERTPX-628 Added support to create new cert with minor version for h/w cert.
- CERTPX-547 Added rhcert-cli (no args) command for guided workflow. - Supports two new commands:   $ rhcert-cli   $ rhcert-cli --test <testname>

* Sat Feb 11 2017 Ben Rose <brose@redhat.com>
- CERTPX-715 - add the details modal to login page for unreachable cwe
- CERTPX-719 - respect dismissal of toast on login page
- CERTPX-716 - Create more details modal on base template

* Fri Feb 10 2017 Ben Rose <brose@redhat.com>
- CERTPX-719 - on login screen, disable button, show toast for unreachable cwe
- CERTPX-718 - add toast for dropped/unreachable
- CERTPX-718 - add toast for dropped/reachable
- CERTPX-721 - Add to Ajax, call to rhcert endpoint cwe/status and set hidden field

* Thu Feb 09 2017 Ben Rose <brose@redhat.com>
- CERTPX-975 - create rhcert endpoint for cwe connection status

* Thu Feb 09 2017 Greg Nichols <gnichols@redhat.com>
- CERTPX-665 rhcert web UI support for vendor product creation/updates     - move from RCUE to Patternfly     - default / url shows certifications" page (/certifications)     - for logged in user

* Wed Feb 08 2017 Kun Yan <kyan@redhat.com>
- RHCWE-1843 XMLRPC support for vendor product attachments

* Wed Feb 08 2017 Rajasi Kulkarni <rajkulka@redhat.com>
- CERTPX-929 Fixed 'rhcert-ci save --cert_id giving no such option error'

* Mon Feb 06 2017 Anshul Behl <abehl@redhat.com>
- CERTPX-667 remove the traceback when getting dependency for xsl files from test Harness
- CERTPX-670 results file list view is needed to support review

* Mon Feb 06 2017 Greg Nichols <gnichols@redhat.com>
- version 4.5
- CERTPX-698 kdump test doesn't restart daemon or listener upon reboot

* Fri Feb 03 2017 Greg Nichols <gnichols@redhat.com>
- CERTPX-656 design: rhcert web UI support for vendor product creation/updates    - protoype create product and/or cert from certifications page

* Thu Feb 02 2017 Greg Nichols <gnichols@redhat.com>
- CERTPX-943 rhcert-ci plan giving traceback    - rhcert-ci --remote now requires program and id (local sandbox id).
- CERTPX-942 rhcert-cli submit missing in help

* Wed Feb 01 2017 Greg Nichols <gnichols@redhat.com>
- CERTPX-702 rhcert-ci command no longer needs CI Sanboxes.
- CERTPX-928 CI Sandboxes should be removed from the rhcert WUI    - CI Sandboxes removed    - Local Certifications are now called Sandboxes""

* Tue Jan 31 2017 Greg Nichols <gnichols@redhat.com>
- CERTPX-934 /etc/httpd/conf.d/rhcert.conf is installed with 755 permissions
- CERTPX-723 Rhcert UI generated traceback while Dialog" tab under "Certifications" tab is clicked"
- CERTPX-933 rhcert UI shows (Local)" near ID on view of certification and sandboxes"
- CERTPX-656 design: rhcert web UI support for vendor product creation/updates

* Fri Jan 27 2017 Greg Nichols <gnichols@redhat.com>
- fix build

* Thu Jan 26 2017 Ben Rose <brose@redhat.com>
- CERTPX-705 - update valid-kernels.json
- CERTPX-294 - Enable real kernel version checks for Realtime

* Wed Jan 25 2017 Anshul Behl <abehl@redhat.com>
- CERTPX-646 Update SUT view to Add Live Output Page per UXD session -Show debug logs on Testing and Dialog page despite the debug enabled checked -#TODO Make the results scrollable -#TODO Harness Dialog log

* Wed Jan 25 2017 Jianjun Wang <jianjwan@redhat.com>
- RHCWE-1835 update createCert api for test plan changes and protocol changes both for cinder and manila

* Wed Jan 25 2017 Kun Yan <kyan@redhat.com>
- Add File.upload File.download API specification in swagger yaml file

* Wed Jan 25 2017 Pooja Tiwari <ptiwari@redhat.com>
- CERTPX-694 Removed Go To Workflow" links from Certification and Sandbox pages."
- CERTPX-638  Removed dependency of bug ID from following rhcert XMLRPC API call:  1. Cert.getValidationReports  2. Cert.getKey

* Tue Jan 24 2017 Shiyi Yuan <shiyuan@redhat.com>
- Add a new api getSupportProtocolsForOsp and change a desc for createLayerCert

* Tue Jan 24 2017 Anshul Behl <abehl@redhat.com>
- CERTPX-534 RHCERT should return better error message

* Mon Jan 23 2017 Anshul Behl <abehl@redhat.com>
- CERTPX-564 Ambiguous Certifications response error

* Mon Jan 23 2017 Pooja Tiwari <ptiwari@redhat.com>
- RHCWE-1797 Modified xmlrpc-api.yaml.  - Reflected changes into develop which were merged to master branch directly.

* Fri Jan 20 2017 Greg Nichols <gnichols@redhat.com>
- CERTPX-683 Rhcert UI generated traceback while CI Sandboxes" tab is clicked     - Changed "local certifications" to "sandboxes"     - fixed traceback     - changed "ecosystem" to "program"     - removed "workflow" from tables"

* Fri Jan 20 2017 Anshul Behl <abehl@redhat.com>
- CERTPX-677 rhcert-ci for director test

* Thu Jan 19 2017 Feng Wang <fwang@redhat.com>
- RHCWE-1797: Remove the dependency of bug ids from the CWE API

* Thu Jan 19 2017 Greg Nichols <gnichols@redhat.com>
- CERTPX-685 There is no rhcert-cli submit" command"

* Wed Jan 18 2017 Greg Nichols <gnichols@redhat.com>
- CERTPX-365 Add Certifications" Top-Level Page     - implemented download of all products/certs     - currently invoked via button at bottom of table."
- CERTPX-365 Add Certifications" Top-Level Page    - added "Results Files" page at top url "/results/""
- CERTPX-676 rhcert-util command traceback

* Tue Jan 17 2017 Greg Nichols <gnichols@redhat.com>
- CERTPX-602 rhcertd register command - enhanced client registration     - limit sensing of broadcast to 10 cycles     - if sensing fails, ask user for server

* Mon Jan 16 2017 Greg Nichols <gnichols@redhat.com>
- CERTPX-547 Add rhcert-cli command     - add rhcert-cli     - move commands from rhcert-backend not in rhcert-cli to rhcert-util     - move server commands to rhcertd

* Fri Jan 13 2017 Greg Nichols <gnichols@redhat.com>
- CERTPX-365 Add Certifications" Top-Level Page     - initial prototype - just shows previously downloaded/created certs from the product pages."
- CERTPX-602 rhcertd register command - enhanced client registration    - set rhcert.conf and project/wsgi.py to start Beacon on httpd start    - use environment listener port from /etc/results.xml    - check and ask to open listner port (tcp and udp)

* Fri Jan 13 2017 Pooja Tiwari <ptiwari@redhat.com>
- CERTPX-651 Fixed kernel test - It should take the name for Real Time Kernel correctly.

* Wed Jan 11 2017 Jianjun <jianjwan@redhat.com>
- RHCWE-1772 Provide new APIs for RHCERT to create passthrough spec and cert

* Wed Jan 11 2017 Anshul Behl <abehl@redhat.com>
- CERTPX-658 rhcert-cli --help throws traceback

* Tue Jan 10 2017 Greg Nichols <gnichols@redhat.com>
- CERTPX-602 rhcertd register command - enhanced client registration
- CERTPX-638 Update RHCERT to call updated APIs of CWE which remove the dependency of bug ids

* Fri Jan 06 2017 Greg Nichols <gnichols@redhat.com>
- XMLRPC spec
- CERTPX-621 Supportable/Kernel Test returned None for tainted kernel. -Removing exttra whitespaces from file Change-Id: Iecedc6159f8eabb6ffbece4906c591fb2f3210b9
- CERTPX-563 Remove Bugzilla URL setting from config. screen

* Fri Jan 06 2017 Pooja Tiwari <ptiwari@redhat.com>
- CERTPX-637  Improved presentation of updated result for RPM Freshness using  rhcert-backend update"."
- CERTPX-622 Cloud/Security Password test should PASS for SHA512/sha512.

* Thu Jan 05 2017 Anshul Behl <abehl@redhat.com>
- CERTPX-622 Password configuration test give wrong password message

* Thu Jan 05 2017 Greg Nichols <gnichols@redhat.com>
- CERTPX-621 Supportable/Kernel Test returned None for tainted kernel.
- CERTPX-627 rhcert does not update the results for deferred test correctly.    - adjust microservices update logic for list of subtests

* Wed Jan 04 2017 Greg Nichols <gnichols@redhat.com>
- CERTPX-625 boot parameter check is missing in 4.2 version test suite
- CERTPX-627 rhcert does not update the results for deferred test correctly.    - fix to update all tests/subtests in all test runs
- version 4.4

* Wed Jan 04 2017 Pooja Tiwari <ptiwari@redhat.com>
- CERTPX-598 Fixed missing import statement for Kernel Test.

* Tue Jan 03 2017 Greg Nichols <gnichols@redhat.com>
- CERTPX-631 remove redhat-certification-openstack subpackage from redhat-certification-backend.el6

* Wed Dec 21 2016 Greg Nichols <gnichols@redhat.com>
- correct inandertant change

* Mon Dec 19 2016 Anshul Behl <abehl@redhat.com>
- Revert CERTPX-530 Pass test regex instead of test names to tempest in RCO""

* Mon Dec 19 2016 Pooja Tiwari <ptiwari@redhat.com>
- CERTPX-609 Modified kernel test to use valid-kernels microservice.

* Fri Dec 16 2016 Anshul Behl <abehl@redhat.com>
- CERTPX-576 Tempest existing log removal is not working correctly
- CERTPX-530 Pass test regex instead of test names to tempest in RCO
- CERTPX-528 SHARE_EXPORT_LOCATIONS plugin is displays many times.

* Fri Dec 16 2016 Pooja Tiwari <ptiwari@redhat.com>
- CERTPX-554 - Removed the logging of the parameter-set for   microservice in the case of a failed call. - Modified the display messages accordingly for   installed RPM and rpm freshness tests.
- CERTPX-587 cloud/configuration Network test should not fail if httpd is not running.

* Thu Dec 15 2016 Anshul Behl <abehl@redhat.com>
- CERTPX-597 Removing the scap dependency from RCO
- CERTPX-552 Add support for rhcert-cli in openstack(tempest)
- CERTPX-525 Remove version check for manila planning

* Tue Dec 13 2016 Amol Kahat <akahat@redhat.com>
- Fixed neutron json file format.

* Tue Dec 13 2016 Greg Nichols <gnichols@redhat.com>
- CERTPX-473 Build docker images from released base images
- CERTPX-547 Add rhcert-cli command
- CERTPX-593 rhcert-backend extract traceback

* Tue Dec 13 2016 Anshul Behl <abehl@redhat.com>
- Revert Fixed neutron json file format.""

* Mon Dec 12 2016 Greg Nichols <gnichols@redhat.com>
- CERTPX-545 Operations Plan for Microservices    - set default config for production microservices proxy

* Mon Dec 12 2016 Pooja Tiwari <ptiwari@redhat.com>
- CERTPX-415 CCSP Software Repo test should fail if no RH repo configured.

* Fri Dec 09 2016 Greg Nichols <gnichols@redhat.com>
- CERTPX-583 Build openstack and cloud test suites as redhat-certification subpackages

* Thu Dec 08 2016 Greg Nichols <gnichols@redhat.com>
- CERTPX-573 rhcert XML schema is missing some recent changes

* Wed Dec 07 2016 Anshul Behl <abehl@redhat.com>
- CERTPX-525 Remove manila planning by version

* Wed Dec 07 2016 Greg Nichols <gnichols@redhat.com>
- CERTPX-562 Version 4.3

* Wed Dec 07 2016 Pooja Tiwari <ptiwari@redhat.com>
- Fixes in Cloud Supportable Software Repo Test  - CERTPX-415 Empty repolist should fail the test.  - CERTPX-435 Removed separate 'Environment GPGKey' test.  - CERTPX-531 Fail the test if gpgcheck=0.  - CERTPX-556 Print the Red Hat repos(PASS scenario).
- CERTPX-555 Revised list of Red Hat supported hypervisors.

* Tue Dec 06 2016 Greg Nichols <gnichols@redhat.com>
- CERTPX-552 rhcert-ci support in openstack for interactive tests (tempest)     - restored test_config.json.sample     - added code to use it for defaults if interactive     - added code to require it for auto mode runs (rhcert-ci)

* Tue Dec 06 2016 Pooja Tiwari <ptiwari@redhat.com>
- CERTPX-481 Added support for 'hyperv' hypervisor.

* Wed Nov 30 2016 Anshul Behl <abehl@redhat.com>
- CERTPX-524 Neutron JSON file is not generated properly.

* Tue Nov 29 2016 Greg Nichols <gnichols@redhat.com>
- CERTPX-491 Manila-specific Parameter Problems     - changed rhcert to handle nested dictionaries in cert data from catalog

* Mon Nov 28 2016 Anshul Behl <abehl@redhat.com>
- CERTPX-523 - Manila run has some other tests in it

* Mon Nov 28 2016 Greg Nichols <gnichols@redhat.com>
- fix build process

* Fri Nov 25 2016 Anshul Behl <abehl@redhat.com>
- Collect director test_logs
- CERTPX-509 APIs are not listinig for manila on RHOSP10

* Fri Nov 25 2016 Pooja Tiwari <ptiwari@redhat.com>
- CERTPX-519 Fixed attribute error in director test.

* Wed Nov 23 2016 Anshul Behl <abehl@redhat.com>
- CERTPX-499 Tests can't be seen on RHCERTUI - Namespace issue with existing openstack folder - Changes name from openstack to openstack_cert Change-Id: I51817ff3d32f84cbcb57fe50d99e03776b140ed5
- CERTPX-496 Add tempest.conf.sample to source
- CERTPX-490 validation_report.json fixes

* Wed Nov 23 2016 Pooja Tiwari <ptiwari@redhat.com>
- Added missing changelogs.

* Tue Nov 22 2016 Anshul Behl <abehl@redhat.com>
- CERTPX-496 Fix RHOS8 tempest generation
- Neutron Code Refactoring
- CERTPX-490 Add validation_report.json for review purposes

* Tue Nov 22 2016 Pooja Tiwari <ptiwari@redhat.com>
- CERTPX-493 Unsupported API tests should fail with Error message.
- CERTPX-457 Added sos package as required rpm for supportable/system-report test.

* Tue Nov 22 2016 Greg Nichols <gnichols@redhat.com>
- CERTPX-496 Fix RHOS8 tempest generation      - Neutron Code Refactoring
- CERTPX-489 Move redhat-certification-openstack sources to rhcert repo     - remove redundant log entries from redhat-certification-spec.in
- CERTPX-492 openstack/manila: automatic api selection should observe maximum microversion
- CERTPX-489 Move redhat-certification-openstack sources to rhcert repo
- CERTPX-478 Director dependency resolved

* Mon Nov 21 2016 Anshul Behl <abehl@redhat.com>
- CERTPX-414 Clear any existing logs in .testrepository directory

* Wed Nov 16 2016 Ben Rose <brose@redhat.com>
- CERTPX-479 No longer install redhat-certification-information

* Tue Nov 15 2016 Greg Nichols <gnichols@redhat.com>
- Moved Supportable/InstalledRPMs test to rhcert/tests/InstalledRPMs.py.

* Mon Nov 14 2016 Greg Nichols <gnichols@redhat.com>
- CERTPX-439 Define common 'openstack/supportable' test for all components
- CERTPX-399 Should not be able to create a Manila cert for RHOSP8/9

* Thu Nov 10 2016 Greg Nichols <gnichols@redhat.com>
- CERTPX-436 OpenStack: Manila Certification Creation Dialog

* Wed Nov 09 2016 Greg Nichols <gnichols@redhat.com>
- CERTPX-425 kernel verification test needs update for 7.3 GA

* Thu Nov 03 2016 Greg Nichols <gnichols@redhat.com>
- CERTPX-423 Test Plan Components appear twice in dropdown on assignment and testing pages
- redhat-certification 4.2

* Mon Oct 31 2016 Greg Nichols <gnichols@redhat.com>
- CERTPX-418 Submitted Results show as Not Submitted" on Progress page"

* Thu Oct 27 2016 Greg Nichols <gnichols@redhat.com>
- CERTPX-371 SubTest XSLT/CSS display Should only show sub-test.
- CERTPX-372 Error:, Needs Review:, and Warning: log lines should be colorized/highlighted CERTPX-374 Test/Subtest widget replace Result:" with "Combined:""

* Wed Oct 26 2016 Greg Nichols <gnichols@redhat.com>
- update image repo package versions
- fix changelog generation
- CERTPX-410 Exception on rhcert UI when trying to restart the subtest
- Fix changelog generation

* Wed Oct 26 2016 Pooja Tiwari <ptiwari@redhat.com>
- Added missing changelogs in redhat-certification-cloud.spec.in.

* Tue Oct 25 2016 Greg Nichols <gnichols@redhat.com>
- CERTPX-343 rhcert needs to provide re-evaluation of microservices calls for review     - implemented --results option to pass results file path
- CERTPX-343 rhcert needs to provide re-evaluation of microservices calls for review     - implemented cloud/supportable/InstalledRPMS aka ValidRPMs service
- CERTPX-408 redhat-certification-cloud 4 is missing the package changelog

* Tue Oct 25 2016 Pooja Tiwari <ptiwari@redhat.com>
- Fixed CERTPX-405 - Numeric indices required in the format specs to support   older python versions.
- Fixed CERTPX-401 and CERTPX-402 - Removed hardcoded service url from rhcert.microservice. - Covered the scenario where service url is not present in   /etc/rhcert.xml. - fixed typo.

* Fri Oct 21 2016 Greg Nichols <gnichols@redhat.com>
- CERTPX-393 redhat-certification: rhcert-default.xml exposes internal system name
- CERTPX-294 Enable RHEL for Realtime 7.3 Hardware Certifications

* Thu Oct 20 2016 Greg Nichols <gnichols@redhat.com>
- CERTPX-374 Test/Subtest widget replace Result:" with "Combined:""
- CERTPX-385 Not able to create file storage certificate for manila test from RHCERT UI

* Thu Oct 20 2016 Pooja Tiwari <ptiwari@redhat.com>
- CERTPX-388 RCC 4.1 should %Require rhcert-backend-4.1. - Modified cloud spec file.
- CERTPX-370 Removed false-positives from output. CERTPX-373 Added corrective action in installed rpm test. Minor output changes in hypervisor test.
- CERTPX-392 Fixed bug: Unable to submit redhat-cert h/w results. - Added required log data for h/w cert in rhcert/platform. - Added kernel debug info.

* Wed Oct 19 2016 Greg Nichols <gnichols@redhat.com>
- CERTPX-367 Progress Page needs revisions for WARN and REVIEW test results

* Tue Oct 18 2016 Pooja Tiwari <ptiwari@redhat.com>
- CERTPX-244 Security/rpm-freshness test shows installed vs updated version-release for each un-fresh package.

* Mon Oct 17 2016 Greg Nichols <gnichols@redhat.com>
- CERTPX-375 supportable/hypervisor test should show dmidecode
- CERTPX-233 kernel version check of info test failing on aarch64 with RHEL 7.3     - changed ValidKernels microservice to use a single json file cache     - added 7.3 beta/candidate kernel info     - added RHELSA amd RHELMRG info.

* Mon Oct 17 2016 Pooja Tiwari <ptiwari@redhat.com>
- CERTPX-217 Fixed bug: Network test returning None. - Added httpd service and port 443. - optimized code.

* Fri Oct 14 2016 Greg Nichols <gnichols@redhat.com>
- CERTPX-339 OpenStack 9.0 certifications downloaded from CWE are shown as 10.0

* Fri Oct 14 2016 Pooja Tiwari <ptiwari@redhat.com>
- CERTPX-353 Fixed bug in installed rpm test for rhel 6.x. Added minor fixes in environment gpg key check.

* Thu Oct 13 2016 Pooja Tiwari <ptiwari@redhat.com>
- Enhanced output for Kernel validation for all certification programs. CERTPX-313 Segregated kernel_rpm, kernel_version and kernel_tainted sub-tests. CERTPX-314 Segregated kernel_module_techpreview and kernel_modules_origin sub-tests.

* Wed Oct 12 2016 Greg Nichols <gnichols@redhat.com>
- CERTPX-343 rhcert needs to provide re-evaluation of microservices calls for review     - add rhcert-backend update command to re-try deferred microservice calls.     - microservices module defines update mechanism     - microservice subclasses must define update" method to support it     - implemented RPMFreshness.update"

* Wed Oct 12 2016 Pooja Tiwari <ptiwari@redhat.com>
- CERTPX-345 Fixed Bug. - Kernel version test throwing exception while retrieving data from cache.

* Tue Oct 11 2016 Greg Nichols <gnichols@redhat.com>
- CERTPX-343 rhcert needs to provide re-evaluation of microservices calls for review    - implement saving microservice object state for deferred call in results.xml
- CERTPX-297 replace redhat-certification-information and kernelInfo.xml with the Kernel Version Service      - added handler for missing cache file(s).

* Sat Oct 08 2016 Pooja Tiwari <ptiwari@redhat.com>
- CERTPX-308 Architecture Test: support only x86 or x86_64 architecture for RHEL7 or 6. CERTPX-335/CERTPX-331 Rename hypervisor test. CERTPX-335/CERTPX-332 Rename Default logging test. CERTPX-335/CERTPX-334 Remove ping test from Network Configuration Test.

* Thu Oct 06 2016 Greg Nichols <gnichols@redhat.com>
- CERTPX-312 rhcert-backend plan --add --test <path> does not check required rpms for the new test
- CERTPX-315 redhat-certification WUI should show description for each test.
- CERTPX-299 Not able to create RHEl 7.3 Certification on rhcert
- CERTPX-297 replace redhat-certification-information and kernelInfo.xml with the Kernel Version Service      - changed microservices module to separate call() and getCache() methods      - updated cloud callers to new class-based interface      - changed rhcert platform test to handle fail-over from call->getCache

* Thu Oct 06 2016 Pooja Tiwari <ptiwari@redhat.com>
- CERTPX-302 Made software repository test interactive.
- CERTPX-300 Password Configuration Test should give proper message about the used password hash.

* Wed Oct 05 2016 Greg Nichols <gnichols@redhat.com>
- CERTPX-297 replace redhat-certification-information and kernelInfo.xml with the Kernel Version Service      - package services cache files in the package.

* Wed Oct 05 2016 Pooja Tiwari <ptiwari@redhat.com>
- CERTPX-301 Remove test 'Log Versions' from cloud suite.

* Tue Oct 04 2016 Greg Nichols <gnichols@redhat.com>
- CERTPX-210 rhcert should log in user immediately if CWE is accessable.     - fix cancel button to return to previous page

* Tue Oct 04 2016 Pooja Tiwari <ptiwari@redhat.com>
- Added '%{version}' in redhat-certification-cloud.spec.in.
- CERTPX-310 Impactful description, success and failure data for unsupported hardware test.
- CERTPX-91 Installed RPM Test

* Mon Oct 03 2016 Greg Nichols <gnichols@redhat.com>
- CERTPX-321 Interactive tests giving Page Not Found (404) error

* Fri Sep 30 2016 Greg Nichols <gnichols@redhat.com>
- CERTPX-318 The redhat-certification-package should include cached output from Microservices     - a Microservice class is added as a base class for microservice wrapper classes.     - it implements methods for calling the microservice, and fail-over to cache     - RpmFreshness, ProductNameService, and KernelVersion subclasses wrap respective microservices.     - The Microservices class is revised to support the prior methods and implements methods for caching results to the file system.
- CERTPX-317 redhat-certification 4.1

* Thu Sep 29 2016 Anshul Behl <abehl@redhat.com>
- rhcert is not handling promptConfirm No" answer properly"

* Wed Sep 28 2016 Pooja Tiwari <ptiwari@redhat.com>
- CERTPX-90 Cloud Supportable: environment_gpgkeys Test

* Tue Sep 27 2016 Greg Nichols <gnichols@redhat.com>
- CERTPX-204 The base os is not match the minor_version on rhcert site.
- CERTPX-270 rhcert-backend plan --add --test <path> should try and match by name
- CERTPX-252 Enhance rhcert micro-service module
- CERTPX-231 Container certification option still seen while submitting the result through CLI.

* Tue Sep 27 2016 Pooja Tiwari <ptiwari@redhat.com>
- CERTPX-249 Cloud Interactive Tests need to support --mode auto for rhcert-ci.

* Fri Sep 23 2016 Greg Nichols <gnichols@redhat.com>

* Thu Sep 22 2016 Greg Nichols <gnichols@redhat.com>
- CERTPX-114 attributeError on invalid results URL

* Wed Sep 21 2016 Ben Rose <brose@redhat.com>
- CERTPX-261 - fix test run selection with less code

* Tue Sep 20 2016 Greg Nichols <gnichols@redhat.com>
- CERTPX-210 rhcert should log in user immediately if CWE is accessable.

* Tue Sep 20 2016 Ben Rose <brose@redhat.com>
- CERTPX-257 - Change reboot detection errors to warnings for any tests using them

* Tue Sep 20 2016 Pooja Tiwari <ptiwari@redhat.com>
- CERTPX-242 Hypervisor test should use 'virt-what' command instead of 'lscpu'.

* Mon Sep 19 2016 Greg Nichols <gnichols@redhat.com>
- CERTPX-213 Local Products/Certifications should be separated
- CERTPX-228 Remove optional" test checkboxes from certification creation dialog"

* Mon Sep 19 2016 Pooja Tiwari <ptiwari@redhat.com>
- Improve rpm freshness test

* Fri Sep 16 2016 Pooja Tiwari <ptiwari@redhat.com>
- CERTPX-255 Move %Requires python-requests to redhat-certification-backend

* Thu Sep 15 2016 Ben Rose <brose@redhat.com>
- CERTPX-226 corrected parsing code for pulling arguments from options string for test selected in run.py

* Wed Sep 14 2016 Greg Nichols <gnichols@redhat.com>
- CERTPX-64 Generate System Report test should FAIL for large sosreports
- CERTPX-189 Kernel RPM Version Test     - rewritten microservice check to observe criteria

* Wed Sep 14 2016 Pooja Tiwari <ptiwari@redhat.com>
- CERTPX-243 Show only required data in output

* Tue Sep 13 2016 Greg Nichols <gnichols@redhat.com>
- CERTPX-189 Kernel RPM Version Test
- CERTPX-203 Package Version-Release alignment: 4.0

* Fri Sep 09 2016 Greg Nichols <gnichols@redhat.com>
- Set redhat-certification-cloud to 3.5.1

* Fri Sep 09 2016 Pooja Tiwari <ptiwari@redhat.com>
- CERTPX-230 security selinux shows PASS" after setenforce 0"

* Thu Sep 08 2016 Greg Nichols <gnichols@redhat.com>
-     CERTPX-225

* Thu Sep 08 2016 Pooja Tiwari <ptiwari@redhat.com>
- CERTPX-165 URI fix in rpm freshness

* Wed Sep 07 2016 Greg Nichols <gnichols@redhat.com>
- CERTPX-216 Interactive test should redirect to testing status page after answering prompt
- CERTPX-220 redhat-certification-cloud should require python-requests
-  CERTPX-7 Cloud Supportable Test - designate test as interactive  CERTPX-32 Cloud Configuration Test - designate test as interactive

* Wed Sep 07 2016 Pooja Tiwari <ptiwari@redhat.com>
- CERTPX-165 Cloud Security: RPM Freshness

* Tue Sep 06 2016 Greg Nichols <gnichols@redhat.com>
- CERTPX-209 Certification Parameters are not accessable during test planning

* Fri Sep 02 2016 Greg Nichols <gnichols@redhat.com>
- CERTPX-91 Cloud Supportable: software_rpms Test

* Thu Sep 01 2016 Pooja Tiwari <ptiwari@redhat.com>
- CERTPX-167 fix in Subscription Service test

* Wed Aug 31 2016 Greg Nichols <gnichols@redhat.com>
- CERTPX-104 Cloud Configuration: Add Network Access tests      - add open ports subtest section
- CERTPX-178: add certification details in debug mode
- CERTPX-167 Cloud Configuration: subscription services      - fix subtest names per PM      - Use Error:" to denote error strings      - changed Subscription Services from WARN to FAIL.      - revised logic re: RHUI - must find both packages and repos."
- CERTPX-195 Unable to see the product details,certificates with the product from RHCERT UI

* Wed Aug 31 2016 Pooja Tiwari <ptiwari@redhat.com>
- CERTPX-167 Cloud Configuration: subscription services

* Tue Aug 30 2016 Greg Nichols <gnichols@redhat.com>
- CERTPX-189 Kernel RPM Version Test    - Generalizes rhcert.tests.KernelTest For different critera (candidate, release, update)    - Adds rhcert.tags.TestResult class to manage PASS/WARN/REVIEW/FAIL values CERTPX-166 Cloud Supportable: kernel_version    - Sets KernelTest to allow release  and update kernels, and warn on candidates.

* Mon Aug 29 2016 Greg Nichols <gnichols@redhat.com>
- CERTPX-104 Cloud Configuration: Add Network Access tests      - fixed results accumulation logic
- CERTPX-187 can't add system to redhat-certification LTS
- pin redhat-certification-cloud at 4.0 for the container repo
-  CERTPX-7 Cloud Supportable Test

* Mon Aug 29 2016 Chandan Kumar <chkumar@redhat.com>
- Added service control tests
- Added network access tests

* Fri Aug 26 2016 Greg Nichols <gnichols@redhat.com>
- CERTPX-178 openstack - capture cert creation details in certification stored by rhcert

* Thu Aug 25 2016 Pooja Tiwari <ptiwari@redhat.com>
- CERTPX-164 Cloud configurtion: file system - round to MB

* Wed Aug 24 2016 Greg Nichols <gnichols@redhat.com>
- CERTPX-168 Support WARN test result

* Tue Aug 23 2016 Greg Nichols <gnichols@redhat.com>
- CERTPX-163 Move cloud sources into the rhcert git repo
- CERTPX-102 redhat-certification-devel: Development Tools for CERTPX
- CERTPX-162 redhat-certification 2.9

* Fri Aug 19 2016 Greg Nichols <gnichols@redhat.com>
- CERTPX-135 Enable 7.3 cloud certifications in Redhat-certification

* Wed Aug 17 2016 Greg Nichols <gnichols@redhat.com>
- CERTPX-134 Enable 7.3 hardware certifications in Redhat-certification

* Mon Aug 15 2016 Greg Nichols <gnichols@redhat.com>
- comment out some of the filler, and forgot password links
- CERTPX-10 rhcert-backend submit using bugzilla login for hardware
- CERTPX-9 Downloaded certification minor versions for hardware and cloud are sometimes wrong.
- fix container image to redhat-certification-openstack 1.5.0 for RHEL7

* Fri Aug 12 2016 Greg Nichols <gnichols@redhat.com>
- CERTPX-117 Automated Change Logs show duplicate commit messages

* Fri Aug 05 2016 Greg Nichols <gnichols@redhat.com>
- CERTPX-5 Improve Web UI for showing sub-tests/results roll-up

* Thu Aug 04 2016 Greg Nichols <gnichols@redhat.com>
- CERTPX-94 Support REVIEW test result
-  CERTPX-1 redhat-certification-backend should require redhat-certification-information

* Mon Aug 01 2016 Greg Nichols <gnichols@redhat.com>
- CERTPX-2 rhcert-backend plan lists wrong number of test
- CERTPX-63 redhat-certification 2.8

* Tue Jul 26 2016 Greg Nichols <gnichols@redhat.com>
- set container to use redhat-certification-cloud 3.4.1

* Mon Jul 25 2016 Greg Nichols <gnichols@redhat.com>
- RHCERT-509 info test failing on RHEL6 due to Verification of redhat-certification package failed

* Fri Jul 22 2016 Greg Nichols <gnichols@redhat.com>
- remove redhat-certification-sosreport, pin -cloud to 3.4
- RHCERT-507 Unable to create certificate for RHOS 8 and 9 for neutron plugin from rhcert ui

* Thu Jul 21 2016 Ben Rose <brose@redhat.com>
- 1358479 - Update kernel tainted messages in rhcert platform test

* Thu Jul 21 2016 Greg Nichols <gnichols@redhat.com>
- RHCERT-506 While creating RHOSP 9 new networking plugin certificate its displaying 8.0 in high availabilty section info

* Wed Jul 20 2016 Greg Nichols <gnichols@redhat.com>
- RHCERT-504 OpenStack common question improvement
- RHCERT-503 Remove Manila questions from Management-Application from RHCERT side

* Tue Jul 19 2016 Greg Nichols <gnichols@redhat.com>
- RHCERT-476 Move RHEL platform validation code to rhcert libaries
- RHCERT-499 WebUI navigation missing for continued testing page

* Fri Jul 15 2016 Ben Rose <brose@redhat.com>
- 1327711 - fix multiple devices for the same test from being both run when only one is selected as well as debug option

* Wed Jul 13 2016 kgough <kgough@redhat.com>
- Login page updated to reflect latest RCUE design (includes alert boxes)

* Wed Jul 06 2016 Greg Nichols <gnichols@redhat.com>
- remove
- RHCERT-86 Ship rhcert server preconfigured as a container
- RHCERT-480 version 2.7

* Fri Jul 01 2016 Greg Nichols <gnichols@redhat.com>
- 1332654 - The Upload a Results File Feature Fails

* Mon Jun 27 2016 Greg Nichols <gnichols@redhat.com>
- RHCERT-488 Unable to create rhosp9 certification from rhcert-2.6

* Thu Jun 23 2016 Greg Nichols <gnichols@redhat.com>
- RHCERT-469 Move Hardware Partner Programs to SSO

* Wed Jun 22 2016 Greg Nichols <gnichols@redhat.com>
- Add XMLRPC api doc

* Tue Jun 21 2016 Greg Nichols <gnichols@redhat.com>
- RHCERT-467 No longer display the container certification program in RHCERT

* Mon Jun 20 2016 Greg Nichols <gnichols@redhat.com>
- test fix dockerfile

* Thu Jun 16 2016 Greg Nichols <gnichols@redhat.com>
- RHCERT-478 rhcert-ci certify giving Fault -32601 errors

* Tue Jun 07 2016 Greg Nichols <gnichols@redhat.com>
- RHCERT-474 rhcert should fail tests run when plan-time-required packages are not installed
- RHCERT-464 http proxy support

* Wed Jun 01 2016 Greg Nichols <gnichols@redhat.com>
- RHCERT-440 rhcert-2.6 New Version

* Thu May 26 2016 Greg Nichols <gnichols@redhat.com>
- RHCERT-439 rhcert-ci certify (local) results in traceback

* Wed May 25 2016 Greg Nichols <gnichols@redhat.com>
- RHCERT-438 RealTime machine can't be recognized by rhcert

* Tue May 24 2016 Greg Nichols <gnichols@redhat.com>
- RHCERT-458 OpenStack block storage cert created from rhcert can't set quota-set-extension
- RHCERT-457 Error while creating certification-other-application" from rhcert-2.5 UI"
- RHCERT-456 Unable to Open A RHOSP Management Application Certification from rhcert-2.5
- RHCERT-454 RHELOSP4,5 should be removed from cert creation

* Mon May 23 2016 Greg Nichols <gnichols@redhat.com>
- RHCERT-453 RHOSP 9.0 certifications can not be created in rhcert 2.5

* Fri May 20 2016 Greg Nichols <gnichols@redhat.com>
- RHCERT-448 RHEL 7.0 certs are displayed as RHEL 7.2 in redhat-certification UI

* Thu May 19 2016 Greg Nichols <gnichols@redhat.com>
- RHCERT-444 rhcert is not parsing the certs for OSP6, RT, etc. correctly.
- RHCERT-443 Cert Creation dialog needs confirmation message

* Wed May 18 2016 Greg Nichols <gnichols@redhat.com>
- RHCERT-415 rhcertd command missing help, and crashes with bad or missing arguments
- RHCERT-396 rhcert-ci <command> --help is missing the --client option for some commands
- RHCERT-394 Local certifications should not offer Submit" and other actions."

* Tue May 17 2016 Greg Nichols <gnichols@redhat.com>
- RHCERT-434 No certs displayed in rhcert when product is  Red Hat Enterprise Linux Server for ARM""
- RHCERT-410 Enable Open A RHOSP Sahara Certification from rhcert WUI

* Fri May 13 2016 Greg Nichols <gnichols@redhat.com>
- RHCERT-433 Open A RHEL Certification from rhcert WUI

* Mon May 09 2016 Greg Nichols <gnichols@redhat.com>
- RHCERT-416 Open Certifications via multi-step dialogs with CWE

* Wed May 04 2016 Greg Nichols <gnichols@redhat.com>
- RHCERT-431 BZ 1332654 Results file import produces redirect to 404

* Mon May 02 2016 Greg Nichols <gnichols@redhat.com>
- RHCERT-395 rhcert-2.5 May Release (new version)

* Thu Apr 14 2016 Greg Nichols <gnichols@redhat.com>
- RHCERT-378 Docker image and manifest file are not successfully uploaded to rhcert UI
- RHCERT-397 progress tab is visible on local certifications for catalog products
- RHCERT-352 Meta-Data Update for RHEL 6.8

* Wed Apr 13 2016 Greg Nichols <gnichols@redhat.com>
- RHCERT-393 traceback on rhcert-backen submit

* Tue Apr 12 2016 Greg Nichols <gnichols@redhat.com>
- RHCERT-390 redhat-certification-backend.el6 should require mod_wsgi
- RHCERT-391 rhcert-ci certify: submitted results missing on local server

* Mon Apr 11 2016 Greg Nichols <gnichols@redhat.com>
- RHCERT-384 Error while clicking on product created locally on server
- RHCERT-386 Remove" Button for Certifications is no longer valid"

* Fri Apr 08 2016 Greg Nichols <gnichols@redhat.com>
- RHCERT-381 Open Certification from Sandbox

* Thu Apr 07 2016 Greg Nichols <gnichols@redhat.com>
- RHCERT-216 rhcert container should provide test suites as a yum repo

* Mon Apr 04 2016 Greg Nichols <gnichols@redhat.com>
- RHCERT-366 	rhcert-ci support calling individual tests

* Wed Mar 30 2016 Greg Nichols <gnichols@redhat.com>
- RHCERT-356 Display test plan and progress downloaded from CWE for software programs

* Wed Mar 23 2016 Greg Nichols <gnichols@redhat.com>
- RHCERT-375 Unable to add certification for open-stack product created on local server RHCERT-376 Creating local products should not require login

* Mon Mar 21 2016 Greg Nichols <gnichols@redhat.com>
- RHCERT-354 test plan download should be automatic on page load
- RHCERT-373 Name changed from RHELOSP8 to RHOSP8

* Thu Mar 17 2016 Greg Nichols <gnichols@redhat.com>
- RHCERT-368 Test Crashes should not kill the rhcert client daemon
- RHCERT-369 rhcert-ci submit unable to save job ID

* Tue Mar 15 2016 Greg Nichols <gnichols@redhat.com>
- RHCERT-364 Show validation reports in results file view
- RHCERT-360 Unable to create container CI sandbox in webUI

* Thu Mar 10 2016 Greg Nichols <gnichols@redhat.com>
- RHCERT-359 Product Page: replace Add Certification" button with "Syncronize" and "Create Local""

* Fri Mar 04 2016 Greg Nichols <gnichols@redhat.com>
- RHCERT-353 Cert suite does not provide warning of 16 MB upload limit on results files

* Thu Mar 03 2016 Greg Nichols <gnichols@redhat.com>
- Version 2.4

* Tue Mar 01 2016 Greg Nichols <gnichols@redhat.com>
- RHCERT-349 rhcert-ci local/direct is broken

* Mon Feb 29 2016 Greg Nichols <gnichols@redhat.com>
- RHCERT-347 Attachments that are html should be viewed directly
- RHCERT-339 Paralell CI - Web UI for Sandboxes

* Wed Feb 24 2016 Greg Nichols <gnichols@redhat.com>
- RHCERT-309 rhcert-ci should allow the product key to be stored in a file, and passed as --key-file
- RHCERT-343 Error occurs when use rhcert-ci run""
- RHCERT-344 Run rhcert-ci without parameter will throw error
- RHCERT-340 No option to submit cloud/openstack test results through rhcert UI

* Mon Feb 22 2016 Kun Yan <kyan@redhat.com>
- Modify for new catalog API name

* Wed Feb 17 2016 Greg Nichols <gnichols@redhat.com>
- RHCERT-308 CI Remote Support

* Wed Feb 10 2016 Greg Nichols <gnichols@redhat.com>
- RHCERT-338 rhcert-backend submit container traceback - wrong number of arguments
- RHCERT-331 rhcert-ci support for parallel CI

* Fri Feb 05 2016 Greg Nichols <gnichols@redhat.com>
- RHCERT-330 Web UI returns to Testing" page after results submtted"
- RHCERT-335 Certification Test page shows None" in the header when the test has not been run."

* Tue Feb 02 2016 Greg Nichols <gnichols@redhat.com>
- RHCERT-328 rhcert-ci submit container returns error"

* Fri Jan 29 2016 Greg Nichols <gnichols@redhat.com>
- RHCERT-327 Web UI For Containers should select either image or the pull URL

* Thu Jan 28 2016 Greg Nichols <gnichols@redhat.com>
- RHCERT-324 [Container] Can not submit container with rhcert UI
- RHCERT-326 WebUI Container image submission files: files not found

* Wed Jan 27 2016 Greg Nichols <gnichols@redhat.com>
- RHCERT-320 rhcert-ci traceback on container submit (rhcertci.py line 234)
- RHCERT-313 rhcert shows the test plan as Frozen, when it's Melted in CWE
- RHCERT-319 [Container] Unable to submit an image through rhcert UI
- RHCERT-318 Mandatory field of Base OS not present in openstack cert creation.

* Tue Jan 26 2016 Greg Nichols <gnichols@redhat.com>
- RHCERT-315 rhcert login should replace SSO vs BZ radio buttons with a single checkbox for hardware
- RHCERT-316 rhcert-ci submit/results should return review" results from CWE/CaaS as a failure"

* Fri Jan 22 2016 Greg Nichols <gnichols@redhat.com>
- RHCERT-310 rhcert gives response: []" error on Test Plan Download"
- RHCERT-311 Test Plan Component Assignment does not show test names

* Thu Jan 21 2016 Greg Nichols <gnichols@redhat.com>
- RHCERT-305     CI Support rhcert submit command needs to accept a product key (cloud, openstack)

* Wed Jan 20 2016 Greg Nichols <gnichols@redhat.com>
- RHCERT-304 CI Support: rhcert CLI needs a command to get a product key

* Tue Jan 19 2016 Greg Nichols <gnichols@redhat.com>
- RHCERT-106 FEAT: upload command for adding a downloaded file to a different server (sneakernet)`

* Fri Jan 15 2016 Greg Nichols <gnichols@redhat.com>
- RHCERT-305 CI Support rhcert submit command needs to accept a product key

* Thu Jan 14 2016 Greg Nichols <gnichols@redhat.com>
- RHCERT-302 CI Support: rhcert command to get validation results

* Tue Jan 12 2016 Greg Nichols <gnichols@redhat.com>
- RHCERT-306 Web UI needs to support docker pull url for container submission
- RHCERT-219 CI Support: container submit via docker pull URL

* Mon Jan 11 2016 Greg Nichols <gnichols@redhat.com>
- RHCERT-301 ci example scripts
- CI Support: rhcert CLI needs a command to get a product token
- RHCERT-302 CI Support: rhcert command to get validation resultsng
- RHCERT-305 CI Support rhcert submit command needs to accept a product token
- RHCERT-304 CI Support: rhcert CLI needs a command to get a product token

* Thu Jan 07 2016 Greg Nichols <gnichols@redhat.com>
- Begin Version 2.2 (RHCERT-301)
- RHCERT-303 unicode input to local products causes traceback

* Tue Jan 05 2016 Greg Nichols <gnichols@redhat.com>
- RHCERT-300 CWE missing node IDs for some certifications downloaded to rhcert

* Tue Dec 22 2015 Greg Nichols <gnichols@redhat.com>
- RHCERT-299 Dialog order should be configurable

* Mon Dec 21 2015 Greg Nichols <gnichols@redhat.com>
- RHCERT-218 rhcert should display comments and activity from CWE

* Thu Dec 17 2015 Greg Nichols <gnichols@redhat.com>
- 1292245 - daemon crashes with traceback after resume from suspend-to-disk

* Wed Dec 16 2015 Greg Nichols <gnichols@redhat.com>
- RHCERT-294 non-ascii data from CWE causes invalid XML document on Test Plan Download
- RHCERT-294 non-ascii data from CWE causes invalid XML document on Test Plan Download RHCERT-295 rhcert fails to fetch cert list for rhos7 saying Error: Your current account type is sso, but ecosystem openstack requires bz login.

* Mon Dec 14 2015 Greg Nichols <gnichols@redhat.com>
- RHCERT-217 rhcert should download the test plan from CWE

* Fri Dec 11 2015 Greg Nichols <gnichols@redhat.com>
- RHCERT-217

* Tue Dec 08 2015 Greg Nichols <gnichols@redhat.com>
- RHCERT-286 trying login after a failed login results in exception

* Fri Dec 04 2015 Greg Nichols <gnichols@redhat.com>
- RHCERT-118 Add register" option to the rhcert-backend command's help text"
- RHCERT-285 rhcert-backend CLI clean-up for unified certification

* Thu Dec 03 2015 Greg Nichols <gnichols@redhat.com>
- RHCERT-283 rhcert should not try to detect when a selected host is already assigned to a certification

* Wed Dec 02 2015 Greg Nichols <gnichols@redhat.com>
- RHCERT-284 rhcert is not able to load result file even if the size limit is increased

* Tue Nov 24 2015 Greg Nichols <gnichols@redhat.com>
- RHCERT-282 Continue" button on host results page results in traceback"
- RHCERT-145 FEAT - save each test results as they are produced
- RHCERT-6 rhcert-backend clean all causes traceback to be displayed on LTS
-  RHCERT-231 Invalid error when user does not provide password

* Mon Nov 23 2015 Greg Nichols <gnichols@redhat.com>
- RHCERT-244 Client daemon/listener should be controlled via rhcertd on the SUT

* Thu Nov 19 2015 Greg Nichols <gnichols@redhat.com>
- RHCERT-244 Client daemon/listener should be controlled via rhcertd" on the SUT"
- RHCERT-247 rhcert having lxml issue for el6 rpms

* Wed Nov 18 2015 Greg Nichols <gnichols@redhat.com>
- RHCERT-160 redhat-certification defines RHEL.major as RHEL7" regardless of OS version"

* Tue Nov 17 2015 Greg Nichols <gnichols@redhat.com>
- 1282658 - fv_network test fail - guest network test is incomplete

* Mon Nov 16 2015 Greg Nichols <gnichols@redhat.com>
- RHCERT-243 Error while uploading an image in rhcert UI
- RHCERT-236 Confusion between bug Ids and certIds for cloud certiification

* Tue Nov 10 2015 Greg Nichols <gnichols@redhat.com>
- RHCERT-241 Image is not encrypted while uploading through rhcert 2.0 UI

* Fri Nov 06 2015 Greg Nichols <gnichols@redhat.com>
- 1278497 - rhcert Web UI does not correctly identify RHEL version for Cloud certifications

* Wed Nov 04 2015 Greg Nichols <gnichols@redhat.com>
- RHCERT-233 RHCert don't report duplication docker image error for container cert throw from CWE
- 1277920 - Wrong entry for Red Hat Enterprise Linux Server for ARM Development Preview 7.2 in certificationIndex.xml

* Tue Nov 03 2015 Greg Nichols <gnichols@redhat.com>
- 1274121 - Error: could not detect reboot encountered when running kdump on rhel 7.2
- RHCERT-232 Rhcert 2.0 treats CWE cert id as Node id

* Thu Oct 29 2015 Greg Nichols <gnichols@redhat.com>
- RHCERT-228 cloud certification should change to sso

* Wed Oct 28 2015 Greg Nichols <gnichols@redhat.com>
- RHCERT-226 Add Certification button not working for openstack and container certifications.

* Tue Oct 27 2015 Ben Rose <brose@redhat.com>
- 1262067 - update detection for ARM kernel versions (via uname)

* Thu Oct 22 2015 Greg Nichols <gnichols@redhat.com>
- RHCERT-213 delete is needed products and certifications
- add account to CWE login

* Wed Oct 21 2015 Greg Nichols <gnichols@redhat.com>
- RHCERT-223 rhcert needs to implement a test plan ID attribute

* Tue Oct 20 2015 Greg Nichols <gnichols@redhat.com>
- RHCERT-217 rhcert should download the test plan from CWE starting

* Fri Oct 16 2015 Greg Nichols <gnichols@redhat.com>
- RHCERT-200 rhcert should use sessions via CWE (sso) to avoid repeated logins

* Thu Oct 15 2015 Greg Nichols <gnichols@redhat.com>
- Bump version to 2.1

* Tue Oct 13 2015 Greg Nichols <gnichols@redhat.com>
- 1271313 - rhcert does not pass correct account type to CWE
- 1260192 - FEAT: Provide the ability to upload results files to the LTS that were obtained elsewhere

* Thu Oct 08 2015 Greg Nichols <gnichols@redhat.com>
- RHCERT-211 When adding a Host to a Cert, Status of the SUT shows only checking... state
- 1269900 - network and kdump tests fail when server and SUT have localhost hostnames

* Wed Oct 07 2015 Greg Nichols <gnichols@redhat.com>
- fix Dockerfile generation

* Tue Oct 06 2015 Greg Nichols <gnichols@redhat.com>
- 1269274 - Interactive links sometimes lack host connection parameter
- 1269173 - Results table links for tests with devices are not correct

* Wed Sep 30 2015 Greg Nichols <gnichols@redhat.com>
- RHCERT-209 [OpenStack] multi-select prompt is not rendered as checkboxes RHCERT-210 [OpenStack] large text edit shown as simple text prompt.

* Tue Sep 29 2015 Greg Nichols <gnichols@redhat.com>
- RHCERT-117 Save command results in invalid URL

* Mon Sep 28 2015 Greg Nichols <gnichols@redhat.com>
- RHCERT-85 RHEL 6 option not available for Container Certification

* Fri Sep 25 2015 Greg Nichols <gnichols@redhat.com>
- RHCERT-205 close command does not clean results from the host
- RHCWE-518 Can not submit hardware test results
- PHCWE-518 Can not submit hardware test results

* Thu Sep 24 2015 Greg Nichols <gnichols@redhat.com>
- PHCERT-202
- RHCERT-198 [Openstack]Workflow confusion on rhcert2 for CWE and bugzilla ids
- PHCERT-198 [Openstack]Workflow confusion on rhcert2 for CWE and bugzilla ids

* Wed Sep 23 2015 Greg Nichols <gnichols@redhat.com>
- RHCERT-199 rhcert does not restrict workflow for local AKA scratch certs and results
- RHCERT-201 Cloud certifications downloaded from CWE are shown as Hardware""
-     RHCERT-196

* Tue Sep 22 2015 Luke Brooker <lbrooker@redhat.com>
- Adjust sidebar even when it has a datatable in the body
- Fix failed labels so they display red and update label order

* Tue Sep 22 2015 Greg Nichols <gnichols@redhat.com>
- 1264487 - Web UI: Product and Certification lists should display workflow and certification ID

* Fri Sep 18 2015 Greg Nichols <gnichols@redhat.com>
- 1264484 - Local Products should only use Make for Hardware

* Thu Sep 17 2015 Greg Nichols <gnichols@redhat.com>
- 1263842 - In debug mode, the WebUI host logging displays do not work
- 1263755 - WebUI needs to capture ecosystem when adding products and certifications

* Wed Sep 16 2015 Greg Nichols <gnichols@redhat.com>
- move RHEL6 back to -backend package

* Tue Sep 15 2015 Greg Nichols <gnichols@redhat.com>
- 1263462 - Container Certifications traceback after creation in the web UI

* Mon Sep 14 2015 Greg Nichols <gnichols@redhat.com>
- 1262980 - test attachments should be shown on the results table
- fix el6 provides
- move to -backend subpackage for RHEL6
- 1261195 - Clicking continue testing button results in 404
- 1262057 - A text input dialog appears instead of Yes/No buttons for hwcert/kdump test. 1261197 - Dropdown for selecting device for storage test is not a dropdown.
- 1262048 - Incorrect links on 'Test Results' page. 1257954 - Manual test planning treats a device logical name as a UDI match 1255640 - Test suite run with all the type of the devices though only one was planed by a parameter udi/device.

* Fri Sep 11 2015 Greg Nichols <gnichols@redhat.com>
- i1227488 - stop button functionality incomplete
- 1262109 - clicking 'stop' button for a test causes AttributeError

* Thu Sep 10 2015 Greg Nichols <gnichols@redhat.com>
- 1262113 - Certifications downloaded from the catalog are shown as scratch
- 1262097 - Cloud Certifications downloaded from Catalog create Container certs on rhcert
- 1262084 - test run debug output on certification results listing page is shown when Enable Debug is not selected
- 1262080 - RHELOSP5 is needed in the product meta-data
- 1261937 - redhat-certification package should be split into redhat-certification-backend

* Wed Sep 09 2015 Greg Nichols <gnichols@redhat.com>
- 1261506 - redhat-certification 2.0 must be ported to django 1.6 for el6

* Tue Sep 08 2015 Greg Nichols <gnichols@redhat.com>
- 1261089 - debug checkbox will not 'uncheck'
- 1256809 - certification information must include details on Red Hat products being certified

* Fri Sep 04 2015 Ben Rose <brose@redhat.com>
- 1259984 - add RHEL7.2 to dropdown of products

* Fri Aug 21 2015 Greg Nichols <gnichols@redhat.com>
- fix broken product page, test host action
- new product and vendor XML, UI

* Mon Aug 17 2015 Greg Nichols <gnichols@redhat.com>
- rhcert-2

* Thu Aug 13 2015 Greg Nichols <gnichols@redhat.com>
- fill in products page status
- 1252571 - daemon and/or listener logs disappear

* Wed Aug 12 2015 Greg Nichols <gnichols@redhat.com>
- 1246226 - tests appear in plan multiple times after test run
- 1252998 - RHEL6 deprecation warning on md5 module
- 1243990 - stale pid files left behind after server shutdown
- 1252739 - Can not specify a IP address for test server when running rhcert-backend plan

* Tue Aug 11 2015 Greg Nichols <gnichols@redhat.com>
- 1181296 - rhcert listener doesn't always start

* Fri Aug 07 2015 Greg Nichols <gnichols@redhat.com>
- product fixes

* Wed Aug 05 2015 Greg Nichols <gnichols@redhat.com>
- incorporate product-based navigation design

* Tue Aug 04 2015 Greg Nichols <gnichols@redhat.com>
- fix submit of results
- implement delete and clean commands
- debug test running, host results

* Mon Aug 03 2015 Greg Nichols <gnichols@redhat.com>
- move http error to stderr
- bump to version 2.0

* Wed Jul 22 2015 Ben Rose <brose@redhat.com>
- BZ1228318 - update rhcert web UI to allow selection of RHEL 6.7 for certifications

* Fri Jul 17 2015 Greg Nichols <gnichols@redhat.com>
- remaining port - untested
- initial 2.0 build

* Tue Jul 14 2015 Greg Nichols <gnichols@redhat.com>
- move django to apache/mod_wsgi

* Tue Jul 07 2015 Ben Rose <brose@redhat.com>
- BZ1240674 - temporarily update urls in default xml

* Wed Jul 01 2015 Greg Nichols <gnichols@redhat.com>
- more proof-of-concept

* Mon Jun 29 2015 Greg Nichols <gnichols@redhat.com>
- initial proof-of-concept

* Wed Jun 24 2015 Greg Nichols <gnichols@redhat.com>
- 1235365 - rhcert error on results submission: can not submit results ()""
- 1230871 - FEAT: rhcert shipped as a container

* Tue Jun 23 2015 Greg Nichols <gnichols@redhat.com>
- 1235001 - traceback on adding cert if CWE returns no vendor, make, product response

* Mon Jun 22 2015 Praveen Kumar <prkumar@redhat.com>
- Add Entrypoint with default CMD - Add maintainer details - Reduce extra layer

* Mon Jun 22 2015 Greg Nichols <gnichols@redhat.com>
- 1233977 - /etc/rhcert-default.xml has wrong python version on RHEL6

* Fri Jun 19 2015 Greg Nichols <gnichols@redhat.com>
- 1232852 - FEAT: rhcert-backend server start
Thu, 18 Jun 2015 16:06:07 -0400,Greg Nichols,gnichols@redhat.com,78f00f72,1232934 - add RHELSA to redhat-certification hardware certification options"

* Wed Jun 17 2015 Greg Nichols <gnichols@redhat.com>
- fix respin calculation

* Wed Jun 17 2015 Ben Rose <brose@redhat.com>
- BZ1232721 - fix bug in return statement within Environment.showChangesFromDefault

* Fri Jun 12 2015 Greg Nichols <gnichols@redhat.com>
- 1231336 - rhcert configuration (/etc/rhcert.xml) should be installed via package with defaults

* Thu Jun 11 2015 Praveen Kumar <prkumar@redhat.com>
- Pep8 fixes and quiet/debug mode with boolean options

* Thu Jun 11 2015 Greg Nichols <gnichols@redhat.com>
- 1228790 - rhcert should use provides when installing test-required packages
- 1230698 - redhat-certification has difficulties with networks without DNS support

* Wed May 27 2015 Greg Nichols <gnichols@redhat.com>
- 1225533 - KeyError python traceback un-set command option via Web UI

* Tue May 26 2015 Greg Nichols <gnichols@redhat.com>
- 1221633 - Key Error while adding a system in the certification tool

* Wed May 20 2015 Greg Nichols <gnichols@redhat.com>
- 1223514 - Links to interative prompts on Configuration and Certification pages are invalid
- 1217211 - demo test text file upload gives padding error
- 1179200 - Initialization of download from attachments hyperlink takes too much time to start.

* Tue May 19 2015 Greg Nichols <gnichols@redhat.com>
- 1216150 - test server forgotten after planning in network tests

* Mon May 18 2015 Greg Nichols <gnichols@redhat.com>
- 1208330 - The debug checkbox has no effect on the test run

* Thu May 14 2015 Greg Nichols <gnichols@redhat.com>
- 1179358 - Test suite log message are not shown in web UI

* Tue May 12 2015 Greg Nichols <gnichols@redhat.com>
- 1212964 - editText doesnt work for LargeText in CLI

* Fri May 08 2015 Praveen Kumar <prkumar@redhat.com>
- Filter auto merge message to master

* Fri May 08 2015 Greg Nichols <gnichols@redhat.com>
- 1212966 - No persistent logs available for rhcert-backend daemon and listener

* Thu May 07 2015 Greg Nichols <gnichols@redhat.com>
- 1204952 - redhat-certification confused by RHELSA uname output
- 1201491 - KeyError when creating new hardware certification test - RHELSA
- 1214072 - use only SMBIOS Type 1 to query system manufacturer, make, and model

* Tue May 05 2015 Greg Nichols <gnichols@redhat.com>
- 1218622 - rhcert-backend submit does not prompt for certification type

* Mon May 04 2015 Greg Nichols <gnichols@redhat.com>
- 1215726 - traceback on rhcert-backend submit command

* Thu Apr 30 2015 Praveen Kumar <prkumar@redhat.com>
- Filter gerrit merge commits to get in changelog

* Thu Apr 30 2015 Greg Nichols <gnichols@redhat.com>
- 1216963 - python-lxml not present as dependency for redhat-certification package

* Mon Apr 20 2015 Greg Nichols <gnichols@redhat.com>
-  1213391 - display of attachments are not sorted properly by test name and run

* Fri Apr 17 2015 Shreyank Gupta <sgupta@redhat.com>
- Trello#7E480dVc: Support 6.x minor versions for cloud

* Fri Apr 17 2015 Greg Nichols <gnichols@redhat.com>
- 1212928 - Create New Results File error for host identified by IP address

* Wed Apr 15 2015 Greg Nichols <gnichols@redhat.com>
- 1212171 - Web Server can't manage clients without DNS support
- 1211343 - aarch64: python traceback on rhcert server after registering a system

* Fri Apr 10 2015 Greg Nichols <gnichols@redhat.com>
- 1210160 - FEAT: rhcert-backend command to extract test run attachments

* Thu Apr 09 2015 Praveen Kumar <prkumar@redhat.com>
- Add functionality to extract latest commit message to add in changelog

* Thu Apr 09 2015 Greg Nichols <gnichols@redhat.com>
- 1208881 - traceback on ImportError if test suite files deleted
- changelog correction

* Tue Apr 07 2015 Greg Nichols <gnichols@redhat.com>
- 1209438 - Error page appears for empty certification results when beginning testing

* Fri Apr 03 2015 Greg Nichols <gnichols@redhat.com>
- 1206619 - SUT can not be registered from the web UI if the server does not have a hostname

* Tue Mar 31 2015 Greg Nichols <gnichols@redhat.com>
- changelog

* Tue Mar 31 2015 Shreyank Gupta <sgupta@redhat.com>
- Trello#SohS9ihO: Add unicode support for logging.

* Wed Mar 25 2015 Shreyank Gupta <sgupta@redhat.com>
- Workaround for python 2.6 issue5762

* Wed Mar 25 2015 Greg Nichols <gnichols@redhat.com>
- 1205644 - RHEL6 cloud certification traceback on saving results file after openscap test:

* Tue Mar 24 2015 Greg Nichols <gnichols@redhat.com>
- 1205358 - Can't add hwcert/storage test to a plan manually due to python error
- 1205357 - need to enable cloud certifications

* Mon Mar 23 2015 Greg Nichols <gnichols@redhat.com>
- 1179290 - Not able to delete created certification

* Fri Mar 20 2015 Greg Nichols <gnichols@redhat.com>
- 1203244 - Test Scheduling does not always observe test priority

* Thu Mar 19 2015 Greg Nichols <gnichols@redhat.com>
- 1201865 - FEAT: muti-select for web UI

* Thu Mar 12 2015 Ben Rose <brose@redhat.com>
- update changelog
- BZ1198764 - fix uname parsing for ARM RHEL

* Tue Mar 10 2015 Greg Nichols <gnichols@redhat.com>
- 1200386 - system registration message on server UI shows debug output

* Mon Mar 09 2015 Greg Nichols <gnichols@redhat.com>
- 1199650 - rhcert command should be removed.
- 1199650 - Running rhcert with no parameters should display help message and exit

* Wed Mar 04 2015 Greg Nichols <gnichols@redhat.com>
- 1198751 - Server over-specifies redirects to http://<server hostname>

* Tue Mar 03 2015 Greg Nichols <gnichols@redhat.com>
- 1198324 - Spelling error in OpenStack button on main web page
- 1198201 - Web UI Improvements

* Fri Feb 27 2015 Greg Nichols <gnichols@redhat.com>
- 1197215 - command-line container submission does not submit encrypted file

* Thu Feb 26 2015 Greg Nichols <gnichols@redhat.com>
- 1196828 - redhat-backend server start-up - spurious output
- 1196817 - The save command should save results directly to the local server

* Wed Feb 25 2015 Greg Nichols <gnichols@redhat.com>
- 1196370 - Interactive UI uses whole-page refresh polling for status

* Tue Feb 24 2015 Greg Nichols <gnichols@redhat.com>
- 1195744 - fv_network test fails http transfer test - can not find IP address seen by server
- 1195734 - fv_network test fails http transfer test - can not find IP address seen by server\n\nChange message for backwards compatability with hwcert-client 1.6.5.2 in fv_network

* Mon Feb 23 2015 Greg Nichols <gnichols@redhat.com>
- 1195291 - Build Errors: No images in image directory
- 1195311 - hardware and container certifications should be enabled

* Sat Feb 21 2015 Ben Rose <brose@redhat.com>
- [trello-aGu1SHpZ] - add support for ael7<alpha> kernel version product

* Fri Feb 20 2015 Greg Nichols <gnichols@redhat.com>
- public key update for container
- 1194782 - Interactive UI looses track of host during reboot for the kdump test

* Thu Feb 19 2015 Greg Nichols <gnichols@redhat.com>
- 1194021 - client daemon trackback on start after clean
- 1194313 - openstack bugzilla default URL should point to production, not stage

* Wed Feb 18 2015 Ben Rose <brose@redhat.com>
- updated changelog
- [trello-ul6LAdIN] - update regex and update parsing code a bit

* Wed Feb 18 2015 Greg Nichols <gnichols@redhat.com>
- update public key for container encryption

* Tue Feb 17 2015 Greg Nichols <gnichols@redhat.com>
- 1193647 - rhcert does not save updated results if incomplete tests are finished after reboot.
- 1193589 - Selection of device-specific tests doesn't work

* Mon Feb 16 2015 Greg Nichols <gnichols@redhat.com>
- 1193086 - fv_network test can not save test files during http transfer test
- remove add certifications button

* Sun Feb 15 2015 Greg Nichols <gnichols@redhat.com>
- 1192598 - rhcert needs to provide interfaces for network testing of hosts running hwcert-client 1.6.5.2

* Fri Feb 13 2015 Greg Nichols <gnichols@redhat.com>
- 1192542 - Failed fv tests reported as passing
- 1192492 - Traceback on container image submisstion

* Wed Feb 11 2015 Greg Nichols <gnichols@redhat.com>
- fix traceback on adding a cert
- package install public key
- fix traceback on end of interactive test

* Tue Feb 10 2015 Greg Nichols <gnichols@redhat.com>
- obselete ccp-client
- 1179283 - Unable to delete hosts in rhcert UI
- remove scratch certifications for container

* Wed Feb 04 2015 Greg Nichols <gnichols@redhat.com>
- fix rhcert-backend save container
- fix rhcert-backend command line for saving and/or submitting container files

* Tue Feb 03 2015 Greg Nichols <gnichols@redhat.com>
- add bugzilla URL to config display
- fix comment
- add python-magic and m2crypto to Requires

* Mon Feb 02 2015 Greg Nichols <gnichols@redhat.com>
- correct workflow link to be bugilla for openstack, catalog for other types
- traceback on container image submission, no key file
- change compression detection to use python-magic, rather than the file command

* Fri Jan 30 2015 Greg Nichols <gnichols@redhat.com>
- fix traceback on first interactive run of a new results document
- change container image compression from bzip2 to gzip

* Thu Jan 29 2015 Greg Nichols <gnichols@redhat.com>
- add compression of container images
- fix file handling of image keys

* Wed Jan 28 2015 Greg Nichols <gnichols@redhat.com>
- fix typo
- disable all but openstack certs

* Tue Jan 27 2015 Greg Nichols <gnichols@redhat.com>
- change attachment size limit to 128MB
- add calls to encrypt container images and manage random keys
- File encryption utility wrapper

* Tue Jan 20 2015 Greg Nichols <gnichols@redhat.com>
- fix logic allowing 7.1 hosts on 7.0-min certs
- disable cert types other than hardware and openstack

* Mon Jan 19 2015 Greg Nichols <gnichols@redhat.com>
- fix interactive test status reporting on certification page
- start listner last, after a sec

* Fri Jan 16 2015 Greg Nichols <gnichols@redhat.com>
- add promptFile for file uploading

* Thu Jan 15 2015 Greg Nichols <gnichols@redhat.com>
- fix schema validation errors\n https://trello.com/c/Y9iUtQwO

* Tue Jan 13 2015 Greg Nichols <gnichols@redhat.com>
- remove debug output
- Several UI improvements involving host status and relevant commands.
- remove extrainious output statement

* Fri Jan 09 2015 Greg Nichols <gnichols@redhat.com>
- 1179181 - New openstack certification asks to add hosts 2 times instead of 1
- 1179305 - CWE API change needed for Vendor, Make, and Model

* Thu Jan 08 2015 Greg Nichols <gnichols@redhat.com>
- disable cloud certs

* Wed Jan 07 2015 Greg Nichols <gnichols@redhat.com>
- 1179363 - self.statusMessage does not output provided input message to the rhcert web UI

* Mon Jan 05 2015 Greg Nichols <gnichols@redhat.com>
- remove post script that opens 80 and 8009 in firewall

* Mon Dec 22 2014 Greg Nichols <gnichols@redhat.com>
- add openstack certification type
- change listener to bind to current host name/ip
- set huge_tree=True when parsing XML to allow 24MB+ attachments

* Thu Dec 18 2014 Greg Nichols <gnichols@redhat.com>
- fix traceback on listener daemon start
- add /etc/init.d/rhcert-backend to %files
- remove call to continue
- Add continuation support for tests needing to reboot the system (https://trello.com/c/dg0xUQM9)
- https://trello.com/c/ijC1U52N

* Tue Dec 09 2014 Greg Nichols <gnichols@redhat.com>
- Add support for /store URLS

* Wed Nov 26 2014 Guangze Bai <gbai@redhat.com>
- 1161648 - Put mandatory post tests at last

* Tue Nov 25 2014 Greg Nichols <gnichols@redhat.com>
- fix manual addition of tests
- 1164857 - hwcert-client confused by RHELSA contents in /etc/redhat-release

* Mon Nov 24 2014 Greg Nichols <gnichols@redhat.com>
- add requires for firewalld in %post

* Fri Nov 21 2014 Greg Nichols <gnichols@redhat.com>
- add RHEL 7.1
- open port 80 in firewall for RHEL7
- remove requires systemd for post in RHEL6
- %post scriptlet errors: selinux and firewall

* Thu Nov 20 2014 Greg Nichols <gnichols@redhat.com>
- fix schema parsing errors, validation against current rhcert-generated results.xml

* Wed Nov 19 2014 Shreyank Gupta <sgupta@redhat.com>
- Trello#lCQGfo3Z: Adding the mimetype and encoding of attachments into results.xml

* Wed Nov 19 2014 Greg Nichols <gnichols@redhat.com>
- Scratch Certifications: ui hiding of id slot, tracking certification documents as scratch, removing link to Go To Workflow"."
- Version to 1.0, changelog
- remove hard-coded mimetypes, use mimetpyes module and attachment document attributes

* Tue Nov 18 2014 Shreyank Gupta <sgupta@redhat.com>
- Trello#KYcrrmLH: Adding the MD5sum of attachments into results.xml

* Mon Nov 17 2014 Greg Nichols <gnichols@redhat.com>
- draft schema

* Wed Nov 05 2014 Greg Nichols <gnichols@redhat.com>
- name change for hardware test suite

* Mon Nov 03 2014 Greg Nichols <gnichols@redhat.com>
- call CWE to get Vendor/Make/Product when existing certification is added

* Wed Oct 29 2014 Greg Nichols <gnichols@redhat.com>
- improve container image pair layout on certification page

* Wed Oct 22 2014 Shreyank Gupta <sgupta@redhat.com>
- Trello#0WJe9U5n: Passing fromlist=[] to __import__, to preserve global variables for individual tests.

* Fri Oct 17 2014 Greg Nichols <gnichols@redhat.com>
- move container image pair description, add defaulting, stub-in CWE xmlrpc call to get vendor, product
- interaction improvements on certification page

* Thu Oct 16 2014 Greg Nichols <gnichols@redhat.com>
- add stop/restart capability on hosts and interactive pages

* Wed Oct 15 2014 Greg Nichols <gnichols@redhat.com>
- revised certification page layout, added new and close operations

* Fri Oct 10 2014 Greg Nichols <gnichols@redhat.com>
- fix traceback
- reset action selectors on back/cancel

* Thu Oct 09 2014 Greg Nichols <gnichols@redhat.com>
- implement results action selectors on certification pages
- change host status to use ajax/javascript polling

* Wed Oct 08 2014 Greg Nichols <gnichols@redhat.com>
- change package name to redhat-certification, merge in -server subpackage

* Tue Oct 07 2014 Greg Nichols <gnichols@redhat.com>
- fix bug where results aren't saved to the certification
- clean up certification UI

* Thu Oct 02 2014 Greg Nichols <gnichols@redhat.com>
- Minor UI edits on certification page for containers: https://trello.com/c/iteEktAp/46-minor-ui-edits

* Wed Oct 01 2014 Greg Nichols <gnichols@redhat.com>
- error checking for adding image pairs, deletion

* Tue Sep 30 2014 Greg Nichols <gnichols@redhat.com>
- container cert: add image info to image lists, provide time submitted

* Thu Sep 25 2014 Greg Nichols <gnichols@redhat.com>
- 1146461 - rhcert-client 0.3: rhcert-backend server start doesn't start NFS for kdump\n\n remove quotes around subcommand

* Wed Sep 24 2014 Greg Nichols <gnichols@redhat.com>
- 1146099 - rhcert-client 0.3: traceback on rhcert-backend register

* Tue Sep 23 2014 Greg Nichols <gnichols@redhat.com>
- fix traceback on attempts to submit container images

* Mon Sep 22 2014 Greg Nichols <gnichols@redhat.com>
- add certificationIndex.xml to %files
- add vendor/product and image descriptions
- move cert types to separate xml file:\n /usr/lib/<python>/site-packages/rhcert/info/certificationIndex.xml
- rhcert store changed to organize results files by cert type/id

* Thu Sep 18 2014 Greg Nichols <gnichols@redhat.com>
- Add status feedback on testing progress for both interactive and non-interactive testing

* Wed Sep 17 2014 Greg Nichols <gnichols@redhat.com>
- fix deletion of empty results, add certification page refresh for non-container certs

* Tue Sep 16 2014 Greg Nichols <gnichols@redhat.com>
- fix bug preventing saving of results files, and clean-up of empty ones
- fix dropbox download url
- fix initial testing flow - show test plan, then clean it up later
- fix container upload missing or corrupted files trello OKdgVQIz

* Mon Sep 15 2014 Greg Nichols <gnichols@redhat.com>
- fix bugs in initial test run
- test host selection UI improvements
- Add collection of vendor, make, and model to the Add Certification" dialog for hardware certifications."
- implement delete for test results

* Wed Sep 10 2014 Greg Nichols <gnichols@redhat.com>
- Support multi-line prompts/message in listener/interactive Tasks

* Tue Sep 09 2014 Greg Nichols <gnichols@redhat.com>
- Change to docker image upload catalog XMLRPC call

* Mon Sep 08 2014 Greg Nichols <gnichols@redhat.com>
- fix interactive web UI

* Fri Sep 05 2014 Greg Nichols <gnichols@redhat.com>
- fix web prompting bugs, add selections, interactive demo
- interactive tests - initial implementation complete

* Thu Sep 04 2014 Greg Nichols <gnichols@redhat.com>
- interactive tests part2: bug fixes for calling interactive tests, displaying system status
- interactive test support (partial)

* Wed Sep 03 2014 Greg Nichols <gnichols@redhat.com>
- fix container image upload

* Tue Sep 02 2014 Greg Nichols <gnichols@redhat.com>
- fix expression typo
- fix duplicate registration of test classes

* Fri Aug 29 2014 Greg Nichols <gnichols@redhat.com>
- Revise test suite planning to eliminate name conflicts

* Mon Aug 25 2014 Luke Brooker <lbrooker@redhat.com>
- update summary results with new template

* Thu Aug 21 2014 Greg Nichols <gnichols@redhat.com>
- add reinitialization of SUT for cert type and/or ID changes

* Wed Aug 20 2014 Greg Nichols <gnichols@redhat.com>
- fix traceback for Add Host via cert ID
- add certification type information to the Tests page

* Tue Aug 19 2014 Greg Nichols <gnichols@redhat.com>
- improve certification presentation, and test run flow
- improve listener feedback from test runs

* Mon Aug 18 2014 Luke Brooker <lbrooker@redhat.com>
- Fix breaking certifications results table
- Add rcue assets and update Makefiles and .conf accordingly
- Add rcue template changes and merge. Still need to add the assets for the templates to work

* Mon Aug 18 2014 Greg Nichols <gnichols@redhat.com>
- change back to using ip address for client of image upload
- remove extra <table> tag
- add submit command for container certs

* Sun Aug 17 2014 Greg Nichols <gnichols@redhat.com>
- add back results.css to install

* Fri Aug 15 2014 Greg Nichols <gnichols@redhat.com>
- fix redirect to visit new cert after add
- selinux setting in %post to allow httpd to ftp
- fix container save from rhcert-backend
- add error reporting to ftp push

* Thu Aug 14 2014 Greg Nichols <gnichols@redhat.com>
- add submit and save commands to backend for container files
- container image upload
- add ftp dropbox url/host

* Wed Aug 13 2014 Greg Nichols <gnichols@redhat.com>
- add redirects to smooth adding certs and running tests
- container certification image submission

* Tue Aug 12 2014 Greg Nichols <gnichols@redhat.com>
- move store filesystem code to its own class
- docker AKA container cert image upload
- fix firewall conditional

* Mon Aug 11 2014 Greg Nichols <gnichols@redhat.com>
- fix incomplete settings for continue runs
- restrict firewall config to RHEL7

* Thu Aug 07 2014 Greg Nichols <gnichols@redhat.com>
- add %post to open 8009 in firewall
- server selinux and port settings
- Add version-release info to page footers
- fix foreground mode to run other process correctly

* Wed Aug 06 2014 Greg Nichols <gnichols@redhat.com>
- Fix garbled task output, remove redundant code for writing to it.
- Change listener and daemon foreground mode to run other process in background.

* Tue Aug 05 2014 Greg Nichols <gnichols@redhat.com>
- Server-driven SUT registration

* Thu Jul 31 2014 Shreyank Gupta <sgupta@redhat.com>
- Adds RawIOBase capabilities to Log object. sys.stdout retains io attributes.

* Thu Jul 31 2014 Greg Nichols <gnichols@redhat.com>
- Add test run request feedback and host status.
- add RHEL 6.6

* Wed Jul 30 2014 Greg Nichols <gnichols@redhat.com>
- Fix initial testing flow to install the test suite packages required by the test plan

* Mon Jul 28 2014 Greg Nichols <gnichols@redhat.com>
- fix respin numbering to be rhel-major-version-specific

* Fri Jul 11 2014 Greg Nichols <gnichols@redhat.com>
- fix clean to observer --mode auto
- Fix sorting and display of tests by path

* Thu Jul 10 2014 Greg Nichols <gnichols@redhat.com>
- fix /etc/rhcert.xml defaults to get correct python version site-packages path
- have listener use hostname from socket

* Wed Jul 09 2014 Greg Nichols <gnichols@redhat.com>
- fix rpm build re: web store
- New prototype UI to create certifications. Add prototype interface for creating new (or existing) certifications on the server, and choosing hosts to begin testing.

* Wed Jul 02 2014 Greg Nichols <gnichols@redhat.com>
- Fix build for RHEL6 build portability for python versions in spec file and Makefile conditional code for systemctl vs. server to start httpd fixed bug with initialization of process ID tracking files

* Tue Jul 01 2014 Greg Nichols <gnichols@redhat.com>
- Initial implementation of listener client service and server/web-driven testing.

* Fri Jun 27 2014 Greg Nichols <gnichols@redhat.com>
- remove unncecessary requires from spec
- extend attr setting on web directory

* Thu Jun 26 2014 Greg Nichols <gnichols@redhat.com>
- only install Makefile and .c in test directory
- set output file in test parameters before run
- change test return value to True/False

* Wed Jun 25 2014 Greg Nichols <gnichols@redhat.com>
- fix selinux
- fix network test

* Mon Jun 23 2014 Greg Nichols <gnichols@redhat.com>
- set selinux for server files
- fix packaging
- move installation of libs to python2.7/site-packages

* Fri Jun 20 2014 Greg Nichols <gnichols@redhat.com>
- add layout and headers
- add headers, cert ID output
- fix NewRun header for multiple runs
- improve layout, add file sizes
- fix PASS/FAIL links for device tests
- fix Download link and allow direct results serving via /rhcert-results/... urls
- add more to demo tests

* Thu Jun 19 2014 Greg Nichols <gnichols@redhat.com>
- fix mimetypes for xml
- remove device logging
- added simple demo suite
- fix page title and link for logo
- change save page to return text when saving files, rather than html
- set server version to 0.1
- allow response to be written to a buffer
- set hostname to socket.gethostname
- fix test parameter copying during test planning
- add indications of interactive and mandatory tests in new run column of summary sheet
- implement server status response

* Wed Jun 18 2014 Greg Nichols <gnichols@redhat.com>
- remove aliases for compatability with pre-1.7.0.1 hwcert-server
- initial run-from-server code

* Mon Jun 16 2014 Greg Nichols <gnichols@redhat.com>
- change run to runCommand

* Fri Jun 13 2014 Greg Nichols <gnichols@redhat.com>
- move to hwcert suite
- sort certifications by product-release
- delete temporart doc when registering

* Thu Jun 12 2014 Greg Nichols <gnichols@redhat.com>
- fix build script
- port of cgi to wsgi

* Fri Jun 06 2014 Greg Nichols <gnichols@redhat.com>
- added submit function to server, also added XSLT-based filtering for faster results loading

* Tue Jun 03 2014 Greg Nichols <gnichols@redhat.com>
- add build scripting
- replace iwconfig with iw
- move kernelInfo to hwcert-suite

* Mon Jun 02 2014 Greg Nichols <gnichols@redhat.com>
- Add xsl to server files

* Fri May 30 2014 Greg Nichols <gnichols@redhat.com>
- fix planner to use suite directory
- exclude tools dir from sources
- add requires mod_wsgi
- remove requires for rhcert-client-info

* Thu May 29 2014 Greg Nichols <gnichols@redhat.com>
- set to version 0.1
- add register command, fix file saving, add xslt render

* Wed May 28 2014 Greg Nichols <gnichols@redhat.com>
- move server to wsgi

* Fri May 23 2014 Greg Nichols <gnichols@redhat.com>
- rename server->listener and web->server

* Thu May 22 2014 Greg Nichols <gnichols@redhat.com>
- initial work to replace daemon and named pipes with XMLRPC listener.py

* Mon May 19 2014 Greg Nichols <gnichols@redhat.com>
- remove debug prints

* Fri May 16 2014 Greg Nichols <gnichols@redhat.com>
- fix rpm building

